/*
ssc (static site checker)
Copyright (c) 2020,2021 Dylan Harris
https://dylanharris.org/

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public Licence as published by
the Free Software Foundation, either version 3 of the Licence, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public Licence for more details.

You should have received a copy of the GNU General Public
Licence along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#include "main/standard.h"
#include "schema/schema_name.h"
#include "utility/common.h"

struct property_name
{   const char* name_ = nullptr;
    e_schema root_;
    e_schema_property prop_; };

property_name namtab [] =
{   // creative commons
    { "attributionName", s_cc, cc_attributionname },
    { "attributionURL", s_cc, cc_attributionurl },
    { "deprecatedOn", s_cc, cc_deprecatedon },
    { "jurisdiction", s_cc, cc_jurisdiction },
    { "legalCode", s_cc, cc_legalcode },
    { "license", s_cc, cc_licence },
    { "morePermissions", s_cc, cc_morepermissions },
    { "permits", s_cc, cc_permits },
    { "prohibits", s_cc, cc_prohibits },
    { "requires", s_cc, cc_requires },

    // common tag
    { "label", s_ctag, ctag_label },
    { "means", s_ctag, ctag_means },
    { "tagged", s_ctag, ctag_tagged },
    { "taggingDate", s_ctag, ctag_taggingdate },

    // dublin core elements
    { "contributor", s_dc, dc_contributor },
    { "coverage", s_dc, dc_coverage },
    { "creator", s_dc, dc_creator },
    { "date", s_dc, dc_date },
    { "description", s_dc, dc_description },
    { "format", s_dc, dc_format },
    { "identifier", s_dc, dc_identifier },
    { "language", s_dc, dc_language },
    { "publisher", s_dc, dc_publisher },
    { "relation", s_dc, dc_relation },
    { "rights", s_dc, dc_rights },
    { "source", s_dc, dc_source },
    { "subject", s_dc, dc_subject },
    { "title", s_dc, dc_title },
    { "type", s_dc, dc_type },

    // dublin core vocabulary description
    { "domainIncludes", s_dcam, dcam_domainincludes },
    { "memberOf", s_dcam, dcam_memberof },
    { "rangeIncludes", s_dcam, dcam_rangeincludes },

    // dublin core terms
    { "abstract", s_dct, dct_abstract },
    { "accessRights", s_dct, dct_accessrights },
    { "accrualMethod", s_dct, dct_accrualmethod },
    { "accrualPeriodicity", s_dct, dct_accrualperiodicity },
    { "accrualPolicy", s_dct, dct_accrualpolicy },
    { "alternative", s_dct, dct_alternative },
    { "audience", s_dct, dct_audience },
    { "available", s_dct, dct_available },
    { "bibliographicCitation", s_dct, dct_bibliographiccitation },
    { "conformsTo", s_dct, dct_conformsto },
    { "contributor", s_dct, dct_contributor },
    { "coverage", s_dct, dct_coverage },
    { "created", s_dct, dct_created },
    { "creator", s_dct, dct_creator },
    { "date", s_dct, dct_date },
    { "dateAccepted", s_dct, dct_dateaccepted },
    { "dateCopyrighted", s_dct, dct_datecopyrighted },
    { "dateSubmitted", s_dct, dct_datesubmitted },
    { "description", s_dct, dct_description },
    { "educationLevel", s_dct, dct_educationlevel },
    { "extent", s_dct, dct_extent },
    { "format", s_dct, dct_format },
    { "hasFormat", s_dct, dct_hasformat },
    { "hasPart", s_dct, dct_haspart },
    { "hasVersion", s_dct, dct_hasversion },
    { "identifier", s_dct, dct_identifier },
    { "instructionalMethod", s_dct, dct_instructionalmethod },
    { "isFormatOf", s_dct, dct_isformatof },
    { "isPartOf", s_dct, dct_ispartof },
    { "isReferencedBy", s_dct, dct_isreferencedby },
    { "isReplacedBy", s_dct, dct_isreplacedby },
    { "isRequiredBy", s_dct, dct_isrequiredby },
    { "issued", s_dct, dct_issued },
    { "isVersionOf", s_dct, dct_isversionof },
    { "language", s_dct, dct_language },
    { "license", s_dct, dct_licence },
    { "mediator", s_dct, dct_mediator },
    { "medium", s_dct, dct_medium },
    { "modified", s_dct, dct_modified },
    { "provenance", s_dct, dct_provenance },
    { "publisher", s_dct, dct_publisher },
    { "references", s_dct, dct_references },
    { "relation", s_dct, dct_relation },
    { "replaces", s_dct, dct_replaces },
    { "requires", s_dct, dct_requires },
    { "rights", s_dct, dct_rights },
    { "rightsHolder", s_dct, dct_rightsholder },
    { "source", s_dct, dct_source },
    { "spatial", s_dct, dct_spatial },
    { "subject", s_dct, dct_subject },
    { "tableOfContents", s_dct, dct_tableofcontents },
    { "temporal", s_dct, dct_temporal },
    { "title", s_dct, dct_title },
    { "type", s_dct, dct_type },
    { "valid", s_dct, dct_valid },

    // foaf
    { "account", s_foaf, foaf_account },
    { "accountName", s_foaf, foaf_accountname },
    { "accountServiceHomepage", s_foaf, foaf_accountservicehomepage },
    { "age", s_foaf, foaf_age },
    { "aimChatID", s_foaf, foaf_aimchatid },
    { "based_near", s_foaf, foaf_basednear },
    { "birthday", s_foaf, foaf_birthday },
    { "currentProject", s_foaf, foaf_currentproject },
    { "depiction", s_foaf, foaf_depiction },
    { "depicts", s_foaf, foaf_depicts },
    { "dnaChecksum", s_foaf, foaf_dnachecksum },
    { "familyName", s_foaf, foaf_familyname },
    { "family_name", s_foaf, foaf_familyname },
    { "firstName", s_foaf, foaf_firstname },
    { "focus", s_foaf, foaf_focus },
    { "fundedBy", s_foaf, foaf_fundedby },
    { "geekcode", s_foaf, foaf_geekcode },
    { "gender", s_foaf, foaf_gender },
    { "givenName", s_foaf, foaf_givenname },
    { "holdsAccount", s_foaf, foaf_holdsaccount },
    { "homepage", s_foaf, foaf_homepage },
    { "icqChatID", s_foaf, foaf_icqchatid },
    { "img", s_foaf, foaf_img },
    { "interest", s_foaf, foaf_interest },
    { "isPrimaryTopicOf", s_foaf, foaf_isprimarytopicof },
    { "jabberID", s_foaf, foaf_jabberid },
    { "knows", s_foaf, foaf_knows },
    { "lastName", s_foaf, foaf_lastname },
    { "logo", s_foaf, foaf_logo },
    { "made", s_foaf, foaf_made },
    { "maker", s_foaf, foaf_maker },
    { "mbox", s_foaf, foaf_mbox },
    { "mbox_sha1sum", s_foaf, foaf_mboxsha1sum },
    { "member", s_foaf, foaf_member },
    { "membershipClass", s_foaf, foaf_membershipclass },
    { "msnChatID", s_foaf, foaf_msnchatid },
    { "myersBriggs", s_foaf, foaf_myersbriggs },
    { "name", s_foaf, foaf_name },
    { "nick", s_foaf, foaf_nick },
    { "openid", s_foaf, foaf_openid },
    { "page", s_foaf, foaf_page },
    { "pastProject", s_foaf, foaf_pastproject },
    { "phone", s_foaf, foaf_phone },
    { "plan", s_foaf, foaf_plan },
    { "primaryTopic", s_foaf, foaf_primarytopic },
    { "publications", s_foaf, foaf_publications },
    { "schoolHomepage", s_foaf, foaf_schoolhomepage },
    { "sha1", s_foaf, foaf_sha1 },
    { "skypeID", s_foaf, foaf_skypeid },
    { "status", s_foaf, foaf_status },
    { "surname", s_foaf, foaf_surname },
    { "theme", s_foaf, foaf_theme },
    { "thumbnail", s_foaf, foaf_thumbnail },
    { "tipjar", s_foaf, foaf_tipjar },
    { "title", s_foaf, foaf_title },
    { "topic", s_foaf, foaf_topic },
    { "topic_interest", s_foaf, foaf_topic_interest },
    { "weblog", s_foaf, foaf_weblog },
    { "workinfoHomepage", s_foaf, foaf_workinfohomepage },
    { "workplaceHomepage", s_foaf, foaf_workplacehomepage },
    { "yahooChatID", s_foaf, foaf_yahoochatid },

    // good relations
    { "acceptedPaymentMethods", s_gr, gr_acceptedpaymentmethods },
    { "addOn", s_gr, gr_addon },
    { "advanceBookingRequirement", s_gr, gr_advancebookingrequirement },
    { "amountOfThisGood", s_gr, gr_amountofgoods },
    { "appliesToDeliveryMethod", s_gr, gr_appliestodeliverymethod },
    { "appliesToPaymentMethod", s_gr, gr_appliestopaymentmethod },
    { "availabilityEnds", s_gr, gr_availabilityends },
    { "availabilityStarts", s_gr, gr_availabilitystarts },
    { "availableAtOrFrom", s_gr, gr_availableatorfrom },
    { "availableDeliveryMethods", s_gr, gr_availabledeliverymethods },
    { "billingIncrement", s_gr, gr_billingincrement },
    { "category", s_gr, gr_category },
    { "closes", s_gr, gr_closes },
    { "color", s_gr, gr_colour },
    { "condition", s_gr, gr_condition },
    { "datatypeProductOrServiceProperty", s_gr, gr_datatypeproductorserviceproperty },
    { "deliveryLeadTime", s_gr, gr_deliveryleadtime },
    { "depth", s_gr, gr_depth },
    { "description", s_gr, gr_description },
    { "displayPosition", s_gr, gr_displayposition },
    { "durationOfWarrantyInMonths", s_gr, gr_durationofwarrantyinmonths },
    { "eligibleCustomerTypes", s_gr, gr_eligiblecustomertypes },
    { "eligibleDuration", s_gr, gr_eligibleduration },
    { "eligibleRegions", s_gr, gr_eligibleregions },
    { "eligibleTransactionVolume", s_gr, gr_eligibletransactionvolume },
    { "equal", s_gr, gr_equal },
    { "greater", s_gr, gr_greater },
    { "greaterOrEqual", s_gr, gr_greaterorequal },
    { "hasBrand", s_gr, gr_hasbrand },
    { "hasBusinessFunction", s_gr, gr_hasbusinessfunction },
    { "hasCurrency", s_gr, gr_hascurrency },
    { "hasCurrencyValue", s_gr, gr_hascurrencyvalue },
    { "hasDUNS", s_gr, gr_hasduns },
    { "hasEAN_UCC-13", s_gr, gr_hasean_ucc_13 },
    { "hasEligibleQuantity", s_gr, gr_haseligiblequantity },
    { "hasGTIN-14", s_gr, gr_hasgtin_14 },
    { "hasGTIN-8", s_gr, gr_hasgtin_8 },
    { "hasGlobalLocationNumber", s_gr, gr_hasgloballocationnumber },
    { "hasISICv4", s_gr, gr_hasisicv4 },
    { "hasInventoryLevel", s_gr, gr_hasinventorylevel },
    { "hasMakeAndModel", s_gr, gr_hasmakeandmodel },
    { "hasManufacturer", s_gr, gr_hasmanufacturer },
    { "hasMaxCurrencyValue", s_gr, gr_hasmaxcurrencyvalue },
    { "hasMaxValue", s_gr, gr_hasmaxvalue },
    { "hasMaxValueFloat", s_gr, gr_hasmaxvaluefloat },
    { "hasMaxValueInteger", s_gr, gr_hasmaxvalueinteger },
    { "hasMinCurrencyValue", s_gr, gr_hasmincurrencyvalue },
    { "hasMinValue", s_gr, gr_hasminvalue },
    { "hasMinValueFloat", s_gr, gr_hasminvaluefloat },
    { "hasMinValueInteger", s_gr, gr_hasminvalueinteger },
    { "hasMPN", s_gr, gr_hasmpn },
    { "hasNAICS", s_gr, gr_hasnaics },
    { "hasNext", s_gr, gr_hasnext },
    { "hasOpeningHoursDayOfWeek", s_gr, gr_hasopeninghoursdayofweek },
    { "hasOpeningHoursSpecification", s_gr, gr_hasopeninghoursspecification },
    { "hasPOS", s_gr, gr_haspos },
    { "hasPrevious", s_gr, gr_hasprevious },
    { "hasPriceSpecification", s_gr, gr_haspricespecification },
    { "hasStockKeepingUnit", s_gr, gr_hasstockkeepingunit },
    { "hasUnitOfMeasurement", s_gr, gr_hasunitofmeasurement },
    { "hasValue", s_gr, gr_hasvalue },
    { "hasValueFloat", s_gr, gr_hasvaluefloat },
    { "hasValueInteger", s_gr, gr_hasvalueinteger },
    { "hasWarrantyPromise", s_gr, gr_haswarrantypromise },
    { "hasWarrantyScope", s_gr, gr_haswarrantyscope },
    { "height", s_gr, gr_height },
    { "includes", s_gr, gr_includes },
    { "includesObject", s_gr, gr_includesobject },
    { "isAccessoryOrSparePartFor", s_gr, gr_isaccessoryorsparepartfor },
    { "isConsumableFor", s_gr, gr_isconsumablefor },
    { "isListPrice", s_gr, gr_islistprice },
    { "isSimilarTo", s_gr, gr_issimilarto },
    { "isVariantOf", s_gr, gr_isvariantof },
    { "legalName", s_gr, gr_legalname },
    { "lesser", s_gr, gr_lesser },
    { "lesserOrEqual", s_gr, gr_lesserorequal },
    { "name", s_gr, gr_name },
    { "nonEqual", s_gr, gr_nonequal },
    { "offers", s_gr, gr_offers },
    { "opens", s_gr, gr_opens },
    { "owns", s_gr, gr_owns },
    { "predecessorOf", s_gr, gr_predecessorof },
    { "priceType", s_gr, gr_pricetype },
    { "qualitativeProductOrServiceProperty", s_gr, gr_qualitativeproductorserviceproperty },
    { "quantitativeProductOrServiceProperty", s_gr, gr_quantitativeproductorserviceproperty },
    { "relatedWebService", s_gr, gr_relatedwebservice },
    { "seeks", s_gr, gr_seeks },
    { "serialNumber", s_gr, gr_serialnumber },
    { "successorOf", s_gr, gr_successorof },
    { "taxID", s_gr, gr_taxid },
    { "typeOfGood", s_gr, gr_typeofgoods },
    { "validFrom", s_gr, gr_validfrom },
    { "validThrough", s_gr, gr_validto },
    { "valueAddedTaxIncluded", s_gr, gr_valueaddedtaxincluded },
    { "valueReference", s_gr, gr_valuereference },
    { "vatID", s_gr, gr_vatid },
    { "weight", s_gr, gr_weight },
    { "width", s_gr, gr_width },

    //  ical
    { "action", s_ical, ical_action },
    { "attendee", s_ical, ical_attendee },
    { "byday", s_ical, ical_byday },
    { "bymonth", s_ical, ical_bymonth },
    { "calAddress", s_ical, ical_caladdress },
    { "calscale", s_ical, ical_calscale },
    { "categories", s_ical, ical_categories },
    { "class", s_ical, ical_class },
    { "cn", s_ical, ical_cn },
    { "comment", s_ical, ical_comment },
    { "component", s_ical, ical_component },
    { "cutype", s_ical, ical_cutype },
    { "date", s_ical, ical_date },
    { "dateTime", s_ical, ical_datetime },
    { "daylight", s_ical, ical_daylight },
    { "description", s_ical, ical_description },
    { "dtend", s_ical, ical_dtend },
    { "dstamp", s_ical, ical_dstamp },
    { "dtstart", s_ical, ical_dtstart },
    { "duration", s_ical, ical_duration },
    { "freq", s_ical, ical_freq },
    { "interval", s_ical, ical_interval },
    { "language", s_ical, ical_language },
    { "location", s_ical, ical_location },
    { "organizer", s_ical, ical_organiser },
    { "partstat", s_ical, ical_partstat },
    { "prodid", s_ical, ical_prodid },
    { "related", s_ical, ical_related },
    { "role", s_ical, ical_role },
    { "rrule", s_ical, ical_rrule },
    { "rsvp", s_ical, ical_rsvp },
    { "sequence", s_ical, ical_sequence },
    { "standard", s_ical, ical_standard },
    { "summary", s_ical, ical_summary },
    { "transp", s_ical, ical_transp },
    { "trigger", s_ical, ical_trigger },
    { "tzid", s_ical, ical_tzid },
    { "tzname", s_ical, ical_tzname },
    { "tzoffsetfrom", s_ical, ical_tzoffsetfrom },
    { "tzoffsetto", s_ical, ical_tzoffsetto },
    { "uid", s_ical, ical_uid },
    { "valarm", s_ical, ical_valarm },
    { "version", s_ical, ical_version },

    // living standard / microformats v1
    { "additional-name", s_microformats, mp_additional_name },
    { "adr", s_microformats, mp_adr },
    { "affliation", s_microformats, mp_affliation },
    { "agent", s_microformats, mp_agent },
    { "album", s_microformats, mp_album },
    { "anniversary", s_microformats, mp_anniversary },
    { "attach", s_microformats, mp_attach },
    { "attendee", s_microformats, mp_attendee },
    { "author", s_microformats, mp_author },
    { "availability", s_microformats, mp_availability },
    { "bday", s_microformats, mp_bday },
    { "best", s_microformats, mp_best },
    { "bookmark", s_microformats, mp_bookmark },
    { "categories", s_microformats, mp_categories },
    { "category", s_microformats, mp_category },
    { "class", s_microformats, mp_class },
    { "comment", s_microformats, mp_comment },
    { "contact", s_microformats, mp_contact },
    { "contributor", s_microformats, mp_contributor },
    { "count", s_microformats, mp_count },
    { "country-name", s_microformats, mp_country_name },
    { "created", s_microformats, mp_created },
    { "dateline", s_microformats, mp_dateline },
    { "description", s_microformats, mp_description },
    { "dtend", s_microformats, mp_dtend },
    { "dtexpired", s_microformats, mp_dtexpired },
    { "dtlisted", s_microformats, mp_dtlisted },
    { "dtreviewed", s_microformats, mp_dtreviewed },
    { "dtstart", s_microformats, mp_dtstart },
    { "duration", s_microformats, mp_duration },
    { "education", s_microformats, mp_education },
    { "email", s_microformats, mp_email },
    { "enclosure", s_microformats, mp_enclosure },
    { "entry", s_microformats, mp_entry },
    { "entry-content", s_microformats, mp_entry_content },
    { "entry-summary", s_microformats, mp_entry_summary },
    { "entry-title", s_microformats, mp_entry_title },
    { "exdate", s_microformats, mp_exdate },
    { "experience", s_microformats, mp_experience },
    { "extended-address", s_microformats, mp_extended_address },
    { "family-name", s_microformats, mp_family_name },
    { "feed-category", s_microformats, mp_feed_category },
    { "fn", s_microformats, mp_fn },
    { "gender-identity", s_microformats, mp_gender_identity },
    { "geo", s_microformats, mp_geo },
    { "given-name", s_microformats, mp_given_name },
    { "h", s_microformats, mp_h },
    { "hentry", s_microformats, mp_hentry },
    { "honourific-prefix", s_microformats, mp_honourific_prefix },
    { "honourific-suffixr", s_microformats, mp_honourific_suffix },
    { "impp", s_microformats, mp_impp },
    { "include", s_microformats, mp_include },
    { "info", s_microformats, mp_info },
    { "ingredient", s_microformats, mp_ingredient },
    { "instructions", s_microformats, mp_instructions },
    { "item", s_microformats, mp_item },
    { "item-license", s_microformats, mp_licence },
    { "key", s_microformats, mp_key },
    { "kind", s_microformats, mp_kind },
    { "label", s_microformats, mp_label },
    { "lang", s_microformats, mp_lang },
    { "last-modified", s_microformats, mp_last_modified },
    { "latitude", s_microformats, mp_latitude },
    { "license", s_microformats, mp_licence },
    { "lister", s_microformats, mp_lister },
    { "listing-action", s_microformats, mp_listing_action },
    { "locality", s_microformats, mp_locality },
    { "location", s_microformats, mp_location },
    { "logo", s_microformats, mp_logo },
    { "longitude", s_microformats, mp_longitude },
    { "mailer", s_microformats, mp_mailer },
    { "member", s_microformats, mp_member },
    { "method", s_microformats, mp_method },
    { "min", s_microformats, mp_min },
    { "n", s_microformats, mp_n },
    { "nickname", s_microformats, mp_nickname },
    { "note", s_microformats, mp_note },
    { "nutrition", s_microformats, mp_nutrition },
    { "org", s_microformats, mp_org },
    { "organisation-name", s_microformats, mp_organisation_name },
    { "organisation-unit", s_microformats, mp_organisation_unit },
    { "organizer", s_microformats, mp_organiser },
    { "partstat", s_microformats, mp_partstat },
    { "payment", s_microformats, mp_payment },
    { "permalink", s_microformats, mp_permalink },
    { "photo", s_microformats, mp_photo },
    { "player", s_microformats, mp_player },
    { "position", s_microformats, mp_position },
    { "post-office-box", s_microformats, mp_post_office_box },
    { "postal-code", s_microformats, mp_postal_code },
    { "price", s_microformats, mp_price },
    { "principles", s_microformats, mp_principles },
    { "publications", s_microformats, mp_publications },
    { "published", s_microformats, mp_published },
    { "rating", s_microformats, mp_rating },
    { "rdate", s_microformats, mp_rdate },
    { "region", s_microformats, mp_region },
    { "rel", s_microformats, mp_rel },
    { "related", s_microformats, mp_related },
    { "rev", s_microformats, mp_rev },
    { "review", s_microformats, mp_review },
    { "reviewer", s_microformats, mp_reviewer },
    { "role", s_microformats, mp_role },
    { "rrule", s_microformats, mp_rrule },
    { "resources", s_microformats, mp_resources },
    { "s", s_microformats, mp_s },
    { "sample", s_microformats, mp_sample },
    { "sequence", s_microformats, mp_sequence },
    { "self", s_microformats, mp_self },
    { "sex", s_microformats, mp_sex },
    { "skill", s_microformats, mp_skill },
    { "skills", s_microformats, mp_skill },
    { "sort-string", s_microformats, mp_sort_string },
    { "sound", s_microformats, mp_sound },
    { "source-org", s_microformats, mp_source_org },
    { "status", s_microformats, mp_status },
    { "street-address", s_microformats, mp_street_address },
    { "summary", s_microformats, mp_summary },
    { "tag", s_microformats, mp_tag },
    { "tags", s_microformats, mp_tags },
    { "tel", s_microformats, mp_tel },
    { "term", s_microformats, mp_term },
    { "title", s_microformats, mp_title },
    { "transp", s_microformats, mp_transp },
    { "type", s_microformats, mp_type },
    { "tz", s_microformats, mp_tz },
    { "uid", s_microformats, mp_uid },
    { "updated", s_microformats, mp_updated },
    { "url", s_microformats, mp_url },
    { "value", s_microformats, mp_value },
    { "value-title", s_microformats, mp_value_title },
    { "version", s_microformats, mp_version },
    { "votes", s_microformats, mp_votes },
    { "worst", s_microformats, mp_worst },
    { "yield", s_microformats, mp_yield },

    // microformats v2
    { "dt-accessed", s_microformats, mp2_dt_accessed },
    { "dt-anniversary", s_microformats, mp2_dt_anniversary },
    { "dt-bday", s_microformats, mp2_dt_bday },
    { "dt-duration", s_microformats, mp2_dt_duration },
    { "dt-end", s_microformats, mp2_dt_end },
    { "dt-expired", s_microformats, mp2_dt_expired },
    { "dt-listed", s_microformats, mp2_dt_listed },
    { "dt-published", s_microformats, mp2_dt_published },
    { "dt-start", s_microformats, mp2_dt_start },
    { "dt-updated", s_microformats, mp2_dt_updated },
    { "e-content", s_microformats, mp2_e_content },
    { "e-description", s_microformats, mp2_e_description },
    { "e-instructions", s_microformats, mp2_e_instructions },
    { "h-breadcrumb", s_microformats, mp2_h_breadcrumb },
    { "h-entry", s_microformats, mp2_h_entry },
    { "p-action", s_microformats, mp2_p_action },
    { "p-additional-name", s_microformats, mp2_p_additional_name },
    { "p-adr", s_microformats, mp2_p_adr },
    { "p-affiliation", s_microformats, mp2_p_affiliation },
    { "p-altitude", s_microformats, mp2_p_altitude },
    { "p-attendee", s_microformats, mp2_p_attendee },
    { "p-author", s_microformats, mp2_p_author },
    { "p-best", s_microformats, mp2_p_best },
    { "p-category", s_microformats, mp2_p_category },
    { "p-comment", s_microformats, mp2_p_comment },
    { "p-contact", s_microformats, mp2_p_contact },
    { "p-content", s_microformats, mp2_p_content },
    { "p-country-name", s_microformats, mp2_p_country_name },
    { "p-description", s_microformats, mp2_p_description },
    { "p-duration", s_microformats, mp2_p_duration },
    { "p-education", s_microformats, mp2_p_education },
    { "p-entry", s_microformats, mp2_p_entry },
    { "p-experience", s_microformats, mp2_p_experience },
    { "p-extended-address", s_microformats, mp2_p_extended_address },
    { "p-family-name", s_microformats, mp2_p_family_name },
    { "p-region", s_microformats, mp2_p_region },
    { "p-gender-identity", s_microformats, mp2_p_gender_identity },
    { "p-geo", s_microformats, mp2_p_geo },
    { "p-given_name", s_microformats, mp2_p_given_name },
    { "p-honourific-prefix", s_microformats, mp2_p_honourific_prefix },
    { "p-honourific-suffix", s_microformats, mp2_p_honourific_suffix },
    { "p-ingredient", s_microformats, mp2_p_ingredient },
    { "p-item", s_microformats, mp2_p_item },
    { "p-job-title", s_microformats, mp2_p_job_title },
    { "p-label", s_microformats, mp2_p_label },
    { "p-latitude", s_microformats, mp2_p_latitude },
    { "p-lister", s_microformats, mp2_p_lister },
    { "p-locality", s_microformats, mp2_p_locality },
    { "p-location", s_microformats, mp2_p_location },
    { "p-longitude", s_microformats, mp2_p_longitude },
    { "p-name", s_microformats, mp2_p_name },
    { "p-nickname", s_microformats, mp2_p_nickname },
    { "p-note", s_microformats, mp2_p_note },
    { "p-nutrition", s_microformats, mp2_p_nutrition },
    { "p-post-office-box", s_microformats, mp2_p_post_office_box },
    { "p-postal-code", s_microformats, mp2_p_postal_code },
    { "p-publication", s_microformats, mp2_p_publication },
    { "p-org", s_microformats, mp2_p_org },
    { "p-price", s_microformats, mp2_p_price },
    { "p-rating", s_microformats, mp2_p_rating },
    { "p-read-of", s_microformats, mp2_p_read_of },
    { "p-role", s_microformats, mp2_p_role },
    { "p-rsvp", s_microformats, mp2_p_rsvp },
    { "p-sex", s_microformats, mp2_p_sex },
    { "p-size", s_microformats, mp2_p_size },
    { "p-skill", s_microformats, mp2_p_skill },
    { "p-sort-string", s_microformats, mp2_p_sort_string },
    { "p-street-address", s_microformats, mp2_p_street_address },
    { "p-summary", s_microformats, mp2_p_summary },
    { "p-tz", s_microformats, mp2_p_tz },
    { "p-worst", s_microformats, mp2_p_worst },
    { "p-yield", s_microformats, mp2_p_yield },
    { "u-audio", s_microformats, mp2_u_audio },
    { "u-bookmark-of", s_microformats, mp2_u_bookmark_of },
    { "u-email", s_microformats, mp2_u_email },
    { "u-featured", s_microformats, mp2_u_featured },
    { "u-geo", s_microformats, mp2_u_geo },
    { "u-impp", s_microformats, mp2_u_impp },
    { "u-in-reply-to", s_microformats, mp2_u_in_reply_to },
    { "u-like", s_microformats, mp2_u_like },
    { "u-like-of", s_microformats, mp2_u_like_of },
    { "u-listen-of", s_microformats, mp2_u_listen_of },
    { "u-logo", s_microformats, mp2_u_logo },
    { "u-key", s_microformats, mp2_u_key },
    { "u-photo", s_microformats, mp2_u_photo },
    { "u-read-of", s_microformats, mp2_u_read_of },
    { "u-repost", s_microformats, mp2_u_repost },
    { "u-repost-of", s_microformats, mp2_u_repost_of },
    { "u-sound", s_microformats, mp2_u_sound },
    { "u-syndication", s_microformats, mp2_u_syndication },
    { "u-translation-of", s_microformats, mp2_u_translation_of },
    { "u-uid", s_microformats, mp2_u_uid },
    { "u-url", s_microformats, mp2_u_url },
    { "u-video", s_microformats, mp2_u_video },
    { "u-watch-of", s_microformats, mp2_u_watch_of },

    // open graph
    { "audio", s_og, og_audio },
    { "audio:secure_url", s_og, og_audio_secure_url },
    { "audio:type", s_og, og_audio_type },
    { "audio:url", s_og, og_audio_url },
    { "description", s_og, od_description },
    { "determiner", s_og, og_determiner },
    { "image", s_og, og_image },
    { "image:alt", s_og, og_image_alt },
    { "image:height", s_og, og_image_height },
    { "image:secure_url", s_og, og_image_secure_url },
    { "image:type", s_og, og_image_type },
    { "image:url", s_og, og_image_url },
    { "image:width", s_og, og_image_width },
    { "locale", s_og, og_locale },
    { "locale:alternate", s_og, og_locale_alternative },
    { "site_name", s_og, og_site_name },
    { "title", s_og, og_title },
    { "type", s_og, og_type },
    { "url", s_og, og_url },
    { "video", s_og, og_video },
    { "video:alt", s_og, og_video_alt },
    { "video:height", s_og, og_video_height },
    { "video:secure_url", s_og, og_video_secure_url },
    { "video:type", s_og, og_video_type },
    { "video:url", s_og, og_video_url },
    { "video:width", s_og, og_video_width },

    // poetry
     { "age", s_poetry, poetry_age },
     { "containedinPoem", s_poetry, poetry_containedinpoem },
     { "containsPoem", s_poetry, poetry_containspoem },
     { "hasForm", s_poetry, poetry_hasform },
     { "hasStanza", s_poetry, poetry_hasstanza },
     { "inDialect", s_poetry, poetry_indialect },
     { "isChorus", s_poetry, poetry_ischorus },
     { "isLaidOut", s_poetry, poetry_islaidout },
     { "keepsStrictForm", s_poetry, poetry_keepsstrictform },
     { "lines", s_poetry, poetry_lines },
     { "medium", s_poetry, poetry_medium },
     { "metre", s_poetry, poetry_metre },
     { "poet", s_poetry, poetry_poet },
     { "region", s_poetry, poetry_region },
     { "rhymingScheme", s_poetry, poetry_rhymingscheme },
     { "subForm", s_poetry, poetry_subform },

    // RDF
    { "direction", s_rdf, rdf_direction },
    { "first", s_rdf, rdf_first },
    { "language", s_rdf, rdf_language },
    { "object", s_rdf, rdf_object },
    { "predicate", s_rdf, rdf_predicate },
    { "rest", s_rdf, rdf_rest },
    { "subject", s_rdf, rdf_subject },
    { "type", s_rdf, rdf_type },
    { "value", s_rdf, rdf_value },

    // RDFs
    { "comment", s_rdfs, rdfs_comment },
    { "domain", s_rdfs, rdfs_domain },
    { "isDefinedBy", s_rdfs, rdfs_isdefinedby },
    { "label", s_rdfs, rdfs_label },
    { "member", s_rdfs, rdfs_member },
    { "range", s_rdfs, rdfs_range },
    { "seeAlso", s_rdfs, rdfs_seealso },
    { "subClassOf", s_rdfs, rdfs_subclassof },
    { "subPropertyOf", s_rdfs, rdfs_subpropertyof },

    // schema.org
    { "about", s_schema, sp_about },
    { "abridged", s_schema, sp_abridged },
    { "abstract", s_schema, sp_abstract },
    { "accelerationTime", s_schema, sp_accelerationtime },
    { "acceptedAnswer", s_schema, sp_acceptedanswer },
    { "acceptedOffer", s_schema, sp_acceptedoffer },
    { "acceptedPaymentMethod", s_schema, sp_acceptedpaymentmethod },
    { "acceptsReservations", s_schema, sp_acceptsreservations },
    { "accessCode", s_schema, sp_accesscode },
    { "accessMode", s_schema, sp_accessmode },
    { "accessModeSufficient", s_schema, sp_accessmodesufficient },
    { "accessibilityAPI", s_schema, sp_accessibilityapi },
    { "accessibilityControl", s_schema, sp_accessibilitycontrol },
    { "accessibilityFeature", s_schema, sp_accessibilityfeature },
    { "accessibilityHazard", s_schema, sp_accessibilityhazard },
    { "accessibilitySummary", s_schema, sp_accessibilitysummary },
    { "accommodationCategory", s_schema, sp_accommodationcategory },
    { "accommodationFloorPlan", s_schema, sp_accommodationfloorplan },
    { "accountId", s_schema, sp_accountid },
    { "accountMinimumInflow", s_schema, sp_accountminimuminflow },
    { "accountOverdraftLimit", s_schema, sp_accountoverdraftlimit },
    { "accountablePerson", s_schema, sp_accountableperson },
    { "acquireLicensePage", s_schema, sp_acquirelicensepage },
    { "acquiredFrom", s_schema, sp_acquiredfrom },
    { "acrissCode", s_schema, sp_acrisscode },
    { "action", s_schema, sp_action },
    { "actionAccessibilityRequirement", s_schema, sp_actionaccessibilityrequirement },
    { "actionApplication", s_schema, sp_actionapplication },
    { "actionOption", s_schema, sp_actionoption },
    { "actionPlatform", s_schema, sp_actionplatform },
    { "actionStatus", s_schema, sp_actionstatus },
    { "actionableFeedbackPolicy", s_schema, sp_actionablefeedbackpolicy },
    { "activeIngredient", s_schema, sp_activeingredient },
    { "activityDuration", s_schema, sp_activityduration },
    { "activityFrequency", s_schema, sp_activityfrequency },
    { "actor", s_schema, sp_actor },
    { "addOn", s_schema, sp_addon },
    { "additionalName", s_schema, sp_additionalname },
    { "additionalNumberOfGuests", s_schema, sp_additionalnumberofguests },
    { "additionalProperty", s_schema, sp_additionalproperty },
    { "additionalType", s_schema, sp_additionaltype },
    { "additionalVariable", s_schema, sp_additionalvariable },
    { "address", s_schema, sp_address },
    { "addressCountry", s_schema, sp_addresscountry },
    { "addressLocality", s_schema, sp_addresslocality },
    { "addressRegion", s_schema, sp_addressregion },
    { "administrationRoute", s_schema, sp_administrationroute },
    { "advanceBookingRequirement", s_schema, sp_advancebookingrequirement },
    { "adverseOutcome", s_schema, sp_adverseoutcome },
    { "affectedBy", s_schema, sp_affectedby },
    { "affiliation", s_schema, sp_affiliation },
    { "afterMedia", s_schema, sp_aftermedia },
    { "agent", s_schema, sp_agent },
    { "aggregateRating", s_schema, sp_aggregaterating },
    { "aircraft", s_schema, sp_aircraft },
    { "album", s_schema, sp_album },
    { "albumProductionType", s_schema, sp_albumproductiontype },
    { "albumRelease", s_schema, sp_albumrelease },
    { "albumReleaseType", s_schema, sp_albumreleasetype },
    { "alcoholWarning", s_schema, sp_alcoholwarning },
    { "algorithm", s_schema, sp_algorithm },
    { "alignmentType", s_schema, sp_alignmenttype },
    { "alternateName", s_schema, sp_alternativename },
    { "alternativeHeadline", s_schema, sp_alternativeheadline },
    { "alternativeOf", s_schema, sp_alternativeof },
    { "alumni", s_schema, sp_alumni },
    { "alumniOf", s_schema, sp_alumniof },
    { "amenityFeature", s_schema, sp_amenityfeature },
    { "amount", s_schema, sp_amount },
    { "amountOfThisGood", s_schema, sp_amountofthisgood },
    { "announcementLocation", s_schema, sp_announcementlocation },
    { "annualPercentageRate", s_schema, sp_annualpercentagerate },
    { "answerCount", s_schema, sp_answercount },
    { "antagonist", s_schema, sp_antagonist },
    { "appearance", s_schema, sp_appearance },
    { "applicableLocation", s_schema, sp_applicablelocation },
    { "applicantContact", s_schema, sp_applicantcontact },
    { "applicantLocationRequirements", s_schema, sp_applicantlocationrequirements },
    { "applicationCategory", s_schema, sp_applicationcategory },
    { "applicationDeadline", s_schema, sp_applicationdeadline },
    { "applicationStartDate", s_schema, sp_applicationstartdate },
    { "applicationSubCategory", s_schema, sp_applicationsubcategory },
    { "applicationSuite", s_schema, sp_applicationsuite },
    { "appliesToDeliveryMethod", s_schema, sp_appliestodeliverymethod },
    { "appliesToPaymentMethod", s_schema, sp_appliestopaymentmethod },
    { "archivedAt", s_schema, sp_archivedat },
    { "archiveHeld", s_schema, sp_archiveheld },
    { "areaServed", s_schema, sp_areaserved },
    { "arrivalAirport", s_schema, sp_arrivalairport },
    { "arrivalBoatTerminal", s_schema, sp_arrivalboatterminal },
    { "arrivalBusStop", s_schema, sp_arrivalbusstop },
    { "arrivalGate", s_schema, sp_arrivalgate },
    { "arrivalPlatform", s_schema, sp_arrivalplatform },
    { "arrivalStation", s_schema, sp_arrivalstation },
    { "arrivalTerminal", s_schema, sp_arrivalterminal },
    { "arrivalTime", s_schema, sp_arrivaltime },
    { "artEdition", s_schema, sp_artedition },
    { "artMedium", s_schema, sp_artmedium },
    { "arterialBranch", s_schema, sp_arterialbranch },
    { "artform", s_schema, sp_artform },
    { "articleBody", s_schema, sp_articlebody },
    { "articleSection", s_schema, sp_articlesection },
    { "artist", s_schema, sp_artist },
    { "artworkSurface", s_schema, sp_artworksurface },
    { "aspect", s_schema, sp_aspect },
    { "assemblyVersion", s_schema, sp_assemblyversion },
    { "assess", s_schema, sp_assess },
    { "assesses", s_schema, sp_assesses },
    { "associatedAnatomy", s_schema, sp_associatedanatomy },
    { "associatedArticle", s_schema, sp_associatedarticle },
    { "associatedClaimReview", s_schema, sp_associatedclaimreview },
    { "associatedDisease", s_schema, sp_associateddisease },
    { "associatedMedia", s_schema, sp_associatedmedia },
    { "associatedMediaReview", s_schema, sp_associatedmediareview },
    { "associatedPathophysiology", s_schema, sp_associatedpathophysiology },
    { "associatedReview", s_schema, sp_associatedreview },
    { "athlete", s_schema, sp_athlete },
    { "attendee", s_schema, sp_attendee },
    { "audience", s_schema, sp_audience },
    { "audienceType", s_schema, sp_audiencetype },
    { "audio", s_schema, sp_audio },
    { "authenticator", s_schema, sp_authenticator },
    { "author", s_schema, sp_author },
    { "availabeDeliveryMethod", s_schema, sp_availabedeliverymethod },
    { "availability", s_schema, sp_availability },
    { "availabilityEnds", s_schema, sp_availabilityends },
    { "availabilityStarts", s_schema, sp_availabilitystarts },
    { "availableAtOrFrom", s_schema, sp_availableatorfrom },
    { "availableChannel", s_schema, sp_availablechannel },
    { "availableDeliveryMethod", s_schema, sp_availabledeliverymethod },
    { "availableFrom", s_schema, sp_availablefrom },
    { "availableIn", s_schema, sp_availablein },
    { "availableLanguage", s_schema, sp_availablelanguage },
    { "availableLocation", s_schema, sp_availablelocation },
    { "availableOnDevice", s_schema, sp_availableondevice },
    { "availableService", s_schema, sp_availableservice },
    { "availableStrength", s_schema, sp_availablestrength },
    { "availableTest", s_schema, sp_availabletest },
    { "availableThrough", s_schema, sp_availablethrough },
    { "award", s_schema, sp_award },
    { "awayTeam", s_schema, sp_awayteam },
    { "background", s_schema, sp_background },
    { "backstory", s_schema, sp_backstory },
    { "bankAccountType", s_schema, sp_bankaccounttype },
    { "baseSalary", s_schema, sp_basesalary },
    { "bccRecipient", s_schema, sp_bccrecipient },
    { "bed", s_schema, sp_bed },
    { "beforeMedia", s_schema, sp_beforemedia },
    { "beneficiaryBank", s_schema, sp_beneficiarybank },
    { "benefitsSummaryUrl", s_schema, sp_benefitssummaryurl },
    { "bestRating", s_schema, sp_bestrating },
    { "billingAddress", s_schema, sp_billingaddress },
    { "billingDuration", s_schema, sp_billingduration },
    { "billingIncrement", s_schema, sp_billingincrement },
    { "billingPeriod", s_schema, sp_billingperiod },
    { "billingStart", s_schema, sp_billingstart },
    { "bioChemInteraction", s_schema, sp_biocheminteraction },
    { "bioChemSimilarity", s_schema, sp_biochemsimilarity },
    { "biologicalRole", s_schema, sp_biologicalrole },
    { "biomechanicalClass", s_schema, sp_biomechanicalclass },
    { "birthDate", s_schema, sp_birthdate },
    { "birthPlace", s_schema, sp_birthplace },
    { "bitrate", s_schema, sp_bitrate },
    { "blogPost", s_schema, sp_blogpost },
    { "bloodSupply", s_schema, sp_bloodsupply },
    { "boardingGroup", s_schema, sp_boardinggroup },
    { "boardingPolicy", s_schema, sp_boardingpolicy },
    { "bodyLocation", s_schema, sp_bodylocation },
    { "bodyType", s_schema, sp_bodytype },
    { "bookEdition", s_schema, sp_bookedition },
    { "bookFormat", s_schema, sp_bookformat },
    { "bookingTime", s_schema, sp_bookingtime },
    { "box", s_schema, sp_box },
    { "branch", s_schema, sp_branch },
    { "branchCode", s_schema, sp_branchcode },
    { "brand", s_schema, sp_brand },
    { "breadcrumb", s_schema, sp_breadcrumb },
    { "breastfeedingWarning", s_schema, sp_breastfeedingwarning },
    { "broadcastAffiliateOf", s_schema, sp_broadcastaffiliateof },
    { "broadcastChannelId", s_schema, sp_broadcastchannelid },
    { "broadcastDisplayName", s_schema, sp_broadcastdisplayname },
    { "broadcastFrequency", s_schema, sp_broadcastfrequency },
    { "broadcastFrequencyValue", s_schema, sp_broadcastfrequencyvalue },
    { "broadcastOfEvent", s_schema, sp_broadcastofevent },
    { "broadcastServiceTier", s_schema, sp_broadcastservicetier },
    { "broadcastSignalModulation", s_schema, sp_broadcastsignalmodulation },
    { "broadcastSubChannel", s_schema, sp_broadcastsubchannel },
    { "broadcastTimezone", s_schema, sp_broadcasttimezone },
    { "broadcaster", s_schema, sp_broadcaster },
    { "broker", s_schema, sp_broker },
    { "browserRequirements", s_schema, sp_browserrequirements },
    { "busName", s_schema, sp_busname },
    { "busNumber", s_schema, sp_busnumber },
    { "businessDays", s_schema, sp_businessdays },
    { "businessFunction", s_schema, sp_businessfunction },
    { "buyer", s_schema, sp_buyer },
    { "byArtist", s_schema, sp_byartist },
    { "byDay", s_schema, sp_byday },
    { "byMonth", s_schema, sp_bymonth },
    { "byMonthDay", s_schema, sp_bymonthday },
    { "byMonthWeek", s_schema, sp_bymonthweek },
    { "callSign", s_schema, sp_callsign },
    { "calories", s_schema, sp_calories },
    { "candidate", s_schema, sp_candidate },
    { "caption", s_schema, sp_caption },
    { "carbohydrateContent", s_schema, sp_carbohydratecontent },
    { "cargoVolume", s_schema, sp_cargovolume },
    { "carrierRequirements", s_schema, sp_carrierrequirements },
    { "cashBack", s_schema, sp_cashback },
    { "catalogNumber", s_schema, sp_cataloguenumber },
    { "category", s_schema, sp_category },
    { "cause", s_schema, sp_cause },
    { "causeOf", s_schema, sp_causeof },
    { "ccRecipient", s_schema, sp_ccrecipient },
    { "character", s_schema, sp_character },
    { "characterAttribute", s_schema, sp_characterattribute },
    { "characterName", s_schema, sp_charactername },
    { "cheatCode", s_schema, sp_cheatcode },
    { "checkinTime", s_schema, sp_checkintime },
    { "checkoutTime", s_schema, sp_checkouttime },
    { "chemicalComposition", s_schema, sp_chemicalcomposition },
    { "chemicalRole", s_schema, sp_chemicalrole },
    { "childMaxAge", s_schema, sp_childmaxage },
    { "childMinAge", s_schema, sp_childminage },
    { "children", s_schema, sp_children },
    { "childTaxon", s_schema, sp_childtaxon },
    { "cholesterolContent", s_schema, sp_cholesterolcontent },
    { "circle", s_schema, sp_circle },
    { "citation", s_schema, sp_citation },
    { "claimInterpreter", s_schema, sp_claiminterpreter },
    { "claimReviewed", s_schema, sp_claimreviewed },
    { "clinicalPharamcology", s_schema, sp_clinicalpharamcology },
    { "clipNumber", s_schema, sp_clipnumber },
    { "closes", s_schema, sp_closes },
    { "coach", s_schema, sp_coach },
    { "code", s_schema, sp_code },
    { "codeRepository", s_schema, sp_coderepository },
    { "codeSampleType", s_schema, sp_codesampletype },
    { "codeValue", s_schema, sp_codevalue },
    { "codingSystem", s_schema, sp_codingsystem },
    { "colleague", s_schema, sp_colleague },
    { "collectionSize", s_schema, sp_collectionsize },
    { "color", s_schema, sp_colour },
    { "colorist", s_schema, sp_colourist },
    { "comment", s_schema, sp_comment },
    { "commentCount", s_schema, sp_commentcount },
    { "commentText", s_schema, sp_commenttext },
    { "commentTime", s_schema, sp_commenttime },
    { "competencyRequired", s_schema, sp_competencyrequired },
    { "competitor", s_schema, sp_competitor },
    { "composer", s_schema, sp_composer },
    { "comprisedOf", s_schema, sp_comprisedof },
    { "conditionsOfAccess", s_schema, sp_conditionsofaccess },
    { "confirmationNumber", s_schema, sp_confirmationnumber },
    { "connectedTo", s_schema, sp_connectedto },
    { "constrainingProperty", s_schema, sp_constrainingproperty },
    { "contactOption", s_schema, sp_contactoption },
    { "contactPoint", s_schema, sp_contactpoint },
    { "contactType", s_schema, sp_contacttype },
    { "contactlessPayment", s_schema, sp_contactlesspayment },
    { "containedIn", s_schema, sp_containedin },
    { "containedInPlace", s_schema, sp_containedinplace },
    { "containsPlace", s_schema, sp_containsplace },
    { "containsSeason", s_schema, sp_containsseason },
    { "contentLocation", s_schema, sp_contentlocation },
    { "contentRating", s_schema, sp_contentrating },
    { "contentReferenceTime", s_schema, sp_contentreferencetime },
    { "contentSize", s_schema, sp_contentsize },
    { "contentType", s_schema, sp_contenttype },
    { "contentUrl", s_schema, sp_contenturl },
    { "contraindication", s_schema, sp_contraindication },
    { "contributor", s_schema, sp_contributor },
    { "cookTime", s_schema, sp_cooktime },
    { "cookingMethod", s_schema, sp_cookingmethod },
    { "copyrightHolder", s_schema, sp_copyrightholder },
    { "copyrightNotice", s_schema, sp_copyrightnotice },
    { "copyrightYear", s_schema, sp_copyrightyear },
    { "correction", s_schema, sp_correction },
    { "correctionsPolicy", s_schema, sp_correctionspolicy },
    { "cost", s_schema, sp_cost },
    { "costCategory", s_schema, sp_costcategory },
    { "costCurrency", s_schema, sp_costcurrency },
    { "costOrigin", s_schema, sp_costorigin },
    { "costPerUnit", s_schema, sp_costperunit },
    { "countriesNotSupported", s_schema, sp_countriesnotsupported },
    { "countriesSupported", s_schema, sp_countriessupported },
    { "countryOfAssembly", s_schema, sp_countryofassembly },
    { "countryOfLastProcessing", s_schema, sp_countryoflastprocessing },
    { "countryOfOrigin", s_schema, sp_countryoforigin },
    { "courseCode", s_schema, sp_coursecode },
    { "courseMode", s_schema, sp_coursemode },
    { "coursePresequisites", s_schema, sp_coursepresequisites },
    { "courseWorkload", s_schema, sp_courseworkload },
    { "coverageEndTime", s_schema, sp_coverageendtime },
    { "coverageStartTime", s_schema, sp_coveragestarttime },
    { "creativeWorkStatus", s_schema, sp_creativeworkstatus },
    { "creator", s_schema, sp_creator },
    { "credentialCategory", s_schema, sp_credentialcategory },
    { "creditText", s_schema, sp_credittext },
    { "creditedTo", s_schema, sp_creditedto },
    { "cssSelector", s_schema, sp_cssselector },
    { "currenciesAccepted", s_schema, sp_currenciesaccepted },
    { "currency", s_schema, sp_currency },
    { "currentExchangeRate", s_schema, sp_currentexchangerate },
    { "customer", s_schema, sp_customer },
    { "cutoffTime", s_schema, sp_cutofftime },
    { "cvdCollectionDate", s_schema, sp_cvdcollectiondate },
    { "cvdFacilityCounty", s_schema, sp_cvdfacilitycounty },
    { "cvdFacilityId", s_schema, sp_cvdfacilityid },
    { "cvdNumBeds", s_schema, sp_cvdnumbeds },
    { "cvdNumBedsOcc", s_schema, sp_cvdnumbedsocc },
    { "cvdNumC19Died", s_schema, sp_cvdnumc19died },
    { "cvdNumC19HOPats", s_schema, sp_cvdnumc19hopats },
    { "cvdNumC19HospPats", s_schema, sp_cvdnumc19hosppats },
    { "cvdNumC19MechVentPats", s_schema, sp_cvdnumc19mechventpats },
    { "cvdNumC19OFMechVentPats", s_schema, sp_cvdnumc19ofmechventpats },
    { "cvdNumC19OverflowPats", s_schema, sp_cvdnumc19overflowpats },
    { "cvdNumICUBeds", s_schema, sp_cvdnumicubeds },
    { "cvdNumICUBedsOcc", s_schema, sp_cvdnumicubedsocc },
    { "cvdNumTotBeds", s_schema, sp_cvdnumtotbeds },
    { "cvdNumVent", s_schema, sp_cvdnumvent },
    { "cvdNumVentUse", s_schema, sp_cvdnumventuse },
    { "customerRemorseReturnFees", s_schema, sp_customerremorsereturnfees },
    { "customerRemorseReturnLabelSource", s_schema, sp_customerremorsereturnlabelsource },
    { "customerRemorseReturnShippingFeesAmount", s_schema, sp_customerremorsereturnshippingfeesamount },
    { "dataFeedElement", s_schema, sp_datafeedelement },
    { "dataset", s_schema, sp_dataset },
    { "datasetTimeInterval", s_schema, sp_datasettimeinterval },
    { "dateCreated", s_schema, sp_datecreated },
    { "dateDeleted", s_schema, sp_datedeleted },
    { "dateIssued", s_schema, sp_dateissued },
    { "dateModified", s_schema, sp_datemodified },
    { "datePosted", s_schema, sp_dateposted },
    { "datePublished", s_schema, sp_datepublished },
    { "dateRead", s_schema, sp_dateread },
    { "dateReceived", s_schema, sp_datereceived },
    { "dateSent", s_schema, sp_datesent },
    { "dateVehicleFirstRegistered", s_schema, sp_datevehiclefirstregistered },
    { "dateline", s_schema, sp_dateline },
    { "dayOfWeek", s_schema, sp_dayofweek },
    { "deathDate", s_schema, sp_deathdate },
    { "deathPlace", s_schema, sp_deathplace },
    { "defaultValue", s_schema, sp_defaultvalue },
    { "deliveryAddress", s_schema, sp_deliveryaddress },
    { "deliveryLeadTime", s_schema, sp_deliveryleadtime },
    { "deliveryMethod", s_schema, sp_deliverymethod },
    { "deliveryStatus", s_schema, sp_deliverystatus },
    { "deliveryTime", s_schema, sp_deliverytime },
    { "department", s_schema, sp_department },
    { "departureAirport", s_schema, sp_departureairport },
    { "departureBoatTerminal", s_schema, sp_departureboatterminal },
    { "departureBusStop", s_schema, sp_departurebusstop },
    { "departureGate", s_schema, sp_departuregate },
    { "departurePlatform", s_schema, sp_departureplatform },
    { "departureStation", s_schema, sp_departurestation },
    { "departureTerminal", s_schema, sp_departureterminal },
    { "departureTime", s_schema, sp_departuretime },
    { "dependencies", s_schema, sp_dependencies },
    { "depth", s_schema, sp_depth },
    { "description", s_schema, sp_description },
    { "diagnosis", s_schema, sp_diagnosis },
    { "diagram", s_schema, sp_diagram },
    { "diet", s_schema, sp_diet },
    { "dietFeatures", s_schema, sp_dietfeatures },
    { "differentialDiagnosis", s_schema, sp_differentialdiagnosis },
    { "director", s_schema, sp_director },
    { "directApply", s_schema, sp_directapply },
    { "disambiguatingDescription", s_schema, sp_disambiguatingdescription },
    { "discount", s_schema, sp_discount },
    { "discountCode", s_schema, sp_discountcode },
    { "discountCurrency", s_schema, sp_discountcurrency },
    { "discusses", s_schema, sp_discusses },
    { "discussionUrl", s_schema, sp_discussionurl },
    { "diseasePreventionInfo", s_schema, sp_diseasepreventioninfo },
    { "diseaseSpreadStatistics", s_schema, sp_diseasespreadstatistics },
    { "dissolutionDate", s_schema, sp_dissolutiondate },
    { "distance", s_schema, sp_distance },
    { "distinguishingSign", s_schema, sp_distinguishingsign },
    { "distribution", s_schema, sp_distribution },
    { "diversityPolicy", s_schema, sp_diversitypolicy },
    { "diversityStaffingReport", s_schema, sp_diversitystaffingreport },
    { "documentation", s_schema, sp_documentation },
    { "doesNotShip", s_schema, sp_doesnotship },
    { "domainIncludes", s_schema, sp_domainincludes },
    { "domiciledMortgage", s_schema, sp_domiciledmortgage },
    { "doorTime", s_schema, sp_doortime },
    { "dosageForm", s_schema, sp_dosageform },
    { "doseSchedule", s_schema, sp_doseschedule },
    { "doseUnit", s_schema, sp_doseunit },
    { "doseValue", s_schema, sp_dosevalue },
    { "downPayment", s_schema, sp_downpayment },
    { "downloadUrl", s_schema, sp_downloadurl },
    { "downvoteCount", s_schema, sp_downvotecount },
    { "drainsTo", s_schema, sp_drainsto },
    { "driveWheelConfiguration", s_schema, sp_drivewheelconfiguration },
    { "dropoffLocation", s_schema, sp_dropofflocation },
    { "dropoffTime", s_schema, sp_dropofftime },
    { "drug", s_schema, sp_drug },
    { "drugClass", s_schema, sp_drugclass },
    { "drugUnit", s_schema, sp_drugunit },
    { "duns", s_schema, sp_duns },
    { "duplicateTherapy", s_schema, sp_duplicatetherapy },
    { "duration", s_schema, sp_duration },
    { "durationOfWarranty", s_schema, sp_durationofwarranty },
    { "duringMedia", s_schema, sp_duringmedia },
    { "earlyPrepaymentPenalty", s_schema, sp_earlyprepaymentpenalty },
    { "editEIDR", s_schema, sp_editeidr },
    { "editor", s_schema, sp_editor },
    { "eduQuestionType", s_schema, sp_eduquestiontype },
    { "educationCredentialAwarded", s_schema, sp_educationcredentialawarded },
    { "educationRequirements", s_schema, sp_educationrequirements },
    { "educationalAlignment", s_schema, sp_educationalalignment },
    { "educationalCredentialAwarded", s_schema, sp_educationalcredentialawarded },
    { "educationalFramework", s_schema, sp_educationalframework },
    { "educationalLevel", s_schema, sp_educationallevel },
    { "educationalProgramMode", s_schema, sp_educationalprogrammode },
    { "educationalRole", s_schema, sp_educationalrole },
    { "educationalUse", s_schema, sp_educationaluse },
    { "elevation", s_schema, sp_elevation },
    { "eligibileCustomerType", s_schema, sp_eligibilecustomertype },
    { "eligibilityToWorkRequirement", s_schema, sp_eligibilitytoworkrequirement },
    { "eligibleCustomerType", s_schema, sp_eligiblecustomertype },
    { "eligibleDuration", s_schema, sp_eligibleduration },
    { "eligibleQuantity", s_schema, sp_eligiblequantity },
    { "eligibleRegion", s_schema, sp_eligibleregion },
    { "eligibleTransactionVolume", s_schema, sp_eligibletransactionvolume },
    { "email", s_schema, sp_email },
    { "embeddedTextCaption", s_schema, sp_embeddedtextcaption },
    { "embedUrl", s_schema, sp_embedurl },
    { "emmissionsCO2", s_schema, sp_emmissionsco2 },
    { "employee", s_schema, sp_employee },
    { "employerOverview", s_schema, sp_employeroverview },
    { "employmentType", s_schema, sp_employmenttype },
    { "employmentUnit", s_schema, sp_employmentunit },
    { "encodesBioChementity", s_schema, sp_encodesbiochementity },
    { "encodesCreativeWork", s_schema, sp_encodescreativework },
    { "encoding", s_schema, sp_encoding },
    { "encodingFormat", s_schema, sp_encodingformat },
    { "encodingType", s_schema, sp_encodingtype },
    { "endDate", s_schema, sp_enddate },
    { "endOffset", s_schema, sp_endoffset },
    { "endTime", s_schema, sp_endtime },
    { "endorsee", s_schema, sp_endorsee },
    { "endorsers", s_schema, sp_endorsers },
    { "energyEfficiencyScaleMax", s_schema, sp_energyefficiencyscalemax },
    { "energyEfficiencyScaleMin", s_schema, sp_energyefficiencyscalemin },
    { "engineDisplacement", s_schema, sp_enginedisplacement },
    { "enginePower", s_schema, sp_enginepower },
    { "engineType", s_schema, sp_enginetype },
    { "entertainmentBusiness", s_schema, sp_entertainmentbusiness },
    { "epidemiology", s_schema, sp_epidemiology },
    { "episode", s_schema, sp_episode },
    { "episodeNumber", s_schema, sp_episodenumber },
    { "equal", s_schema, sp_equal },
    { "error", s_schema, sp_error },
    { "estimatedCost", s_schema, sp_estimatedcost },
    { "estimatedFlightDuration", s_schema, sp_estimatedflightduration },
    { "estimatedSalary", s_schema, sp_estimatedsalary },
    { "estimatesRiskOf", s_schema, sp_estimatesriskof },
    { "ethicsPolicy", s_schema, sp_ethicspolicy },
    { "event", s_schema, sp_event },
    { "eventAttendanceMode", s_schema, sp_eventattendancemode },
    { "eventSchedule", s_schema, sp_eventschedule },
    { "eventStatus", s_schema, sp_eventstatus },
    { "evidenceLevel", s_schema, sp_evidencelevel },
    { "evidenceOrigin", s_schema, sp_evidenceorigin },
    { "exampleOfWork", s_schema, sp_exampleofwork },
    { "exceptDate", s_schema, sp_exceptdate },
    { "exchangeRateSpread", s_schema, sp_exchangeratespread },
    { "executableLibraryName", s_schema, sp_executablelibraryname },
    { "exerciseCourse", s_schema, sp_exercisecourse },
    { "exercisePlan", s_schema, sp_exerciseplan },
    { "exerciseRelatedDiet", s_schema, sp_exerciserelateddiet },
    { "exerciseType", s_schema, sp_exercisetype },
    { "exifData", s_schema, sp_exifdata },
    { "expectedArrivalFrom", s_schema, sp_expectedarrivalfrom },
    { "expectedArrivalUntil", s_schema, sp_expectedarrivaluntil },
    { "expectedPrognosis", s_schema, sp_expectedprognosis },
    { "expectsAcceptanceOf", s_schema, sp_expectsacceptanceof },
    { "experienceRequirements", s_schema, sp_experiencerequirements },
    { "expeienceRequirements", s_schema, sp_experiencerequirements }, // typo in early original schema.org docs
    { "experienceInPlaceOfEducation", s_schema, sp_experienceinplaceofeducation },
    { "expires", s_schema, sp_expires },
    { "expressedIn", s_schema, sp_expressedin },
    { "exportConsiderations", s_schema, sp_exportconsiderations },
    { "familyName", s_schema, sp_familyname },
    { "fatContent", s_schema, sp_fatcontent },
    { "faxNumber", s_schema, sp_faxnumber },
    { "featureList", s_schema, sp_featurelist },
    { "feesAndCommissionsSpecification", s_schema, sp_feesandcommissionsspecification },
    { "fiberContent", s_schema, sp_fibrecontent },
    { "fileFormat", s_schema, sp_fileformat },
    { "fileSize", s_schema, sp_filesize },
    { "financialAidEligible", s_schema, sp_financialaideligible },
    { "firstAppearance", s_schema, sp_firstappearance },
    { "firstPerformance", s_schema, sp_firstperformance },
    { "flightDistance", s_schema, sp_flightdistance },
    { "flightNumber", s_schema, sp_flightnumber },
    { "floorLevel", s_schema, sp_floorlevel },
    { "floorLimit", s_schema, sp_floorlimit },
    { "floorSize", s_schema, sp_floorsize },
    { "followee", s_schema, sp_followee },
    { "follows", s_schema, sp_follows },
    { "followup", s_schema, sp_followup },
    { "foodEstablishment", s_schema, sp_foodestablishment },
    { "foodEvent", s_schema, sp_foodevent },
    { "foodWarning", s_schema, sp_foodwarning },
    { "founder", s_schema, sp_founder },
    { "foundingDate", s_schema, sp_foundingdate },
    { "foundingLocation", s_schema, sp_foundinglocation },
    { "freeShippingThreshold", s_schema, sp_freeshippingthreshold },
    { "frequency", s_schema, sp_frequency },
    { "fromLocation", s_schema, sp_fromlocation },
    { "fuelCapacity", s_schema, sp_fuelcapacity },
    { "fuelConsumption", s_schema, sp_fuelconsumption },
    { "fuelEfficiency", s_schema, sp_fuelefficiency },
    { "fuelType", s_schema, sp_fueltype },
    { "funcionalClass", s_schema, sp_funcionalclass },
    { "function", s_schema, sp_function },
    { "fundedItem", s_schema, sp_fundeditem },
    { "funder", s_schema, sp_funder },
    { "game", s_schema, sp_game },
    { "gameItem", s_schema, sp_gameitem },
    { "gameLocation", s_schema, sp_gamelocation },
    { "gamePlatform", s_schema, sp_gameplatform },
    { "gameServer", s_schema, sp_gameserver },
    { "gameTip", s_schema, sp_gametip },
    { "gender", s_schema, sp_gender },
    { "genre", s_schema, sp_genre },
    { "geo", s_schema, sp_geo },
    { "geoContains", s_schema, sp_geocontains },
    { "geoCoveredBy", s_schema, sp_geocoveredby },
    { "geoCovers", s_schema, sp_geocovers },
    { "geoCrosses", s_schema, sp_geocrosses },
    { "geoDisjoint", s_schema, sp_geodisjoint },
    { "geoEquals", s_schema, sp_geoequals },
    { "geoIntersects", s_schema, sp_geointersects },
    { "geoMidpoint", s_schema, sp_geomidpoint },
    { "geoOverlaps", s_schema, sp_geooverlaps },
    { "geoRadius", s_schema, sp_georadius },
    { "geoTouches", s_schema, sp_geotouches },
    { "geoWithin", s_schema, sp_geowithin },
    { "geographicArea", s_schema, sp_geographicarea },
    { "gettingTestedInfo", s_schema, sp_gettingtestedinfo },
    { "givenName", s_schema, sp_givenname },
    { "globalLocationNumber", s_schema, sp_globallocationnumber },
    { "governmentBenefitsInfo", s_schema, sp_governmentbenefitsinfo },
    { "gracePeriod", s_schema, sp_graceperiod },
    { "grantee", s_schema, sp_grantee },
    { "greater", s_schema, sp_greater },
    { "greaterOrEqual", s_schema, sp_greaterorequal },
    { "gtin", s_schema, sp_gtin },
    { "gtin12", s_schema, sp_gtin12 },
    { "gtin13", s_schema, sp_gtin13 },
    { "gtin14", s_schema, sp_gtin14 },
    { "gtin8", s_schema, sp_gtin8 },
    { "guideline", s_schema, sp_guideline },
    { "guidelineDate", s_schema, sp_guidelinedate },
    { "guidelineSubject", s_schema, sp_guidelinesubject },
    { "handlingTime", s_schema, sp_handlingtime },
    { "hasBioPolymerSequence", s_schema, sp_hasbiopolymersequence },
    { "hasBroadcastChannel", s_schema, sp_hasbroadcastchannel },
    { "hasCategoryCode", s_schema, sp_hascategorycode },
    { "hasCourse", s_schema, sp_hascourse },
    { "hasCourseInstance", s_schema, sp_hascourseinstance },
    { "hasCredential", s_schema, sp_hascredential },
    { "hasDefinedTerm", s_schema, sp_hasdefinedterm },
    { "hasDeliveryMethod", s_schema, sp_hasdeliverymethod },
    { "hasDigitalDocumentPermission", s_schema, sp_hasdigitaldocumentpermission },
    { "hasDriveThroughService", s_schema, sp_hasdrivethroughservice },
    { "hasEnergyConsumptionDetails", s_schema, sp_hasenergyconsumptiondetails },
    { "hasEnergyEfficiencyCategory", s_schema, sp_hasenergyefficiencycategory },
    { "hasHealthAspect", s_schema, sp_hashealthaspect },
    { "hasMap", s_schema, sp_hasmap },
    { "hasMeasurement", s_schema, sp_hasmeasurement },
    { "hasMenu", s_schema, sp_hasmenu },
    { "hasMenuItem", s_schema, sp_hasmenuitem },
    { "hasMenuSection", s_schema, sp_hasmenusection },
    { "hasMerchantReturnPolicy", s_schema, sp_hasmerchantreturnpolicy },
    { "hasOccupation", s_schema, sp_hasoccupation },
    { "hasOfferCatalog", s_schema, sp_hasoffercatalogue },
    { "hasPOS", s_schema, sp_haspos },
    { "hasPart", s_schema, sp_haspart },
    { "hasProductReturnPolicy", s_schema, sp_hasproductreturnpolicy },
    { "hasVariant", s_schema, sp_hasvariant },
    { "headline", s_schema, sp_headline },
    { "healthCondition", s_schema, sp_healthcondition },
    { "healthPlanCoinsuranceOption", s_schema, sp_healthplancoinsuranceoption },
    { "healthPlanCoinsuranceRate", s_schema, sp_healthplancoinsurancerate },
    { "healthPlanCopay", s_schema, sp_healthplancopay },
    { "healthPlanCopayOption", s_schema, sp_healthplancopayoption },
    { "healthPlanCostSharing", s_schema, sp_healthplancostsharing },
    { "healthPlanDrugOption", s_schema, sp_healthplandrugoption },
    { "healthPlanDrugTier", s_schema, sp_healthplandrugtier },
    { "healthPlanId", s_schema, sp_healthplanid },
    { "healthPlanMarketingUrl", s_schema, sp_healthplanmarketingurl },
    { "healthPlanNetworkId", s_schema, sp_healthplannetworkid },
    { "healthPlanNetworkTier", s_schema, sp_healthplannetworktier },
    { "healthPlanPharmacyCategory", s_schema, sp_healthplanpharmacycategory },
    { "healthcareReportingData", s_schema, sp_healthcarereportingdata },
    { "height", s_schema, sp_height },
    { "highPrice", s_schema, sp_highprice },
    { "hiringOrganization", s_schema, sp_hiringorganization },
    { "holdingArchive", s_schema, sp_holdingarchive },
    { "homeLocation", s_schema, sp_homelocation },
    { "homeTeam", s_schema, sp_hometeam },
    { "honorificPrefix", s_schema, sp_honourificprefix },
    { "honorificSuffix", s_schema, sp_honourificsuffix },
    { "hospitalAffiliation", s_schema, sp_hospitalaffiliation },
    { "hostingOrganization", s_schema, sp_hostingorganisation },
    { "hoursAvailable", s_schema, sp_hoursavailable },
    { "howPerformed", s_schema, sp_howperformed },
    { "httpMethod", s_schema, sp_httpmethod },
    { "iataCode", s_schema, sp_iatacode },
    { "identifier", s_schema, sp_identifier },
    { "identifyingExam", s_schema, sp_identifyingexam },
    { "identifyingTest", s_schema, sp_identifyingtest },
    { "illustrator", s_schema, sp_illustrator },
    { "image", s_schema, sp_image },
    { "imagingTechnique", s_schema, sp_imagingtechnique },
    { "inAlbum", s_schema, sp_inalbum },
    { "inBroadcastLineup", s_schema, sp_inbroadcastlineup },
    { "inChI", s_schema, sp_inchi },
    { "inChIKey", s_schema, sp_inchikey },
    { "inCodeSet", s_schema, sp_incodeset },
    { "inDefinedTermSet", s_schema, sp_indefinedtermset },
    { "inLanguage", s_schema, sp_inlanguage },
    { "inPlaylist", s_schema, sp_inplaylist },
    { "inProductGroupWithID", s_schema, sp_inproductgroupwithid },
    { "inStoreReturnsOffered", s_schema, sp_instorereturnsoffered },
    { "inSupportOf", s_schema, sp_insupportof },
    { "incentiveCompensation", s_schema, sp_incentivecompensation },
    { "includedComposition", s_schema, sp_includedcomposition },
    { "includedDataCatalog", s_schema, sp_includeddatacatalog },
    { "includedInHealthInsurancePlan", s_schema, sp_includedinhealthinsuranceplan },
    { "includedRiskFactor", s_schema, sp_includedriskfactor },
    { "includesAttraction", s_schema, sp_includesattraction },
    { "includesHealthPlanFormulary", s_schema, sp_includeshealthplanformulary },
    { "includesHealthPlanNetwork", s_schema, sp_includeshealthplannetwork },
    { "includesObject", s_schema, sp_includesobject },
    { "increasesRiskOf", s_schema, sp_increasesriskof },
    { "indication", s_schema, sp_indication },
    { "industry", s_schema, sp_industry },
    { "ineligibleRegion", s_schema, sp_ineligibleregion },
    { "infectiousAgent", s_schema, sp_infectiousagent },
    { "infectiousAgentClass", s_schema, sp_infectiousagentclass },
    { "inker", s_schema, sp_inker },
    { "insertion", s_schema, sp_insertion },
    { "installUrl", s_schema, sp_installurl },
    { "instructor", s_schema, sp_instructor },
    { "instrument", s_schema, sp_instrument },
    { "intensity", s_schema, sp_intensity },
    { "interactingDrug", s_schema, sp_interactingdrug },
    { "interactionService", s_schema, sp_interactionservice },
    { "interactionStatistic", s_schema, sp_interactionstatistic },
    { "interactionType", s_schema, sp_interactiontype },
    { "interactivityType", s_schema, sp_interactivitytype },
    { "interestRate", s_schema, sp_interestrate },
    { "interpretedAsClaim", s_schema, sp_interpretedasclaim },
    { "inventoryLevel", s_schema, sp_inventorylevel },
    { "inverseOf", s_schema, sp_inverseof },
    { "isAcceptingNewPatients", s_schema, sp_isacceptingnewpatients },
    { "isAccessibleForFree", s_schema, sp_isaccessibleforfree },
    { "isAccessoryOrSparePartFor", s_schema, sp_isaccessoryorsparepartfor },
    { "isAvailableGenerally", s_schema, sp_isavailablegenerally },
    { "isBasedOn", s_schema, sp_isbasedon },
    { "isBasedOnUrl", s_schema, sp_isbasedonurl },
    { "isConsumableFor", s_schema, sp_isconsumablefor },
    { "isFamilyFriendly", s_schema, sp_isfamilyfriendly },
    { "isGift", s_schema, sp_isgift },
    { "isLiveBroadcast", s_schema, sp_islivebroadcast },
    { "isPartOf", s_schema, sp_ispartof },
    { "isPlanForApartment", s_schema, sp_isplanforapartment },
    { "isProprietary", s_schema, sp_isproprietary },
    { "isRelatedTo", s_schema, sp_isrelatedto },
    { "isResizable", s_schema, sp_isresizable },
    { "isSimilarTo", s_schema, sp_issimilarto },
    { "isUnlabelledFallback", s_schema, sp_isunlabelledfallback },
    { "isVariantOf", s_schema, sp_isvariantof },
    { "isbn", s_schema, sp_isbn },
    { "isicV4", s_schema, sp_isicv4 },
    { "isrcCode", s_schema, sp_isrccode },
    { "issn", s_schema, sp_issn },
    { "issueNumber", s_schema, sp_issuenumber },
    { "issuedBy", s_schema, sp_issuedby },
    { "issuedThrough", s_schema, sp_issuedthrough },
    { "iswcCode", s_schema, sp_iswccode },
    { "item", s_schema, sp_item },
    { "itemCondition", s_schema, sp_itemcondition },
    { "itemDefectReturnFees", s_schema, sp_itemdefectreturnfees },
    { "itemDefectReturnLabelSource", s_schema, sp_itemdefectreturnlabelsource },
    { "itemDefectReturnShippingFeesAmount", s_schema, sp_itemdefectreturnshippingfeesamount },
    { "itemListElement", s_schema, sp_itemlistelement },
    { "itemListOrder", s_schema, sp_itemlistorder },
    { "itemLocation", s_schema, sp_itemlocation },
    { "itemOffered", s_schema, sp_itemoffered },
    { "itemReviewed", s_schema, sp_itemreviewed },
    { "itemShipped", s_schema, sp_itemshipped },
    { "itinerary", s_schema, sp_itinerary },
    { "iupacName", s_schema, sp_iupacname },
    { "jobBenefits", s_schema, sp_jobbenefits },
    { "jobImmediateStart", s_schema, sp_jobimmediatestart },
    { "jobLocation", s_schema, sp_joblocation },
    { "jobLocationType", s_schema, sp_joblocationtype },
    { "jobStartDate", s_schema, sp_jobstartdate },
    { "jobTitle", s_schema, sp_jobtitle },
    { "jurisdiction", s_schema, sp_jurisdiction },
    { "keywords", s_schema, sp_keywords },
    { "knownVehicleDamages", s_schema, sp_knownvehicledamages },
    { "knows", s_schema, sp_knows },
    { "knowsAbout", s_schema, sp_knowsabout },
    { "knowsLanguage", s_schema, sp_knowslanguage },
    { "labelDetails", s_schema, sp_labeldetails },
    { "landlord", s_schema, sp_landlord },
    { "lastReviewed", s_schema, sp_lastreviewed },
    { "latitude", s_schema, sp_latitude },
    { "layoutImage", s_schema, sp_layoutimage },
    { "learningResourceType", s_schema, sp_learningresourcetype },
    { "leaseLength", s_schema, sp_leaselength },
    { "legalName", s_schema, sp_legalname },
    { "legalStatus", s_schema, sp_legalstatus },
    { "legislationApplies", s_schema, sp_legislationapplies },
    { "legislationChanges", s_schema, sp_legislationchanges },
    { "legislationConsolidates", s_schema, sp_legislationconsolidates },
    { "legislationDate", s_schema, sp_legislationdate },
    { "legislationDateVersion", s_schema, sp_legislationdateversion },
    { "legislationIdentifier", s_schema, sp_legislationidentifier },
    { "legislationJurisdiction", s_schema, sp_legislationjurisdiction },
    { "legislationLegalForce", s_schema, sp_legislationlegalforce },
    { "legislationLegalValue", s_schema, sp_legislationlegalvalue },
    { "legislationPassedBy", s_schema, sp_legislationpassedby },
    { "legislationResponsible", s_schema, sp_legislationresponsible },
    { "legislationTransposes", s_schema, sp_legislationtransposes },
    { "legislationType", s_schema, sp_legislationtype },
    { "leiCode", s_schema, sp_leicode },
    { "lender", s_schema, sp_lender },
    { "lesser", s_schema, sp_lesser },
    { "lesserOrEqual", s_schema, sp_lesserorequal },
    { "letterer", s_schema, sp_letterer },
    { "license", s_schema, sp_license },
    { "line", s_schema, sp_line },
    { "linkRelationship", s_schema, sp_linkrelationship },
    { "liveBlogUpdate", s_schema, sp_liveblogupdate },
    { "loanMortgagaMandateAmount", s_schema, sp_loanmortgagamandateamount },
    { "loanPaymentAmount", s_schema, sp_loanpaymentamount },
    { "loanPaymentFrequency", s_schema, sp_loanpaymentfrequency },
    { "loanRepaymentForm", s_schema, sp_loanrepaymentform },
    { "loanTerm", s_schema, sp_loanterm },
    { "loanType", s_schema, sp_loantype },
    { "location", s_schema, sp_location },
    { "locationCreated", s_schema, sp_locationcreated },
    { "lodgingUnitDescription", s_schema, sp_lodgingunitdescription },
    { "lodgingUnitType", s_schema, sp_lodgingunittype },
    { "logo", s_schema, sp_logo },
    { "longitude", s_schema, sp_longitude },
    { "loser", s_schema, sp_loser },
    { "lowPrice", s_schema, sp_lowprice },
    { "lyricist", s_schema, sp_lyricist },
    { "lyrics", s_schema, sp_lyrics },
    { "mainContentOfPage", s_schema, sp_maincontentofpage },
    { "mainEntity", s_schema, sp_mainentity },
    { "mainEntityOfPage", s_schema, sp_mainentityofpage },
    { "maintainer", s_schema, sp_maintainer },
    { "makesOffer", s_schema, sp_makesoffer },
    { "manufacturer", s_schema, sp_manufacturer },
    { "mapType", s_schema, sp_maptype },
    { "marginOfError", s_schema, sp_marginoferror },
    { "masthead", s_schema, sp_masthead },
    { "material", s_schema, sp_material },
    { "materialExtent", s_schema, sp_materialextent },
    { "mathExpression", s_schema, sp_mathexpression },
    { "maxPrice", s_schema, sp_maxprice },
    { "maxValue", s_schema, sp_maxvalue },
    { "maximumAttendeeCapacity", s_schema, sp_maximumattendeecapacity },
    { "maximumEnrollment", s_schema, sp_maximumenrollment },
    { "maximumIntake", s_schema, sp_maximumintake },
    { "maximumPhysicalAttendeeCapacity", s_schema, sp_maximumphysicalattendeecapacity },
    { "maximumVirtualAttendeeCapacity", s_schema, sp_maximumvirtualattendeecapacity },
    { "mealService", s_schema, sp_mealservice },
    { "measuredProperty", s_schema, sp_measuredproperty },
    { "measuredValue", s_schema, sp_measuredvalue },
    { "measurementTechnique", s_schema, sp_measurementtechnique },
    { "mechanismOfAction", s_schema, sp_mechanismofaction },
    { "mediaAuthenticityCategory", s_schema, sp_mediaauthenticitycategory },
    { "mediaItemAppearance", s_schema, sp_mediaitemappearance },
    { "median", s_schema, sp_median },
    { "medicalAudience", s_schema, sp_medicalaudience },
    { "medicalSpeciality", s_schema, sp_medicalspeciality },
    { "medicineSystem", s_schema, sp_medicinesystem },
    { "meetsEmissionStandard", s_schema, sp_meetsemissionstandard },
    { "member", s_schema, sp_member },
    { "memberOf", s_schema, sp_memberof },
    { "membershipNumber", s_schema, sp_membershipnumber },
    { "membershipPointsEarned", s_schema, sp_membershippointsearned },
    { "memoryRequirements", s_schema, sp_memoryrequirements },
    { "mentions", s_schema, sp_mentions },
    { "menu", s_schema, sp_menu },
    { "menuAddOn", s_schema, sp_menuaddon },
    { "merchantReturnDays", s_schema, sp_merchantreturndays },
    { "merchantReturnLink", s_schema, sp_merchantreturnlink },
    { "messageAttachment", s_schema, sp_messageattachment },
    { "mileageFromOdometer", s_schema, sp_mileagefromodometer },
    { "minPrice", s_schema, sp_minprice },
    { "minValue", s_schema, sp_minvalue },
    { "minimumMonthlyRepaymentAmount", s_schema, sp_minimummonthlyrepaymentamount },
    { "minimumPaymentDue", s_schema, sp_minimumpaymentdue },
    { "missionCoveragePrioritiesPolicy", s_schema, sp_missioncoverageprioritiespolicy },
    { "model", s_schema, sp_model },
    { "modelDate", s_schema, sp_modeldate },
    { "modifiedTime", s_schema, sp_modifiedtime },
    { "molecularFormula", s_schema, sp_molecularformula },
    { "molecularWeight", s_schema, sp_molecularweight },
    { "monoistopicMolecularWeight", s_schema, sp_monoistopicmolecularweight },
    { "monthsOfExperience", s_schema, sp_monthsofexperience },
    { "mpn", s_schema, sp_mpn },
    { "multipleValues", s_schema, sp_multiplevalues },
    { "muscleAction", s_schema, sp_muscleaction },
    { "musicArrangement", s_schema, sp_musicarrangement },
    { "musicBy", s_schema, sp_musicby },
    { "musicCompositionForm", s_schema, sp_musiccompositionform },
    { "musicReleaseFormat", s_schema, sp_musicreleaseformat },
    { "musicalKey", s_schema, sp_musicalkey },
    { "naics", s_schema, sp_naics },
    { "name", s_schema, sp_name },
    { "nationality", s_schema, sp_nationality },
    { "naturalProgression", s_schema, sp_naturalprogression },
    { "negativeVotes", s_schema, sp_negativevotes },
    { "nerve", s_schema, sp_nerve },
    { "nerveMotor", s_schema, sp_nervemotor },
    { "netWorth", s_schema, sp_networth },
    { "newUpdatesAndGuideLines", s_schema, sp_newupdatesandguidelines },
    { "nextItem", s_schema, sp_nextitem },
    { "noBylinesPolicy", s_schema, sp_nobylinespolicy },
    { "nonEqual", s_schema, sp_nonequal },
    { "nonPropriatryName", s_schema, sp_nonpropriatryname },
    { "nonProprietaryName", s_schema, sp_nonproprietaryname },
    { "nonprofitStatus", s_schema, sp_nonprofitstatus },
    { "normalRange", s_schema, sp_normalrange },
    { "nsn", s_schema, sp_nsn },
    { "numAdults", s_schema, sp_numadults },
    { "numChildren", s_schema, sp_numchildren },
    { "numConstraints", s_schema, sp_numconstraints },
    { "numTracks", s_schema, sp_numtracks },
    { "numberOfAccommodationUnits", s_schema, sp_numberofaccommodationunits },
    { "numberOfAirbags", s_schema, sp_numberofairbags },
    { "numberOfAvailableAccommodationUnits", s_schema, sp_numberofavailableaccommodationunits },
    { "numberOfAxles", s_schema, sp_numberofaxles },
    { "numberOfBathroomsTotal", s_schema, sp_numberofbathroomstotal },
    { "numberOfBedrooms", s_schema, sp_numberofbedrooms },
    { "numberOfBeds", s_schema, sp_numberofbeds },
    { "numberOfCredits", s_schema, sp_numberofcredits },
    { "numberOfDoors", s_schema, sp_numberofdoors },
    { "numberOfEmployees", s_schema, sp_numberofemployees },
    { "numberOfEpisodes", s_schema, sp_numberofepisodes },
    { "numberOfForwardgears", s_schema, sp_numberofforwardgears },
    { "numberOfFullBathrooms", s_schema, sp_numberoffullbathrooms },
    { "numberOfItems", s_schema, sp_numberofitems },
    { "numberOfLoanPayments", s_schema, sp_numberofloanpayments },
    { "numberOfPages", s_schema, sp_numberofpages },
    { "numberOfPartialBathrooms", s_schema, sp_numberofpartialbathrooms },
    { "numberOfPlayers", s_schema, sp_numberofplayers },
    { "numberOfPreviousowners", s_schema, sp_numberofpreviousowners },
    { "numberOfRooms", s_schema, sp_numberofrooms },
    { "numberOfSeasons", s_schema, sp_numberofseasons },
    { "numberedPosition", s_schema, sp_numberedposition },
    { "nutrition", s_schema, sp_nutrition },
    { "object", s_schema, sp_object },
    { "observationDate", s_schema, sp_observationdate },
    { "observedNode", s_schema, sp_observednode },
    { "ocaoCode", s_schema, sp_ocaocode },
    { "occupancy", s_schema, sp_occupancy },
    { "occupationLocation", s_schema, sp_occupationlocation },
    { "occupationalCategory", s_schema, sp_occupationalcategory },
    { "occupationalCredentialAwarded", s_schema, sp_occupationalcredentialawarded },
    { "offerCount", s_schema, sp_offercount },
    { "offeredBy", s_schema, sp_offeredby },
    { "offers", s_schema, sp_offers },
    { "offersPrescriptionByMail", s_schema, sp_offersprescriptionbymail },
    { "openingHours", s_schema, sp_openinghours },
    { "openingHoursSpecification", s_schema, sp_openinghoursspecification },
    { "opens", s_schema, sp_opens },
    { "operatingSystem", s_schema, sp_operatingsystem },
    { "opponent", s_schema, sp_opponent },
    { "orderDate", s_schema, sp_orderdate },
    { "orderDelivery", s_schema, sp_orderdelivery },
    { "orderItemNumber", s_schema, sp_orderitemnumber },
    { "orderItemStatus", s_schema, sp_orderitemstatus },
    { "orderNumber", s_schema, sp_ordernumber },
    { "orderQuantity", s_schema, sp_orderquantity },
    { "orderStatus", s_schema, sp_orderstatus },
    { "orderedItem", s_schema, sp_ordereditem },
    { "organizer", s_schema, sp_organiser },
    { "origin", s_schema, sp_origin },
    { "originAddress", s_schema, sp_originaddress },
    { "originalMediaContentDescription", s_schema, sp_originalmediacontentdescription },
    { "originalMedialink", s_schema, sp_originalmedialink },
    { "originatesFrom", s_schema, sp_originatesfrom },
    { "outcome", s_schema, sp_outcome },
    { "overdosage", s_schema, sp_overdosage },
    { "overview", s_schema, sp_overview },
    { "ownedFrom", s_schema, sp_ownedfrom },
    { "ownedThrough", s_schema, sp_ownedthrough },
    { "ownershipFundingInfo", s_schema, sp_ownershipfundinginfo },
    { "owns", s_schema, sp_owns },
    { "pageEnd", s_schema, sp_pageend },
    { "pageStart", s_schema, sp_pagestart },
    { "pagination", s_schema, sp_pagination },
    { "parent", s_schema, sp_parent },
    { "parentItem", s_schema, sp_parentitem },
    { "parentOrganization", s_schema, sp_parentorganisation },
    { "parentService", s_schema, sp_parentservice },
    { "parentTaxon", s_schema, sp_parenttaxon },
    { "partOfEpisode", s_schema, sp_partofepisode },
    { "partOfInvoice", s_schema, sp_partofinvoice },
    { "partOfSeason", s_schema, sp_partofseason },
    { "partOfSeries", s_schema, sp_partofseries },
    { "partOfSystem", s_schema, sp_partofsystem },
    { "partOfTrip", s_schema, sp_partoftrip },
    { "participant", s_schema, sp_participant },
    { "partofOrder", s_schema, sp_partoforder },
    { "partySize", s_schema, sp_partysize },
    { "passengerPriorityStatus", s_schema, sp_passengerprioritystatus },
    { "passengerSequenceNumber", s_schema, sp_passengersequencenumber },
    { "pathophysiology", s_schema, sp_pathophysiology },
    { "pattern", s_schema, sp_pattern },
    { "payload", s_schema, sp_payload },
    { "paymentAccepted", s_schema, sp_paymentaccepted },
    { "paymentDue", s_schema, sp_paymentdue },
    { "paymentDueDate", s_schema, sp_paymentduedate },
    { "paymentMethod", s_schema, sp_paymentmethod },
    { "paymentMethodId", s_schema, sp_paymentmethodid },
    { "paymentStatus", s_schema, sp_paymentstatus },
    { "paymentUrl", s_schema, sp_paymenturl },
    { "penciler", s_schema, sp_penciler },
    { "percentile10", s_schema, sp_percentile10 },
    { "percentile25", s_schema, sp_percentile25 },
    { "percentile75", s_schema, sp_percentile75 },
    { "percentile90", s_schema, sp_percentile90 },
    { "performTime", s_schema, sp_performtime },
    { "performer", s_schema, sp_performer },
    { "performerIn", s_schema, sp_performerin },
    { "permissionType", s_schema, sp_permissiontype },
    { "permissions", s_schema, sp_permissions },
    { "permitAudience", s_schema, sp_permitaudience },
    { "permittedUsage", s_schema, sp_permittedusage },
    { "petsAllowed", s_schema, sp_petsallowed },
    { "phase", s_schema, sp_phase },
    { "phoneticText", s_schema, sp_phonetictext },
    { "photo", s_schema, sp_photo },
    { "physicalRequirement", s_schema, sp_physicalrequirement },
    { "physiologicalBenefits", s_schema, sp_physiologicalbenefits },
    { "pickupLocation", s_schema, sp_pickuplocation },
    { "pickupTime", s_schema, sp_pickuptime },
    { "playMode", s_schema, sp_playmode },
    { "playerType", s_schema, sp_playertype },
    { "playersOnline", s_schema, sp_playersonline },
    { "polygon", s_schema, sp_polygon },
    { "population", s_schema, sp_population },
    { "populationType", s_schema, sp_populationtype },
    { "position", s_schema, sp_position },
    { "positiveVotes", s_schema, sp_positivevotes },
    { "possibleComplication", s_schema, sp_possiblecomplication },
    { "possibleTreatment", s_schema, sp_possibletreatment },
    { "postOfficeBoxNumber", s_schema, sp_postofficeboxnumber },
    { "postOp", s_schema, sp_postop },
    { "postalCode", s_schema, sp_postalcode },
    { "postalCodeBegin", s_schema, sp_postalcodebegin },
    { "postalCodeEnd", s_schema, sp_postalcodeend },
    { "postalCodePrefix", s_schema, sp_postalcodeprefix },
    { "postalCodeRange", s_schema, sp_postalcoderange },
    { "potentialAction", s_schema, sp_potentialaction },
    { "potentialUse", s_schema, sp_potentialuse },
    { "preOp", s_schema, sp_preop },
    { "predecessorOf", s_schema, sp_predecessorof },
    { "pregnancyCategory", s_schema, sp_pregnancycategory },
    { "pregnancyWarning", s_schema, sp_pregnancywarning },
    { "prepTime", s_schema, sp_preptime },
    { "preparation", s_schema, sp_preparation },
    { "prescribingInfo", s_schema, sp_prescribinginfo },
    { "prescriptionStatus", s_schema, sp_prescriptionstatus },
    { "previousItem", s_schema, sp_previousitem },
    { "previousStartDate", s_schema, sp_previousstartdate },
    { "price", s_schema, sp_price },
    { "priceComponent", s_schema, sp_pricecomponent },
    { "priceComponentType", s_schema, sp_pricecomponenttype },
    { "priceCurrency", s_schema, sp_pricecurrency },
    { "priceRange", s_schema, sp_pricerange },
    { "priceSpecification", s_schema, sp_pricespecification },
    { "priceType", s_schema, sp_pricetype },
    { "priceValidUntil", s_schema, sp_pricevaliduntil },
    { "primaryImageOfPage", s_schema, sp_primaryimageofpage },
    { "primaryPrevention", s_schema, sp_primaryprevention },
    { "printColumn", s_schema, sp_printcolumn },
    { "printEdition", s_schema, sp_printedition },
    { "printPage", s_schema, sp_printpage },
    { "printSection", s_schema, sp_printsection },
    { "procedure", s_schema, sp_procedure },
    { "procedureType", s_schema, sp_proceduretype },
    { "processingTime", s_schema, sp_processingtime },
    { "processorRequirements", s_schema, sp_processorrequirements },
    { "producer", s_schema, sp_producer },
    { "productGroupID", s_schema, sp_productgroupid },
    { "productID", s_schema, sp_productid },
    { "productSupported", s_schema, sp_productsupported },
    { "productionCompany", s_schema, sp_productioncompany },
    { "productionDate", s_schema, sp_productiondate },
    { "proficiencyLevel", s_schema, sp_proficiencylevel },
    { "programMembershipUse", s_schema, sp_programmemembershipused },
    { "programName", s_schema, sp_programmename },
    { "programPrequisites", s_schema, sp_programprequisites },
    { "programType", s_schema, sp_programtype },
    { "programmingLanguage", s_schema, sp_programminglanguage },
    { "programmingModel", s_schema, sp_programmingmodel },
    { "propertyID", s_schema, sp_propertyid },
    { "propriatryName", s_schema, sp_propriatryname },
    { "proprietaryName", s_schema, sp_proprietaryname },
    { "proteinContent", s_schema, sp_proteincontent },
    { "provider", s_schema, sp_provider },
    { "providerMobility", s_schema, sp_providermobility },
    { "providesBroadcastService", s_schema, sp_providesbroadcastservice },
    { "providesService", s_schema, sp_providesservice },
    { "publicAccess", s_schema, sp_publicaccess },
    { "publicTransportClosuresInfo", s_schema, sp_publictransportclosuresinfo },
    { "publication", s_schema, sp_publication },
    { "publicationType", s_schema, sp_publicationtype },
    { "publishedBy", s_schema, sp_publishedby },
    { "publishedOn", s_schema, sp_publishedon },
    { "publisher", s_schema, sp_publisher },
    { "publisherImprint", s_schema, sp_publisherimprint },
    { "publishingPrinciples", s_schema, sp_publishingprinciples },
    { "purchaseDate", s_schema, sp_purchasedate },
    { "purpose", s_schema, sp_purpose },
    { "qualifications", s_schema, sp_qualifications },
    { "quarantineGuidelines", s_schema, sp_quarantineguidelines },
    { "query", s_schema, sp_query },
    { "quest", s_schema, sp_quest },
    { "question", s_schema, sp_question },
    { "rangeIncludes", s_schema, sp_rangeincludes },
    { "ratingCount", s_schema, sp_ratingcount },
    { "ratingExplanation", s_schema, sp_ratingexplanation },
    { "ratingValue", s_schema, sp_ratingvalue },
    { "readBy", s_schema, sp_readby },
    { "readonlyValue", s_schema, sp_readonlyvalue },
    { "realEstateAgent", s_schema, sp_realestateagent },
    { "recipe", s_schema, sp_recipe },
    { "recipeCategory", s_schema, sp_recipecategory },
    { "recipeCuisine", s_schema, sp_recipecuisine },
    { "recipeIngredient", s_schema, sp_recipeingredient },
    { "recipeInstructions", s_schema, sp_recipeinstructions },
    { "recipeYield", s_schema, sp_recipeyield },
    { "recipient", s_schema, sp_recipient },
    { "recognisedBy", s_schema, sp_recognisedby },
    { "recognisingAuthority", s_schema, sp_recognisingauthority },
    { "recommendationStrength", s_schema, sp_recommendationstrength },
    { "recommendedIntake", s_schema, sp_recommendedintake },
    { "recordLabel", s_schema, sp_recordlabel },
    { "recordedAs", s_schema, sp_recordedas },
    { "recordedAt", s_schema, sp_recordedat },
    { "recordedIn", s_schema, sp_recordedin },
    { "recordingOf", s_schema, sp_recordingof },
    { "recourseLoan", s_schema, sp_recourseloan },
    { "referenceQuantity", s_schema, sp_referencequantity },
    { "referencesOrder", s_schema, sp_referencesorder },
    { "refundType", s_schema, sp_refundtype },
    { "regionDrained", s_schema, sp_regiondrained },
    { "regionsAllowed", s_schema, sp_regionsallowed },
    { "relatedAnatomy", s_schema, sp_relatedanatomy },
    { "relatedCondition", s_schema, sp_relatedcondition },
    { "relatedDrug", s_schema, sp_relateddrug },
    { "relatedLink", s_schema, sp_relatedlink },
    { "relatedStructure", s_schema, sp_relatedstructure },
    { "relatedTherapy", s_schema, sp_relatedtherapy },
    { "relatedTo", s_schema, sp_relatedto },
    { "releaseDate", s_schema, sp_releasedate },
    { "releaseNotes", s_schema, sp_releasenotes },
    { "releaseOf", s_schema, sp_releaseof },
    { "releasedEvent", s_schema, sp_releasedevent },
    { "relevantOccupation", s_schema, sp_relevantoccupation },
    { "relevantSpeciality", s_schema, sp_relevantspeciality },
    { "remainingAttendeeCapacity", s_schema, sp_remainingattendeecapacity },
    { "renegotiableLoan", s_schema, sp_renegotiableloan },
    { "repeatCount", s_schema, sp_repeatcount },
    { "repeatFrequency", s_schema, sp_repeatfrequency },
    { "repetitions", s_schema, sp_repetitions },
    { "replacee", s_schema, sp_replacee },
    { "replacer", s_schema, sp_replacer },
    { "replyToUrl", s_schema, sp_replytourl },
    { "reportNumber", s_schema, sp_reportnumber },
    { "representativeOfPage", s_schema, sp_representativeofpage },
    { "requiredCollateral", s_schema, sp_requiredcollateral },
    { "requiredGender", s_schema, sp_requiredgender },
    { "requiredMaxAge", s_schema, sp_requiredmaxage },
    { "requiredMinAge", s_schema, sp_requiredminage },
    { "requiredQuantity", s_schema, sp_requiredquantity },
    { "requiresSubscription", s_schema, sp_requiressubscription },
    { "reservationFor", s_schema, sp_reservationfor },
    { "reservationId", s_schema, sp_reservationid },
    { "reservationStatus", s_schema, sp_reservationstatus },
    { "reservedTicket", s_schema, sp_reservedticket },
    { "restockingFee", s_schema, sp_restockingfee },
    { "responsibilities", s_schema, sp_responsibilities },
    { "restPeriods", s_schema, sp_restperiods },
    { "result", s_schema, sp_result },
    { "resultComment", s_schema, sp_resultcomment },
    { "resultReview", s_schema, sp_resultreview },
    { "returnFees", s_schema, sp_returnfees },
    { "returnLabelSource", s_schema, sp_returnlabelsource },
    { "returnMethod", s_schema, sp_returnmethod },
    { "returnPolicyCategory", s_schema, sp_returnpolicycategory },
    { "returnPolicyCountry", s_schema, sp_returnpolicycountry },
    { "returnPolicySeasonalOverride", s_schema, sp_returnpolicyseasonaloverride },
    { "returnShippingFeesAmount", s_schema, sp_returnshippingfeesamount },
    { "review", s_schema, sp_review },
    { "reviewAspect", s_schema, sp_reviewaspect },
    { "reviewBody", s_schema, sp_reviewbody },
    { "reviewCount", s_schema, sp_reviewcount },
    { "reviewRating", s_schema, sp_reviewrating },
    { "reviewedBy", s_schema, sp_reviewedby },
    { "riskFactor", s_schema, sp_riskfactor },
    { "risks", s_schema, sp_risks },
    { "roleName", s_schema, sp_rolename },
    { "roofLoad", s_schema, sp_roofload },
    { "rsvpResponse", s_schema, sp_rsvpresponse },
    { "runsTo", s_schema, sp_runsto },
    { "runtimePlatform", s_schema, sp_runtimeplatform },
    { "rxcui", s_schema, sp_rxcui },
    { "safetyConsideration", s_schema, sp_safetyconsideration },
    { "salaryCurrency", s_schema, sp_salarycurrency },
    { "salaryUponCompletion", s_schema, sp_salaryuponcompletion },
    { "sameAs", s_schema, sp_sameas },
    { "saturatedFatContent", s_schema, sp_saturatedfatcontent },
    { "scheduledPaymentDate", s_schema, sp_scheduledpaymentdate },
    { "scheduledTime", s_schema, sp_scheduledtime },
    { "schemaVersion", s_schema, sp_schemaversion },
    { "schoolClosuresInfo", s_schema, sp_schoolclosuresinfo },
    { "screenCount", s_schema, sp_screencount },
    { "screenshot", s_schema, sp_screenshot },
    { "sdDatePublished", s_schema, sp_sddatepublished },
    { "sdLicense", s_schema, sp_sdlicence },
    { "sdPublisher", s_schema, sp_sdpublisher },
    { "seasonNumber", s_schema, sp_seasonnumber },
    { "seatNumber", s_schema, sp_seatnumber },
    { "seatRow", s_schema, sp_seatrow },
    { "seatSection", s_schema, sp_seatsection },
    { "seatingCapacity", s_schema, sp_seatingcapacity },
    { "seatingType", s_schema, sp_seatingtype },
    { "secondaryPrevention", s_schema, sp_secondaryprevention },
    { "securityClearanceRequirement", s_schema, sp_securityclearancerequirement },
    { "securityScreening", s_schema, sp_securityscreening },
    { "seeks", s_schema, sp_seeks },
    { "seller", s_schema, sp_seller },
    { "sender", s_schema, sp_sender },
    { "sensoryClearanceRequirement", s_schema, sp_sensoryclearancerequirement },
    { "sensoryUnit", s_schema, sp_sensoryunit },
    { "serialNumber", s_schema, sp_serialnumber },
    { "seriousAdverseOutcome", s_schema, sp_seriousadverseoutcome },
    { "serverStatus", s_schema, sp_serverstatus },
    { "servesCuisine", s_schema, sp_servescuisine },
    { "serviceArea", s_schema, sp_servicearea },
    { "serviceLocation", s_schema, sp_servicelocation },
    { "serviceOperator", s_schema, sp_serviceoperator },
    { "serviceOutput", s_schema, sp_serviceoutput },
    { "servicePhone", s_schema, sp_servicephone },
    { "servicePostalAddress", s_schema, sp_servicepostaladdress },
    { "serviceSmsNumber", s_schema, sp_servicesmsnumber },
    { "serviceType", s_schema, sp_servicetype },
    { "serviceUrl", s_schema, sp_serviceurl },
    { "servingSize", s_schema, sp_servingsize },
    { "sha256", s_schema, sp_sha256 },
    { "sharedContent", s_schema, sp_sharedcontent },
    { "shippingDestination", s_schema, sp_shippingdestination },
    { "shippingLabel", s_schema, sp_shippinglabel },
    { "shippingRate", s_schema, sp_shippingrate },
    { "shippingSettingsLink", s_schema, sp_shippingsettingslink },
    { "sibling", s_schema, sp_sibling },
    { "signDetected", s_schema, sp_signdetected },
    { "signOrSymptom", s_schema, sp_signorsymptom },
    { "significance", s_schema, sp_significance },
    { "significantLink", s_schema, sp_significantlink },
    { "size", s_schema, sp_size },
    { "sizeGroup", s_schema, sp_sizegroup },
    { "sizeSystem", s_schema, sp_sizesystem },
    { "skills", s_schema, sp_skills },
    { "sku", s_schema, sp_sku },
    { "slogan", s_schema, sp_slogan },
    { "smiles", s_schema, sp_smiles },
    { "smokingAllowed", s_schema, sp_smokingallowed },
    { "sodiumContent", s_schema, sp_sodiumcontent },
    { "softwareAddOn", s_schema, sp_softwareaddon },
    { "softwareHelp", s_schema, sp_softwarehelp },
    { "softwareRequirements", s_schema, sp_softwarerequirements },
    { "softwareVersion", s_schema, sp_softwareversion },
    { "source", s_schema, sp_source },
    { "sourceOrganization", s_schema, sp_sourceorganisation },
    { "sourcedFrom", s_schema, sp_sourcedfrom },
    { "spatial", s_schema, sp_spatial },
    { "spatialCoverage", s_schema, sp_spatialcoverage },
    { "speakable", s_schema, sp_speakable },
    { "specialCommitments", s_schema, sp_specialcommitments },
    { "specialOpeningHoursSpecification", s_schema, sp_specialopeninghoursspecification },
    { "specialty", s_schema, sp_speciality },
    { "speechToTextMarkup", s_schema, sp_speechtotextmarkup },
    { "speed", s_schema, sp_speed },
    { "spokenByCharacter", s_schema, sp_spokenbycharacter },
    { "sponsor", s_schema, sp_sponsor },
    { "sport", s_schema, sp_sport },
    { "sportsActivityLocation", s_schema, sp_sportsactivitylocation },
    { "sportsEvent", s_schema, sp_sportsevent },
    { "sportsTeam", s_schema, sp_sportsteam },
    { "spouse", s_schema, sp_spouse },
    { "sscheduleTimezone", s_schema, sp_scheduletimezone },
    { "stage", s_schema, sp_stage },
    { "stageAsNumber", s_schema, sp_stageasnumber },
    { "starRating", s_schema, sp_starrating },
    { "startDate", s_schema, sp_startdate },
    { "startOffset", s_schema, sp_startoffset },
    { "startTime", s_schema, sp_starttime },
    { "status", s_schema, sp_status },
    { "steeringPosition", s_schema, sp_steeringposition },
    { "step", s_schema, sp_step },
    { "stepValue", s_schema, sp_stepvalue },
    { "steps", s_schema, sp_steps },
    { "storageRequirements", s_schema, sp_storagerequirements },
    { "streetAddress", s_schema, sp_streetaddress },
    { "strengthUnit", s_schema, sp_strengthunit },
    { "strengthValue", s_schema, sp_strengthvalue },
    { "structuralClass", s_schema, sp_structuralclass },
    { "study", s_schema, sp_study },
    { "studyDesign", s_schema, sp_studydesign },
    { "studyLocation", s_schema, sp_studylocation },
    { "studySubject", s_schema, sp_studysubject },
    { "stupidProperty", s_schema, sp_stupidproperty },
    { "subEvent", s_schema, sp_subevent },
    { "subOrganization", s_schema, sp_suborganisation },
    { "subReservation", s_schema, sp_subreservation },
    { "subStageSuffix", s_schema, sp_substagesuffix },
    { "subStructure", s_schema, sp_substructure },
    { "subTrip", s_schema, sp_subtrip },
    { "subjectOf", s_schema, sp_subjectof },
    { "subtitleLanguage", s_schema, sp_subtitlelanguage },
    { "subtype", s_schema, sp_subtype },
    { "successorOf", s_schema, sp_successorof },
    { "sugarContent", s_schema, sp_sugarcontent },
    { "suggestedAge", s_schema, sp_suggestedage },
    { "suggestedAnswer", s_schema, sp_suggestedanswer },
    { "suggestedGender", s_schema, sp_suggestedgender },
    { "suggestedMaxAge", s_schema, sp_suggestedmaxage },
    { "suggestedMeasurement", s_schema, sp_suggestedmeasurement },
    { "suggestedMinAge", s_schema, sp_suggestedminage },
    { "suitableForDiet", s_schema, sp_suitablefordiet },
    { "superEvent", s_schema, sp_superevent },
    { "supersededBy", s_schema, sp_supersededby },
    { "supply", s_schema, sp_supply },
    { "supplyTo", s_schema, sp_supplyto },
    { "supportingData", s_schema, sp_supportingdata },
    { "suspersededBy", s_schema, sp_suspersededby },
    { "target", s_schema, sp_target },
    { "targetCollection", s_schema, sp_targetcollection },
    { "targetDescription", s_schema, sp_targetdescription },
    { "targetName", s_schema, sp_targetname },
    { "targetPlatform", s_schema, sp_targetplatform },
    { "targetPopulation", s_schema, sp_targetpopulation },
    { "targetUrl", s_schema, sp_targeturl },
    { "taxID", s_schema, sp_taxid },
    { "taxonRank", s_schema, sp_taxonrank },
    { "teaches", s_schema, sp_teaches },
    { "telephone", s_schema, sp_telephone },
    { "temporal", s_schema, sp_temporal },
    { "temporalCoverage", s_schema, sp_temporalcoverage },
    { "termCode", s_schema, sp_termcode },
    { "termDuration", s_schema, sp_termduration },
    { "termsOfService", s_schema, sp_termsofservice },
    { "termsPerYear", s_schema, sp_termsperyear },
    { "text", s_schema, sp_text },
    { "textValue", s_schema, sp_textvalue },
    { "thumbnail", s_schema, sp_thumbnail },
    { "thumbnailUrl", s_schema, sp_thumbnailurl },
    { "tickerSymbol", s_schema, sp_tickersymbol },
    { "ticketNumber", s_schema, sp_ticketnumber },
    { "ticketToken", s_schema, sp_tickettoken },
    { "ticketedSeat", s_schema, sp_ticketedseat },
    { "timeOfDay", s_schema, sp_timeofday },
    { "timeRequired", s_schema, sp_timerequired },
    { "timeToComplete", s_schema, sp_timetocomplete },
    { "tissueSample", s_schema, sp_tissuesample },
    { "title", s_schema, sp_title },
    { "titleEIDR", s_schema, sp_titleeidr },
    { "toLocation", s_schema, sp_tolocation },
    { "toRecipient", s_schema, sp_torecipient },
    { "tocContinuation", s_schema, sp_toccontinuation },
    { "tocEntry", s_schema, sp_tocentry },
    { "tongueWeight", s_schema, sp_tongueweight },
    { "tool", s_schema, sp_tool },
    { "torque", s_schema, sp_torque },
    { "totalJobOpenings", s_schema, sp_totaljobopenings },
    { "totalPaymentDue", s_schema, sp_totalpaymentdue },
    { "totalPrice", s_schema, sp_totalprice },
    { "totalTime", s_schema, sp_totaltime },
    { "tourBookingPage", s_schema, sp_tourbookingpage },
    { "touristType", s_schema, sp_touristtype },
    { "track", s_schema, sp_track },
    { "trackingNumber", s_schema, sp_trackingnumber },
    { "trackingUrl", s_schema, sp_trackingurl },
    { "trailer", s_schema, sp_trailer },
    { "trailerWeight", s_schema, sp_trailerweight },
    { "trainName", s_schema, sp_trainname },
    { "trainNumber", s_schema, sp_trainnumber },
    { "trainingSalary", s_schema, sp_trainingsalary },
    { "transFatContent", s_schema, sp_transfatcontent },
    { "transcript", s_schema, sp_transcript },
    { "transitTime", s_schema, sp_transittime },
    { "transitTimeLabel", s_schema, sp_transittimelabel },
    { "translationOfWork", s_schema, sp_translationofwork },
    { "translator", s_schema, sp_translator },
    { "transmissionMethod", s_schema, sp_transmissionmethod },
    { "travelBans", s_schema, sp_travelbans },
    { "trialDesign", s_schema, sp_trialdesign },
    { "tributary", s_schema, sp_tributary },
    { "typeOfBed", s_schema, sp_typeofbed },
    { "typeOfGood", s_schema, sp_typeofgood },
    { "typicalAgeRange", s_schema, sp_typicalagerange },
    { "typicalCreditsPerTerm", s_schema, sp_typicalcreditsperterm },
    { "typicalTest", s_schema, sp_typicaltest },
    { "underName", s_schema, sp_undername },
    { "unitCode", s_schema, sp_unitcode },
    { "unitText", s_schema, sp_unittext },
    { "unnamedSourcesPolicy", s_schema, sp_unnamedsourcespolicy },
    { "unsaturatedFatContent", s_schema, sp_unsaturatedfatcontent },
    { "uploadDate", s_schema, sp_uploaddate },
    { "upvoteCount", s_schema, sp_upvotecount },
    { "url", s_schema, sp_url },
    { "urlTemplate", s_schema, sp_urltemplate },
    { "usageInfo", s_schema, sp_usageinfo },
    { "usedToDiagnose", s_schema, sp_usedtodiagnose },
    { "userInteractionCount", s_schema, sp_userinteractioncount },
    { "usesDevice", s_schema, sp_usesdevice },
    { "usesHealthPlanIdStandard", s_schema, sp_useshealthplanidstandard },
    { "utterances", s_schema, sp_utterances },
    { "validFor", s_schema, sp_validfor },
    { "validFrom", s_schema, sp_validfrom },
    { "validIn", s_schema, sp_validin },
    { "validThrough", s_schema, sp_validthrough },
    { "validUntil", s_schema, sp_validuntil },
    { "value", s_schema, sp_value },
    { "valueAddedTaxIncluded", s_schema, sp_valueaddedtaxincluded },
    { "valueMaxLength", s_schema, sp_valuemaxlength },
    { "valueMinLength", s_schema, sp_valueminlength },
    { "valueName", s_schema, sp_valuename },
    { "valuePattern", s_schema, sp_valuepattern },
    { "valueReference", s_schema, sp_valuereference },
    { "valueRequired", s_schema, sp_valuerequired },
    { "variableMeasured", s_schema, sp_variablemeasured },
    { "variablesMeasured", s_schema, sp_variablesmeasured },
    { "variantCover", s_schema, sp_variantcover },
    { "variesBy", s_schema, sp_variesby },
    { "vatID", s_schema, sp_vatid },
    { "vehicleConfiguration", s_schema, sp_vehicleconfiguration },
    { "vehicleEngine", s_schema, sp_vehicleengine },
    { "vehicleIdentificationNumber", s_schema, sp_vehicleidentificationnumber },
    { "vehicleInteriorColor", s_schema, sp_vehicleinteriorcolour },
    { "vehicleInteriorType", s_schema, sp_vehicleinteriortype },
    { "vehicleModelDate", s_schema, sp_vehiclemodeldate },
    { "vehicleSeatingCapacity", s_schema, sp_vehicleseatingcapacity },
    { "vehicleSpecialUsage", s_schema, sp_vehiclespecialusage },
    { "vehicleTransmission", s_schema, sp_vehicletransmission },
    { "verificationFactCheckingPolicy", s_schema, sp_verificationfactcheckingpolicy },
    { "version", s_schema, sp_version },
    { "video", s_schema, sp_video },
    { "videoFormat", s_schema, sp_videoformat },
    { "videoFrameSize", s_schema, sp_videoframesize },
    { "videoQuality", s_schema, sp_videoquality },
    { "volumeNumber", s_schema, sp_volumenumber },
    { "warning", s_schema, sp_warning },
    { "warranty", s_schema, sp_warranty },
    { "warrantyScope", s_schema, sp_warrantyscope },
    { "webCheckInTime", s_schema, sp_webcheckintime },
    { "webFeed", s_schema, sp_webfeed },
    { "weight", s_schema, sp_weight },
    { "weightTotal", s_schema, sp_weighttotal },
    { "wheelbase", s_schema, sp_wheelbase },
    { "width", s_schema, sp_width },
    { "winner", s_schema, sp_winner },
    { "wordCount", s_schema, sp_wordcount },
    { "workExample", s_schema, sp_workexample },
    { "workFeatured", s_schema, sp_workfeatured },
    { "workHours", s_schema, sp_workhours },
    { "workLocation", s_schema, sp_worklocation },
    { "workPerformed", s_schema, sp_workperformed },
    { "workPresented", s_schema, sp_workpresented },
    { "workTranslation", s_schema, sp_worktranslation },
    { "workload", s_schema, sp_workload },
    { "worksFor", s_schema, sp_worksfor },
    { "worstRating", s_schema, sp_worstrating },
    { "xpath", s_schema, sp_xpath },
    { "yearBuilt", s_schema, sp_yearbuilt },
    { "yearlyRevenue", s_schema, sp_yearlyrevenue },
    { "yearsInOperation", s_schema, sp_yearsinoperation },
    { "yield", s_schema, sp_yield },

    // WDRS
    { "describedby", s_wdrs, wdrs_describedby },

    // living standard
    { "author", s_whatwg, wp_author },
    { "license", s_whatwg, wp_license },
    { "title", s_whatwg, wp_title },
    { "work", s_whatwg, wp_work },

    { nullptr, s_none, sp_illegal } };

typedef ssc_mm < ::std::string, property_name* > mpn_t;
typedef ssc_map < e_schema_property, property_name* > mnp_t;
mpn_t mpn;
mnp_t mnp;

void schema_name_init (nitpick& nits)
{   PRESUME (mpn.empty (), __FILE__, __LINE__);
    PRESUME (mnp.empty (), __FILE__, __LINE__);
    for (property_name* p = &namtab [0]; p -> prop_ != sp_illegal; ++p)
        if (p -> name_ != nullptr)
        {   ::std::string n (::boost::to_lower_copy (::std::string (p -> name_)));
            for (mpn_t::const_iterator ci = mpn.find (n); (ci != mpn.cend ()) && compare_no_case (ci -> first, n); ++ci)
                if (ci -> second -> root_ == p -> root_)
                {   nits.pick (nit_symbol_aleady_defined, es_catastrophic, ec_init, "property name ", n, " (", p -> root_, ") defined more than once");
                    break; }
            auto i = mnp.find (p -> prop_);
            if (i != mnp.cend ())
            {   nits.pick (nit_symbol_aleady_defined, es_splurge, ec_init, "property ", p -> prop_, " ('", i -> second -> name_, "', '", p -> name_, "') has many names");
                mpn.insert (mpn_t::value_type (n, p)); }
            else
            {   mpn.insert (mpn_t::value_type (n, p));
                mnp.insert (mnp_t::value_type (p -> prop_, p)); } } }

::std::string schema_property_name (const e_schema_property p)
{   mnp_t::const_iterator i = mnp.find (p);
    if (i == mnp.cend ()) return ::std::string ();
    return i -> second -> name_; }

e_schema_property get_schema_property (const ::std::string& s)
{   mpn_t::const_iterator i = mpn.find (s);
    if (i == mpn.cend ()) return sp_illegal;
    VERIFY_NOT_NULL (i -> second, __FILE__, __LINE__);
    return i -> second -> prop_; }

vsp_t get_schema_properties (const ::std::string& s, const e_schema root)
{   vsp_t res;
    for (mpn_t::const_iterator i = mpn.find (s); (i != mpn.cend ()) && compare_no_case (i -> first, s); ++i)
        if ((root == s_none) || (root == i -> second -> root_))
        {   VERIFY_NOT_NULL (i -> second, __FILE__, __LINE__)
            res.emplace_back (i -> second -> prop_); }
    return res; }

e_schema get_property_root (const ::std::string& s)
{   mpn_t::const_iterator ci = mpn.find (s);
    if (ci == mpn.cend ()) return s_none;
    VERIFY_NOT_NULL (ci -> second, __FILE__, __LINE__);
    return ci -> second -> root_; }

e_schema get_property_root (const e_schema_property sp)
{   mnp_t::const_iterator ci = mnp.find (sp);
    if (ci == mnp.cend ()) return s_none;
    VERIFY_NOT_NULL (ci -> second, __FILE__, __LINE__);
    return ci -> second -> root_; }
