/*
ssc (static site checker)
Copyright (c) 2020,2021 Dylan Harris
https://dylanharris.org/

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public Licence as published by
the Free Software Foundation, either version 3 of the Licence, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public Licence for more details.

You should have received a copy of the GNU General Public
Licence along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#include "main/standard.h"
#include "symbol/nstr.h"

// some from:
// https://www.w3.org/TR/ttml-imsc1.0.1/#namespaces
// https://www.informit.com/articles/article.aspx?p=31837&seqNum=10

n_string_entry < e_namespace, 3 > namespace_name_entries [] =
{   { { XHTML_1_0 }, { HTML_UNDEF }, ns_bibo, 0, { "bibo", HTTP PURL_ORG "g/ontology/bibo/", "bibliographic ontology" } }, // https://github.com/structureddynamics/Bibliographic-Ontology-BIBO/blob/master/bibo.owl
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_cc, 0, { "cc", HTTP CC "/ns#", "creative commons" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_crs, 0, { "crs", HTTP OGC "/crs", "common reporting standard" } }, // https://www.oecd.org/tax/exchange-of-tax-information/common-reporting-standard-xml-schema-user-guide-for-tax-administrations-june-2019.pdf
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_dbp, 0, { "dbp", HTTP DBPEDIA "/property/", "dbpedia" } },  // https://www.dbpedia.org/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_dbp_owl, 0, { "dbp-owl", HTTP DBPEDIA "/ontology/", "dbpedia ontology" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_dbr, 0, { "dbr", HTTP DBPEDIA "/resource/", "dbpedia resources" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_dc, 0, { "dc", HTTP PURL_ORG "/dc/elements/1.1/", "dublin core" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_dcterms, 0, { "dcterms", HTTP PURL_ORG "/dc/terms/", "dublin core terms" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_dt, 0, { "dt", HTTP_W3 "/2001/XMLSchema-datatypes", "XML Schema Part 2 : datatypes" } },
    { { HTML_JUL15 }, { HTML_UNDEF }, ns_ebuttm, 0, { "ebuttm", "urn:ebu:tt:metadata", "european broadcasting union TECH 3380 (subtitles)" } },  // http://xmlns.com/foaf/spec/
    { { HTML_JUL15 }, { HTML_UNDEF }, ns_ebutts, 0, { "ebutts", "urn:ebu:tt:style", "european broadcasting union TECH 3380 (subtitles)" } },  // http://xmlns.com/foaf/spec/
    { { HTML_JAN05 }, { HTML_UNDEF }, ns_err, 0, { "err", HTTP_W3 "/2005/xqt-errirs", "xqt errors" } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_ex, 0, { "ex", HTTP DEFAULT_DOMAIN "/", "example" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_exsl, 0, { "exsl", "http://xmlns.opentechnology.org/xslt-extensions/common", "Extensions to XSLT 1.0" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_exsl, 0, { "exsl", "http://xmlns.opentechnology.org/xslt-extensions/functions", "Extensions to XSLT 1.0 (functions)" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_exsl, 0, { "exsl", "http://xmlns.opentechnology.org/xslt-extensions/math", "Extensions to XSLT 1.0 (math)" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_exsl, 0, { "exsl", "http://xmlns.opentechnology.org/xslt-extensions/sets", "Extensions to XSLT 1.0 (sets)" } },
    { { HTML_JAN05 }, { HTML_UNDEF }, ns_fn, 0, { "fn", HTTP_W3 "/2005/xpath-functions", "XPath functions" } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_fo, 0, { "fo", HTTP_W3 "/1999/XSL/Format", "XSL Formatting Objects" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_foaf, 0, { "foaf", HTTP XCOM "/foaf/0.1/", "friend of a friend" } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_html, NS_DEFAULT, { "html", HTTP_W3 "/1999/html", "hypertext markup language"  } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_ims, 0, { "ims", "http://www.imsglobal.org/xsd/imsmd_v1p2", "IMS Global Learning Consortium"  } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_ims, 0, { "ims", "http://www.imsglobal.org/xsd/imsmd_v1p2p2", "IMS Global Learning Consortium"  } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_ims, 0, { "ims", "http://www.imsglobal.org/xsd/imsmd_v1p2p4", "IMS Global Learning Consortium"  } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_ims, 0, { "ims", "http://www.imsglobal.org/xsd/imsmd_v1p3", "IMS Global Learning Consortium"  } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_ims, 0, { "ims", "http://www.imsglobal.org/xsd/imsmd_v1p3p2", "IMS Global Learning Consortium"  } },  // http://xmlns.com/foaf/spec/
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_its, 0, { "its", HTTP_W3 "/2005/11/its", "internationalisation tag set" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittm, 0, { "ittm", HTTP_W3 "/ns/ttml/profile/imsc1#metadata", "IMCS metadata" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittp, 0, { "ittp", HTTP_W3 "/ns/ttml/profile/imsc1#parameter", "IMCS parameter" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_itts, 0, { "itts", HTTP_W3 "/ns/ttml/profile/imsc1#styling", "IMCS styling" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittx, 0, { "ittx", HTTP_W3 "/ns/ttml/profile/imsc1/extension/", "IMCS extension" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittxi, 0, { "ittxi", HTTP_W3 "/ns/ttml/profile/imsc1/image", "IMCS image extension" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittxt, 0, { "ittxt", HTTP_W3 "/ns/ttml/profile/imsc1/text", "IMCS text extension" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittm, 0, { "ittm", HTTP_W3 "/ns/ttml", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittm, 0, { "ittp", HTTP_W3 "/ns/ttml#parameter", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittm, 0, { "itts", HTTP_W3 "/ns/ttml#styling", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittm, 0, { "ittx", HTTP_W3 "/ns/ttml/feature/", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittm, 0, { "ittxi", HTTP_W3 "/ns/ttml", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ittm, 0, { "ittxt", HTTP_W3 "/ns/ttml", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_MATH1 }, { HTML_UNDEF }, ns_math, 0, { "math", HTTP_W3 "/1998/Math/MathML", "mathML" } },
    { { HTML_MATH1 }, { HTML_UNDEF }, ns_math, 0, { "m", HTTP_W3 "/1998/Math/MathML", "mathML" } },
    { { HTML_MATH1 }, { HTML_UNDEF }, ns_math, 0, { "mml", HTTP_W3 "/1998/Math/MathML", "mathML" } },
    { { HTML_OWL10 }, { HTML_UNDEF }, ns_odd, 0, { "odd", "http://odrl.net/1.0/ODRL-DD", "Open Digital Rights Language" } },
    { { HTML_OWL10 }, { HTML_UNDEF }, ns_oex, 0, { "oex", "http://odrl.net/1.0/ODRL-EX", "Open Digital Rights Language" } },
    { { HTML_OWL10 }, { HTML_UNDEF }, ns_owl, 0, { "owl", HTTP_W3 "/2002/07/owl#", "Web Ontology Language 1.0" } }, // http://xmlns.com/foaf/spec/ too
    { { HTML_OWL11 }, { HTML_UNDEF }, ns_owl, 0, { "owl11", HTTP_W3 "/2006/12/owl11#", "Web Ontology Language 1.1" } }, // http://xmlns.com/foaf/spec/ too
    { { HTML_OWL11 }, { HTML_UNDEF }, ns_owlxml, 0, { "owl11xml", HTTP_W3 "/2006/12/owl11-xml#", "Web Ontology Language 1.1 XML" } }, // http://xmlns.com/foaf/spec/ too
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_rddl, 0, { "rddl", "http://www.rddl.org/", "resource directory description language" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_rdf, 0, { "rdf", HTTP_W3 "/1999/02/22-rdf-syntax-ns#", "resource description framework" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_rdfa, 0, { "rdfa", HTTP_W3 "/ns/rdfa#", "Resource Description Framework in Attributes" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_rdfs, 0, { "rdfs", HTTP_W3 "/2000/01/rdf-schema#", "Resource Description Framework Schema" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_saxon, 0, { "saxon", "http://icl.com/saxon", "Saxon XSLT Extensions" } }, // http://saxon.sourceforge.net/saxon6.5/extensions.html
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_smil, 0, { "smil", HTTP_W3 "/2001/SMIL20", "Synchronized Multimedia Integration Language" } },
    { { HTML_JAN13 }, { HTML_UNDEF }, ns_smpte, 0, { "smpte", "http://www.smpte-ra.org/schemas/2052-1/2013/smpte-tt", "Society of Motion Pictures and Television Engineers" } },
    { { HTML_SVG10 }, { HTML_UNDEF }, ns_svg, 0, { "svg", HTTP SVG_2000, "scalable vector graphics" } },
    { { HTML_TTML }, { HTML_UNDEF }, ns_tt, 0, { "tt", HTTP_W3 "/ns/ttml", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ttf, 0, { "ttf", HTTP_W3 "/ns/ttml#parameter", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_ttp, 0, { "ttp", HTTP_W3 "/ns/ttml#styling", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { HTML_TTML }, { HTML_UNDEF }, ns_tts, 0, { "tts", HTTP_W3 "/ns/ttml/feature/", "timed text markup language" } }, // https://en.wikipedia.org/wiki/Internationalization_Tag_Set
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xalan, 0, { "xalan", "http://xml.apache.org/xslt", "Xalan XSLT Extensions" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xalan, 0, { "lxslt", "http://xml.apache.org/xslt", "Xalan XSLT Extensions" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xf, 0, { "xf", HTTP_W3 "/2001/08/xquery-operators", "XQuery 1.0" } },
    { { HTML_XLINK10 }, { HTML_UNDEF }, ns_xlink, 0, { "xlink", HTTP_W3 "/1999/xlink", "XLink 1.0" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xhtml, NS_PREDECLARED, { XHTMLNS, HTTP_W3 "/1999/xhtml", "XHTML 1.0" } },
    { { XHTML_1_0, HV_DEPRECATEDX10 }, { HTML_UNDEF }, ns_xhtml, NS_DEPRECATED, { XHTMLNS, HTTP_W3 "/TR/xhtml1/strict", "XHTML 1.0" } },
    { { XHTML_1_0, HV_DEPRECATEDX10 }, { HTML_UNDEF }, ns_xhtml, NS_DEPRECATED, { XHTMLNS, HTTP_W3 "/TR/xhtml1/transitional", "XHTML 1.0" } },
    { { XHTML_1_0, HV_DEPRECATEDX10 }, { HTML_UNDEF }, ns_xhtml, NS_DEPRECATED, { XHTMLNS, HTTP_W3 "/TR/xhtml1/frameset", "XHTML 1.0" } },
    { { XHTML_1_1 }, { HTML_UNDEF }, ns_xhtml, NS_PREDECLARED, { XHTMLNS, HTTP_W3 "/2000/xhtml", "XHTML 1.1" } },
    { { XHTML_2_0 }, { HTML_UNDEF }, ns_xhtml, NS_PREDECLARED, { XHTMLNS, HTTP_W3 "/2004/xhtml", "XHTML 2.0" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xhv, 0, { "xhv", HTTP_W3 "/1999/xhtml/vocab#", "XHTML Vocabulary" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xi, 0, { "xi", HTTP_W3 "/2001/XInclude", "XML Merge" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xmlevents, 0, { "ev", HTTP_W3 "/2001/xml-events", "XML events" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xmlns, NS_UNDECLARABLE | NS_PREDECLARED, { XMLNS, HTTP_W3 "/2000/xmlns/", "XML namespace declaration" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xs, 0, { "xs", HTTP_W3 "/2001/XMLSchema#", "XML Schema Definition Language" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xs, 0, { "xsd", HTTP_W3 "/2001/XMLSchema", "XML Schema Definition Language" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xsi, 0, { "xsi", HTTP_W3 "/2001/XMLSchema-instance", "XML Schema Instance" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xslt, 0, { "xsl", HTTP_W3 "/1999/XSL/Transform", "XML Stylesheet Language Transformations" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xslt, 0, { "transform", HTTP_W3 "/1999/XSL/Transform", "XML Stylesheet Language Transformations" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_xtm, 0, { "xtm", "http://www.topicmaps.org/xtm/1.0/", "XML Topic Maps" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, ns_error, 0, { nullptr, nullptr, nullptr } } };

n_string_entry < e_protocol, 2 > protocol_name_entries [] =
{   { { HTML_TAGS }, { HTML_UNDEF }, pr_aaa, 0, { "aaa", "diameter" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_aaas, 0, { "aaas", "secure diameter" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_about, 0, { "about", "about" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_acap, 0, { "acap", "application configuration access" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_acct, 0, { "acct", "identifying user account" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_acr, 0, { "acr", "anonymous customer reference" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_adiumxtra, 0, { "adiumxtra", "adium xtra plugin" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_admin, 0, { "admin", "gnome virtual filesystem" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_afp, 0, { "afp", "apple file" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_afs, 0, { "afs", "andrew filesystem" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_aim, 0, { "aim", "aol instance messenger" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_apt, 0, { "apt", "advanced passenger train (not)" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_app, 0, { "app", "google container" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_attachment, 0, { "attachment", "MHTML attachment" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_aw, 0, { "aw", "active words" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_amss, 0, { "amss", "AMSS broadcast identifier" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_barian, 0, { "barian", "barion e-money wallet" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_beshare, 0, { "beshare", "beshare search query" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_bitcoin, 0, { "bitcoin", "climate change acceleration" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_blob, 0, { "blob", "binary data access" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_bolo, 0, { "bolo", "bolo game" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_callto, 0, { "callto", "skype call" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_cap, 0, { "cap", "calendr access" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_chrome, 0, { "chrome", "browser" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_chrome_extension, 0, { "chrome-extension", "browser settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_cid, 0, { "cid", "MIME component" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_clsid, 0, { "clsid", "class id" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_coap, 0, { "coap", "constrained application" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_coaps, 0, { "coaps", "secure constrained application" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_com_eventbrite_attendee, 0, { "com-eventbrite_attendee", "eventbrite attendee" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_content, 0, { "content", "android content provider" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_crid, 0, { "crid", "content reference identifier" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_cvs, 0, { "cvs", "concurrent version system" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dab, 0, { "dab", "DAB broadcast" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_data, 0, { "data", "data" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dav, 0, { "dav", "HTTP distributed authoring extension" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dict, 0, { "dict", "dictionary service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dina_playsingle, 0, { "dina-playsingle", "dina" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dina_playcontainer, 0, { "dina-playcontainer", "dina" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dns, 0, { "dns", "domain name service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dntp, 0, { "dntp", "direct network transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_doi, 0, { "doi", "digial object identifier" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_drm, 0, { "drm", "DRM broadcast identifier" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dtn, 0, { "dtn", "disruption tolerant networking" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_dvb, 0, { "dvb", "digital video broadcasting" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ed2k, 0, { "ed2k", "eDonkey 2000 resources" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_example, 0, { "example", "example" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_facetime, 0, { "facetime", "apple videoconference" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_fax, 0, { "fax", "telefacsimile" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_feed, 0, { "feed", "web feed subscription" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_file, 0, { "file", "local file" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_filesystem, 0, { "filesystem", "filesystem" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_finger, 0, { "finger", "finger user information" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_fish, 0, { "fish", "ssh file" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_fm, 0, { "fm", "FM identifier" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ftp, 0, { "ftp", "file transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ftps, 0, { "ftps", "secure file transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_gemini, 0, { "gemini", "distributed hypertext information" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_geo, 0, { "geo", "geolocation uri" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_gg, 0, { "gg", "gadu-gadu char" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_git, 0, { "git", "git repository" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_gizmoproject, 0, { "gizmoproject", "gizmo5 calling link" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_go, 0, { "go", "common name resolution" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_gopher, 0, { "gopher", "a distributed document" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_gtalk, 0, { "gtalk", "google chat" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_h323, 0, { "h323", "h323 multimedia" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_hcp, 0, { "hcp", "windows help" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_http, 0, { "http", "hypertext transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_https, 0, { "https", "secure hypertext transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_iax, 0, { "iax", "inter-asterisk exchange" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_icap, 0, { "icap", "internet common adaption" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_icon, 0, { "icon", "intensive care online network" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_im, 0, { "im", "instant messaging" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_imap, 0, { "imap", "email resource" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_info, 0, { "info", "information assets" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_iotdisco, 0, { "iotdisco", "internet of things identification" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ipn, 0, { "ipn", "ipn messaging" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ipp, 0, { "ipp", "internet printing" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ipps, 0, { "ipps", "secure internet printing" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_irc, 0, { "irc", "internet relay chat" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_irc6, 0, { "irc6", "ipv6 internet relay chat" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ircs, 0, { "ircs", "secure internet relay chat" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_iris, 0, { "iris", "internet registry information service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_iris_beep, 0, { "iris-beep", "internet registry information service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_iris_xpc, 0, { "iris-xpc", "internet registry information service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_iris_xpcs, 0, { "iris-xpcs", "internet registry information service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_iris_lws, 0, { "iris-lws", "internet registry information service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_itms, 0, { "itms", "itunes music store" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_jabber, 0, { "jabber", "talk talk" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_jar, 0, { "jar", "java archive" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_javascript, 0, { "javascript", "javascript" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_jdbc, 0, { "jdbc", "java database connectivity" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_jms, 0, { "jms", "java message service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_keyparc, 0, { "keyparc", "keyparc resource" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_lastfm, 0, { "lastfm", "lastfm radio stream" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ldap, 0, { "ldap", "ldap directory request" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ldaps, 0, { "ldaps", "secure ldap directory request" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_magnet, 0, { "magnet", "magnet links" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_mailserver, 0, { "mailserver", "mail server" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_mailto, 0, { "mailto", "SMTP email" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_maps, 0, { "maps", "maps links" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_market, 0, { "market", "google play" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_message, 0, { "message", "email message" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_mid, 0, { "mid", "mime content" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_mms, 0, { "mms", "windows streaming media" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_modem, 0, { "modem", "modem" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_help, 0, { "ms-help", "windows help" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings, 0, { "ms-settings", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_airplanemode, 0, { "ms-settings_airplanemode", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_bluetooth, 0, { "ms-settings_bluetooth", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_camera, 0, { "ms-settings_camera", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_cellular, 0, { "ms-settings_cellular", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_cloudstorage, 0, { "ms-settings_cloudstorage", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_emailandaccounts, 0, { "ms-settings_emailandaccounts", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_language, 0, { "ms-settings-language", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_location, 0, { "ms-settings_location", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_lock, 0, { "ms-settings_lock", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_nfctransactions, 0, { "ms-settings_nfctransactions", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_notifications, 0, { "ms-settings_notifications", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_power, 0, { "ms-settings_power", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_privacy, 0, { "ms-settings_privacy", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_proximity, 0, { "ms-settings_proximity", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_screenrotation, 0, { "ms-settings_screenrotation", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_wifi, 0, { "ms-settings_wifi", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ms_settings_workplace, 0, { "ms-settings_workplace", "windows settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_msnum, 0, { "msnum", "windows live messanger" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_msrp, 0, { "msrp", "message session relay" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_msrps, 0, { "msrps", "secure message session relay" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_mtqp, 0, { "mtqp", "message tracking query" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_mumble, 0, { "mumble", "mumber server" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_mupdate, 0, { "mupdate", "mailbox update" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_mvn, 0, { "mvn", "apache maven repository" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_news, 0, { "news", "usenet news" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_nfs, 0, { "nfs", "network file system" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ni, 0, { "ni", "naming things hash" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_nih, 0, { "nih", "naming things hash" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_nntp, 0, { "nntp", "network news transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_notes, 0, { "notes", "lotus notes" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ocsp, 0, { "ocsp", "online certificate status" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_odbc, 0, { "odbc", "open database connectivity" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_oid, 0, { "oid", "object identifier" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_opaquelocktoken, 0, { "opaquelocktoken", "opaque lock token" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_openpgp4fpr, 0, { "openpgp4fpr", "open pgp 4 public key" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_pack, 0, { "pack", "packaging" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_palm, 0, { "palm", "hp palm service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_paparazzi, 0, { "paparazzi", "paparazzi screenshot" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_payto, 0, { "payto", "payment target" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_pkcs11, 0, { "pkcs11", "public key 11" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_platform, 0, { "platform", "eclipse platform" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_pop, 0, { "pop", "post office" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_pres, 0, { "pres", "common profile for presence" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_prospero, 0, { "prospero", "prospero directory service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_proxy, 0, { "proxy", "proxy settings" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_psyc, 0, { "psyc", "synchronous conferencing" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_query, 0, { "query", "filestream query" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_redis, 0, { "redis", "redis database" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_rediss, 0, { "rediss", "secure redis database" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_reload, 0, { "reload", "resource location discovery" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_res, 0, { "res", "error page" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_resource, 0, { "resource", "resource mapping" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_rmi, 0, { "rmi", "rmi java object" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_rsync, 0, { "rsync", "remote synchronisation" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_rtmfp, 0, { "rtmfp", "real time media flow" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_rtmp, 0, { "rtmp", "realm time messaging" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_rtsp, 0, { "rtsp", "real time streaming" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_s3, 0, { "s3", "amazon s3 bucket" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_secondlife, 0, { "secondlife", "second life teleportation" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_service, 0, { "service", "service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_session, 0, { "session", "media resource control" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_sftp, 0, { "sftp", "secure file transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_sgn, 0, { "sgn", "social graph node mapper" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_shttp, 0, { "shttp", "secure hypertext transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_sieve, 0, { "sieve", "manage sieve" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_sip, 0, { "sip", "session initiation" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_sips, 0, { "sips", "secure session initiation" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_skype, 0, { "skype", "skype video conferencing" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_slack, 0, { "slack", "slack client" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_smb, 0, { "smb", "smb/cifs share" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_sms, 0, { "sms", "simple messaging service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_snews, 0, { "snews", "secure network news" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_snmp, 0, { "snmp", "simple network management" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_soap_beep, 0, { "soap-beep", "simple object access" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_soap_beeps, 0, { "soap-beeps", "simple object access" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_soldat, 0, { "soldat", "soldat gaming" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_spotify, 0, { "spotify", "spotify search" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ssh, 0, { "ssh", "secure shell" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_steam, 0, { "steam", "steam gaming" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_stratum, 0, { "stratum", "climate change acceleration" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_stun, 0, { "stun", "session transversal utilities" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_stuns, 0, { "stuns", "secure session transversal utilities" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_snv, 0, { "snv", "subversion source control" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_tag, 0, { "tag", "hashtag registry" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_teamspeak, 0, { "teamspeak", "team speak" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_tel, 0, { "tel", "telephone number" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_telnet, 0, { "telnet", "virtual terminal" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_tftp, 0, { "tftp", "trivial file transfer" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_things, 0, { "things", "internet of things" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_thismessage, 0, { "thismessage", "thismessage" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_tn3270, 0, { "tn3270", "3270 emulation" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_tip, 0, { "tip", "transaction internet" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_trueconf, 0, { "trueconf", "trueconf video conferencing" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_turn, 0, { "turn", "transversal using realys around NAT" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_turns, 0, { "turns", "secure transversal using realys around NAT" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_tv, 0, { "tv", "tv broadcast" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_udp, 0, { "udp", "user datagram" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_unreal, 0, { "unreal", "unreal (game)" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_urn, 0, { "urn", "uniform resource name" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ut2004, 0, { "ut2004", "unreal tournament 2004" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_vemmi, 0, { "vemmi", "versatile multimedia interface" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ventrilo, 0, { "ventrilo", "ventrilo voice over IP" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_videotex, 0, { "videotex", "videotex terminal" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_view_source, 0, { "view-source", "view source" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_vnc, 0, { "vnc", "virtual network computing" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_wais, 0, { "wais", "wide area information service" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_webcal, 0, { "webcal", "calendar subscription" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_webplus, 0, { "webplus", "living standard namespace" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ws, 0, { "ws", "web sockets" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_wss, 0, { "wss", "secure web sockets" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_wtai, 0, { "wtai", "wireless telephony application" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_wyciwyg, 0, { "wyciwyg", "what you cache is what you get" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_xcon, 0, { "xcon", "centralised conferencing" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_xcon_userid, 0, { "xcon-userid", "xcon" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_xfire, 0, { "xfire", "xfire instant messaging" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_xmlrpc_beep, 0, { "xmlrpc-beep", "xml rpc" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_xmlrpc_beeps, 0, { "xmlrpc-beeps", "xml rpc" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_xmpp, 0, { "xmpp", "extensib;e message presence" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_xri, 0, { "xri", "extensible resource identifier" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_ymsgr, 0, { "ymsgr", "yahoo contact" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_z39_50, 0, { "z39-50", "z39.50 information access" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_z39_50r, 0, { "z39-50r", "z39.50 retrieval" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_z39_50s, 0, { "z39-50s", "z39.50 session" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_zoommtg, 0, { "zoommtg", "zoom conferencing software" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_zoomus, 0, { "zoomus", "zoom conferencing software" } },
    { { HTML_TAGS }, { HTML_UNDEF }, pr_error, 0, { nullptr, nullptr } } };

n_string_entry < e_schema, 3 > schema_name_entries [] =
{   { { HTML_RDF10 }, { HTML_UNDEF }, s_article, 0, { "article", "http://ogp.me/ns/article#", "Open Graph Article" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_article, 0, { "article", "https://ogp.me/ns/article#", "Open Graph Article" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_as, SCHEMA_PREFIX_CONTEXT, { "as", HTTP_W3 "/ns/activitystreams#", "Activity Vocabulary" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_as, 0, { "as", HTTPS_W3 "/ns/activitystreams#", "Activity Vocabulary" } },
    { { HTML_RDF11 }, { HTML_UNDEF }, s_bibo, SCHEMA_PREFIX_CONTEXT, { "bibo", HTTP PURL_ORG  "/ontology/bibo/", "bibo" } },
    { { HTML_RDF11 }, { HTML_UNDEF }, s_bibo, 0, { "bibo", HTTPS PURL_ORG  "/ontology/bibo/", "bibo" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_book, 0, { "book", "http://ogp.me/ns/book#", "Open Graph Book" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_book, 0, { "book", "https://ogp.me/ns/book#", "Open Graph Book" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_cc, SCHEMA_PREFIX_CONTEXT, { "cc", "http://creativecommons.org/ns#", "creative commons" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_cc, 0, { "cc", "https://creativecommons.org/ns#", "creative commons" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_csvw, SCHEMA_PREFIX_CONTEXT, { "csvw", HTTP_W3 "/ns/csvw#", "csvw" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_csvw, 0, { "csvw", HTTPS_W3 "/ns/csvw#", "csvw" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ctag, SCHEMA_PREFIX_CONTEXT, { "ctag", "http://commontag.org/ns#", "ctag" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ctag, 0, { "ctag", "https://commontag.org/ns#", "ctag" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_dbp, SCHEMA_PREFIX_CONTEXT, { "dbp", HTTP DBPEDIA "/property/", "dbpedia" } },  // https://www.dbpedia.org/
    { { HTML_RDF10 }, { HTML_UNDEF }, s_dbp, 0, { "dbp", HTTPS DBPEDIA "/property/", "dbpedia" } },  // https://www.dbpedia.org/
    { { HTML_RDF11 }, { HTML_UNDEF }, s_dbp_owl, SCHEMA_PREFIX_CONTEXT, { "dbp-owl", HTTP DBPEDIA "/ontology/", "dbpedia" } },  // https://www.dbpedia.org/
    { { HTML_RDF11 }, { HTML_UNDEF }, s_dbp_owl, 0, { "dbp-owl", HTTPS DBPEDIA "/ontology/", "dbpedia" } },  // https://www.dbpedia.org/
    { { HTML_RDF10 }, { HTML_UNDEF }, s_dbr, SCHEMA_PREFIX_CONTEXT, { "dbr", HTTP DBPEDIA "/resource/", "dbpedia resources" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_dbr, 0, { "dbr", HTTPS DBPEDIA "/resource/", "dbpedia resources" } },
//    { { HTML_RDF10 }, { HTML_DEC10 }, s_dc, SCHEMA_PREFIX_CONTEXT, { "dc", HTTP PURL_ORG "/dc/", "dublin core elements" } },
//    { { HTML_RDF10 }, { HTML_DEC10 }, s_dc, 0, { "dc", HTTPS PURL_ORG "/dc/", "dublin core elements" } },
//    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dc, SCHEMA_PREFIX_CONTEXT, { "dc", HTTP PURL_ORG "/dc/terms/", "dublin core terms" } },
//    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dc, 0, { "dc", HTTPS PURL_ORG "/dc/terms/", "dublin core terms" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dc, SCHEMA_PREFIX_CONTEXT, { "dc11", HTTP PURL_ORG "/dc/elements/1.1/", "dublin core elements 1.1" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dc, 0, { "dc11", HTTPS PURL_ORG "/dc/elements/1.1/", "dublin core elements 1.1" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dcam, 0, { "dcam", HTTP PURL_ORG "/dc/dcam/", "dublin core vocabulary description" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dcam, 0, { "dcam", HTTPS PURL_ORG "/dc/dcam/", "dublin core vocabulary description" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dcat, SCHEMA_PREFIX_CONTEXT, { "dcat", HTTP_W3 "/ns/dcat#", "dcat" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dcat, 0, { "dcat", HTTPS_W3 "/ns/dcat#", "dcat" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dcmi, 0, { "dcmi", HTTP PURL_ORG "/dc/dcmitype/", "dcmi type vocabulary" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dcmi, 0, { "dcmi", HTTPS PURL_ORG "/dc/dcmitype/", "dcmi type vocabulary" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_dct, SCHEMA_PREFIX_CONTEXT, { "dcterms", HTTP PURL_ORG "/dc/terms/", "dublin core terms" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_dct, 0, { "dcterms", HTTPS PURL_ORG "/dc/terms/", "dublin core terms" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_dct, SCHEMA_PREFIX_CONTEXT, { "dc", HTTP PURL_ORG "/dc/terms/", "dublin core terms" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_dct, 0, { "dc", HTTPS PURL_ORG "/dc/terms/", "dublin core terms" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dqv, SCHEMA_PREFIX_CONTEXT, { "dqv", HTTP_W3 "/ns/dqv#", "dqv" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_dqv, 0, { "dqv", HTTPS_W3 "/ns/dqv#", "dqv" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_describedby, SCHEMA_PREFIX_CONTEXT, { "describedby", HTTP_W3 "/2007/05/powder-s#describedby", "describedby" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_describedby, 0, { "describedby", HTTPS_W3 "/2007/05/powder-s#describedby", "describedby" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_duv, SCHEMA_PREFIX_CONTEXT, { "duv", HTTP_W3 "/ns/duv#", "duv" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_duv, 0, { "duv", HTTPS_W3 "/ns/duv#", "duv" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_earl, SCHEMA_PREFIX_CONTEXT, { "earl", HTTP_W3 "/ns/earl#", "earl" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_earl, 0, { "earl", HTTPS_W3 "/ns/earl#", "earl" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_foaf, SCHEMA_PREFIX_CONTEXT, { "foaf", "http://xmlns.com/foaf/0.1/", "friend of a friend" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_foaf, 0, { "foaf", "https://xmlns.com/foaf/0.1/", "friend of a friend" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, s_frbr_core, 0, { "frbr_core", HTTP PURL_ORG "/vocab/frbr/core#", "frbr_core" } },  // https://vocab.org/
    { { XHTML_1_0 }, { HTML_UNDEF }, s_frbr_core, 0, { "frbr_core", HTTPS PURL_ORG "/vocab/frbr/core#", "frbr_core" } },  // https://vocab.org/
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_gr, SCHEMA_PREFIX_CONTEXT, { "gr", HTTP PURL_ORG "/goodrelations/v1#", "gr" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_gr, 0, { "gr", HTTPS PURL_ORG "/goodrelations/v1#", "gr" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_grddl, SCHEMA_PREFIX_CONTEXT, { "grddl", HTTP_W3 "/2003/g/data-view#", "grddl" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_grddl, 0, { "grddl", HTTPS_W3 "/2003/g/data-view#", "grddl" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ical, SCHEMA_PREFIX_CONTEXT, { "ical", HTTP_W3 "/2002/12/cal/ical#", "ical" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ical, 0, { "ical", HTTPS_W3 "/2002/12/cal/ical#", "ical" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_icaltzd, 0, { "icaltzd", HTTP_W3 "/2002/12/cal/icaltzd#", "icaltzd" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_icaltzd, 0, { "icaltzd", HTTPS_W3 "/2002/12/cal/icaltzd#", "icaltzd" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_jsonld, SCHEMA_PREFIX_CONTEXT, { "jsonld", HTTP_W3 "/ns/json-ld#", "jsonld" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_jsonld, 0, { "jsonld", HTTPS_W3 "/ns/json-ld#", "jsonld" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ldp, SCHEMA_PREFIX_CONTEXT, { "ldp", HTTP_W3 "/ns/ldp#", "ldp" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ldp, 0, { "ldp", HTTPS_W3 "/ns/ldp#", "ldp" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_licence, SCHEMA_PREFIX_CONTEXT, { "license", HTTP_W3 "/1999/xhtml/vocab#license", "licence" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_licence, 0, { "license", HTTPS_W3 "/1999/xhtml/vocab#license", "licence" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ma, SCHEMA_PREFIX_CONTEXT, { "ma", HTTP_W3 "/ns/ma-ont#", "ma" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ma, 0, { "ma", HTTPS_W3 "/ns/ma-ont#", "ma" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, s_microformats, 0, { "mf", HTTP_MF "/", "microformats" } },
    { { XHTML_1_0 }, { HTML_UNDEF }, s_microformats, 0, { "mf", HTTPS_MF "/", "microformats" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_music, 0, { "music", "http://ogp.me/ns/music#", "Open Graph Music" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_music, 0, { "music", "https://ogp.me/ns/music#", "Open Graph Music" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_oa, SCHEMA_PREFIX_CONTEXT, { "oa", HTTP_W3 "/ns/oa#", "oa" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_oa, 0, { "oa", HTTPS_W3 "/ns/oa#", "oa" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_odrl, SCHEMA_PREFIX_CONTEXT, { "odrl", HTTP_W3 "/ns/odrl2/", "odrl" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_odrl, 0, { "odrl", HTTPS_W3 "/ns/odrl2/", "odrl" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_og, SCHEMA_PREFIX_CONTEXT, { "og", "http://ogp.me/ns#", "og" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_og, 0, { "og", "https://ogp.me/ns#", "og" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_org, SCHEMA_PREFIX_CONTEXT, { "org", HTTP_W3 "/ns/org#", "Organisations" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_org, 0, { "org", HTTPS_W3 "/ns/org#", "Organisations" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_owl, SCHEMA_PREFIX_CONTEXT, { "owl", HTTP_W3 "/2002/07/owl#", "OWL" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_owl, 0, { "owl", HTTPS_W3 "/2002/07/owl#", "OWL" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_profile, 0, { "profile", "http://ogp.me/ns/profile#", "Open Graph Profile" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_profile, 0, { "profile", "https://ogp.me/ns/profile#", "Open Graph Profile" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_prov, SCHEMA_PREFIX_CONTEXT, { "prov", HTTP_W3 "/ns/prov#", "Provenance Vocabulary" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_prov, 0, { "prov", HTTPS_W3 "/ns/prov#", "Provenance Vocabulary" } },
    { { HTML_JAN17 }, { HTML_UNDEF }, s_poetry, SCHEMA_BESPOKE, { "poetry", "http://dylanharris.org/poetry/", "Poetry" } },
    { { HTML_JAN17 }, { HTML_UNDEF }, s_poetry, SCHEMA_BESPOKE, { "poetry", "https://dylanharris.org/poetry/", "Poetry" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_qb, SCHEMA_PREFIX_CONTEXT, { "qb", HTTP PURL_ORG "/linked-data/cube#", "Data Cubes" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_qb, 0, { "qb", HTTPS PURL_ORG "/linked-data/cube#", "Data Cubes" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_rdf, SCHEMA_PREFIX_CONTEXT, { "rdf", HTTP_W3 "/1999/02/22-rdf-syntax-ns#", "RDF" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_rdf, 0, { "rdf", HTTPS_W3 "/1999/02/22-rdf-syntax-ns#", "RDF" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_rdfa, SCHEMA_PREFIX_CONTEXT, { "rdfa", HTTP_W3 "/ns/rdfa#", "RDFa vocabulary" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_rdfa, 0, { "rdfa", HTTPS_W3 "/ns/rdfa#", "RDFa vocabulary" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_rdfs, SCHEMA_PREFIX_CONTEXT, { "rdfs", HTTP_W3 "/2000/01/rdf-schema#", "RDF Schema" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_rdfs, 0, { "rdfs", HTTPS_W3 "/2000/01/rdf-schema#", "RDF Schema" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_rev, SCHEMA_PREFIX_CONTEXT, { "rev", HTTP PURL_ORG "/stuff/rev#", "rev" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_rev, 0, { "rev", HTTPS PURL_ORG "/stuff/rev#", "rev" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_rif, SCHEMA_PREFIX_CONTEXT, { "rif", HTTP_W3 "/2007/rif#", "rif" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_rif, 0, { "rif", HTTPS_W3 "/2007/rif#", "rif" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_role, SCHEMA_PREFIX_CONTEXT, { "role", HTTP_W3 "/1999/xhtml/vocab#role", "role" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_role, 0, { "role", HTTPS_W3 "/1999/xhtml/vocab#role", "role" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_rr, SCHEMA_PREFIX_CONTEXT, { "rr", HTTP_W3 "/ns/r2rml#", "rr" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_rr, 0, { "rr", HTTPS_W3 "/ns/r2rml#", "rr" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_schema, SCHEMA_PREFIX_CONTEXT, { "schema", HTTP SCHEMA_ORG "/", "schema.org vocabulary" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_schema, 0, { "schema", HTTPS SCHEMA_ORG "/", "schema.org vocabulary" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_sd, SCHEMA_PREFIX_CONTEXT, { "sd", HTTP_W3 "/ns/parql-service-description#", "sd" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_sd, 0, { "sd", HTTPS_W3 "/ns/parql-service-description#", "sd" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_sioc, SCHEMA_PREFIX_CONTEXT, { "sioc", "http://rdfs.org/sioc/ns#", "sioc" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_sioc, 0, { "sioc", "https://rdfs.org/sioc/ns#", "sioc" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_skos, SCHEMA_PREFIX_CONTEXT, { "skos", HTTP_W3 "/2004/02/skos/core#", "skos" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_skos, 0, { "skos", HTTPS_W3 "/2004/02/skos/core#", "skos" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_skosxl, SCHEMA_PREFIX_CONTEXT, { "skosxl", HTTP_W3 "/2008/05/skos-xl#", "skosxl" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_skosxl, 0, { "skosxl", HTTPS_W3 "/2008/05/skos-xl#", "skosxl" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ssn, SCHEMA_PREFIX_CONTEXT, { "ssn", HTTP_W3 "/ns/ssn/", "ssn" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_ssn, 0, { "ssn", HTTPS_W3 "/ns/ssn/", "ssn" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_sosa, SCHEMA_PREFIX_CONTEXT, { "sosa", HTTP_W3 "/ns/sosa/", "sosa" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_sosa, 0, { "sosa", HTTPS_W3 "/ns/sosa/", "sosa" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_taxo, SCHEMA_PREFIX_CONTEXT, { "taxo", HTTP PURL_ORG "/rss/1.0/modules/taxonomy/", "taxonomy" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_taxo, 0, { "taxo", HTTPS PURL_ORG "/rss/1.0/modules/taxonomy/", "taxonomy" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_time, SCHEMA_PREFIX_CONTEXT, { "time", HTTP_W3 "/2006/time#", "time" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_time, 0, { "time", HTTPS_W3 "/2006/time#", "time" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_v, SCHEMA_PREFIX_CONTEXT, { "v", "http://rdf.data-vocabulary.org/#", "v" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_v, 0, { "v", "https://rdf.data-vocabulary.org/#", "v" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_vcard, SCHEMA_PREFIX_CONTEXT, { "vcard", HTTP_W3 "/2006/vcard/ns#", "vcard" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_vcard, 0, { "vcard", HTTPS_W3 "/2006/vcard/ns#", "vcard" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_video, 0, { "video", "http://ogp.me/ns/video#", "Open Graph Video" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_video, 0, { "video", "https://ogp.me/ns/video#", "Open Graph Video" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_void, SCHEMA_PREFIX_CONTEXT, { "void", HTTP RDFS_ORG "/ns/void#", "void" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_void, 0, { "void", HTTPS RDFS_ORG "/ns/void#", "void" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_wdr, SCHEMA_PREFIX_CONTEXT, { "wdr", HTTP_W3 "/2007/05/powder#", "Protocol for Web Description Resources" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_wdr, 0, { "wdr", HTTPS_W3 "/2007/05/powder#", "Protocol for Web Description Resources" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_wdrs, SCHEMA_PREFIX_CONTEXT, { "wdrs", HTTP_W3 "/2007/05/powder-s#", "Protocol for Web Description Resources" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_wdrs, 0, { "wdrs", HTTPS_W3 "/2007/05/powder-s#", "Protocol for Web Description Resources" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_website, 0, { "website", "http://ogp.me/ns/website#", "Open Graph Website" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_website, 0, { "website", "https://ogp.me/ns/website#", "Open Graph Website" } },
    { { HTML_JAN09 }, { HTML_UNDEF }, s_whatwg, 0, { "wwg", HTTP N_WHATWG_ORG "/", "HTTP Living Standard" } },
    { { HTML_JAN09 }, { HTML_UNDEF }, s_whatwg, 0, { "wwg", HTTPS N_WHATWG_ORG "/", "HTTP Living Standard" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_xhv, SCHEMA_PREFIX_CONTEXT, { "xhv", HTTP_W3 "/1999/xhtml/vocab#", "RDFa Core 1.1" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_xhv, 0, { "xhv", HTTPS_W3 "/1999/xhtml/vocab#", "RDFa Core 1.1" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_xml, SCHEMA_PREFIX_CONTEXT, { "xml", HTTP_W3 "/XML/1998/namespace", "Namespaces in XML 1.0" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_xml, 0, { "xml", HTTPS_W3 "/XML/1998/namespace", "Namespaces in XML 1.0" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_xsd, SCHEMA_PREFIX_CONTEXT, { "xsd", HTTP_W3 "/2001/XMLSchema#", "XML Schema Part 2" } },
    { { HTML_RDF10 }, { HTML_UNDEF }, s_xsd, 0, { "xsd", HTTPS_W3 "/2001/XMLSchema#", "XML Schema Part 2" } },
    { { HTML_RDF10_CON }, { HTML_UNDEF }, s_error, SCHEMA_PREFIX_CONTEXT, { nullptr, nullptr, nullptr } } };

namespace_names_t namespace_names;
protocol_names_t protocol_names;
schema_names_t schema_names;

void init_nstrs (nitpick& nits)
{   namespace_names.init (nits, &namespace_name_entries [0]);
    protocol_names.init (nits, &protocol_name_entries [0]);
    schema_names.init (nits, &schema_name_entries [0]); }
