/*
ssc (static site checker)
Copyright (c) 2020,2021 Dylan Harris
https://dylanharris.org/

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public Licence as published by
the Free Software Foundation, either version 3 of the Licence, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public Licence for more details.

You should have received a copy of the GNU General Public
Licence along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#include "main/standard.h"
#include "schema/schema_structure.h"
#include "schema/schema_property.h"
#include "main/context.h"

// only used for microformats
#define SS_REQUIRED         0x00000001
#define SS_REPEATABLE       0x00000002

struct microdata_structure
{   schema_version from_;
    schema_version to_;
    e_schema_type record_ = sty_context;
    e_schema_property property_ = sp_context;
    uint32_t flags_ = 0; };

microdata_structure schema_structure [] =
{   // common tag
    { { s_ctag, 1, 0 }, { 0, 0 }, ctag_tag, ctag_label },
    { { s_ctag, 1, 0 }, { 0, 0 }, ctag_tag, ctag_means },
    { { s_ctag, 1, 0 }, { 0, 0 }, ctag_tag, ctag_tagged },
    { { s_ctag, 1, 0 }, { 0, 0 }, ctag_tag, ctag_taggingdate },

    // dublin core terms
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agent, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_agentclass, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_bibliographicresource, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_fileformat, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_frequency, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_jurisdiction, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_licencedocument, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_linguisticsystem, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_location, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_locationperiodorjurisdiction, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatype, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_mediatypeorextent, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofaccrual, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_methodofinstruction, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_periodoftime, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalmedium, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_physicalresource, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_policy, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_provenancestatement, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_rightsstatement, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_sizeorduration, dct_valid },

    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_abstract },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_accessrights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_accrualmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_accrualperiodicity },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_accrualpolicy },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_alternative },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_audience },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_available },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_bibliographiccitation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_conformsto },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_contributor },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_coverage },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_created },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_creator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_date },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_dateaccepted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_datecopyrighted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_datesubmitted },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_description },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_educationlevel },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_extent },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_format },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_hasformat },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_haspart },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_hasversion },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_identifier },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_instructionalmethod },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_isformatof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_ispartof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_isreferencedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_isreplacedby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_isrequiredby },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_issued },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_isversionof },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_language },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_licence },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_mediator },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_medium },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_modified },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_provenance },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_publisher },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_references },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_relation },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_replaces },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_requires },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_rights },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_rightsholder },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_source },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_spatial },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_subject },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_tableofcontents },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_temporal },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_title },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_type },
    { { s_dct, 1, 0 }, { 0, 0 }, dct_standard, dct_valid },

    // foaf
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_account },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_age },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_aimchatid },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_birthday },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_holdsaccount },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_icqchatid },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_interest },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_jabberid },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_made },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_mbox },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_mboxsha1sum },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_msnchatid },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_openid },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_tipjar },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_topic_interest },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_skypeid },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_status },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_weblog },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_agent, foaf_yahoochatid },

    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_document, foaf_topic },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_document, foaf_primarytopic },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_document, foaf_sha1 },

    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_group, foaf_member },

    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_image, foaf_depicts },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_image, foaf_thumbnail },

    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_currentproject },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_familyname },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_firstname },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_geekcode },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_img },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_knows },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_lastname },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_myersbriggs },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_pastproject },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_publications },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_schoolhomepage },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_surname },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_thumbnail },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_workinfohomepage },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_person, foaf_workplacehomepage },

    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_onlineaccount, foaf_accountname },
    { { s_foaf, 0, 1 }, { 0, 0 }, foaf_onlineaccount, foaf_accountservicehomepage },

    // good relations
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_colour },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_condition },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_datatypeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_depth },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_hasbrand },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_hasean_ucc_13 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_hasgtin_14 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_hasgtin_8 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_hasmpn },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_hasmanufacturer },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_hasstockkeepingunit },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_height },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_isaccessoryorsparepartfor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_isconsumablefor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_issimilarto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_qualitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_quantitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_weight },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_actualproductorserviceinstance, gr_width },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_brand, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_brand, gr_name },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_hasbrand },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_hasduns },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_hasgloballocationnumber },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_hasisicv4 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_hasnaics },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_haspos },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_legalname },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_offers },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_owns },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_seeks },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_taxid },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentity, gr_vatid },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentitytype, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessentitytype, gr_name },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessfunction, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_businessfunction, gr_name },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_dayofweek, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_dayofweek, gr_hasnext },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_dayofweek, gr_hasprevious },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_dayofweek, gr_name },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_appliestodeliverymethod },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_eligibleregions },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_eligibletransactionvolume },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_hascurrency },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_hascurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_haseligiblequantity },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_hasmaxcurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_hasmincurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_validfrom },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_validto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverychargespecification, gr_valueaddedtaxincluded },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_colour },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_condition },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_datatypeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_depth },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_hasbrand },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_hasean_ucc_13 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_hasgtin_14 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_hasgtin_8 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_hasmpn },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_hasmakeandmodel },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_hasmanufacturer },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_hasstockkeepingunit },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_height },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_isaccessoryorsparepartfor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_isconsumablefor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_issimilarto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_qualitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_quantitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_serialnumber },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_weight },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_deliverymethod, gr_width },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_licence, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_licence, gr_eligibleduration },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_licence, gr_eligibleregions },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_licence, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_licence, gr_validfrom },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_licence, gr_validto },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_location, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_location, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_location, gr_hasgloballocationnumber },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_location, gr_hasisicv4 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_location, gr_hasopeninghoursspecification },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_location, gr_name },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_acceptedpaymentmethods },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_addon },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_advancebookingrequirement },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_availabilityends },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_availabilitystarts },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_availableatorfrom },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_availabledeliverymethods },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_condition },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_deliveryleadtime },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_eligiblecustomertypes },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_eligibleduration },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_eligibleregions },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_eligibletransactionvolume },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_hasbusinessfunction },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_hasean_ucc_13 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_haseligiblequantity },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_hasgtin_14 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_hasgtin_8 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_hasinventorylevel },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_hasmpn },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_haspricespecification },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_hasstockkeepingunit },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_haswarrantypromise },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_includes },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_includesobject },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_serialnumber },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_validfrom },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_offering, gr_validto },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_openinghoursspecification, gr_closes },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_openinghoursspecification, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_openinghoursspecification, gr_hasopeninghoursdayofweek },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_openinghoursspecification, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_openinghoursspecification, gr_opens },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_openinghoursspecification, gr_validfrom },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_openinghoursspecification, gr_validto },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_appliestopaymentmethod },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_eligibletransactionvolume },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_hascurrency },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_hascurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_haseligiblequantity },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_hasmaxcurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_hasmincurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_validfrom },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_validto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentchargespecification, gr_valueaddedtaxincluded },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentmethod, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_paymentmethod, gr_name },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_eligibletransactionvolume },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_hascurrency },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_hascurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_haseligiblequantity },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_hasmaxcurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_hasmincurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_validfrom },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_validto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_pricespecification, gr_valueaddedtaxincluded },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_colour },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_condition },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_datatypeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_depth },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_hasbrand },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_hasean_ucc_13 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_hasgtin_14 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_hasgtin_8 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_hasmpn },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_hasmanufacturer },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_hasstockkeepingunit },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_height },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_isaccessoryorsparepartfor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_isconsumablefor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_issimilarto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_qualitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_quantitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_weight },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservice, gr_width },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_colour },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_condition },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_datatypeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_depth },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_hasbrand },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_hasean_ucc_13 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_hasgtin_14 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_hasgtin_8 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_hasmpn },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_hasmakeandmodel },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_hasmanufacturer },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_hasstockkeepingunit },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_height },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_isaccessoryorsparepartfor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_isconsumablefor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_issimilarto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_isvariantof },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_predecessorof },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_qualitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_quantitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_serialnumber },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_successorof },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_weight },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_productorservicemodel, gr_width },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_colour },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_condition },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_datatypeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_depth },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_hasbrand },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_hasean_ucc_13 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_hasgtin_14 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_hasgtin_8 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_hasmpn },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_hasmanufacturer },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_hasstockkeepingunit },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_height },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_isaccessoryorsparepartfor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_isconsumablefor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_issimilarto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_qualitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_quantitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_weight },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_locationofsalesorserviceprovisioning, gr_width },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_equal },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_greater },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_greaterorequal },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_lesser },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_lesserorequal },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_nonequal },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_qualitativevalue, gr_valuereference },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalue, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalue, gr_hasmaxvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalue, gr_hasminvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalue, gr_hasunitofmeasurement },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalue, gr_hasvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalue, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalue, gr_valuereference },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_hasmaxvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_hasmaxvaluefloat },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_hasminvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_hasminvaluefloat },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_hasunitofmeasurement },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_hasvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_hasvaluefloat },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevaluefloat, gr_valuereference },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_hasmaxvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_hasmaxvalueinteger },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_hasminvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_hasminvalueinteger },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_hasunitofmeasurement },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_hasvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_hasvalueinteger },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_quantitativevalueinteger, gr_valuereference },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_category },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_colour },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_condition },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_datatypeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_depth },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasbrand },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasean_ucc_13 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasgtin_14 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasgtin_8 },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasinventorylevel },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasmpn },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasmakeandmodel },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasmanufacturer },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_hasstockkeepingunit },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_height },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_isaccessoryorsparepartfor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_isconsumablefor },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_issimilarto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_isvariantof },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_qualitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_quantitativeproductorserviceproperty },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_serialnumber },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_weight },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_someitems, gr_width },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_typeandquantitynode, gr_amountofgoods },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_typeandquantitynode, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_typeandquantitynode, gr_hasbusinessfunction },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_typeandquantitynode, gr_hasunitofmeasurement },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_typeandquantitynode, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_typeandquantitynode, gr_typeofgoods },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_billingincrement },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_eligibletransactionvolume },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_hascurrency },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_hascurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_haseligiblequantity },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_hasmaxcurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_hasmincurrencyvalue },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_hasunitofmeasurement },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_name },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_pricetype },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_validfrom },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_validto },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_unitpricespecification, gr_valueaddedtaxincluded },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_warrantypromise, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_warrantypromise, gr_durationofwarrantyinmonths },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_warrantypromise, gr_haswarrantyscope },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_warrantypromise, gr_name },

    { { s_gr, 1, 0 }, { 0, 0 }, gr_warrantyscope, gr_description },
    { { s_gr, 1, 0 }, { 0, 0 }, gr_warrantyscope, gr_name },

    // ical
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_action },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_attendee },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_byday },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_bymonth },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_caladdress },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_calscale },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_categories },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_class },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_cn },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_comment },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_component },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_cutype },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_date },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_datetime },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_daylight },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_description },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_dtend },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_dstamp },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_dtstart },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_duration },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_freq },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_interval },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_language },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_location },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_organiser },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_partstat },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_prodid },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_related },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_role },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_rrule },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_rsvp },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_sequence },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_standard },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_summary },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_transp },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_trigger },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_tzid },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_tzname },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_tzoffsetfrom },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_tzoffsetto },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_uid },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_valarm },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vevent, ical_version },

    { { s_ical, 1, 0 }, { 0, 0 }, ical_vtimezone, ical_tzid },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vtimezone, ical_tzname },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vtimezone, ical_tzoffsetfrom },
    { { s_ical, 1, 0 }, { 0, 0 }, ical_vtimezone, ical_tzoffsetto },

    // microformats v1
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_adr, mp_country_name },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_adr, mp_extended_address, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_adr, mp_locality },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_adr, mp_post_office_box, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_adr, mp_postal_code },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_adr, mp_region },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_adr, mp_street_address, SS_REPEATABLE },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_geo, mp_latitude }, // looks like MF only, not living standard, but ...
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_geo, mp_longitude }, // looks like MF only, not living standard, but ...

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haggregate, mp_best },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haggregate, mp_count },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haggregate, mp_item, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haggregate, mp_rating, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haggregate, mp_summary },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haggregate, mp_votes },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haggregate, mp_worst },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_author, SS_REQUIRED | SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_bookmark, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_category, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_entry_content, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_entry_summary, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_entry_title, SS_REQUIRED | SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_feed_category },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_hentry, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_label, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_published, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_tag, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_tags },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_term, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_updated, SS_REQUIRED | SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_value, SS_REPEATABLE }, // XMDP
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hatom, mp_value_title, SS_REPEATABLE }, // XMDP

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_album },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_amount },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_category, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_contributor },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_currency },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_description },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_duration },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_enclosure },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_fn },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_h },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_item },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_min },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_payment, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_position },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_photo, SS_REPEATABLE  },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_published },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_price },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_s },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_haudio, mp_sample, SS_REPEATABLE },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_attach },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_attendee },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_category },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_class },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_comment },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_contact },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_created },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_description },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_dtstart, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_dtend },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_duration },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_exdate },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_geo },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_last_modified },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_latitude },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_location },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_longitude },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_method }, // XMDP
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_organiser },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_partstat },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_rdate },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_role },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_resources },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_rrule },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_sequence },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_status },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_summary, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_transp },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_uid },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_url },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_value }, // XMDP
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcalendar, mp_value_title }, // XMDP

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_author, SS_REQUIRED | SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_bookmark, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_entry_content, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_entry_summary, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_entry_title, SS_REQUIRED | SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_published, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_tag, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_tags },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hentry, mp_updated, SS_REQUIRED | SS_REPEATABLE },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_amount },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_currency },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_description, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_dtlisted },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_dtexpired },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_info, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_item },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_lister, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_listing_action },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_location },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_permalink },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_price },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_summary },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_tag },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_tags, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_type },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hlisting, mp_version },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hmedia, mp_contributor, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hmedia, mp_enclosure, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hmedia, mp_fn, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hmedia, mp_photo },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hmedia, mp_player },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hnews, mp_dateline },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hnews, mp_entry },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hnews, mp_geo },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hnews, mp_hentry },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hnews, mp_item_licence },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hnews, mp_principles },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hnews, mp_source_org, SS_REQUIRED },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_availability },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_brand },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_category, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_description },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_fn, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_identifier },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_listing, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_photo, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_price },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_review, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hproduct, mp_url },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_author, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_duration, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_fn, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_h, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_ingredient, SS_REQUIRED | SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_instructions },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_licence, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_min, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_nutrition, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_photo, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_published },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_s, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_summary },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_tag, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_tags },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_type },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_value },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hrecipe, mp_yield },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_affliation, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_contact, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_education, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_experience, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_include },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_publications, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_skill, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_summary },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_value },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hresume, mp_value_title },

    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_best },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_description },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_dtreviewed },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_fn },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_item, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_licence },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_reviewer },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_permalink },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_photo },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_rating },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_self },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_summary },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_tag, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_tags },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_type },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_url },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_version },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_worst },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_value },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hreview, mp_value_title },

    // living standard / microformats
    // Note that the MF and Living Standard docs differ for a number of fields, but since the living standard
    // explicitly reference the MF definition (as http://microformats.org/profile/hcard), I've explicitly included
    // the MF fields.
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_additional_name, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_adr, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_agent, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_anniversary },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_bday },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_categories, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_category }, // looks like MF only, not living standard, but ...
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_class }, // looks like MF only, not living standard, but ...
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_country_name },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_email, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_extended_address, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_family_name, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_fn, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_gender_identity },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_geo, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_given_name, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_honourific_prefix, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_honourific_suffix, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_impp, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_key }, // looks like MF only, not living standard, but ...
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_kind },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_lang, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_latitude }, // looks like MF only, not living standard, but ...
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_locality },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_logo, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_longitude }, // looks like MF only, not living standard, but ...
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_mailer }, // looks like MF only, not living standard, but ...
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_member, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_n, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_nickname, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_note, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_org, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_organisation_name },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_organisation_unit, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_photo, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_post_office_box, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_postal_code },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_region },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_rel },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_related, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_rev, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_role, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_sex },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_sort_string },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_sound, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_street_address, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_tel, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_title, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_type, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_tz, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_uid },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_url, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_value },
    { { s_microformats, 1, 0 }, { 0, 0 }, mft_hcard, mp_value_title },

    // living standard
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_attach, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_categories, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_class },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_comment, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_contact, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_created },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_description },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_dtstart, SS_REQUIRED },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_dtend },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_duration },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_exdate, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_geo },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_last_modified },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_location },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_rdate, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_resources, SS_REPEATABLE },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_rrule },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_sequence },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_status },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_summary },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_transp },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_uid },
    { { s_microformats, 1, 0 }, { 0, 0 }, mf_vevent, mp_url },

    // microformats v2
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_altitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_country_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_extended_address },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_region },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_geo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_label },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_latitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_locality },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_longitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_post_office_box },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_postal_code },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hadr, mp2_p_street_address },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hbreadcrumb, mp2_h_breadcrumb },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hbreadcrumb, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hbreadcrumb, mp2_u_url },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_dt_anniversary },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_dt_bday },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_dt_rev },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_additional_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_adr },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_altitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_category },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_country_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_extended_address },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_family_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_region },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_gender_identity },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_geo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_given_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_honourific_prefix },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_honourific_suffix },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_job_title },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_label },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_latitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_locality },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_longitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_nickname },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_note },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_post_office_box },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_postal_code },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_org },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_organisation_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_organisation_unit },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_role },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_sex },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_sort_string },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_street_address },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_tel },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_p_tz },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_email },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_geo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_impp },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_logo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_key },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_photo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_sound },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_uid },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcard, mp2_u_url },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcite, mp2_dt_accessed },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcite, mp2_p_author },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcite, mp2_p_content },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcite, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcite, mp2_p_publication },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcite, mp2_dt_published },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcite, mp2_u_uid },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hcite, mp2_u_url },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_audio },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_author },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_bookmark_of },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_category },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_comment },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_e_content },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_duration },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_featured },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_in_reply_to },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_like },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_like_of },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_listen_of },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_latitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_location },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_longitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_photo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_dt_published },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_repost },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_repost_of },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_read_of },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_read_of },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_rsvp },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_size },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_p_summary },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_syndication },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_translation_of },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_uid },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_dt_updated },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_url },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_video },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hentry, mp2_u_watch_of },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_p_attendee },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_p_category },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_p_description },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_dt_duration },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_e_content },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_dt_end },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_p_location },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_dt_start },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_p_summary },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hevent, mp2_u_url },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hfeed, mp2_p_author },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hfeed, mp2_h_entry },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hfeed, mp2_p_entry },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hfeed, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hfeed, mp2_u_photo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hfeed, mp2_p_summary },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hfeed, mp2_u_url },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hgeo, mp2_p_altitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hgeo, mp2_p_latitude },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hgeo, mp2_p_longitude },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hitem, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hitem, mp2_u_photo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hitem, mp2_u_url },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hlisting, mp2_p_action },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hlisting, mp2_p_category },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hlisting, mp2_dt_expired },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hlisting, mp2_dt_listed },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hlisting, mp2_p_lister },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hlisting, mp2_p_price },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hlisting, mp2_u_url },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_p_brand },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_p_category },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_e_description },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_u_identifier },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_u_photo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_p_price },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_p_review },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hproduct, mp2_u_url },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_p_author },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_p_category },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_dt_duration },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_p_ingredient },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_e_instructions },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_p_nutrition },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_u_photo },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_dt_published },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_p_summary },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hrecipe, mp2_p_yield },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hresume, mp2_p_affiliation },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hresume, mp2_p_contact },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hresume, mp2_p_education },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hresume, mp2_p_experience },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hresume, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hresume, mp2_p_skill },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hresume, mp2_p_summary },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_author },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_best },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_category },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_e_content },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_dt_published },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_item },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_location },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_rating },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_summary },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_u_syndication },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_u_url },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_hreview, mp2_p_worst },

    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_haggregate, mp2_p_average },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_haggregate, mp2_p_best },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_haggregate, mp2_p_count },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_haggregate, mp2_p_item },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_haggregate, mp2_p_name },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_haggregate, mp2_p_votes },
    { { s_microformats, 2, 0 }, { 0, 0 }, mft2_haggregate, mp2_p_worst },

    // RDF / RDFs
    { { s_rdfs, 1, 0 }, { 0, 0 }, rdfs_class, rdfs_subclassof },
    { { s_rdf, 1, 0 }, { 0, 0 }, rdfs_class, rdf_type },

    { { s_rdf, 1, 0 }, { 0, 0 }, rdf_list, rdf_rest },

    { { s_rdfs, 1, 0 }, { 0, 0 }, rdf_property, rdfs_domain },
    { { s_rdfs, 1, 0 }, { 0, 0 }, rdf_property, rdfs_range },
    { { s_rdfs, 1, 0 }, { 0, 0 }, rdf_property, rdfs_subpropertyof },

    { { s_rdfs, 1, 0 }, { 0, 0 }, rdfs_resource, rdfs_comment },
    { { s_rdf, 1, 0 }, { 0, 0 }, rdfs_resource, rdf_first },
    { { s_rdfs, 1, 0 }, { 0, 0 }, rdfs_resource, rdfs_isdefinedby },
    { { s_rdfs, 1, 0 }, { 0, 0 }, rdfs_resource, rdfs_label },
    { { s_rdfs, 1, 0 }, { 0, 0 }, rdfs_resource, rdfs_member },
    { { s_rdf, 1, 0 }, { 0, 0 }, rdfs_resource, rdf_object },
    { { s_rdf, 1, 0 }, { 0, 0 }, rdfs_resource, rdf_predicate },
    { { s_rdfs, 1, 0 }, { 0, 0 }, rdfs_resource, rdfs_seealso },
    { { s_rdf, 1, 0 }, { 0, 0 }, rdfs_resource, rdf_subject },
    { { s_rdf, 1, 0 }, { 0, 0 }, rdfs_resource, rdf_value },

    // schema.org
    { { 6, 0 }, { 0, 0 }, sch_3dmodel, sp_isresizable },

    { { 5, 0 }, { 0, 0 }, sch_accommodation, sp_accommodationcategory },
    { { 6, 0 }, { 0, 0 }, sch_accommodation, sp_accommodationfloorplan },
    { { 3, 1 }, { 0, 0 }, sch_accommodation, sp_amenityfeature },
    { { 5, 0 }, { 0, 0 }, sch_accommodation, sp_floorlevel },
    { { 3, 1 }, { 0, 0 }, sch_accommodation, sp_floorsize },
    { { 5, 0 }, { 0, 0 }, sch_accommodation, sp_leaselength },
    { { 5, 0 }, { 0, 0 }, sch_accommodation, sp_numberofbathroomstotal },
    { { 7, 0 }, { 0, 0 }, sch_accommodation, sp_numberofbedrooms },
    { { 5, 0 }, { 0, 0 }, sch_accommodation, sp_numberoffullbathrooms },
    { { 6, 0 }, { 0, 0 }, sch_accommodation, sp_numberofpartialbathrooms },
    { { 3, 1 }, { 0, 0 }, sch_accommodation, sp_numberofrooms },
    { { 3, 1 }, { 0, 0 }, sch_accommodation, sp_permittedusage },
    { { 3, 1 }, { 0, 0 }, sch_accommodation, sp_petsallowed },
    { { 7, 0 }, { 0, 0 }, sch_accommodation, sp_tourbookingpage },
    { { 6, 0 }, { 0, 0 }, sch_accommodation, sp_yearbuilt },

    { { 2, 0 }, { 0, 0 }, sch_action, sp_actionstatus },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_agent },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_endtime },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_error },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_instrument },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_location },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_object },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_participant },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_result },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_starttime },
    { { 2, 0 }, { 0, 0 }, sch_action, sp_target },

    { { 3, 5 }, { 0, 0 }, sch_actionaccessspecification, sp_availabilityends },
    { { 3, 5 }, { 0, 0 }, sch_actionaccessspecification, sp_availabilitystarts },
    { { 3, 5 }, { 0, 0 }, sch_actionaccessspecification, sp_category },
    { { 3, 5 }, { 0, 0 }, sch_actionaccessspecification, sp_eligibleregion },
    { { 3, 5 }, { 0, 0 }, sch_actionaccessspecification, sp_expectsacceptanceof },
    { { 3, 9 }, { 0, 0 }, sch_actionaccessspecification, sp_ineligibleregion },
    { { 3, 5 }, { 0, 0 }, sch_actionaccessspecification, sp_requiressubscription },

    { { 2, 0 }, { 0, 0 }, sch_aggregateoffer, sp_highprice },
    { { 2, 0 }, { 0, 0 }, sch_aggregateoffer, sp_lowprice },
    { { 2, 0 }, { 0, 0 }, sch_aggregateoffer, sp_offercount },
    { { 2, 0 }, { 0, 0 }, sch_aggregateoffer, sp_offers },

    { { 2, 0 }, { 0, 0 }, sch_aggregaterating, sp_itemreviewed },
    { { 2, 0 }, { 0, 0 }, sch_aggregaterating, sp_ratingcount },
    { { 2, 0 }, { 0, 0 }, sch_aggregaterating, sp_reviewcount },

    { { 2, 0 }, { 0, 0 }, sch_airline, sp_boardingpolicy },
    { { 2, 0 }, { 0, 0 }, sch_airline, sp_iatacode },

    { { 2, 0 }, { 0, 0 }, sch_airport, sp_iatacode },
    { { 2, 0 }, { 0, 0 }, sch_airport, sp_ocaocode },

    { { 2, 0 }, { 0, 0 }, sch_alignmentobject, sp_alignmenttype },
    { { 2, 0 }, { 0, 0 }, sch_alignmentobject, sp_educationalframework },
    { { 2, 0 }, { 0, 0 }, sch_alignmentobject, sp_targetdescription },
    { { 2, 0 }, { 0, 0 }, sch_alignmentobject, sp_targetname },
    { { 2, 0 }, { 0, 0 }, sch_alignmentobject, sp_targeturl },

    { { 2, 0, SV_NOT_3034 }, { 6, 0 }, sch_allocateaction, sp_purpose },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalstructure, sp_associatedpathophysiology },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalstructure, sp_bodylocation },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalstructure, sp_connectedto },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalstructure, sp_diagram },
    { { 2, 0, SV_NOT_3034 }, { 6, 0 }, sch_anatomicalstructure, sp_function },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalstructure, sp_partofsystem },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalstructure, sp_relatedcondition },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalstructure, sp_relatedtherapy },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalstructure, sp_substructure },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalsystem, sp_associatedpathophysiology },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalsystem, sp_comprisedof },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalsystem, sp_relatedcondition },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalsystem, sp_relatedstructure },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_anatomicalsystem, sp_relatedtherapy },

    { { 3, 1 }, { 0, 0 }, sch_apartment, sp_numberofrooms },
    { { 3, 1 }, { 0, 0 }, sch_apartment, sp_occupancy },

    { { 6, 0 }, { 0, 0 }, sch_apartmentcomplex, sp_numberofaccommodationunits },
    { { 6, 0 }, { 0, 0 }, sch_apartmentcomplex, sp_numberofavailableaccommodationunits },
    { { 7, 0 }, { 0, 0 }, sch_apartmentcomplex, sp_numberofbedrooms },
    { { 7, 0 }, { 0, 0 }, sch_apartmentcomplex, sp_petsallowed },
    { { 7, 0 }, { 0, 0 }, sch_apartmentcomplex, sp_tourbookingpage },

    { { 2, 0 }, { 0, 0 }, sch_apireference, sp_assemblyversion },
    { { 2, 0 }, { 0, 0 }, sch_apireference, sp_executablelibraryname },
    { { 2, 0 }, { 0, 0 }, sch_apireference, sp_programmingmodel },
    { { 2, 0 }, { 0, 0 }, sch_apireference, sp_targetplatform },

    { { 3, 5 }, { 0, 0 }, sch_archivecomponent, sp_holdingarchive },
    { { 3, 5 }, { 0, 0 }, sch_archivecomponent, sp_itemlocation },

    { { 3, 5 }, { 0, 0 }, sch_archiveorganisation, sp_archiveheld },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_artery, sp_arterialbranch },
    { { 2, 0, SV_NOT_3034 }, { 6, 0 }, sch_artery, sp_source },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_artery, sp_supplyto },

    { { 2, 0 }, { 0, 0 }, sch_article, sp_articlebody },
    { { 2, 0 }, { 0, 0 }, sch_article, sp_articlesection },
    { { 3, 5 }, { 0, 0 }, sch_article, sp_backstory },
    { { 2, 0 }, { 0, 0 }, sch_article, sp_pageend },
    { { 2, 0 }, { 0, 0 }, sch_article, sp_pagestart },
    { { 2, 0 }, { 0, 0 }, sch_article, sp_pagination },
    { { 3, 5 }, { 0, 0 }, sch_article, sp_speakable },
    { { 2, 0 }, { 0, 0 }, sch_article, sp_wordcount },

    { { 2, 0 }, { 0, 0 }, sch_askaction, sp_question },

    { { 2, 0 }, { 0, 0 }, sch_audience, sp_audiencetype },
    { { 2, 0 }, { 0, 0 }, sch_audience, sp_geographicarea },

    { { 3, 5 }, { 0, 0 }, sch_audiobook, sp_duration },
    { { 3, 5 }, { 0, 0 }, sch_audiobook, sp_readby },

    { { 3, 5 }, { 0, 0 }, sch_audioobject, sp_caption },
    { { 13, 0 }, { 0, 0 }, sch_audioobject, sp_embeddedtextcaption },
    { { 2, 0 }, { 0, 0 }, sch_audioobject, sp_transcript },

    { { 2, 0 }, { 0, 0 }, sch_authoriseaction, sp_recipient },

    { { 3, 5 }, { 0, 0 }, sch_bankaccount, sp_accountminimuminflow },
    { { 3, 5 }, { 0, 0 }, sch_bankaccount, sp_accountoverdraftlimit },
    { { 3, 5 }, { 0, 0 }, sch_bankaccount, sp_bankaccounttype },

    { { 3, 1 }, { 0, 0 }, sch_beddetails, sp_numberofbeds },
    { { 3, 1 }, { 0, 0 }, sch_beddetails, sp_typeofbed },

    { { 3, 5 }, { 0, 0 }, sch_bedtype, sp_bed },
    { { 3, 5 }, { 0, 0 }, sch_bedtype, sp_typeofbed },

    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_associateddisease },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_biocheminteraction },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_biochemsimilarity },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_biologicalrole },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_hasbiochementitypart },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_hasmolecularfunction },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_hasrepresentation },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_isencodedbybiochementity },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_isinvolvedinbiologicalprocess },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_islocatedinsubcellularlocation },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_ispartofbiochementity },
    { { 13, 0 }, { 0, 0 }, sch_biochementity, sp_taxonomicrange },

    { { 2, 0 }, { 0, 0 }, sch_blog, sp_blogpost },
    { { 3, 5 }, { 0, 0 }, sch_blog, sp_issn },

    { { 9, 0 }, { 0, 0 }, sch_boattrip, sp_arrivalboatterminal },
    { { 9, 0 }, { 0, 0 }, sch_boattrip, sp_departureboatterminal },

    { { 3, 5 }, { 0, 0 }, sch_book, sp_abridged },
    { { 2, 0 }, { 0, 0 }, sch_book, sp_bookedition },
    { { 2, 0 }, { 0, 0 }, sch_book, sp_bookformat },
    { { 2, 0 }, { 0, 0 }, sch_book, sp_illustrator },
    { { 2, 0 }, { 0, 0 }, sch_book, sp_isbn },
    { { 2, 0 }, { 0, 0 }, sch_book, sp_numberofpages },

    { { 2, 0 }, { 0, 0 }, sch_borrowaction, sp_lender },

    { { 2, 0 }, { 0, 0 }, sch_brand, sp_aggregaterating },

    { { 2, 0 }, { 0, 0 }, sch_brand, sp_logo },
    { { 2, 0 }, { 0, 0 }, sch_brand, sp_review },
    { { 3, 5 }, { 0, 0 }, sch_brand, sp_slogan },

    { { 2, 0 }, { 0, 0 }, sch_broadcastchannel, sp_broadcastchannelid },
    { { 3, 5 }, { 0, 0 }, sch_broadcastchannel, sp_broadcastfrequency },
    { { 2, 0 }, { 0, 0 }, sch_broadcastchannel, sp_broadcastservicetier },
    { { 3, 2 }, { 0, 0 }, sch_broadcastchannel, sp_genre },
    { { 2, 0 }, { 0, 0 }, sch_broadcastchannel, sp_inbroadcastlineup },
    { { 2, 0 }, { 0, 0 }, sch_broadcastchannel, sp_providesbroadcastservice },

    { { 2, 2 }, { 0, 0 }, sch_broadcastevent, sp_broadcastofevent },
    { { 2, 0 }, { 0, 0 }, sch_broadcastevent, sp_islivebroadcast },
    { { 4, 0 }, { 0, 0 }, sch_broadcastevent, sp_subtitlelanguage },
    { { 2, 1, SV_NOT_30 }, { 0, 0 }, sch_broadcastevent, sp_videoformat },

    { { 3, 5 }, { 0, 0 }, sch_broadcastfrequencyspecification, sp_broadcastfrequencyvalue },
    { { 3, 5 }, { 0, 0 }, sch_broadcastfrequencyspecification, sp_broadcastsignalmodulation },
    { { 3, 5 }, { 0, 0 }, sch_broadcastfrequencyspecification, sp_broadcastsubchannel },

    { { 2, 0 }, { 0, 0 }, sch_broadcastservice, sp_broadcastaffiliateof },
    { { 2, 0 }, { 0, 0 }, sch_broadcastservice, sp_broadcastdisplayname },
    { { 2, 0 }, { 0, 0 }, sch_broadcastservice, sp_broadcasttimezone },
    { { 2, 0 }, { 0, 0 }, sch_broadcastservice, sp_broadcaster },
    { { 5, 0 }, { 0, 0 }, sch_broadcastservice, sp_callsign },
    { { 3, 5 }, { 0, 0 }, sch_broadcastservice, sp_hasbroadcastchannel },
    { { 4, 0 }, { 0, 0 }, sch_broadcastservice, sp_inlanguage },
    { { 2, 0 }, { 0, 0 }, sch_broadcastservice, sp_parentservice },
    { { 2, 1, SV_NOT_30 }, { 0, 0 }, sch_broadcastservice, sp_videoformat },

    { { 3, 5 }, { 0, 0 }, sch_busorcoach, sp_acrisscode },
    { { 3, 5 }, { 0, 0 }, sch_busorcoach, sp_roofload },

    { { 2, 0 }, { 0, 0 }, sch_bustrip, sp_arrivalbusstop },
    { { 2, 0 }, { 3, 3 }, sch_bustrip, sp_arrivaltime },
    { { 2, 0 }, { 0, 0 }, sch_bustrip, sp_busname },
    { { 2, 0 }, { 0, 0 }, sch_bustrip, sp_busnumber },
    { { 2, 0 }, { 0, 0 }, sch_bustrip, sp_departurebusstop },
    { { 2, 0 }, { 3, 3 }, sch_bustrip, sp_departuretime },
    { { 2, 0 }, { 3, 3 }, sch_bustrip, sp_provider },

    { { 2, 0 }, { 0, 0 }, sch_businessaudience, sp_numberofemployees },
    { { 2, 0 }, { 0, 0 }, sch_businessaudience, sp_yearlyrevenue },
    { { 2, 0 }, { 0, 0 }, sch_businessaudience, sp_yearsinoperation },

    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdcollectiondate },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdfacilitycounty },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdfacilityid },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumbeds },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumbedsocc },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumc19died },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumc19hopats },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumc19hosppats },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumc19mechventpats },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumc19ofmechventpats },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumc19overflowpats },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumicubeds },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumicubedsocc },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumtotbeds },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumvent },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_cvdnumventuse },
    { { 7, 3 }, { 0, 0 }, sch_cdcpmdrecord, sp_dateposted },

    { { 3, 5 }, { 0, 0 }, sch_car, sp_acrisscode },
    { { 3, 5 }, { 0, 0 }, sch_car, sp_roofload },

    { { 3, 5 }, { 0, 0 }, sch_categorycode, sp_codevalue },
    { { 3, 5 }, { 0, 0 }, sch_categorycode, sp_incodeset },

    { { 3, 5 }, { 0, 0 }, sch_categorycodeset, sp_hascategorycode },

    { { 3, 5 }, { 0, 0 }, sch_chapter, sp_pageend },
    { { 3, 5 }, { 0, 0 }, sch_chapter, sp_pagestart },
    { { 3, 5 }, { 0, 0 }, sch_chapter, sp_pagination },

    { { 13, 0 }, { 0, 0 }, sch_chemicalsubstance, sp_chemicalcomposition },
    { { 13, 0 }, { 0, 0 }, sch_chemicalsubstance, sp_chemicalrole },
    { { 13, 0 }, { 0, 0 }, sch_chemicalsubstance, sp_potentialuse },

    { { 2, 0 }, { 0, 0 }, sch_chooseaction, sp_actionoption },

    { { 2, 0 }, { 0, 0 }, sch_civicstructure, sp_openinghours },

    { { 3, 5 }, { 0, 0 }, sch_claim, sp_appearance },
    { { 13, 0 }, { 0, 0 }, sch_claim, sp_claiminterpreter },
    { { 3, 5 }, { 0, 0 }, sch_claim, sp_firstappearance },

    { { 3, 2 }, { 0, 0 }, sch_claimreview, sp_claimreviewed },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_class, sp_supersededby },

    { { 2, 0 }, { 0, 0 }, sch_clip, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_clip, sp_clipnumber },
    { { 2, 0 }, { 0, 0 }, sch_clip, sp_director },
    { { 3, 5 }, { 0, 0 }, sch_clip, sp_endoffset },
    { { 2, 0 }, { 0, 0 }, sch_clip, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_clip, sp_partofepisode },
    { { 2, 0 }, { 0, 0 }, sch_clip, sp_partofseason },
    { { 2, 0 }, { 0, 0 }, sch_clip, sp_partofseries },
    { { 3, 5 }, { 0, 0 }, sch_clip, sp_startoffset },

    { { 3, 5 }, { 0, 0 }, sch_collection, sp_collectionsize },

    { { 3, 5 }, { 0, 0 }, sch_comicissue, sp_artist },
    { { 3, 5 }, { 0, 0 }, sch_comicissue, sp_colourist },
    { { 3, 5 }, { 0, 0 }, sch_comicissue, sp_inker },
    { { 3, 5 }, { 0, 0 }, sch_comicissue, sp_letterer },
    { { 3, 5 }, { 0, 0 }, sch_comicissue, sp_penciler },
    { { 3, 5 }, { 0, 0 }, sch_comicissue, sp_variantcover },

    { { 3, 5 }, { 0, 0 }, sch_comicstory, sp_artist },
    { { 3, 5 }, { 0, 0 }, sch_comicstory, sp_colourist },
    { { 3, 5 }, { 0, 0 }, sch_comicstory, sp_inker },
    { { 3, 5 }, { 0, 0 }, sch_comicstory, sp_letterer },
    { { 3, 5 }, { 0, 0 }, sch_comicstory, sp_penciler },

    { { 2, 0 }, { 0, 0 }, sch_comment, sp_downvotecount },
    { { 2, 0 }, { 0, 0 }, sch_comment, sp_parentitem },
    { { 2, 0 }, { 0, 0 }, sch_comment, sp_upvotecount },

    { { 2, 0 }, { 0, 0 }, sch_commentaction, sp_resultcomment },

    { { 2, 0 }, { 0, 0 }, sch_communicateaction, sp_about },
    { { 2, 0 }, { 0, 0 }, sch_communicateaction, sp_inlanguage },
    { { 2, 0 }, { 0, 0 }, sch_communicateaction, sp_recipient },

    { { 3, 0 }, { 0, 0 }, sch_compoundpricespecification, sp_pricecomponent },
    { { 11, 0 }, { 0, 0 }, sch_compoundpricespecification, sp_pricetype },

    { { 3, 5 }, { 0, 0 }, sch_consumeaction, sp_actionaccessibilityrequirement },
    { { 2, 0 }, { 0, 0 }, sch_consumeaction, sp_expectsacceptanceof },

    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_areaserved },
    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_availablelanguage },
    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_contactoption },
    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_contacttype },
    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_email },
    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_faxnumber },
    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_hoursavailable },
    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_productsupported },
    { { 2, 0 }, { 0, 0 }, sch_contactpoint, sp_telephone },

    { { 2, 0 }, { 0, 0 }, sch_cookaction, sp_foodestablishment },
    { { 2, 0 }, { 0, 0 }, sch_cookaction, sp_foodevent },
    { { 2, 0 }, { 0, 0 }, sch_cookaction, sp_recipe },

    { { 2, 0 }, { 0, 0 }, sch_corporation, sp_tickersymbol },

    { { 3, 4 }, { 0, 0 }, sch_course, sp_coursecode },
    { { 3, 4 }, { 0, 0 }, sch_course, sp_coursepresequisites },
    { { 3, 5 }, { 0, 0 }, sch_course, sp_educationcredentialawarded },
    { { 3, 4 }, { 0, 0 }, sch_course, sp_hascourseinstance },
    { { 6, 0 }, { 0, 0 }, sch_course, sp_numberofcredits },
    { { 3, 9 }, { 0, 0 }, sch_course, sp_occupationalcredentialawarded },

    { { 3, 4 }, { 0, 0 }, sch_courseinstance, sp_coursemode },
    { { 3, 6 }, { 0, 0 }, sch_courseinstance, sp_courseworkload },
    { { 3, 4 }, { 0, 0 }, sch_courseinstance, sp_instructor },

    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_about },
    { { 4, 0 }, { 0, 0 }, sch_creativework, sp_abstract },
    { { 3, 0 }, { 0, 0 }, sch_creativework, sp_accessmode },
    { { 3, 0 }, { 0, 0 }, sch_creativework, sp_accessmodesufficient },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_accessibilityapi },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_accessibilitycontrol },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_accessibilityfeature },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_accessibilityhazard },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_accessibilitysummary },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_accountableperson },
    { { 7, 0 }, { 0, 0 }, sch_creativework, sp_acquirelicensepage },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_aggregaterating },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_alternativeheadline },
    { { 13, 0 }, { 0, 0 }, sch_creativework, sp_archivedat },
    { { 9, 0 }, { 0, 0 }, sch_creativework, sp_assesses },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_associatedmedia },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_audience },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_audio },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_author },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_award },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_character },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_citation },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_comment },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_commentcount },
    { { 3, 8 }, { 0, 0 }, sch_creativework, sp_conditionsofaccess },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_contentlocation },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_contentrating },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_contentreferencetime },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_contributor },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_copyrightholder },
    { { 11, 0 }, { 0, 0 }, sch_creativework, sp_copyrightnotice },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_copyrightyear },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_correction },
    { { 3, 8 }, { 0, 0 }, sch_creativework, sp_creativeworkstatus },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_creator },
    { { 11, 0 }, { 0, 0 }, sch_creativework, sp_credittext },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_datecreated },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_datemodified },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_datepublished },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_discussionurl },
    { { 8, 0 }, { 0, 0 }, sch_creativework, sp_editeidr },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_editor },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_educationalalignment },
    { { 8, 0 }, { 0, 0 }, sch_creativework, sp_educationallevel },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_educationaluse },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_encoding },
    { { 3, 4 }, { 0, 0 }, sch_creativework, sp_encodingformat },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_exampleofwork },
    { { 3, 3 }, { 0, 0 }, sch_creativework, sp_expires },
    { { 2, 2 }, { 3, 3 }, sch_creativework, sp_fileformat },
    { { 3, 1 }, { 0, 0 }, sch_creativework, sp_funder },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_genre },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_haspart },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_headline },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_inlanguage },
    { { 2, 1 }, { 0, 0 }, sch_creativework, sp_interactionstatistic },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_interactivitytype },
    { { 13, 0 }, { 0, 0 }, sch_creativework, sp_interpretedasclaim },
    { { 3, 1 }, { 0, 0 }, sch_creativework, sp_isaccessibleforfree },
    { { 3, 0 }, { 0, 0 }, sch_creativework, sp_isbasedon },
    { { 2, 0 }, { 2, 1 }, sch_creativework, sp_isbasedonurl },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_isfamilyfriendly },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_ispartof },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_keywords },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_learningresourcetype },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_license },
    { { 2, 2 }, { 0, 0 }, sch_creativework, sp_locationcreated },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_mainentity },
    { { 6, 0 }, { 0, 0 }, sch_creativework, sp_maintainer },
    { { 3, 2 }, { 0, 0 }, sch_creativework, sp_material },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_materialextent },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_mentions },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_offers },
    { { 9, 0 }, { 0, 0 }, sch_creativework, sp_pattern },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_position },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_producer },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_provider },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_publication },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_publisher },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_publisherimprint },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_publishingprinciples },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_recordedat },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_releasedevent },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_review },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_schemaversion },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_sddatepublished },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_sdlicence },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_sdpublisher },
    { { 9, 0 }, { 0, 0 }, sch_creativework, sp_size },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_sourceorganisation },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_spatial },
    { { 3, 1 }, { 0, 0 }, sch_creativework, sp_spatialcoverage },
    { { 3, 1 }, { 0, 0 }, sch_creativework, sp_sponsor },
    { { 8, 0 }, { 0, 0 }, sch_creativework, sp_teaches },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_temporal },
    { { 3, 1 }, { 0, 0 }, sch_creativework, sp_temporalcoverage },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_text },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_thumbnailurl },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_timerequired },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_translationofwork },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_translator },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_typicalagerange },
    { { 7, 0 }, { 0, 0 }, sch_creativework, sp_usageinfo },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_version },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_video },
    { { 2, 0 }, { 0, 0 }, sch_creativework, sp_workexample },
    { { 3, 5 }, { 0, 0 }, sch_creativework, sp_worktranslation },

    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_director },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_enddate },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_episode },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_numberofepisodes },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_partofseries },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_productioncompany },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_seasonnumber },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_startdate },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseason, sp_trailer },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseries, sp_enddate },
    { { 3, 3 }, { 0, 0 }, sch_creativeworkseries, sp_issn },
    { { 2, 0 }, { 0, 0 }, sch_creativeworkseries, sp_startdate },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_ddxelement, sp_diagnosis },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_ddxelement, sp_distinguishingsign },

    { { 2, 0 }, { 0, 0 }, sch_datacatalogue, sp_dataset },
    { { 3, 5 }, { 0, 0 }, sch_datacatalogue, sp_measurementtechnique },

    { { 3, 5 }, { 0, 0 }, sch_datadownload, sp_measurementtechnique },

    { { 2, 2 }, { 0, 0 }, sch_datafeed, sp_datafeedelement },

    { { 2, 2 }, { 0, 0 }, sch_datafeeditem, sp_datecreated },
    { { 3, 0 }, { 0, 0 }, sch_datafeeditem, sp_datedeleted },
    { { 2, 2 }, { 0, 0 }, sch_datafeeditem, sp_datemodified },
    { { 2, 2 }, { 0, 0 }, sch_datafeeditem, sp_item },

    { { 2, 0 }, { 3, 0 }, sch_dataset, sp_datasettimeinterval },
    { { 2, 0 }, { 0, 0 }, sch_dataset, sp_distribution },
    { { 2, 0 }, { 0, 0 }, sch_dataset, sp_includeddatacatalog },
    { { 2, 0 }, { 3, 0 }, sch_dataset, sp_spatial },
    { { 3, 3 }, { 0, 0 }, sch_dataset, sp_issn },
    { { 3, 5 }, { 0, 0 }, sch_dataset, sp_measurementtechnique },
    { { 3, 5 }, { 0, 0 }, sch_dataset, sp_variablemeasured },
    { { 3, 5 }, { 0, 0 }, sch_dataset, sp_variablesmeasured },

    { { 2, 0 }, { 0, 0 }, sch_datedmoneyspecification, sp_amount },
    { { 2, 0 }, { 0, 0 }, sch_datedmoneyspecification, sp_currency },
    { { 2, 0 }, { 0, 0 }, sch_datedmoneyspecification, sp_enddate },
    { { 2, 0 }, { 0, 0 }, sch_datedmoneyspecification, sp_startdate },

    { { 8, 0 }, { 0, 0 }, sch_definedregion, sp_addresscountry },
    { { 8, 0 }, { 0, 0 }, sch_definedregion, sp_addressregion },
    { { 8, 0 }, { 0, 0 }, sch_definedregion, sp_postalcode },
    { { 8, 0 }, { 0, 0 }, sch_definedregion, sp_postalcodeprefix },
    { { 8, 0 }, { 0, 0 }, sch_definedregion, sp_postalcoderange },

    { { 3, 5 }, { 0, 0 }, sch_definedterm, sp_indefinedtermset },
    { { 3, 5 }, { 0, 0 }, sch_definedterm, sp_termcode },

    { { 3, 5 }, { 0, 0 }, sch_definedtermset, sp_hasdefinedterm },

    { { 2, 0 }, { 0, 0 }, sch_deliverychargespecification, sp_appliestodeliverymethod },
    { { 2, 2 }, { 0, 0 }, sch_deliverychargespecification, sp_areaserved },
    { { 2, 0 }, { 0, 0 }, sch_deliverychargespecification, sp_eligibleregion },
    { { 2, 0 }, { 0, 0 }, sch_deliverychargespecification, sp_ineligibleregion },

    { { 2, 0 }, { 0, 0 }, sch_deliveryevent, sp_accesscode },
    { { 2, 0 }, { 0, 0 }, sch_deliveryevent, sp_availablefrom },
    { { 2, 0 }, { 0, 0 }, sch_deliveryevent, sp_availablethrough },
    { { 2, 0 }, { 0, 0 }, sch_deliveryevent, sp_hasdeliverymethod },

    { { 8, 0 }, { 0, 0 }, sch_deliverytimesettings, sp_deliverytime },
    { { 9, 0 }, { 0, 0 }, sch_deliverytimesettings, sp_isunlabelledfallback },
    { { 8, 0 }, { 0, 0 }, sch_deliverytimesettings, sp_shippingdestination },
    { { 8, 0 }, { 0, 0 }, sch_deliverytimesettings, sp_transittimelabel },

    { { 2, 0 }, { 0, 0 }, sch_demand, sp_acceptedpaymentmethod },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_advancebookingrequirement },
    { { 3, 0 }, { 0, 0 }, sch_demand, sp_areaserved },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_availability },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_availabilityends },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_availabilitystarts },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_availableatorfrom },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_availabedeliverymethod },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_businessfunction },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_deliveryleadtime },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_eligibilecustomertype },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_eligibleduration },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_eligiblequantity },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_eligibleregion },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_eligibletransactionvolume },
    { { 3, 8 }, { 0, 0 }, sch_demand, sp_gtin },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_gtin12 },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_gtin13 },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_gtin14 },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_gtin8 },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_includesobject },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_ineligibleregion },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_inventorylevel },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_itemcondition },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_itemoffered },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_mpn },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_pricespecification },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_seller },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_serialnumber },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_sku },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_validfrom },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_validthrough },
    { { 2, 0 }, { 0, 0 }, sch_demand, sp_warranty },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_diagnosticlab, sp_availabletest },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_diet, sp_dietfeatures },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_diet, sp_endorsers },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_diet, sp_exportconsiderations },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_diet, sp_overview },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_diet, sp_physiologicalbenefits },
    { { 2, 0 }, { 2, 1 }, sch_diet, sp_proprietaryname },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_diet, sp_risks },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_activeingredient },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_background },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_dosageform },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_isproprietary },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_legalstatus },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_manufacturer },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_maximumintake },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_mechanismofaction },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_nonpropriatryname },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_recommendedintake },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_safetyconsideration },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_dietarysupplement, sp_targetpopulation },

    { { 3, 0 }, { 0, 0 }, sch_digitaldocument, sp_hasdigitaldocumentpermission },
    { { 3, 0 }, { 0, 0 }, sch_digitaldocumentpermission, sp_grantee },
    { { 3, 0 }, { 0, 0 }, sch_digitaldocumentpermission, sp_permissiontype },

    { { 2, 0 }, { 0, 0 }, sch_donateaction, sp_recipient },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_doseschedule, sp_doseunit },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_doseschedule, sp_dosevalue },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_doseschedule, sp_frequency },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_doseschedule, sp_targetpopulation },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_activeingredient },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_administrationroute },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_alcoholwarning },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_availablestrength },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_breastfeedingwarning },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_clinicalpharamcology },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_cost },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_dosageform },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_doseschedule },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_drugclass },
    { { 3, 5 }, { 0, 0 }, sch_drug, sp_drugunit },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_foodwarning },
    { { 3, 5 }, { 0, 0 }, sch_drug, sp_includedinhealthinsuranceplan },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_interactingdrug },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_isavailablegenerally },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_isproprietary },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_labeldetails },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_legalstatus },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_manufacturer },
    { { 3, 5 }, { 0, 0 }, sch_drug, sp_maximumintake },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_mechanismofaction },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_nonproprietaryname },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_overdosage },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_pregnancycategory },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_pregnancywarning },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_prescribinginfo },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_prescriptionstatus },
    { { 3, 5 }, { 0, 0 }, sch_drug, sp_proprietaryname },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_relateddrug },
    { { 3, 5 }, { 0, 0 }, sch_drug, sp_rxcui },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drug, sp_warning },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugclass, sp_drug },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugcost, sp_availablelocation },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugcost, sp_costcategory },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugcost, sp_costcurrency },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugcost, sp_costorigin },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugcost, sp_costperunit },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugcost, sp_drugunit },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_druglegalstatus, sp_applicablelocation },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugstrength, sp_activeingredient },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugstrength, sp_availablein },
    { { 3, 5 }, { 0, 0 }, sch_drugstrength, sp_maximumintake },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugstrength, sp_strengthunit },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_drugstrength, sp_strengthvalue },

    { { 8, 0 }, { 0, 0 }, sch_educationevent, sp_assess },
    { { 8, 0 }, { 0, 0 }, sch_educationevent, sp_educationallevel },
    { { 8, 0 }, { 0, 0 }, sch_educationevent, sp_teaches },

    { { 2, 0 }, { 0, 0 }, sch_educationalaudience, sp_educationalrole },

    { { 3, 5 }, { 0, 0 }, sch_educationaloccupationalcredential, sp_competencyrequired },
    { { 3, 5 }, { 0, 0 }, sch_educationaloccupationalcredential, sp_credentialcategory },
    { { 3, 5 }, { 0, 0 }, sch_educationaloccupationalcredential, sp_educationallevel },
    { { 3, 5 }, { 0, 0 }, sch_educationaloccupationalcredential, sp_recognisedby },
    { { 3, 5 }, { 0, 0 }, sch_educationaloccupationalcredential, sp_validfor },
    { { 3, 5 }, { 0, 0 }, sch_educationaloccupationalcredential, sp_validin },

    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_applicationdeadline },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_applicationstartdate },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_dayofweek },
    { { 3, 9 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_educationalcredentialawarded },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_educationalprogrammode },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_enddate },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_financialaideligible },
    { { 10, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_hascourse },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_maximumenrollment },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_numberofcredits },
    { { 7, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_occupationalcategory },
    { { 3, 9 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_occupationalcredentialawarded },
    { { 3, 9 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_offers },
    { { 3, 9 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_programprequisites },
    { { 7, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_programtype },
    { { 3, 9 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_provider },
    { { 3, 9 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_salaryuponcompletion },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_startdate },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_termduration },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_termsperyear },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_timeofday },
    { { 3, 9 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_timetocomplete },
    { { 7, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_trainingsalary },
    { { 6, 0 }, { 0, 0 }, sch_educationaloccupationalprogramme, sp_typicalcreditsperterm },

    { { 2, 0 }, { 0, 0 }, sch_educationalorganisation, sp_alumni },

    { { 2, 0 }, { 0, 0 }, sch_employeerole, sp_basesalary },
    { { 2, 0 }, { 0, 0 }, sch_employeerole, sp_salarycurrency },

    { { 2, 0 }, { 0, 0 }, sch_endorseaction, sp_endorsee },

    { { 10, 0 }, { 0, 0 }, sch_energyconsumptiondetails, sp_energyefficiencyscalemax },
    { { 10, 0 }, { 0, 0 }, sch_energyconsumptiondetails, sp_energyefficiencyscalemin },
    { { 10, 0 }, { 0, 0 }, sch_energyconsumptiondetails, sp_hasenergyefficiencycategory },

    { { 3, 5 }, { 0, 0 }, sch_enginespecification, sp_enginedisplacement },
    { { 3, 5 }, { 0, 0 }, sch_enginespecification, sp_enginepower },
    { { 3, 5 }, { 0, 0 }, sch_enginespecification, sp_enginetype },
    { { 2, 0 }, { 0, 0 }, sch_enginespecification, sp_fueltype },
    { { 3, 5 }, { 0, 0 }, sch_enginespecification, sp_torque },

    { { 2, 0 }, { 0, 0 }, sch_entrypoint, sp_actionapplication },
    { { 2, 2 }, { 0, 0 }, sch_entrypoint, sp_actionplatform },
    { { 2, 0 }, { 0, 0 }, sch_entrypoint, sp_contenttype },
    { { 2, 0 }, { 0, 0 }, sch_entrypoint, sp_encodingtype },
    { { 2, 0 }, { 0, 0 }, sch_entrypoint, sp_httpmethod },
    { { 2, 0 }, { 0, 0 }, sch_entrypoint, sp_urltemplate },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_enumeration, sp_suspersededby },

    { { 2, 0 }, { 0, 0 }, sch_episode, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_episode, sp_director },
    { { 12, 0 }, { 0, 0 }, sch_episode, sp_duration },
    { { 2, 0 }, { 0, 0 }, sch_episode, sp_episodenumber },
    { { 2, 0 }, { 0, 0 }, sch_episode, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_episode, sp_partofseason },
    { { 2, 0 }, { 0, 0 }, sch_episode, sp_partofseries },
    { { 2, 0 }, { 0, 0 }, sch_episode, sp_productioncompany },
    { { 2, 0 }, { 0, 0 }, sch_episode, sp_trailer },

    { { 3, 1 }, { 0, 0 }, sch_event, sp_about },
    { { 3, 0 }, { 0, 0 }, sch_event, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_aggregaterating },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_attendee },
    { { 3, 1 }, { 0, 0 }, sch_event, sp_audience },
    { { 3, 0 }, { 0, 0 }, sch_event, sp_composer },
    { { 3, 0 }, { 0, 0 }, sch_event, sp_contributor },
    { { 3, 0 }, { 0, 0 }, sch_event, sp_director },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_doortime },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_duration },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_enddate },
    { { 7, 0 }, { 0, 0 }, sch_event, sp_eventattendancemode },
    { { 6, 0 }, { 0, 0 }, sch_event, sp_eventschedule },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_eventstatus },
    { { 3, 1 }, { 0, 0 }, sch_event, sp_funder },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_inlanguage },
    { { 3, 1 }, { 0, 0 }, sch_event, sp_isaccessibleforfree },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_location },
    { { 3, 1 }, { 0, 0 }, sch_event, sp_maximumattendeecapacity },
    { { 7, 0 }, { 0, 0 }, sch_event, sp_maximumphysicalattendeecapacity },
    { { 7, 0 }, { 0, 0 }, sch_event, sp_maximumvirtualattendeecapacity },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_offers },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_organiser },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_performer },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_previousstartdate },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_recordedin },
    { { 3, 1 }, { 0, 0 }, sch_event, sp_remainingattendeecapacity },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_review },
    { { 3, 0 }, { 0, 0 }, sch_event, sp_sponsor },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_startdate },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_subevent },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_superevent },
    { { 3, 0 }, { 0, 0 }, sch_event, sp_translator },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_typicalagerange },
    { { 3, 0 }, { 0, 0 }, sch_event, sp_workfeatured },
    { { 2, 0 }, { 0, 0 }, sch_event, sp_workperformed },

    { { 3, 5 }, { 0, 0 }, sch_exchangeratespecification, sp_currency },
    { { 3, 5 }, { 0, 0 }, sch_exchangeratespecification, sp_currentexchangerate },
    { { 3, 5 }, { 0, 0 }, sch_exchangeratespecification, sp_exchangeratespread },

    { { 3, 5 }, { 0, 0 }, sch_exerciseaction, sp_diet },
    { { 2, 0 }, { 0, 0 }, sch_exerciseaction, sp_distance },
    { { 2, 0 }, { 0, 0 }, sch_exerciseaction, sp_exercisecourse },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseaction, sp_exerciseplan },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseaction, sp_exerciserelateddiet },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseaction, sp_exercisetype },
    { { 2, 0 }, { 0, 0 }, sch_exerciseaction, sp_fromlocation },
    { { 2, 0 }, { 0, 0 }, sch_exerciseaction, sp_opponent },
    { { 2, 0 }, { 0, 0 }, sch_exerciseaction, sp_sportsactivitylocation },
    { { 2, 0 }, { 0, 0 }, sch_exerciseaction, sp_sportsevent },
    { { 2, 0 }, { 0, 0 }, sch_exerciseaction, sp_sportsteam },
    { { 2, 0 }, { 0, 0 }, sch_exerciseaction, sp_tolocation },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseplan, sp_activityduration },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseplan, sp_activityfrequency },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseplan, sp_additionalvariable },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseplan, sp_exercisetype },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseplan, sp_intensity },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseplan, sp_repetitions },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseplan, sp_restperiods },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_exerciseplan, sp_workload },

    { { 3, 0 }, { 0, 0 }, sch_financialproduct, sp_annualpercentagerate },
    { { 3, 0 }, { 0, 0 }, sch_financialproduct, sp_feesandcommissionsspecification },
    { { 3, 0 }, { 0, 0 }, sch_financialproduct, sp_interestrate },
    { { 3, 0 }, { 0, 0 }, sch_financialservice, sp_feesandcommissionsspecification },

    { { 2, 0 }, { 0, 0 }, sch_flight, sp_aircraft },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_arrivalairport },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_arrivalgate },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_arrivalterminal },
    { { 2, 0 }, { 3, 3 }, sch_flight, sp_arrivaltime },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_boardingpolicy },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_departureairport },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_departuregate },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_departureterminal },
    { { 2, 0 }, { 3, 3 }, sch_flight, sp_departuretime },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_estimatedflightduration },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_flightdistance },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_flightnumber },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_mealservice },
    { { 2, 0 }, { 3, 3 }, sch_flight, sp_provider },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_seller },
    { { 2, 0 }, { 0, 0 }, sch_flight, sp_webcheckintime },

    { { 2, 0 }, { 0, 0 }, sch_flightreservation, sp_boardinggroup },
    { { 2, 0 }, { 0, 0 }, sch_flightreservation, sp_passengerprioritystatus },
    { { 2, 0 }, { 0, 0 }, sch_flightreservation, sp_passengersequencenumber },
    { { 2, 0 }, { 0, 0 }, sch_flightreservation, sp_securityscreening },

    { { 7, 0 }, { 0, 0 }, sch_floorplan, sp_amenityfeature },
    { { 7, 0 }, { 0, 0 }, sch_floorplan, sp_floorsize },
    { { 6, 0 }, { 0, 0 }, sch_floorplan, sp_isplanforapartment },
    { { 10, 0 }, { 0, 0 }, sch_floorplan, sp_layoutimage },
    { { 6, 0 }, { 0, 0 }, sch_floorplan, sp_numberofaccommodationunits },
    { { 6, 0 }, { 0, 0 }, sch_floorplan, sp_numberofavailableaccommodationunits },
    { { 6, 0 }, { 0, 0 }, sch_floorplan, sp_numberofbathroomstotal },
    { { 7, 0 }, { 0, 0 }, sch_floorplan, sp_numberofbedrooms },
    { { 6, 0 }, { 0, 0 }, sch_floorplan, sp_numberoffullbathrooms },
    { { 6, 0 }, { 0, 0 }, sch_floorplan, sp_numberofpartialbathrooms },
    { { 6, 0 }, { 0, 0 }, sch_floorplan, sp_numberofrooms },
    { { 7, 0 }, { 0, 0 }, sch_floorplan, sp_petsallowed },

    { { 2, 0 }, { 0, 0 }, sch_followaction, sp_followee },

    { { 2, 0 }, { 0, 0 }, sch_foodestablishment, sp_acceptsreservations },
    { { 2, 0 }, { 3, 1 }, sch_foodestablishment, sp_menu },
    { { 3, 2 }, { 0, 0 }, sch_foodestablishment, sp_hasmenu },
    { { 2, 0 }, { 0, 0 }, sch_foodestablishment, sp_servescuisine },
    { { 3, 1 }, { 0, 0 }, sch_foodestablishment, sp_starrating },

    { { 2, 0 }, { 0, 0 }, sch_foodestablishmentreservation, sp_endtime },
    { { 2, 0 }, { 0, 0 }, sch_foodestablishmentreservation, sp_partysize },
    { { 2, 0 }, { 0, 0 }, sch_foodestablishmentreservation, sp_starttime },

    { { 2, 0 }, { 0, 0 }, sch_game, sp_characterattribute },
    { { 2, 0 }, { 0, 0 }, sch_game, sp_gameitem },
    { { 2, 0 }, { 0, 0 }, sch_game, sp_gamelocation },
    { { 2, 0 }, { 0, 0 }, sch_game, sp_numberofplayers },
    { { 2, 0 }, { 0, 0 }, sch_game, sp_quest },

    { { 2, 0 }, { 0, 0 }, sch_gameserver, sp_game },
    { { 2, 0 }, { 0, 0 }, sch_gameserver, sp_playersonline },
    { { 2, 0 }, { 0, 0 }, sch_gameserver, sp_serverstatus },

    { { 13, 0 }, { 0, 0 }, sch_gene, sp_alternativeof },
    { { 13, 0 }, { 0, 0 }, sch_gene, sp_encodesbiochementity },
    { { 13, 0 }, { 0, 0 }, sch_gene, sp_expressedin },
    { { 13, 0 }, { 0, 0 }, sch_gene, sp_hasbiopolymersequence },

    { { 2, 2 }, { 0, 0 }, sch_geocircle, sp_geomidpoint },
    { { 2, 2 }, { 0, 0 }, sch_geocircle, sp_georadius },

    { { 3, 0 }, { 0, 0 }, sch_geocoordinates, sp_address },
    { { 2, 2 }, { 0, 0 }, sch_geocoordinates, sp_addresscountry },
    { { 2, 0 }, { 0, 0 }, sch_geocoordinates, sp_elevation },
    { { 2, 0 }, { 0, 0 }, sch_geocoordinates, sp_latitude },
    { { 2, 0 }, { 0, 0 }, sch_geocoordinates, sp_longitude },
    { { 2, 2 }, { 0, 0 }, sch_geocoordinates, sp_postalcode },

    { { 3, 0 }, { 0, 0 }, sch_geoshape, sp_address },
    { { 2, 2 }, { 0, 0 }, sch_geoshape, sp_addresscountry },
    { { 2, 0 }, { 0, 0 }, sch_geoshape, sp_box },
    { { 2, 0 }, { 0, 0 }, sch_geoshape, sp_circle },
    { { 2, 0 }, { 0, 0 }, sch_geoshape, sp_elevation },
    { { 2, 0 }, { 0, 0 }, sch_geoshape, sp_line },
    { { 2, 0 }, { 0, 0 }, sch_geoshape, sp_polygon },
    { { 2, 2 }, { 0, 0 }, sch_geoshape, sp_postalcode },

    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geocontains },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geocoveredby },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geocovers },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geocrosses },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geodisjoint },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geoequals },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geointersects },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geooverlaps },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geotouches },
    { { 3, 5 }, { 0, 0 }, sch_geospatialgeometry, sp_geowithin },

    { { 2, 0 }, { 0, 0 }, sch_giveaction, sp_recipient },

    { { 7, 4 }, { 0, 0 }, sch_governmentservice, sp_jurisdiction },
    { { 2, 0 }, { 0, 0 }, sch_governmentservice, sp_serviceoperator },

    { { 3, 5 }, { 0, 0 }, sch_grant, sp_fundeditem },
    { { 3, 5 }, { 0, 0 }, sch_grant, sp_sponsor },

    { { 5, 0 }, { 0, 0 }, sch_guide, sp_reviewaspect },

    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_benefitssummaryurl },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_contactpoint },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_healthplandrugoption },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_healthplandrugtier },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_healthplanid },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_healthplanmarketingurl },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_includeshealthplanformulary },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_includeshealthplannetwork },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthinsuranceplan, sp_useshealthplanidstandard },

    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplancostsharingspecification, sp_healthplancoinsuranceoption },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplancostsharingspecification, sp_healthplancoinsurancerate },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplancostsharingspecification, sp_healthplancopay },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplancostsharingspecification, sp_healthplancopayoption },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplancostsharingspecification, sp_healthplanpharmacycategory },

    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplanformulary, sp_healthplancostsharing },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplanformulary, sp_healthplandrugtier },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplanformulary, sp_offersprescriptionbymail },

    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplannetwork, sp_healthplancostsharing },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplannetwork, sp_healthplannetworkid },
    { { 3, 5 }, { 0, 0 }, sch_dystopianhealthplannetwork, sp_healthplannetworktier },

    { { 5, 0 }, { 0, 0 }, sch_healthtopiccontent, sp_hashealthaspect },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_hospital, sp_availableservice },
    { { 7, 3 }, { 0, 0 }, sch_hospital, sp_healthcarereportingdata },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_hospital, sp_medicalspeciality },

    { { 3, 1 }, { 0, 0 }, sch_hotelroom, sp_bed },
    { { 3, 1 }, { 0, 0 }, sch_hotelroom, sp_occupancy },

    { { 3, 1 }, { 0, 0 }, sch_house, sp_numberofrooms },

    { { 3, 3 }, { 0, 0 }, sch_howto, sp_estimatedcost },
    { { 3, 3 }, { 0, 0 }, sch_howto, sp_performtime },
    { { 3, 3 }, { 0, 0 }, sch_howto, sp_preptime },
    { { 3, 4 }, { 0, 0 }, sch_howto, sp_step },
    { { 3, 3 }, { 3, 3 }, sch_howto, sp_steps },
    { { 3, 3 }, { 0, 0 }, sch_howto, sp_supply },
    { { 3, 3 }, { 0, 0 }, sch_howto, sp_tool },
    { { 3, 3 }, { 0, 0 }, sch_howto, sp_totaltime },
    { { 3, 3 }, { 0, 0 }, sch_howto, sp_yield },

    { { 3, 3 }, { 0, 0 }, sch_howtodirection, sp_aftermedia },
    { { 3, 3 }, { 0, 0 }, sch_howtodirection, sp_beforemedia },
    { { 3, 3 }, { 0, 0 }, sch_howtodirection, sp_duringmedia },
    { { 3, 3 }, { 0, 0 }, sch_howtodirection, sp_performtime },
    { { 3, 3 }, { 0, 0 }, sch_howtodirection, sp_preptime },
    { { 3, 3 }, { 0, 0 }, sch_howtodirection, sp_supply },
    { { 3, 3 }, { 0, 0 }, sch_howtodirection, sp_tool },
    { { 3, 3 }, { 0, 0 }, sch_howtodirection, sp_totaltime },

    { { 3, 3 }, { 0, 0 }, sch_howtoitem, sp_requiredquantity },

    { { 3, 3 }, { 3, 3 }, sch_howtosection, sp_steps },
    { { 3, 4 }, { 0, 0 }, sch_howtosection, sp_step },

    { { 3, 3 }, { 0, 0 }, sch_howtosupply, sp_estimatedcost },

    { { 11, 0 }, { 0, 0 }, sch_hypertoc, sp_associatedmedia },
    { { 11, 0 }, { 0, 0 }, sch_hypertoc, sp_tocentry },

    { { 11, 0 }, { 0, 0 }, sch_hypertocentry, sp_associatedmedia },
    { { 11, 0 }, { 0, 0 }, sch_hypertocentry, sp_toccontinuation },
    { { 11, 0 }, { 0, 0 }, sch_hypertocentry, sp_utterances },

    { { 2, 0 }, { 0, 0 }, sch_imageobject, sp_caption },
    { { 13, 0 }, { 0, 0 }, sch_imageobject, sp_embeddedtextcaption },
    { { 2, 0 }, { 0, 0 }, sch_imageobject, sp_exifdata },
    { { 2, 0 }, { 0, 0 }, sch_imageobject, sp_representativeofpage },
    { { 2, 0 }, { 0, 0 }, sch_imageobject, sp_thumbnail },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_imagingtest, sp_imagingtechnique },

    { { 2, 0 }, { 0, 0 }, sch_individualproduct, sp_serialnumber },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_infectiousdisease, sp_infectiousagent },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_infectiousdisease, sp_infectiousagentclass },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_infectiousdisease, sp_transmissionmethod },

    { { 2, 0 }, { 0, 0 }, sch_informaction, sp_event },

    { { 2, 0 }, { 0, 0 }, sch_insertaction, sp_tolocation },

    { { 13, 0 }, { 0, 0 }, sch_interactioncounter, sp_endtime },
    { { 2, 0 }, { 0, 0 }, sch_interactioncounter, sp_interactionservice },
    { { 2, 0 }, { 0, 0 }, sch_interactioncounter, sp_interactiontype },
    { { 13, 0 }, { 0, 0 }, sch_interactioncounter, sp_location },
    { { 13, 0 }, { 0, 0 }, sch_interactioncounter, sp_starttime },
    { { 2, 0 }, { 0, 0 }, sch_interactioncounter, sp_userinteractioncount },

    { { 3, 0 }, { 0, 0 }, sch_investmentordeposit, sp_amount },

    { { 2, 0 }, { 0, 0 }, sch_inviteaction, sp_event },

    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_accountid },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_billingperiod },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_broker },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_category },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_confirmationnumber },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_customer },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_minimumpaymentdue },
    { { 2, 0 }, { 2, 0 }, sch_invoice, sp_paymentdue },
    { { 2, 1 }, { 0, 0 }, sch_invoice, sp_paymentduedate },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_paymentmethod },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_paymentmethodid },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_paymentstatus },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_provider },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_referencesorder },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_scheduledpaymentdate },
    { { 2, 0 }, { 0, 0 }, sch_invoice, sp_totalpaymentdue },

    { { 2, 0 }, { 0, 0 }, sch_itemlist, sp_itemlistelement },
    { { 2, 0 }, { 0, 0 }, sch_itemlist, sp_itemlistorder },
    { { 2, 0 }, { 0, 0 }, sch_itemlist, sp_numberofitems },

    { { 3, 5 }, { 0, 0 }, sch_jobposting, sp_applicantlocationrequirements },
    { { 6, 0 }, { 0, 0 }, sch_jobposting, sp_applicantcontact },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_basesalary },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_dateposted },
    { { 13, 0 }, { 0, 0 }, sch_jobposting, sp_directapply },
    { { 3, 5 }, { 0, 0 }, sch_jobposting, sp_educationrequirements },
    { { 8, 0 }, { 0, 0 }, sch_jobposting, sp_eligibilitytoworkrequirement },
    { { 6, 0 }, { 0, 0 }, sch_jobposting, sp_employeroverview },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_employmenttype },
    { { 4, 0 }, { 0, 0 }, sch_jobposting, sp_employmentunit },
    { { 3, 6 }, { 0, 0 }, sch_jobposting, sp_estimatedsalary },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_experiencerequirements },
    { { 12, 0 }, { 0, 0 }, sch_jobposting, sp_experienceinplaceofeducation },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_hiringorganization },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_incentivecompensation },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_industry },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_jobbenefits },
    { { 3, 8 }, { 0, 0 }, sch_jobposting, sp_jobimmediatestart },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_joblocation },
    { { 3, 5 }, { 0, 0 }, sch_jobposting, sp_joblocationtype },
    { { 3, 8 }, { 0, 0 }, sch_jobposting, sp_jobstartdate },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_occupationalcategory },
    { { 6, 0 }, { 0, 0 }, sch_jobposting, sp_physicalrequirement },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_qualifications },
    { { 3, 5 }, { 0, 0 }, sch_jobposting, sp_relevantoccupation },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_responsibilities },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_salarycurrency },
    { { 6, 0 }, { 0, 0 }, sch_jobposting, sp_securityclearancerequirement },
    { { 6, 0 }, { 0, 0 }, sch_jobposting, sp_sensoryclearancerequirement },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_skills },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_specialcommitments },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_title },
    { { 4, 0 }, { 0, 0 }, sch_jobposting, sp_totaljobopenings },
    { { 3, 0 }, { 0, 0 }, sch_jobposting, sp_validthrough },
    { { 2, 0 }, { 0, 0 }, sch_jobposting, sp_workhours },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_joint, sp_biomechanicalclass },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_joint, sp_funcionalclass },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_joint, sp_structuralclass },

    { { 9, 0 }, { 0, 0 }, sch_learningresource, sp_assesses },
    { { 11, 0 }, { 0, 0 }, sch_learningresource, sp_competencyrequired },
    { { 9, 0 }, { 0, 0 }, sch_learningresource, sp_educationalalignment },
    { { 9, 0 }, { 0, 0 }, sch_learningresource, sp_educationallevel },
    { { 9, 0 }, { 0, 0 }, sch_learningresource, sp_educationaluse },
    { { 10, 0 }, { 0, 0 }, sch_learningresource, sp_learningresourcetype },
    { { 9, 0 }, { 0, 0 }, sch_learningresource, sp_teaches },

    { { 7, 4 }, { 0, 0 }, sch_legislation, sp_jurisdiction },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationapplies },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationchanges },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationconsolidates },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationdate },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationdateversion },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationidentifier },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationjurisdiction },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationlegalforce },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationpassedby },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationresponsible },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationtransposes },
    { { 3, 5 }, { 0, 0 }, sch_legislation, sp_legislationtype },
    { { 3, 5 }, { 0, 0 }, sch_legislationobject, sp_legislationlegalvalue },

    { { 3, 5 }, { 0, 0 }, sch_linkrole, sp_inlanguage },
    { { 3, 5 }, { 0, 0 }, sch_linkrole, sp_linkrelationship },

    { { 2, 0 }, { 0, 0 }, sch_listitem, sp_item },
    { { 2, 0 }, { 0, 0 }, sch_listitem, sp_nextitem },
    { { 2, 0 }, { 0, 0 }, sch_listitem, sp_position },
    { { 2, 0 }, { 0, 0 }, sch_listitem, sp_previousitem },

    { { 2, 1 }, { 0, 0 }, sch_liveblogposting, sp_coverageendtime },
    { { 2, 1 }, { 0, 0 }, sch_liveblogposting, sp_coveragestarttime },
    { { 2, 1 }, { 0, 0 }, sch_liveblogposting, sp_liveblogupdate },

    { { 3, 0 }, { 0, 0 }, sch_loanorcredit, sp_amount },
    { { 3, 5 }, { 0, 0 }, sch_loanorcredit, sp_currency },
    { { 3, 5 }, { 0, 0 }, sch_loanorcredit, sp_graceperiod },
    { { 3, 5 }, { 0, 0 }, sch_loanorcredit, sp_loanrepaymentform },
    { { 3, 0 }, { 0, 0 }, sch_loanorcredit, sp_loanterm },
    { { 3, 5 }, { 0, 0 }, sch_loanorcredit, sp_loantype },
    { { 3, 5 }, { 0, 0 }, sch_loanorcredit, sp_recourseloan },
    { { 3, 5 }, { 0, 0 }, sch_loanorcredit, sp_renegotiableloan },
    { { 3, 0 }, { 0, 0 }, sch_loanorcredit, sp_requiredcollateral },

    { { 2, 0 }, { 0, 0 }, sch_localbusiness, sp_currenciesaccepted },
    { { 2, 0 }, { 0, 0 }, sch_localbusiness, sp_openinghours },
    { { 2, 0 }, { 2, 0 }, sch_localbusiness, sp_parentorganisation },
    { { 2, 0 }, { 0, 0 }, sch_localbusiness, sp_paymentaccepted },
    { { 2, 0 }, { 0, 0 }, sch_localbusiness, sp_pricerange },

    { { 3, 1 }, { 0, 0 }, sch_locationfeaturespecification, sp_hoursavailable },
    { { 3, 1 }, { 0, 0 }, sch_locationfeaturespecification, sp_validfrom },
    { { 3, 1 }, { 0, 0 }, sch_locationfeaturespecification, sp_validthrough },

    { { 3, 1 }, { 0, 0 }, sch_lodgingbusiness, sp_amenityfeature },
    { { 3, 1 }, { 0, 0 }, sch_lodgingbusiness, sp_audience },
    { { 3, 1 }, { 0, 0 }, sch_lodgingbusiness, sp_availablelanguage },
    { { 3, 1 }, { 0, 0 }, sch_lodgingbusiness, sp_checkintime },
    { { 3, 1 }, { 0, 0 }, sch_lodgingbusiness, sp_checkouttime },
    { { 3, 6 }, { 0, 0 }, sch_lodgingbusiness, sp_numberofrooms },
    { { 3, 1 }, { 0, 0 }, sch_lodgingbusiness, sp_petsallowed },
    { { 3, 1 }, { 0, 0 }, sch_lodgingbusiness, sp_starrating },

    { { 2, 0 }, { 0, 0 }, sch_lodgingreservation, sp_checkintime },
    { { 2, 0 }, { 0, 0 }, sch_lodgingreservation, sp_checkouttime },
    { { 2, 0 }, { 0, 0 }, sch_lodgingreservation, sp_lodgingunitdescription },
    { { 2, 0 }, { 0, 0 }, sch_lodgingreservation, sp_lodgingunittype },
    { { 2, 0 }, { 0, 0 }, sch_lodgingreservation, sp_numadults },
    { { 2, 0 }, { 0, 0 }, sch_lodgingreservation, sp_numchildren },

    { { 2, 0 }, { 0, 0 }, sch_loseaction, sp_winner },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_lymphaticvessel, sp_originatesfrom },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_lymphaticvessel, sp_regiondrained },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_lymphaticvessel, sp_runsto },

    { { 2, 0 }, { 0, 0 }, sch_map, sp_maptype },

    { { 11, 0 }, { 0, 0 }, sch_mathsolver, sp_mathexpression },

    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_associatedarticle },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_bitrate },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_contentsize },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_contenturl },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_duration, },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_embedurl },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_encodescreativework },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_encodingformat },
    { { 3, 5 }, { 0, 0 }, sch_mediaobject, sp_endtime },
    { { 2, 0 }, { 3, 2 }, sch_mediaobject, sp_expires },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_height },
    { { 12, 0 }, { 0, 0 }, sch_mediaobject, sp_ineligibleregion },
    { { 13, 0 }, { 0, 0 }, sch_mediaobject, sp_interpretedasclaim },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_playertype },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_productioncompany },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_regionsallowed },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_requiressubscription },
    { { 13, 0 }, { 0, 0 }, sch_mediaobject, sp_sha256 },
    { { 3, 5 }, { 0, 0 }, sch_mediaobject, sp_starttime },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_uploaddate },
    { { 2, 0 }, { 0, 0 }, sch_mediaobject, sp_width },

    { { 7, 0 }, { 0, 0 }, sch_mediareview, sp_mediaauthenticitycategory },
    { { 13, 0 }, { 0, 0 }, sch_mediareview, sp_originalmediacontentdescription },
    { { 13, 0 }, { 0, 0 }, sch_mediareview, sp_originalmedialink },

    { { 13, 0 }, { 0, 0 }, sch_mediareviewitem, sp_mediaitemappearance },

    { { 3, 5 }, { 0, 0 }, sch_mediasubscription, sp_authenticator },
    { { 3, 5 }, { 0, 0 }, sch_mediasubscription, sp_expectsacceptanceof },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcause, sp_causeof },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalclinic, sp_availableservice },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalclinic, sp_medicalspeciality },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcode, sp_codevalue },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcode, sp_codingsystem },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_associatedanatomy },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_cause },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_differentialdiagnosis },
    { { 3, 5 }, { 0, 0 }, sch_medicalcondition, sp_drug },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_epidemiology },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_expectedprognosis },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_naturalprogression },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_pathophysiology },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_possiblecomplication },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_possibletreatment },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_primaryprevention },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_riskfactor },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_secondaryprevention },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_signorsymptom },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_stage },
    { { 3, 5 }, { 0, 0 }, sch_medicalcondition, sp_status },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_subtype },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalcondition, sp_typicaltest },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalconditionstage, sp_stageasnumber },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalconditionstage, sp_substagesuffix },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaldevice, sp_adverseoutcome },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaldevice, sp_contraindication },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaldevice, sp_indication },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaldevice, sp_postop },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaldevice, sp_preop },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaldevice, sp_procedure },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaldevice, sp_purpose },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaldevice, sp_seriousadverseoutcome },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalentity, sp_code },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalentity, sp_guideline },
    { { 3, 5 }, { 0, 0 }, sch_medicalentity, sp_legalstatus },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalentity, sp_medicinesystem },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalentity, sp_recognisingauthority },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalentity, sp_relevantspeciality },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalentity, sp_study },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalguideline, sp_evidencelevel },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalguideline, sp_evidenceorigin },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalguideline, sp_guidelinedate },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalguideline, sp_guidelinesubject },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalguidelinerecommendation, sp_recommendationstrength },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalobservationalstudy, sp_studydesign },

    { { 3, 5 }, { 0, 0 }, sch_medicalorganisation, sp_healthplannetworkid },
    { { 3, 5 }, { 0, 0 }, sch_medicalorganisation, sp_isacceptingnewpatients },
    { { 3, 5 }, { 0, 0 }, sch_medicalorganisation, sp_medicalspeciality },

    { { 3, 5 }, { 0, 0 }, sch_medicalprocedure, sp_bodylocation },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalprocedure, sp_followup },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalprocedure, sp_howperformed },
    { { 3, 5 }, { 6, 0 }, sch_medicalprocedure, sp_indication },
    { { 3, 5 }, { 6, 0 }, sch_medicalprocedure, sp_outcome },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalprocedure, sp_preparation },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalprocedure, sp_proceduretype },
    { { 3, 5 }, { 0, 0 }, sch_medicalprocedure, sp_status },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalriskestimator, sp_estimatesriskof },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalriskestimator, sp_includedriskfactor },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalriskfactor, sp_increasesriskof },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalriskscore, sp_algorithm },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalscholarlyarticle, sp_publicationtype },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalsign, sp_identifyingexam },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalsign, sp_identifyingtest },

    { { 2, 0, SV_NOT_3034 }, { 6, 0 }, sch_medicalsignorsymptom, sp_cause },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalsignorsymptom, sp_possibletreatment },

    { { 3, 5 }, { 0, 0 }, sch_medicalstudy, sp_healthcondition },
    { { 2, 0, SV_NOT_3034 }, { 6, 0 }, sch_medicalstudy, sp_outcome },
    { { 2, 0, SV_NOT_3034 }, { 6, 0 }, sch_medicalstudy, sp_population },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalstudy, sp_sponsor },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalstudy, sp_status },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalstudy, sp_studylocation },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicalstudy, sp_studysubject },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltest, sp_affectedby },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltest, sp_normalrange },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltest, sp_signdetected },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltest, sp_usedtodiagnose },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltest, sp_usesdevice },

    { { 2, 0 }, { 2, 1 }, sch_medicaltherapy, sp_adverseoutcome },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltherapy, sp_contraindication },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltherapy, sp_duplicatetherapy },
    { { 2, 0 }, { 2, 1 }, sch_medicaltherapy, sp_indication },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltherapy, sp_seriousadverseoutcome },

    { { 2, 0, SV_NOT_3034 }, { 6, 0 }, sch_medicaltrial, sp_phase },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_medicaltrial, sp_trialdesign },

    { { 2, 0 }, { 2, 1 }, sch_medicalwebpage, sp_aspect },
    { { 9, 0 }, { 0, 0 }, sch_medicalwebpage, sp_medicalaudience },

    { { 3, 3 }, { 0, 0 }, sch_menu, sp_hasmenuitem },
    { { 3, 3 }, { 0, 0 }, sch_menu, sp_hasmenusection },

    { { 3, 5 }, { 0, 0 }, sch_menuitem, sp_menuaddon },
    { { 3, 3 }, { 0, 0 }, sch_menuitem, sp_nutrition },
    { { 3, 3 }, { 0, 0 }, sch_menuitem, sp_offers },
    { { 3, 3 }, { 0, 0 }, sch_menuitem, sp_suitablefordiet },

    { { 3, 3 }, { 0, 0 }, sch_menusection, sp_hasmenuitem },
    { { 3, 3 }, { 0, 0 }, sch_menusection, sp_hasmenusection },

    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_additionalproperty },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_customerremorsereturnfees },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_customerremorsereturnlabelsource },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_customerremorsereturnshippingfeesamount },
    { { 6, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_instorereturnsoffered },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_itemcondition },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_itemdefectreturnfees },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_itemdefectreturnlabelsource },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_itemdefectreturnshippingfeesamount },
    { { 6, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_merchantreturndays },
    { { 6, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_merchantreturnlink },
    { { 6, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_refundtype },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_restockingfee },
    { { 6, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_returnfees },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_returnlabelsource },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_returnmethod },
    { { 6, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_returnpolicycategory },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_returnpolicycountry },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_returnpolicyseasonaloverride },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicy, sp_returnshippingfeesamount },

    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicyseasonaloverride, sp_enddate },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicyseasonaloverride, sp_merchantreturndays },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicyseasonaloverride, sp_returnpolicycategory },
    { { 13, 0 }, { 0, 0 }, sch_merchantreturnpolicyseasonaloverride, sp_startdate },

    { { 2, 0 }, { 0, 0 }, sch_mobileapplication, sp_carrierrequirements },

    { { 3, 3 }, { 0, 0 }, sch_message, sp_bccrecipient },
    { { 3, 3 }, { 0, 0 }, sch_message, sp_ccrecipient },
    { { 3, 0 }, { 0, 0 }, sch_message, sp_dateread },
    { { 3, 0 }, { 0, 0 }, sch_message, sp_datereceived },
    { { 3, 0 }, { 0, 0 }, sch_message, sp_datesent },
    { { 3, 0 }, { 0, 0 }, sch_message, sp_messageattachment },
    { { 3, 0 }, { 0, 0 }, sch_message, sp_recipient },
    { { 3, 0 }, { 0, 0 }, sch_message, sp_sender },
    { { 3, 3 }, { 0, 0 }, sch_message, sp_torecipient },

    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_chemicalrole },
    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_inchi },
    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_inchikey },
    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_iupacname },
    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_molecularformula },
    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_molecularweight },
    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_monoistopicmolecularweight },
    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_potentialuse },
    { { 13, 0 }, { 0, 0 }, sch_molecularentity, sp_smiles },

    { { 3, 0 }, { 0, 0 }, sch_monetaryamount, sp_currency },
    { { 3, 0 }, { 0, 0 }, sch_monetaryamount, sp_maxvalue },
    { { 3, 0 }, { 0, 0 }, sch_monetaryamount, sp_minvalue },
    { { 3, 0 }, { 0, 0 }, sch_monetaryamount, sp_validfrom },
    { { 3, 0 }, { 0, 0 }, sch_monetaryamount, sp_validthrough },
    { { 3, 0 }, { 0, 0 }, sch_monetaryamount, sp_value },

    { { 3, 5 }, { 0, 0 }, sch_monetaryamountdistribution, sp_currency },

    { { 3, 5 }, { 0, 0 }, sch_monetarygrant, sp_amount },
    { { 3, 5 }, { 0, 0 }, sch_monetarygrant, sp_funder },

    { { 3, 5 }, { 0, 0 }, sch_moneytransfer, sp_amount },
    { { 3, 5 }, { 0, 0 }, sch_moneytransfer, sp_beneficiarybank },

    { { 3, 5 }, { 0, 0 }, sch_mortgageloan, sp_domiciledmortgage },
    { { 3, 5 }, { 0, 0 }, sch_mortgageloan, sp_loanmortgagamandateamount },

    { { 2, 0 }, { 0, 0 }, sch_moveaction, sp_fromlocation },
    { { 2, 0 }, { 0, 0 }, sch_moveaction, sp_tolocation },

    { { 2, 0 }, { 0, 0 }, sch_movie, sp_actor },
    { { 2, 2 }, { 0, 0 }, sch_movie, sp_countryoforigin },
    { { 2, 0 }, { 0, 0 }, sch_movie, sp_director },
    { { 2, 0 }, { 0, 0 }, sch_movie, sp_duration },
    { { 2, 0 }, { 0, 0 }, sch_movie, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_movie, sp_productioncompany },
    { { 2, 0 }, { 0, 0 }, sch_movie, sp_subtitlelanguage },
    { { 8, 0 }, { 0, 0 }, sch_movie, sp_titleeidr },
    { { 2, 0 }, { 0, 0 }, sch_movie, sp_trailer },

    { { 2, 0 }, { 0, 0 }, sch_movieseries, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_movieseries, sp_director },
    { { 2, 0 }, { 0, 0 }, sch_movieseries, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_movieseries, sp_productioncompany },
    { { 2, 0 }, { 0, 0 }, sch_movieseries, sp_trailer },

    { { 2, 0 }, { 0, 0 }, sch_movietheatre, sp_screencount },

    { { 3, 5 }, { 0, 0 }, sch_muscle, sp_action },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_muscle, sp_antagonist },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_muscle, sp_bloodsupply },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_muscle, sp_insertion },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_muscle, sp_muscleaction },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_muscle, sp_nerve, },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_muscle, sp_origin },

    { { 2, 0 }, { 0, 0 }, sch_musicalbum, sp_albumproductiontype },
    { { 2, 0 }, { 0, 0 }, sch_musicalbum, sp_albumrelease },
    { { 2, 0 }, { 0, 0 }, sch_musicalbum, sp_albumreleasetype },
    { { 2, 0 }, { 0, 0 }, sch_musicalbum, sp_byartist },

    { { 2, 0 }, { 0, 0 }, sch_musicgroup, sp_album },
    { { 2, 0 }, { 0, 0 }, sch_musicgroup, sp_genre },
    { { 2, 0 }, { 0, 0 }, sch_musicgroup, sp_track },

    { { 2, 0 }, { 0, 0 }, sch_musicplaylist, sp_numtracks },
    { { 2, 0 }, { 0, 0 }, sch_musicplaylist, sp_track },

    { { 2, 0 }, { 0, 0 }, sch_musicrecording, sp_byartist },
    { { 2, 0 }, { 0, 0 }, sch_musicrecording, sp_duration },
    { { 2, 0 }, { 0, 0 }, sch_musicrecording, sp_inalbum },
    { { 2, 0 }, { 0, 0 }, sch_musicrecording, sp_inplaylist },
    { { 2, 0 }, { 0, 0 }, sch_musicrecording, sp_isrccode },
    { { 2, 0 }, { 0, 0 }, sch_musicrecording, sp_recordingof },

    { { 2, 0 }, { 0, 0 }, sch_musicrelease, sp_cataloguenumber },
    { { 2, 0 }, { 0, 0 }, sch_musicrelease, sp_creditedto },
    { { 2, 0 }, { 0, 0 }, sch_musicrelease, sp_duration },
    { { 2, 0 }, { 0, 0 }, sch_musicrelease, sp_musicreleaseformat },
    { { 2, 0 }, { 0, 0 }, sch_musicrelease, sp_recordlabel },
    { { 2, 0 }, { 0, 0 }, sch_musicrelease, sp_releaseof },

    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_composer },
    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_firstperformance },
    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_includedcomposition },
    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_iswccode },
    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_lyricist },
    { { 2, 1 }, { 0, 0 }, sch_musiccomposition, sp_lyrics },
    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_musicarrangement },
    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_musiccompositionform },
    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_musicalkey },
    { { 2, 0 }, { 0, 0 }, sch_musiccomposition, sp_recordedas },

    { { 2, 0 }, { 0, 0 }, sch_nerve, sp_branch },
    { { 2, 0 }, { 0, 0 }, sch_nerve, sp_nervemotor },
    { { 2, 0 }, { 0, 0 }, sch_nerve, sp_sensoryunit },
    { { 2, 0 }, { 0, 0 }, sch_nerve, sp_sourcedfrom },

    { { 2, 0 }, { 0, 0 }, sch_newsarticle, sp_dateline },
    { { 2, 0 }, { 0, 0 }, sch_newsarticle, sp_printcolumn },
    { { 2, 0 }, { 0, 0 }, sch_newsarticle, sp_printedition },
    { { 2, 0 }, { 0, 0 }, sch_newsarticle, sp_printpage },
    { { 2, 0 }, { 0, 0 }, sch_newsarticle, sp_printsection },

    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_actionablefeedbackpolicy },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_correctionspolicy },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_diversitypolicy },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_diversitystaffingreport },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_ethicspolicy },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_masthead },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_missioncoverageprioritiespolicy },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_nobylinespolicy },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_ownershipfundinginfo },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_unnamedsourcespolicy },
    { { 3, 5 }, { 0, 0 }, sch_newsmediaorganisation, sp_verificationfactcheckingpolicy },

    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_calories },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_carbohydratecontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_cholesterolcontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_fatcontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_fibrecontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_proteincontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_saturatedfatcontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_servingsize },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_sodiumcontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_sugarcontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_transfatcontent },
    { { 2, 0 }, { 0, 0 }, sch_nutritioninformation, sp_unsaturatedfatcontent },

    { { 3, 9 }, { 0, 0 }, sch_observation, sp_marginoferror },
    { { 3, 9 }, { 0, 0 }, sch_observation, sp_measuredproperty },
    { { 3, 9 }, { 0, 0 }, sch_observation, sp_measuredvalue },
    { { 3, 9 }, { 0, 0 }, sch_observation, sp_observationdate },
    { { 3, 9 }, { 0, 0 }, sch_observation, sp_observednode },

    { { 3, 5 }, { 0, 0 }, sch_occupation, sp_educationrequirements },
    { { 3, 5 }, { 0, 0 }, sch_occupation, sp_estimatedsalary },
    { { 3, 5 }, { 0, 0 }, sch_occupation, sp_experiencerequirements },
    { { 3, 5 }, { 0, 0 }, sch_occupation, sp_occupationlocation },
    { { 3, 5 }, { 0, 0 }, sch_occupation, sp_occupationalcategory },
    { { 3, 5 }, { 0, 0 }, sch_occupation, sp_qualifications },
    { { 3, 5 }, { 0, 0 }, sch_occupation, sp_responsibilities },
    { { 3, 5 }, { 0, 0 }, sch_occupation, sp_skills },

    { { 12, 0 }, { 0, 0 }, sch_occupationalexperiencerequirements, sp_monthsofexperience },

    { { 2, 0 }, { 0, 0 }, sch_offer, sp_acceptedpaymentmethod },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_acceptedpaymentmethods },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_addon },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_addon },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_advancebookingrequirement },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_advancebookingrequirement },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_aggregaterating },
    { { 2, 2 }, { 0, 0 }, sch_offer, sp_areaserved },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_availableatorfrom },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_availability },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_availabilityends },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_availabilityends },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_availabilitystarts },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_availabilitystarts },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_availableatorfrom },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_availabledeliverymethod },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_availabledeliverymethods },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_businessfunction },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_category },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_deliveryleadtime },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_deliveryleadtime },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_eligiblecustomertype },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_eligiblecustomertypes },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_eligibleduration },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_eligibleduration },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_eligiblequantity },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_eligibleregion },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_eligibletransactionvolume },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_eligibletransactionvolume },
    { { 3, 8 }, { 0, 0 }, sch_offer, sp_gtin },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_gtin12 },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_gtin13 },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_gtin14 },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_gtin8 },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_hasbusinessfunction },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_haseligiblequantity },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_hasinventorylevel },
    { { 13, 0 }, { 0, 0 }, sch_offer, sp_hasmerchantreturnpolicy },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_haspricespecification },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_haswarrantypromise },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_includes },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_includesobject },
    { { 2, 0 }, { 0, 0 }, sch_offer, gr_includesobject },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_ineligibleregion },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_inventorylevel },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_itemcondition },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_itemoffered },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_mpn },
    { { 2, 2 }, { 0, 0 }, sch_offer, sp_offeredby },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_price },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_pricecurrency },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_pricespecification },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_pricevaliduntil },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_review },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_seller },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_serialnumber },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_sku },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_validfrom },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_validthrough },
    { { 2, 0 }, { 0, 0 }, sch_offer, sp_warranty },

    { { 8, 0 }, { 0, 0 }, sch_offershippingdetails, sp_deliverytime },
    { { 8, 0 }, { 0, 0 }, sch_offershippingdetails, sp_doesnotship },
    { { 7, 2 }, { 0, 0 }, sch_offershippingdetails, sp_shippingdestination },
    { { 8, 0 }, { 0, 0 }, sch_offershippingdetails, sp_shippinglabel },
    { { 8, 0 }, { 0, 0 }, sch_offershippingdetails, sp_shippingrate },
    { { 8, 0 }, { 0, 0 }, sch_offershippingdetails, sp_shippingsettingslink },
    { { 8, 0 }, { 0, 0 }, sch_offershippingdetails, sp_transittimelabel },

    { { 2, 0 }, { 0, 0 }, sch_openinghoursspecification, sp_closes },
    { { 2, 0 }, { 0, 0 }, sch_openinghoursspecification, sp_dayofweek },
    { { 2, 0 }, { 0, 0 }, sch_openinghoursspecification, sp_opens },
    { { 2, 0 }, { 0, 0 }, sch_openinghoursspecification, sp_validfrom },
    { { 2, 0 }, { 0, 0 }, sch_openinghoursspecification, sp_validthrough },

    { { 2, 0 }, { 0, 0 }, sch_order, sp_acceptedoffer },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_billingaddress },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_broker },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_confirmationnumber },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_customer },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_discount },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_discountcode },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_discountcurrency },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_isgift },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_orderdate },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_orderdelivery },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_ordernumber },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_orderstatus },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_ordereditem },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_partofinvoice },
    { { 2, 0 }, { 2, 0 }, sch_order, sp_paymentdue },
    { { 2, 1 }, { 0, 0 }, sch_order, sp_paymentduedate },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_paymentmethod },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_paymentmethodid },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_paymenturl },
    { { 2, 0 }, { 0, 0 }, sch_order, sp_seller },

    { { 2, 0 }, { 0, 0 }, sch_orderaction, sp_deliverymethod },

    { { 2, 0 }, { 0, 0 }, sch_orderitem, sp_orderdelivery },
    { { 2, 0 }, { 0, 0 }, sch_orderitem, sp_orderitemnumber },
    { { 2, 0 }, { 0, 0 }, sch_orderitem, sp_orderitemstatus  },
    { { 2, 0 }, { 0, 0 }, sch_orderitem, sp_orderquantity  },
    { { 2, 0 }, { 0, 0 }, sch_orderitem, sp_ordereditem  },

    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_actionablefeedbackpolicy },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_address },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_aggregaterating },
    { { 2, 2 }, { 0, 0 }, sch_organisation, sp_alumni },
    { { 3, 0 }, { 0, 0 }, sch_organisation, sp_areaserved },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_award },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_brand },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_contactpoint },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_correctionspolicy },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_department },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_dissolutiondate },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_diversitypolicy },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_diversitystaffingreport },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_duns },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_email },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_employee },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_ethicspolicy },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_event },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_faxnumber },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_founder },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_foundingdate },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_foundinglocation },
    { { 3, 1 }, { 0, 0 }, sch_organisation, sp_funder },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_globallocationnumber },
    { { 2, 0 }, { 0, 0 }, sch_organisation, gr_hasbrand },
    { { 3, 9 }, { 0, 0 }, sch_organisation, sp_hascredential },
    { { 6, 0 }, { 0, 0 }, sch_organisation, sp_hasmerchantreturnpolicy },
    { { 2, 2 }, { 0, 0 }, sch_organisation, sp_hasoffercatalogue },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_haspos },
    { { 2, 0 }, { 0, 0 }, sch_organisation, gr_haspos },
    { { 3, 8 }, { 5, 0 }, sch_organisation, sp_hasproductreturnpolicy },
    { { 6, 0 }, { 0, 0 }, sch_organisation, sp_interactionstatistic },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_isicv4 },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_knowsabout },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_knowslanguage },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_legalname },
    { { 3, 0 }, { 0, 0 }, sch_organisation, sp_leicode },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_location },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_logo },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_makesoffer },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_member },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_memberof },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_naics },
    { { 8, 0 }, { 0, 0 }, sch_organisation, sp_nonprofitstatus },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_numberofemployees },
    { { 2, 0 }, { 0, 0 }, sch_organisation, gr_offers },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_ownershipfundinginfo },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_owns },
    { { 2, 0 }, { 0, 0 }, sch_organisation, gr_owns },
    { { 2, 1 }, { 0, 0 }, sch_organisation, sp_parentorganisation },
    { { 3, 3 }, { 0, 0 }, sch_organisation, sp_publishingprinciples },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_review },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_seeks },
    { { 2, 0 }, { 0, 0 }, sch_organisation, gr_seeks },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_slogan },
    { { 3, 0 }, { 0, 0 }, sch_organisation, sp_sponsor },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_suborganisation },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_taxid },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_telephone },
    { { 3, 5 }, { 0, 0 }, sch_organisation, sp_unnamedsourcespolicy },
    { { 2, 0 }, { 0, 0 }, sch_organisation, sp_vatid },

    { { 2, 0 }, { 0, 0 }, sch_organisationrole, sp_numberedposition },

    { { 2, 0 }, { 0, 0 }, sch_ownershipinfo, sp_acquiredfrom },
    { { 2, 0 }, { 0, 0 }, sch_ownershipinfo, sp_ownedfrom },
    { { 2, 0 }, { 0, 0 }, sch_ownershipinfo, sp_ownedthrough },
    { { 2, 0 }, { 0, 0 }, sch_ownershipinfo, sp_typeofgood },

    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_deliveryaddress },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_deliverystatus },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_expectedarrivalfrom },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_expectedarrivaluntil },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_hasdeliverymethod },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_itemshipped },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_originaddress },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_partoforder },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_provider },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_trackingnumber },
    { { 2, 0 }, { 0, 0 }, sch_parceldelivery, sp_trackingurl },

    { { 2, 0 }, { 0, 0 }, sch_parentaudience, sp_childminage },
    { { 2, 0 }, { 0, 0 }, sch_parentaudience, sp_childmaxage  },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_pathologytest, sp_tissuesample },

    { { 3, 5 }, { 0, 0 }, sch_patient, sp_diagnosis },
    { { 3, 5 }, { 0, 0 }, sch_patient, sp_drug },
    { { 3, 5 }, { 0, 0 }, sch_patient, sp_healthcondition },

    { { 2, 0, SV_NOT_3034 }, { 6, 0 }, sch_payaction, sp_purpose },
    { { 2, 0 }, { 0, 0 }, sch_payaction, sp_recipient },

    { { 3, 5 }, { 0, 0 }, sch_paymentcard, sp_cashback },
    { { 3, 5 }, { 0, 0 }, sch_paymentcard, sp_contactlesspayment },
    { { 3, 5 }, { 0, 0 }, sch_paymentcard, sp_floorlimit },
    { { 9, 0 }, { 0, 0 }, sch_paymentcard, sp_minimummonthlyrepaymentamount },

    { { 2, 0 }, { 0, 0 }, sch_paymentchargespecification, sp_appliestodeliverymethod },
    { { 2, 0 }, { 0, 0 }, sch_paymentchargespecification, sp_appliestopaymentmethod },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_peopleaudience, sp_healthcondition },
    { { 2, 0 }, { 0, 0 }, sch_peopleaudience, sp_requiredgender },
    { { 2, 0 }, { 0, 0 }, sch_peopleaudience, sp_requiredmaxage },
    { { 2, 0 }, { 0, 0 }, sch_peopleaudience, sp_requiredminage },
    { { 2, 0 }, { 0, 0 }, sch_peopleaudience, sp_suggestedgender },
    { { 2, 0 }, { 0, 0 }, sch_peopleaudience, sp_suggestedmaxage },
    { { 2, 0 }, { 0, 0 }, sch_peopleaudience, sp_suggestedminage },

    { { 2, 0 }, { 0, 0 }, sch_performaction, sp_entertainmentbusiness },

    { { 2, 0 }, { 0, 0 }, sch_performancerole, sp_charactername },

    { { 2, 0 }, { 3, 2 }, sch_periodical, sp_issn },

    { { 2, 0 }, { 0, 0 }, sch_permit, sp_issuedby },
    { { 2, 0 }, { 0, 0 }, sch_permit, sp_issuedthrough },
    { { 2, 0 }, { 0, 0 }, sch_permit, sp_permitaudience },
    { { 2, 0 }, { 0, 0 }, sch_permit, sp_validfor },
    { { 2, 0 }, { 0, 0 }, sch_permit, sp_validfrom },
    { { 2, 0 }, { 0, 0 }, sch_permit, sp_validin },
    { { 2, 0 }, { 0, 0 }, sch_permit, sp_validuntil },

    { { 2, 0 }, { 0, 0 }, sch_person, sp_additionalname },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_address },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_affiliation },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_alumniof },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_award },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_birthdate },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_birthplace },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_brand },
    { { 5, 0 }, { 0, 0 }, sch_person, sp_callsign },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_children },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_colleague },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_contactpoint },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_deathdate },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_deathplace },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_duns },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_email },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_familyname },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_faxnumber },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_follows },
    { { 3, 1 }, { 0, 0 }, sch_person, sp_funder },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_gender },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_givenname },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_globallocationnumber },
    { { 2, 0 }, { 0, 0 }, sch_person, gr_hasbrand },
    { { 3, 9 }, { 0, 0 }, sch_person, sp_hascredential },
    { { 3, 5 }, { 0, 0 }, sch_person, sp_hasoccupation },
    { { 2, 0 }, { 0, 0 }, sch_person, gr_haspos },
    { { 2, 2 }, { 0, 0 }, sch_person, sp_hasoffercatalogue },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_haspos },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_height },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_homelocation },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_honourificprefix },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_honourificsuffix },
    { { 6, 0 }, { 0, 0 }, sch_person, sp_interactionstatistic },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_isicv4 },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_jobtitle },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_knows },
    { { 3, 5 }, { 0, 0 }, sch_person, sp_knowsabout },
    { { 3, 5 }, { 0, 0 }, sch_person, sp_knowslanguage },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_makesoffer },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_memberof },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_naics },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_nationality },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_networth },
    { { 2, 0 }, { 0, 0 }, sch_person, gr_offers },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_owns },
    { { 2, 0 }, { 0, 0 }, sch_person, gr_owns },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_parent },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_performerin },
    { { 3, 3 }, { 0, 0 }, sch_person, sp_publishingprinciples },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_relatedto },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_seeks },
    { { 2, 0 }, { 0, 0 }, sch_person, gr_seeks },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_sibling },
    { { 3, 0 }, { 0, 0 }, sch_person, sp_sponsor },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_spouse },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_taxid },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_telephone },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_vatid },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_weight },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_worklocation },
    { { 2, 0 }, { 0, 0 }, sch_person, sp_worksfor },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_physicalactivity, sp_associatedanatomy },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_physicalactivity, sp_category },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_physicalactivity, sp_epidemiology },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_physicalactivity, sp_pathophysiology },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_physician, sp_availableservice },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_physician, sp_hospitalaffiliation },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_physician, sp_medicalspeciality },

    { { 2, 0 }, { 0, 0 }, sch_place, sp_additionalproperty },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_address },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_aggregaterating },
    { { 3, 1 }, { 0, 0 }, sch_place, sp_amenityfeature },
    { { 2, 2 }, { 0, 0 }, sch_place, sp_branchcode },
    { { 2, 0 }, { 2, 1 }, sch_place, sp_containedin },
    { { 2, 2 }, { 0, 0 }, sch_place, sp_containedinplace },
    { { 3, 0 }, { 0, 0 }, sch_place, sp_containsplace },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_event },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_faxnumber },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_geo },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geocontains },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geocoveredby },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geocovers },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geocrosses },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geodisjoint },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geoequals },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geointersects },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geooverlaps },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geotouches },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_geowithin },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_globallocationnumber },
    { { 7, 0 }, { 0, 0 }, sch_place, sp_hasdrivethroughservice },
    { { 2, 0 }, { 0, 0 }, sch_place, gr_hasopeninghoursspecification },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_hasmap },
    { { 3, 3 }, { 0, 0 }, sch_place, sp_isaccessibleforfree },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_isicv4 },
    { { 4, 0 }, { 0, 0 }, sch_place, sp_latitude },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_logo },
    { { 4, 0 }, { 0, 0 }, sch_place, sp_longitude },
    { { 3, 2 }, { 0, 0 }, sch_place, sp_maximumattendeecapacity },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_openinghoursspecification },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_photo },
    { { 3, 3 }, { 0, 0 }, sch_place, sp_publicaccess },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_review },
    { { 3, 5 }, { 0, 0 }, sch_place, sp_slogan },
    { { 3, 1 }, { 0, 0 }, sch_place, sp_smokingallowed },
    { { 3, 0 }, { 0, 0 }, sch_place, sp_specialopeninghoursspecification },
    { { 2, 0 }, { 0, 0 }, sch_place, sp_telephone },
    { { 7, 0 }, { 0, 0 }, sch_place, sp_tourbookingpage },

    { { 2, 0 }, { 0, 0 }, sch_planaction, sp_scheduledtime },

    { { 2, 0 }, { 0, 0 }, sch_playaction, sp_audience },
    { { 2, 0 }, { 0, 0 }, sch_playaction, sp_event },

    { { 13, 0 }, { 0, 0 }, sch_podcastseries, sp_actor },
    { { 4, 0 }, { 0, 0 }, sch_podcastseries, sp_webfeed },

    { { 2, 0 }, { 0, 0 }, sch_postaladdress, sp_addresscountry },
    { { 2, 0 }, { 0, 0 }, sch_postaladdress, sp_addresslocality },
    { { 2, 0 }, { 0, 0 }, sch_postaladdress, sp_addressregion },
    { { 2, 0 }, { 0, 0 }, sch_postaladdress, sp_postofficeboxnumber },
    { { 2, 0 }, { 0, 0 }, sch_postaladdress, sp_postalcode },
    { { 2, 0 }, { 0, 0 }, sch_postaladdress, sp_streetaddress },

    { { 8, 0 }, { 0, 0 }, sch_postalcoderangespecification, sp_postalcodebegin },
    { { 8, 0 }, { 0, 0 }, sch_postalcoderangespecification, sp_postalcodeend },

    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_eligiblequantity },
    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_eligibletransactionvolume },
    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_maxprice },
    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_minprice },
    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_price },
    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_pricecurrency },
    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_validfrom },
    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_validthrough },
    { { 2, 0 }, { 0, 0 }, sch_pricespecification, sp_valueaddedtaxincluded },

    { { 2, 0 }, { 0, 0 }, sch_product, sp_additionalproperty },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_aggregaterating },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_audience },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_award },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_brand },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_category },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_colour },
    { { 13, 0 }, { 0, 0 }, sch_product, sp_countryofassembly },
    { { 13, 0 }, { 0, 0 }, sch_product, sp_countryoflastprocessing },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_depth },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_depth },
    { { 3, 8 }, { 0, 0 }, sch_product, sp_gtin },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_gtin12 },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_gtin13 },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_gtin14 },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_gtin8 },
    { { 10, 0 }, { 0, 0 }, sch_product, sp_hasenergyconsumptiondetails },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_hasbrand },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_hasmakeandmodel },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_hasmanufacturer },
    { { 6, 0 }, { 0, 0 }, sch_product, sp_hasmerchantreturnpolicy },
    { { 3, 8 }, { 5, 0 }, sch_product, sp_hasproductreturnpolicy },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_height },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_height },
    { { 9, 0 }, { 0, 0 }, sch_product, sp_inproductgroupwithid },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_isaccessoryorsparepartfor },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_isaccessoryorsparepartfor },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_isconsumablefor },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_isconsumablefor },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_isrelatedto },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_issimilarto },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_issimilarto },
    { { 9, 0 }, { 0, 0 }, sch_product, sp_isvariantof },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_itemcondition },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_logo },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_manufacturer },
    { { 3, 2 }, { 0, 0 }, sch_product, sp_material },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_model },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_mpn },
    { { 3, 5 }, { 0, 0 }, sch_product, sp_nsn },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_offers },
    { { 9, 0 }, { 0, 0 }, sch_product, sp_pattern },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_productid },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_productiondate },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_purchasedate },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_qualitativeproductorserviceproperty },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_quantitativeproductorserviceproperty },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_releasedate },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_review },
    { { 9, 0 }, { 0, 0 }, sch_product, sp_size },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_sku },
    { { 3, 5 }, { 0, 0 }, sch_product, sp_slogan },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_weight },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_weight },
    { { 2, 0 }, { 0, 0 }, sch_product, sp_width },
    { { 2, 0 }, { 0, 0 }, sch_product, gr_width },

    { { 9, 0 }, { 0, 0 }, sch_productcollection, sp_includesobject },

    { { 9, 0 }, { 0, 0 }, sch_productgroup, sp_hasvariant },
    { { 9, 0 }, { 0, 0 }, sch_productgroup, sp_productgroupid },
    { { 9, 0 }, { 0, 0 }, sch_productgroup, sp_variesby },

    { { 2, 0 }, { 0, 0 }, sch_productmodel, sp_isvariantof },
    { { 2, 0 }, { 0, 0 }, sch_productmodel, sp_predecessorof },
    { { 2, 0 }, { 0, 0 }, sch_productmodel, sp_successorof },

    { { 2, 0 }, { 0, 0 }, sch_programmemembership, sp_hostingorganisation },
    { { 2, 0 }, { 0, 0 }, sch_programmemembership, sp_member },
    { { 2, 0 }, { 0, 0 }, sch_programmemembership, sp_membershipnumber },
    { { 3, 5 }, { 0, 0 }, sch_programmemembership, sp_membershippointsearned },
    { { 2, 0 }, { 0, 0 }, sch_programmemembership, sp_programmename },

    { { 6, 0 }, { 0, 0 }, sch_pronounceabletext, sp_inlanguage },
    { { 6, 0 }, { 0, 0 }, sch_pronounceabletext, sp_phonetictext },
    { { 6, 0 }, { 0, 0 }, sch_pronounceabletext, sp_speechtotextmarkup },
    { { 6, 0 }, { 0, 0 }, sch_pronounceabletext, sp_textvalue },

    { { 2, 0 }, { 0, 0 }, sch_property, sp_domainincludes },
    { { 2, 0 }, { 0, 0 }, sch_property, sp_inverseof },
    { { 2, 0 }, { 0, 0 }, sch_property, sp_rangeincludes },
    { { 2, 0 }, { 0, 0 }, sch_property, sp_supersededby },

    { { 2, 0 }, { 0, 0 }, sch_propertyvalue, sp_maxvalue },
    { { 3, 5 }, { 0, 0 }, sch_propertyvalue, sp_measurementtechnique },
    { { 2, 0 }, { 0, 0 }, sch_propertyvalue, sp_minvalue },
    { { 2, 0 }, { 0, 0 }, sch_propertyvalue, sp_propertyid },
    { { 2, 0 }, { 0, 0 }, sch_propertyvalue, sp_unitcode },
    { { 2, 0 }, { 0, 0 }, sch_propertyvalue, sp_unittext },
    { { 2, 0 }, { 0, 0 }, sch_propertyvalue, sp_value },
    { { 2, 0 }, { 0, 0 }, sch_propertyvalue, sp_valuereference },

    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_defaultvalue },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_maxvalue },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_minvalue },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_multiplevalues },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_readonlyvalue },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_stepvalue },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_valuemaxlength },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_valueminlength },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_valuename },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_valuepattern },
    { { 2, 0 }, { 0, 0 }, sch_propertyvaluespecification, sp_valuerequired },

    { { 2, 0 }, { 8, 0 }, sch_publicationevent, sp_isaccessibleforfree },
    { { 3, 5 }, { 0, 0 }, sch_publicationevent, sp_publishedby },
    { { 2, 0 }, { 0, 0 }, sch_publicationevent, sp_publishedon },

    { { 2, 0 }, { 0, 0 }, sch_publicationissue, sp_issuenumber },
    { { 2, 0 }, { 0, 0 }, sch_publicationissue, sp_pageend },
    { { 2, 0 }, { 0, 0 }, sch_publicationissue, sp_pagestart },
    { { 2, 0 }, { 0, 0 }, sch_publicationissue, sp_pagination },

    { { 2, 0 }, { 0, 0 }, sch_publicationvolume, sp_pageend },
    { { 2, 0 }, { 0, 0 }, sch_publicationvolume, sp_pagestart },
    { { 2, 0 }, { 0, 0 }, sch_publicationvolume, sp_pagination },
    { { 2, 0 }, { 0, 0 }, sch_publicationvolume, sp_volumenumber },

    { { 13, 0 }, { 0, 0 }, sch_protein, sp_hasbiopolymersequence },

    { { 2, 0 }, { 0, 0 }, sch_qualitativevalue, sp_additionalproperty },
    { { 2, 0 }, { 0, 0 }, sch_qualitativevalue, sp_equal },
    { { 2, 0 }, { 0, 0 }, sch_qualitativevalue, sp_greater },
    { { 2, 0 }, { 0, 0 }, sch_qualitativevalue, sp_greaterorequal },
    { { 2, 0 }, { 0, 0 }, sch_qualitativevalue, sp_lesser },
    { { 2, 0 }, { 0, 0 }, sch_qualitativevalue, sp_lesserorequal },
    { { 2, 0 }, { 0, 0 }, sch_qualitativevalue, sp_nonequal },
    { { 2, 0 }, { 0, 0 }, sch_qualitativevalue, sp_valuereference },

    { { 2, 0 }, { 0, 0 }, sch_quantitativevalue, sp_additionalproperty },
    { { 2, 0 }, { 0, 0 }, sch_quantitativevalue, sp_maxvalue },
    { { 2, 0 }, { 0, 0 }, sch_quantitativevalue, sp_minvalue },
    { { 2, 0 }, { 0, 0 }, sch_quantitativevalue, sp_unitcode },
    { { 2, 0 }, { 0, 0 }, sch_quantitativevalue, sp_unittext },
    { { 2, 0 }, { 0, 0 }, sch_quantitativevalue, sp_value },
    { { 2, 0 }, { 0, 0 }, sch_quantitativevalue, sp_valuereference },

    { { 3, 5 }, { 0, 0 }, sch_quantitativevaluedistribution, sp_duration },
    { { 3, 5 }, { 0, 0 }, sch_quantitativevaluedistribution, sp_median },
    { { 3, 5 }, { 0, 0 }, sch_quantitativevaluedistribution, sp_percentile10 },
    { { 3, 5 }, { 0, 0 }, sch_quantitativevaluedistribution, sp_percentile25 },
    { { 3, 5 }, { 0, 0 }, sch_quantitativevaluedistribution, sp_percentile75 },
    { { 3, 5 }, { 0, 0 }, sch_quantitativevaluedistribution, sp_percentile90 },

    { { 2, 0 }, { 0, 0 }, sch_question, sp_acceptedanswer },
    { { 2, 0 }, { 0, 0 }, sch_question, sp_answercount },
    { { 2, 0 }, { 0, 0 }, sch_question, sp_downvotecount },
    { { 10, 0 }, { 0, 0 }, sch_question, sp_eduquestiontype },
    { { 2, 0 }, { 0, 0 }, sch_question, sp_suggestedanswer },
    { { 2, 0 }, { 0, 0 }, sch_question, sp_upvotecount },

    { { 3, 5 }, { 0, 0 }, sch_quotation, sp_spokenbycharacter },

    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_containsseason },
    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_director },
    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_episode },
    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_numberofepisodes },
    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_numberofseasons },
    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_productioncompany },
    { { 2, 0 }, { 0, 0 }, sch_radioseries, sp_trailer },

    { { 3, 1 }, { 0, 0 }, sch_rating, sp_author },
    { { 2, 0 }, { 0, 0 }, sch_rating, sp_bestrating },
    { { 3, 9 }, { 0, 0 }, sch_rating, sp_ratingexplanation },
    { { 2, 0 }, { 0, 0 }, sch_rating, sp_ratingvalue },
    { { 3, 5 }, { 0, 0 }, sch_rating, sp_reviewaspect },
    { { 2, 0 }, { 0, 0 }, sch_rating, sp_worstrating },

    { { 5, 0 }, { 0, 0 }, sch_realestatelisting, sp_leaselength },
    { { 6, 0 }, { 0, 0 }, sch_realestatelisting, sp_dateposted },

    { { 2, 0 }, { 0, 0 }, sch_receiveaction, sp_deliverymethod },
    { { 2, 0 }, { 0, 0 }, sch_receiveaction, sp_sender },

    { { 2, 0 }, { 0, 0 }, sch_recipe, sp_cooktime },
    { { 2, 0 }, { 0, 0 }, sch_recipe, sp_cookingmethod },
    { { 2, 0 }, { 0, 0 }, sch_recipe, sp_nutrition },
    { { 2, 0 }, { 3, 2 }, sch_recipe, sp_preptime },
    { { 2, 0 }, { 0, 0 }, sch_recipe, sp_recipecategory },
    { { 2, 0 }, { 0, 0 }, sch_recipe, sp_recipecuisine },
    { { 2, 0 }, { 0, 0 }, sch_recipe, sp_recipeingredient },
    { { 2, 0 }, { 0, 0 }, sch_recipe, sp_recipeinstructions },
    { { 2, 0 }, { 0, 0 }, sch_recipe, sp_recipeyield },
    { { 3, 0 }, { 0, 0 }, sch_recipe, sp_suitablefordiet },
    { { 2, 0 }, { 3, 2 }, sch_recipe, sp_totaltime },

    { { 2, 0 }, { 0, 0 }, sch_rentaction, sp_landlord },
    { { 2, 0 }, { 0, 0 }, sch_rentaction, sp_realestateagent },

    { { 2, 0 }, { 0, 0 }, sch_rentalcarreservation, sp_dropofflocation },
    { { 2, 0 }, { 0, 0 }, sch_rentalcarreservation, sp_dropofftime },
    { { 2, 0 }, { 0, 0 }, sch_rentalcarreservation, sp_pickuplocation },
    { { 2, 0 }, { 0, 0 }, sch_rentalcarreservation, sp_pickuptime },

    { { 3, 5 }, { 0, 0 }, sch_repaymentspecification, sp_downpayment },
    { { 3, 5 }, { 0, 0 }, sch_repaymentspecification, sp_earlyprepaymentpenalty },
    { { 3, 5 }, { 0, 0 }, sch_repaymentspecification, sp_loanpaymentamount },
    { { 3, 5 }, { 0, 0 }, sch_repaymentspecification, sp_loanpaymentfrequency },
    { { 3, 5 }, { 0, 0 }, sch_repaymentspecification, sp_numberofloanpayments },

    { { 2, 0 }, { 0, 0 }, sch_replaceaction, sp_replacee },
    { { 2, 0 }, { 0, 0 }, sch_replaceaction, sp_replacer },

    { { 2, 0 }, { 0, 0 }, sch_replyaction, sp_resultcomment },

    { { 2, 1 }, { 0, 0 }, sch_report, sp_reportnumber },

    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_bookingtime },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_broker },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_modifiedtime },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_pricecurrency },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_programmemembershipused },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_provider },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_reservationfor },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_reservationid },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_reservationstatus },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_reservedticket },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_totalprice },
    { { 2, 0 }, { 0, 0 }, sch_reservation, sp_undername },

    { { 2, 0 }, { 0, 0 }, sch_reservationpackage, sp_subreservation },

    { { 6, 0 }, { 0, 0 }, sch_residence, sp_accommodationfloorplan },

    { { 2, 0 }, { 0, 0 }, sch_returnaction, sp_recipient },

    { { 13, 0 }, { 0, 0 }, sch_review, sp_associatedclaimreview },
    { { 13, 0 }, { 0, 0 }, sch_review, sp_associatedmediareview },
    { { 13, 0 }, { 0, 0 }, sch_review, sp_associatedreview },
    { { 2, 0 }, { 0, 0 }, sch_review, sp_itemreviewed },
    { { 13, 0 }, { 0, 0 }, sch_review, sp_negativevotes },
    { { 13, 0 }, { 0, 0 }, sch_review, sp_positivevotes },
    { { 3, 5 }, { 0, 0 }, sch_review, sp_reviewaspect },
    { { 2, 0 }, { 0, 0 }, sch_review, sp_reviewbody },
    { { 2, 0 }, { 0, 0 }, sch_review, sp_reviewrating },

    { { 2, 0 }, { 0, 0 }, sch_reviewaction, sp_resultreview },

    { { 2, 0 }, { 0, 0 }, sch_role, sp_enddate },
    { { 2, 0 }, { 0, 0 }, sch_role, sp_rolename },
    { { 2, 0 }, { 0, 0 }, sch_role, sp_startdate },

    { { 2, 0 }, { 0, 0 }, sch_rsvpaction, sp_additionalnumberofguests },
    { { 2, 0 }, { 0, 0 }, sch_rsvpaction, sp_comment },
    { { 2, 0 }, { 0, 0 }, sch_rsvpaction, sp_rsvpresponse },

    { { 3, 5 }, { 0, 0 }, sch_schedule, sp_byday },
    { { 3, 5 }, { 0, 0 }, sch_schedule, sp_bymonth },
    { { 3, 5 }, { 0, 0 }, sch_schedule, sp_bymonthday },
    { { 9, 0 }, { 0, 0 }, sch_schedule, sp_bymonthweek },
    { { 6, 0 }, { 0, 0 }, sch_schedule, sp_duration },
    { { 7, 0 }, { 0, 0 }, sch_schedule, sp_enddate },
    { { 7, 4 }, { 0, 0 }, sch_schedule, sp_endtime },
    { { 3, 5 }, { 5, 0 }, sch_schedule, sp_eventschedule },
    { { 3, 5 }, { 0, 0 }, sch_schedule, sp_exceptdate },
    { { 3, 5 }, { 0, 0 }, sch_schedule, sp_repeatcount },
    { { 3, 5 }, { 0, 0 }, sch_schedule, sp_repeatfrequency },
    { { 6, 0 }, { 0, 0 }, sch_schedule, sp_scheduletimezone },
    { { 7, 0 }, { 0, 0 }, sch_schedule, sp_startdate },
    { { 7, 4 }, { 0, 0 }, sch_schedule, sp_starttime },

    { { 2, 0 }, { 0, 0 }, sch_screeningevent, sp_subtitlelanguage },
    { { 2, 0 }, { 0, 0 }, sch_screeningevent, sp_videoformat },
    { { 2, 0 }, { 0, 0 }, sch_screeningevent, sp_workpresented },

    { { 2, 0 }, { 0, 0 }, sch_searchaction, sp_query },

    { { 2, 0 }, { 0, 0 }, sch_seat, sp_seatnumber },
    { { 2, 0 }, { 0, 0 }, sch_seat, sp_seatrow },
    { { 2, 0 }, { 0, 0 }, sch_seat, sp_seatsection },
    { { 2, 0 }, { 0, 0 }, sch_seat, sp_seatingtype },

    { { 13, 0 }, { 0, 0 }, sch_seektoaction, sp_startoffset },

    { { 2, 0 }, { 0, 0 }, sch_sellaction, sp_buyer },

    { { 2, 0 }, { 0, 0 }, sch_sendaction, sp_deliverymethod },
    { { 2, 0 }, { 0, 0 }, sch_sendaction, sp_recipient },

    { { 2, 0 }, { 0, 0 }, sch_service, sp_aggregaterating },
    { { 2, 2 }, { 0, 0 }, sch_service, sp_areaserved },
    { { 3, 0 }, { 0, 0 }, sch_service, sp_audience },
    { { 2, 0 }, { 0, 0 }, sch_service, sp_availablechannel },
    { { 2, 2 }, { 0, 0 }, sch_service, sp_award },
    { { 3, 0 }, { 0, 0 }, sch_service, sp_brand },
    { { 3, 2 }, { 0, 0 }, sch_service, sp_broker },
    { { 2, 2 }, { 0, 0 }, sch_service, sp_category },
    { { 2, 2 }, { 0, 0 }, sch_service, sp_hasoffercatalogue },
    { { 2, 2 }, { 0, 0 }, sch_service, sp_hoursavailable },
    { { 3, 0 }, { 0, 0 }, sch_service, sp_isrelatedto },
    { { 3, 0 }, { 0, 0 }, sch_service, sp_issimilarto },
    { { 3, 0 }, { 0, 0 }, sch_service, sp_logo },
    { { 2, 2 }, { 0, 0 }, sch_service, sp_offers },
    { { 2, 0 }, { 0, 0 }, sch_service, sp_provider },
    { { 2, 2 }, { 0, 0 }, sch_service, sp_providermobility },
    { { 2, 0 }, { 0, 0 }, sch_service, sp_review },
    { { 2, 0 }, { 2, 1 }, sch_service, sp_servicearea },
    { { 2, 0 }, { 0, 0 }, sch_service, sp_serviceoutput },
    { { 2, 0 }, { 0, 0 }, sch_service, sp_servicetype },
    { { 3, 5 }, { 0, 0 }, sch_service, sp_slogan },
    { { 3, 5 }, { 0, 0 }, sch_service, sp_termsofservice },

    { { 2, 0 }, { 0, 0 }, sch_servicechannel, sp_availablelanguage },
    { { 2, 0 }, { 0, 0 }, sch_servicechannel, sp_processingtime },
    { { 2, 0 }, { 0, 0 }, sch_servicechannel, sp_providesservice },
    { { 2, 0 }, { 0, 0 }, sch_servicechannel, sp_servicelocation },
    { { 2, 0 }, { 0, 0 }, sch_servicechannel, sp_servicephone },
    { { 2, 0 }, { 0, 0 }, sch_servicechannel, sp_servicepostaladdress },
    { { 2, 0 }, { 0, 0 }, sch_servicechannel, sp_servicesmsnumber },
    { { 2, 0 }, { 0, 0 }, sch_servicechannel, sp_serviceurl },

    { { 8, 0 }, { 0, 0 }, sch_shippingdeliverytime, sp_businessdays },
    { { 8, 0 }, { 0, 0 }, sch_shippingdeliverytime, sp_cutofftime },
    { { 8, 0 }, { 0, 0 }, sch_shippingdeliverytime, sp_handlingtime },
    { { 8, 0 }, { 0, 0 }, sch_shippingdeliverytime, sp_transittime },

    { { 8, 0 }, { 0, 0 }, sch_shippingratesettings, sp_doesnotship },
    { { 8, 0 }, { 0, 0 }, sch_shippingratesettings, sp_freeshippingthreshold },
    { { 8, 0 }, { 0, 0 }, sch_shippingratesettings, sp_isunlabelledfallback },
    { { 8, 0 }, { 0, 0 }, sch_shippingratesettings, sp_shippingdestination },
    { { 8, 0 }, { 0, 0 }, sch_shippingratesettings, sp_shippinglabel },
    { { 8, 0 }, { 0, 0 }, sch_shippingratesettings, sp_shippingrate },

    { { 3, 1 }, { 0, 0 }, sch_singlefamilyresidence, sp_numberofrooms },
    { { 3, 1 }, { 0, 0 }, sch_singlefamilyresidence, sp_occupancy },

    { { 12, 0 }, { 0, 0 }, sch_sizespecification, sp_hasmeasurement },
    { { 12, 0 }, { 0, 0 }, sch_sizespecification, sp_sizegroup },
    { { 12, 0 }, { 0, 0 }, sch_sizespecification, sp_sizesystem },
    { { 12, 0 }, { 0, 0 }, sch_sizespecification, sp_suggestedage },
    { { 12, 0 }, { 0, 0 }, sch_sizespecification, sp_suggestedgender },
    { { 12, 0 }, { 0, 0 }, sch_sizespecification, sp_suggestedmeasurement },

    { { 2, 1 }, { 0, 0 }, sch_socialmediaposting, sp_sharedcontent },

    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_applicationcategory },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_applicationsubcategory },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_applicationsuite },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_availableondevice },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_countriesnotsupported },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_countriessupported },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_downloadurl },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_featurelist },
    { { 2, 0 }, { 2, 1 }, sch_softwareapplication, sp_fileformat },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_filesize },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_installurl },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_memoryrequirements },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_operatingsystem },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_permissions },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_processorrequirements },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_releasenotes },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_screenshot },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_softwareaddon },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_softwarehelp },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_softwarerequirements },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_softwareversion },
    { { 2, 0 }, { 0, 0 }, sch_softwareapplication, sp_storagerequirements },
    { { 2, 2 }, { 0, 0 }, sch_softwareapplication, sp_supportingdata },

    { { 2, 0 }, { 0, 0 }, sch_softwaresourcecode, sp_coderepository },
    { { 2, 0 }, { 0, 0 }, sch_softwaresourcecode, sp_codesampletype },
    { { 2, 0 }, { 0, 0 }, sch_softwaresourcecode, sp_programminglanguage },
    { { 2, 0 }, { 0, 0 }, sch_softwaresourcecode, sp_runtimeplatform },
    { { 2, 0 }, { 0, 0 }, sch_softwaresourcecode, sp_targetplatform },

    { { 2, 0 }, { 0, 0 }, sch_someproducts, sp_inventorylevel },

    { { 11, 0 }, { 0, 0 }, sch_solvemathaction, sp_eduquestiontype },

    { { 3, 5 }, { 0, 0 }, sch_speakablespecification, sp_cssselector },
    { { 3, 5 }, { 0, 0 }, sch_speakablespecification, sp_xpath },

    { { 7, 2 }, { 0, 0 }, sch_specialannouncement, sp_announcementlocation },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_category },
    { { 7, 1 }, { 0, 0 }, sch_specialannouncement, sp_dateposted },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_diseasepreventioninfo },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_diseasespreadstatistics },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_gettingtestedinfo },
    { { 7, 4 }, { 0, 0 }, sch_specialannouncement, sp_governmentbenefitsinfo },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_newupdatesandguidelines },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_publictransportclosuresinfo },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_quarantineguidelines },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_schoolclosuresinfo },
    { { 7, 0 }, { 0, 0 }, sch_specialannouncement, sp_travelbans },
    { { 7, 3 }, { 0, 0 }, sch_specialannouncement, sp_webfeed },

    { { 2, 0 }, { 0, 0 }, sch_sportsevent, sp_awayteam },
    { { 2, 0 }, { 0, 0 }, sch_sportsevent, sp_competitor },
    { { 2, 0 }, { 0, 0 }, sch_sportsevent, sp_hometeam },
    { { 6, 0 }, { 0, 0 }, sch_sportsevent, sp_sport },

    { { 2, 0 }, { 0, 0 }, sch_sportsorganisation, sp_sport },

    { { 2, 0 }, { 0, 0 }, sch_sportsteam, sp_athlete },
    { { 2, 0 }, { 0, 0 }, sch_sportsteam, sp_coach },
    { { 4, 0 }, { 0, 0 }, sch_sportsteam, sp_gender },

    { { 3, 9 }, { 0, 0 }, sch_statisticalpopulation, sp_constrainingproperty },
    { { 3, 9 }, { 0, 0 }, sch_statisticalpopulation, sp_numconstraints },
    { { 3, 9 }, { 0, 0 }, sch_statisticalpopulation, sp_populationtype },

    { { 3, 5 }, { 0, 0 }, sch_stupidtype, sp_stupidproperty },

    { { 3, 5 }, { 0, 0 }, sch_substance, sp_activeingredient },
    { { 3, 5 }, { 0, 0 }, sch_substance, sp_maximumintake },

    { { 3, 1 }, { 0, 0 }, sch_suite, sp_bed },
    { { 3, 1 }, { 0, 0 }, sch_suite, sp_numberofrooms },
    { { 3, 1 }, { 0, 0 }, sch_suite, sp_occupancy },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_superficialanatomy, sp_associatedpathophysiology },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_superficialanatomy, sp_relatedanatomy },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_superficialanatomy, sp_relatedcondition },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_superficialanatomy, sp_relatedtherapy },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_superficialanatomy, sp_significance },

    { { 13, 0 }, { 0, 0 }, sch_taxon, sp_childtaxon },
    { { 13, 0 }, { 0, 0 }, sch_taxon, sp_hasdefinedterm },
    { { 13, 0 }, { 0, 0 }, sch_taxon, sp_parenttaxon },
    { { 13, 0 }, { 0, 0 }, sch_taxon, sp_taxonrank },

    { { 2, 0 }, { 0, 0 }, sch_taxireservation, sp_partysize },
    { { 2, 0 }, { 0, 0 }, sch_taxireservation, sp_pickuplocation },
    { { 2, 0 }, { 0, 0 }, sch_taxireservation, sp_pickuptime },

    { { 2, 0 }, { 0, 0 }, sch_techarticle, sp_dependencies },
    { { 2, 0 }, { 0, 0 }, sch_techarticle, sp_proficiencylevel },

    { { 3, 5 }, { 0, 0 }, sch_therapeuticprocedure, sp_adverseoutcome },
    { { 3, 5 }, { 0, 0 }, sch_therapeuticprocedure, sp_doseschedule },
    { { 3, 5 }, { 0, 0 }, sch_therapeuticprocedure, sp_drug },
    { { 3, 5 }, { 6, 0 }, sch_therapeuticprocedure, sp_indication },

    { { 3, 5 }, { 0, 0 }, sch_thesis, sp_insupportof },

    { { 2, 0 }, { 0, 0 }, sch_thing, sp_additionaltype },
    { { 2, 0 }, { 0, 0 }, sch_thing, sp_alternativename },
    { { 2, 0 }, { 0, 0 }, sch_thing, sp_description },
    { { 3, 0 }, { 0, 0 }, sch_thing, sp_disambiguatingdescription },
    { { 3, 2 }, { 0, 0 }, sch_thing, sp_identifier },
    { { 2, 0 }, { 0, 0 }, sch_thing, sp_image },
    { { 2, 0 }, { 0, 0 }, sch_thing, sp_mainentityofpage },
    { { 2, 0 }, { 0, 0 }, sch_thing, sp_name },
    { { 2, 0 }, { 0, 0 }, sch_thing, sp_potentialaction },
    { { 2, 0 }, { 0, 0 }, sch_thing, sp_sameas },
    { { 3, 5 }, { 0, 0 }, sch_thing, sp_subjectof },
    { { 2, 0 }, { 0, 0 }, sch_thing, sp_url },

    { { 2, 0 }, { 0, 0 }, sch_ticket, sp_dateissued },
    { { 2, 0 }, { 0, 0 }, sch_ticket, sp_issuedby },
    { { 2, 0 }, { 0, 0 }, sch_ticket, sp_pricecurrency },
    { { 2, 0 }, { 0, 0 }, sch_ticket, sp_ticketnumber },
    { { 2, 0 }, { 0, 0 }, sch_ticket, sp_tickettoken },
    { { 2, 0 }, { 0, 0 }, sch_ticket, sp_ticketedseat },
    { { 2, 0 }, { 0, 0 }, sch_ticket, sp_totalprice },
    { { 2, 0 }, { 0, 0 }, sch_ticket, sp_undername },

    { { 2, 0 }, { 0, 0 }, sch_tipaction, sp_recipient },

    { { 3, 3 }, { 0, 0 }, sch_touristattraction, sp_availablelanguage },
    { { 3, 3 }, { 0, 0 }, sch_touristattraction, sp_touristtype },

    { { 3, 5 }, { 0, 0 }, sch_touristdestination, sp_includesattraction },
    { { 3, 5 }, { 0, 0 }, sch_touristdestination, sp_touristtype },

    { { 3, 5 }, { 0, 0 }, sch_touristtrip, sp_touristtype },

    { { 2, 0 }, { 0, 0 }, sch_trackaction, sp_deliverymethod },

    { { 2, 0 }, { 0, 0 }, sch_tradeaction, sp_price },
    { { 3, 5 }, { 0, 0 }, sch_tradeaction, sp_pricecurrency },
    { { 2, 0 }, { 0, 0 }, sch_tradeaction, sp_pricespecification },

    { { 2, 0 }, { 0, 0 }, sch_traintrip, sp_arrivalplatform },
    { { 2, 0 }, { 0, 0 }, sch_traintrip, sp_arrivalstation },
    { { 2, 0 }, { 3, 3 }, sch_traintrip, sp_arrivaltime },
    { { 2, 0 }, { 0, 0 }, sch_traintrip, sp_departureplatform },
    { { 2, 0 }, { 0, 0 }, sch_traintrip, sp_departurestation },
    { { 2, 0 }, { 3, 3 }, sch_traintrip, sp_departuretime },
    { { 2, 0 }, { 3, 3 }, sch_traintrip, sp_provider },
    { { 2, 0 }, { 0, 0 }, sch_traintrip, sp_trainname },
    { { 2, 0 }, { 0, 0 }, sch_traintrip, sp_trainnumber },

    { { 2, 0 }, { 0, 0 }, sch_transferaction, sp_fromlocation },
    { { 2, 0 }, { 0, 0 }, sch_transferaction, sp_tolocation },

    { { 2, 0 }, { 0, 0 }, sch_travelaction, sp_distance },

    { { 3, 4 }, { 0, 0 }, sch_trip, sp_arrivaltime },
    { { 3, 4 }, { 0, 0 }, sch_trip, sp_departuretime },
    { { 3, 5 }, { 0, 0 }, sch_trip, sp_itinerary },
    { { 3, 4 }, { 0, 0 }, sch_trip, sp_offers },
    { { 3, 5 }, { 0, 0 }, sch_trip, sp_partoftrip },
    { { 3, 4 }, { 0, 0 }, sch_trip, sp_provider },
    { { 3, 5 }, { 0, 0 }, sch_trip, sp_subtrip },

    { { 2, 2 }, { 0, 0 }, sch_tvepisode, sp_countryoforigin },
    { { 2, 0 }, { 0, 0 }, sch_tvepisode, sp_subtitlelanguage },
    { { 8, 0 }, { 0, 0 }, sch_tvepisode, sp_titleeidr },

    { { 2, 2 }, { 0, 0 }, sch_tvseason, sp_countryoforigin },

    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_containsseason },
    { { 2, 2 }, { 0, 0 }, sch_tvseries, sp_countryoforigin },
    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_director },
    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_episode },
    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_numberofepisodes },
    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_numberofseasons },
    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_productioncompany },
    { { 2, 0 }, { 0, 0 }, sch_tvseries, sp_trailer },

    { { 2, 0 }, { 0, 0 }, sch_typeandquantitynode, sp_amountofthisgood },
    { { 2, 0 }, { 0, 0 }, sch_typeandquantitynode, sp_businessfunction },
    { { 2, 0 }, { 0, 0 }, sch_typeandquantitynode, sp_typeofgood },
    { { 2, 0 }, { 0, 0 }, sch_typeandquantitynode, sp_unitcode },
    { { 2, 0 }, { 0, 0 }, sch_typeandquantitynode, sp_unittext },

    { { 11, 0 }, { 0, 0 }, sch_unitpricespecification, sp_billingduration },
    { { 2, 0 }, { 0, 0 }, sch_unitpricespecification, sp_billingincrement },
    { { 11, 0 }, { 0, 0 }, sch_unitpricespecification, sp_billingstart },
    { { 11, 0 }, { 0, 0 }, sch_unitpricespecification, sp_pricecomponenttype },
    { { 2, 0 }, { 0, 0 }, sch_unitpricespecification, sp_pricetype },
    { { 3, 0 }, { 0, 0 }, sch_unitpricespecification, sp_referencequantity },
    { { 2, 0 }, { 0, 0 }, sch_unitpricespecification, sp_unitcode },
    { { 2, 0 }, { 0, 0 }, sch_unitpricespecification, sp_unittext },

    { { 2, 0 }, { 0, 0 }, sch_updateaction, sp_targetcollection },

    { { 2, 0 }, { 0, 0 }, sch_usercomments, sp_commenttext },
    { { 2, 0 }, { 0, 0 }, sch_usercomments, sp_commenttime },
    { { 2, 0 }, { 0, 0 }, sch_usercomments, sp_creator },
    { { 2, 0 }, { 0, 0 }, sch_usercomments, sp_discusses },
    { { 2, 0 }, { 0, 0 }, sch_usercomments, sp_replytourl },

    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_accelerationtime },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_bodytype },
    { { 5, 0 }, { 0, 0 }, sch_vehicle, sp_callsign },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_cargovolume },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_datevehiclefirstregistered },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_drivewheelconfiguration },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_emmissionsco2 },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_fuelcapacity },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_fuelconsumption },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_fuelefficiency },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_fueltype },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_knownvehicledamages },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_meetsemissionstandard },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_mileagefromodometer },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_modeldate },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_numberofairbags },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_numberofaxles },
    { { 2, 1 }, { 0, 0 }, sch_vehicle, sp_numberofdoors },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_numberofforwardgears },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_numberofpreviousowners },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_payload },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_productiondate },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_purchasedate },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_seatingcapacity },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_speed },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_steeringposition },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_stupidproperty }, // ?!
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_tongueweight },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_trailerweight },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_vehicleconfiguration },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_vehicleengine },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_vehicleidentificationnumber },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_vehicleinteriorcolour },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_vehicleinteriortype },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_vehiclemodeldate },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_vehicleseatingcapacity },
    { { 3, 0 }, { 0, 0 }, sch_vehicle, sp_vehiclespecialusage },
    { { 2, 0 }, { 0, 0 }, sch_vehicle, sp_vehicletransmission },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_weighttotal },
    { { 3, 5 }, { 0, 0 }, sch_vehicle, sp_wheelbase },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_vein, sp_drainsto },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_vein, sp_regiondrained },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_vein, sp_tributary },

    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_vessel, sp_bloodsupply },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_vessel, sp_drainsto },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_vessel, sp_originatesfrom },
    { { 2, 0, SV_NOT_3034 }, { 0, 0 }, sch_vessel, sp_runsto },

    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_cheatcode },
    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_director },
    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_gameplatform },
    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_gameserver },
    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_gametip },
    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_playmode },
    { { 2, 0 }, { 0, 0 }, sch_videogame, sp_trailer },

    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_characterattribute },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_cheatcode },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_containsseason },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_director },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_episode },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_gameitem },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_gamelocation },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_gameplatform },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_numberofepisodes },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_numberofplayers },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_numberofseasons },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_playmode },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_productioncompany },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_quest },
    { { 2, 0 }, { 0, 0 }, sch_videogameseries, sp_trailer },

    { { 2, 0 }, { 0, 0 }, sch_videoobject, sp_actor },
    { { 2, 0 }, { 0, 0 }, sch_videoobject, sp_caption },
    { { 2, 0 }, { 0, 0 }, sch_videoobject, sp_director },
    { { 13, 0 }, { 0, 0 }, sch_videoobject, sp_embeddedtextcaption },
    { { 2, 0 }, { 0, 0 }, sch_videoobject, sp_musicby },
    { { 2, 0 }, { 0, 0 }, sch_videoobject, sp_thumbnail },
    { { 2, 0 }, { 0, 0 }, sch_videoobject, sp_transcript },
    { { 2, 0 }, { 0, 0 }, sch_videoobject, sp_videoframesize },
    { { 2, 0 }, { 0, 0 }, sch_videoobject, sp_videoquality },

    { { 2, 0 }, { 0, 0 }, sch_visualartwork, sp_artedition },
    { { 2, 0 }, { 0, 0 }, sch_visualartwork, sp_artmedium },
    { { 2, 0 }, { 0, 0 }, sch_visualartwork, sp_artform },
    { { 3, 5 }, { 0, 0 }, sch_visualartwork, sp_artist },
    { { 2, 0 }, { 0, 0 }, sch_visualartwork, sp_artworksurface },
    { { 3, 5 }, { 0, 0 }, sch_visualartwork, sp_colourist },
    { { 2, 0 }, { 0, 0 }, sch_visualartwork, sp_depth },
    { { 2, 0 }, { 0, 0 }, sch_visualartwork, sp_height },
    { { 3, 5 }, { 0, 0 }, sch_visualartwork, sp_inker },
    { { 3, 5 }, { 0, 0 }, sch_visualartwork, sp_letterer },
    { { 3, 5 }, { 0, 0 }, sch_visualartwork, sp_penciler },
    { { 2, 0 }, { 0, 0 }, sch_visualartwork, sp_width },

    { { 2, 0 }, { 0, 0 }, sch_voteaction, sp_candidate },

    { { 2, 0 }, { 0, 0 }, sch_warrantypromise, sp_durationofwarranty },
    { { 2, 0 }, { 0, 0 }, sch_warrantypromise, sp_warrantyscope },

    { { 3, 5 }, { 0, 0 }, sch_webapi, sp_documentation },

    { { 2, 0 }, { 0, 0 }, sch_webapplication, sp_browserrequirements },

    { { 2, 0 }, { 0, 0 }, sch_webpage, sp_breadcrumb },
    { { 2, 0 }, { 0, 0 }, sch_webpage, sp_lastreviewed },
    { { 2, 0 }, { 0, 0 }, sch_webpage, sp_maincontentofpage },
    { { 2, 0 }, { 0, 0 }, sch_webpage, sp_primaryimageofpage },
    { { 2, 0 }, { 0, 0 }, sch_webpage, sp_relatedlink },
    { { 2, 0 }, { 0, 0 }, sch_webpage, sp_reviewedby },
    { { 2, 0 }, { 0, 0 }, sch_webpage, sp_significantlink },
    { { 3, 5 }, { 0, 0 }, sch_webpage, sp_speakable },
    { { 2, 0 }, { 0, 0 }, sch_webpage, sp_speciality },

    { { 3, 5 }, { 0, 0 }, sch_webpageelement, sp_cssselector },
    { { 3, 5 }, { 0, 0 }, sch_webpageelement, sp_xpath },

    { { 3, 3 }, { 0, 0 }, sch_website, sp_issn },

    { { 2, 0 }, { 0, 0 }, sch_winaction, sp_loser },

    { { 3, 9 }, { 0, 0 }, sch_workbasedprogramme, sp_occupationalcategory },
    { { 3, 9 }, { 0, 0 }, sch_workbasedprogramme, sp_trainingsalary },

    { { 2, 0 }, { 0, 0 }, sch_writeaction, sp_inlanguage },

    // living standard
    { { s_whatwg, 1, 0 }, { 0, 0 }, wwg_work, wp_author },
    { { s_whatwg, 1, 0 }, { 0, 0 }, wwg_work, wp_license },
    { { s_whatwg, 1, 0 }, { 0, 0 }, wwg_work, wp_title },
    { { s_whatwg, 1, 0 }, { 0, 0 }, wwg_work, wp_work },

    { { 0, 0 }, { 0, 0 }, sty_illegal, sp_illegal } };

typedef ::std::pair < e_schema_type, e_schema_property > mmd_key;
typedef ::std::multimap < mmd_key, microdata_structure* > mmd_t;
mmd_t micromap;

void microdata_init (nitpick& )
{   PRESUME (micromap.empty (), __FILE__, __LINE__);
    for (microdata_structure* p = &schema_structure [0]; p -> record_ != sty_illegal; ++p)
    {   VERIFY_NOT_NULL (p, __FILE__, __LINE__);
        if (micromap.find (::std::pair < e_schema_type, e_schema_property > (p -> record_, p -> property_)) != micromap.end ())
            ::std::cerr << "microdata_init reports " << sch::name (p -> record_) << " (" << p -> record_ << "), " << schema_property_name (p -> property_) << " (" << p -> property_ << ") repeated\n";
        else
        {   mmd_key k (p -> record_, p -> property_);
            micromap.insert (mmd_t::value_type (k, p));
#if defined (_DEBUG)
            bool found = false;
            if (! check_schema_property_version (p -> from_, p -> to_, p -> property_, found))
                if (found)
                    ::std::cerr << "microdata_init reports " << sch::name (p -> record_) << " (" << p -> record_ << "), " <<
                                                                schema_property_name (p -> property_) << " (" << p -> property_ << ") is incompatible with version in property table\n";
                else
                    ::std::cerr << "microdata_init reports " << sch::name (p -> record_) << " (" << p -> record_ << "), " <<
                                                                schema_property_name (p -> property_) << " (" << p -> property_ << ") is not found in property table\n";
#endif // _DEBUG
} } }

bool is_schema_property (const e_schema_type s, const e_schema_property p)
{   mmd_t::const_iterator i = micromap.find (mmd_key (s, p));
    if (i == micromap.cend ()) return false;
    VERIFY_NOT_NULL (i -> second, __FILE__, __LINE__);
    return does_apply < schema_version > (context.schema_ver (), i -> second -> from_, i -> second -> to_); };
