/*
ssc (static site checker)
Copyright (c) 2020,2021 Dylan Harris
https://dylanharris.org/

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public Licence as published by
the Free Software Foundation, either version 3 of the Licence, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public Licence for more details.

You should have received a copy of the GNU General Public
Licence along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

#include "main/standard.h"
#include "type/type_mime.h"
#include "symbol/symbol.h"

struct symbol_entry < html_version, e_mimetype > mimetype_symbol_table [] =
{   // avoid the whinge
    { { HTML_4_0 }, { HTML_UNDEF }, "example/context-defined", mime_context, ns_default, MIME_APPLICATION },
    // standard
    { { HTML_4_0 }, { HTML_UNDEF }, "application/1d-interleaved-parityfec", mime_application_1d_interleaved_parityfec, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/3gpdash-qoe-report+xml", mime_application_3gpdash_qoe_report_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/3gpp-ims+xml", mime_application_3gpp_ims_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/A2L", mime_application_A2L, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/activemessage", mime_application_activemessage, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/activity+json", mime_application_activity_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-costmap+json", mime_application_alto_costmap_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-costmapfilter+json", mime_application_alto_costmapfilter_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-directory+json", mime_application_alto_directory_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-endpointprop+json", mime_application_alto_endpointprop_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-endpointpropparams+json", mime_application_alto_endpointpropparams_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-endpointcost+json", mime_application_alto_endpointcost_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-endpointcostparams+json", mime_application_alto_endpointcostparams_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-error+json", mime_application_alto_error_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-networkmapfilter+json", mime_application_alto_networkmapfilter_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-networkmap+json", mime_application_alto_networkmap_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-updatestreamcontrol+json", mime_application_alto_updatestreamcontrol_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/alto-updatestreamparams+json", mime_application_alto_updatestreamparams_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/AML", mime_application_AML, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/andrew-inset", mime_application_andrew_inset, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/applefile", mime_application_applefile, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ATF", mime_application_ATF, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ATFX", mime_application_ATFX, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atom+xml", mime_application_atom_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atomcat+xml", mime_application_atomcat_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atomdeleted+xml", mime_application_atomdeleted_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atomicmail", mime_application_atomicmail, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atomsvc+xml", mime_application_atomsvc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atsc-dwd+xml", mime_application_atsc_dwd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atsc-dynamic-event-message", mime_application_atsc_dynamic_event_message, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atsc-held+xml", mime_application_atsc_held_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atsc-rdt+json", mime_application_atsc_rdt_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/atsc-rsat+xml", mime_application_atsc_rsat_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ATXML", mime_application_ATXML, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/auth-policy+xml", mime_application_auth_policy_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/bacnet-xdd+zip", mime_application_bacnet_xdd_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/batch-SMTP", mime_application_batch_SMTP, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/beep+xml", mime_application_beep_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/calendar+json", mime_application_calendar_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/calendar+xml", mime_application_calendar_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/call-completion", mime_application_call_completion, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cals-1840", mime_application_cals_1840, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cap+xml", mime_application_cap_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cbor", mime_application_cbor, ns_default, MIME_APPLICATION | MIME_CBOR },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cbor-seq", mime_application_cbor_seq, ns_default, MIME_APPLICATION | MIME_CBOR },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cccex", mime_application_cccex, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ccmp+xml", mime_application_ccmp_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ccxml+xml", mime_application_ccxml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/CDFX+XML", mime_application_CDFX_XML, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cdmi-capability", mime_application_cdmi_capability, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cdmi-container", mime_application_cdmi_container, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cdmi-domain", mime_application_cdmi_domain, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cdmi-object", mime_application_cdmi_object, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cdmi-queue", mime_application_cdmi_queue, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cdni", mime_application_cdni, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/CEA", mime_application_CEA, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cea-2018+xml", mime_application_cea_2018_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cellml+xml", mime_application_cellml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cfw", mime_application_cfw, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/clue_info+xml", mime_application_clue_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/clue+xml", mime_application_clue_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cms", mime_application_cms, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cnrp+xml", mime_application_cnrp_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/coap-group+json", mime_application_coap_group_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/coap-payload", mime_application_coap_payload, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/commonground", mime_application_commonground, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/conference-info+xml", mime_application_conference_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cpl+xml", mime_application_cpl_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cose", mime_application_cose, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cose-key", mime_application_cose_key, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cose-key-set", mime_application_cose_key_set, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/csrattrs", mime_application_csrattrs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/csta+xml", mime_application_csta_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/CSTAdata+xml", mime_application_CSTAdata_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/csvm+json", mime_application_csvm_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cwt", mime_application_cwt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/cybercash", mime_application_cybercash, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dash+xml", mime_application_dash_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dashdelta", mime_application_dashdelta, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/davmount+xml", mime_application_davmount_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dca-rft", mime_application_dca_rft, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/DCD", mime_application_DCD, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dec-dx", mime_application_dec_dx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dialog-info+xml", mime_application_dialog_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dicom", mime_application_dicom, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dicom+json", mime_application_dicom_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dicom+xml", mime_application_dicom_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/DII", mime_application_DII, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/DIT", mime_application_DIT, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dns", mime_application_dns, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dns+json", mime_application_dns_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dns-message", mime_application_dns_message, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dots+cbor", mime_application_dots_cbor, ns_default, MIME_APPLICATION | MIME_CBOR },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dskpp+xml", mime_application_dskpp_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dssc+der", mime_application_dssc_der, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dssc+xml", mime_application_dssc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/dvcs", mime_application_dvcs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ecmascript", mime_application_ecmascript, ns_default, MIME_SCRIPT | MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EDI-consent", mime_application_EDI_consent, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EDIFACT", mime_application_EDIFACT, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EDI-X12", mime_application_EDI_X12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/efi", mime_application_efi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EmergencyCallData.Comment+xml", mime_application_EmergencyCallData_Comment_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EmergencyCallData.Control+xml", mime_application_EmergencyCallData_Control_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EmergencyCallData.DeviceInfo+xml", mime_application_EmergencyCallData_DeviceInfo_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EmergencyCallData.eCall.MSD", mime_application_EmergencyCallData_eCall_MSD, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EmergencyCallData.ProviderInfo+xml", mime_application_EmergencyCallData_ProviderInfo_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EmergencyCallData.ServiceInfo+xml", mime_application_EmergencyCallData_ServiceInfo_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EmergencyCallData.SubscriberInfo+xml", mime_application_EmergencyCallData_SubscriberInfo_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/EmergencyCallData.VEDS+xml", mime_application_EmergencyCallData_VEDS_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/emma+xml", mime_application_emma_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/emotionml+xml", mime_application_emotionml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/encaprtp", mime_application_encaprtp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/envoy", mime_application_envoy, ns_default, MIME_APPLICATION  | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/epp+xml", mime_application_epp_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/epub+zip", mime_application_epub_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/eshop", mime_application_eshop, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/example", mime_application_example, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/exi", mime_application_exi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/expect-ct-report+json", mime_application_expect_ct_report_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/fastinfoset", mime_application_fastinfoset, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/fastsoap", mime_application_fastsoap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/fdt+xml", mime_application_fdt_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/fhir+json", mime_application_fhir_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/fhir+xml", mime_application_fhir_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/fits", mime_application_fits, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/flexfec", mime_application_flexfec, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/font-sfnt", mime_application_font_sfnt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/font-tdpfr", mime_application_font_tdpfr, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/font-woff", mime_application_font_woff, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/fractals", mime_application_fractals, ns_default, MIME_APPLICATION  | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/framework-attributes+xml", mime_application_framework_attributes_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/futuresplash", mime_application_futuresplash, ns_default, MIME_APPLICATION  | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/geo+json", mime_application_geo_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/geo+json-seq", mime_application_geo_json_seq, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/geopackage+sqlite3", mime_application_geopackage_sqlite3, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/geoxacml+xml", mime_application_geoxacml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/gltf-buffer", mime_application_gltf_buffer, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/gml+xml", mime_application_gml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/gzip", mime_application_gzip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/H224", mime_application_H224, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/hta", mime_application_hta, ns_default, MIME_APPLICATION  | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/held+xml", mime_application_held_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/http", mime_application_http, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/hyperstudio", mime_application_hyperstudio, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ibe-key-request+xml", mime_application_ibe_key_request_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ibe-pkg-reply+xml", mime_application_ibe_pkg_reply_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ibe-pp-data", mime_application_ibe_pp_data, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/iges", mime_application_iges, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/im-iscomposing+xml", mime_application_im_iscomposing_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/index", mime_application_index, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/index.cmd", mime_application_index_cmd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/index.obj", mime_application_index_obj, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/index.response", mime_application_index_response, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/index.vnd", mime_application_index_vnd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/inkml+xml", mime_application_inkml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/internet-property-stream", mime_application_internet_property_stream, ns_default, MIME_APPLICATION  | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/IOTP", mime_application_IOTP, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ipfix", mime_application_ipfix, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ipp", mime_application_ipp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ISUP", mime_application_ISUP, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/its+xml", mime_application_its_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/java", mime_application_java, ns_default, MIME_SCRIPT | MIME_APPLICATION }, // in HTML4.01 spec
    { { HTML_4_0 }, { HTML_UNDEF }, "application/java-archive", mime_application_java_archive, ns_default, MIME_SCRIPT | MIME_APPLICATION }, // in HTML4.01 spec
    { { HTML_4_0 }, { HTML_UNDEF }, "application/javascript", mime_application_javascript, ns_default, MIME_SCRIPT | MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/jf2feed+json", mime_application_jf2feed_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/jose", mime_application_jose, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/jose+json", mime_application_jose_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/jrd+json", mime_application_jrd_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/json", mime_application_json, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/json-patch+json", mime_application_json_patch_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/json-seq", mime_application_json_seq, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/jwk+json", mime_application_jwk_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/jwk-set+json", mime_application_jwk_set_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/jwt", mime_application_jwt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/kpml-request+xml", mime_application_kpml_request_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/kpml-response+xml", mime_application_kpml_response_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ld+json", mime_application_ld_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/lgr+xml", mime_application_lgr_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/link-format", mime_application_link_format, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/load-control+xml", mime_application_load_control_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/lost+xml", mime_application_lost_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/lostsync+xml", mime_application_lostsync_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/lpf+zip", mime_application_lpf_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/LXF", mime_application_LXF, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mac-binhex40", mime_application_mac_binhex40, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/macwriteii", mime_application_macwriteii, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mads+xml", mime_application_mads_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/marc", mime_application_marc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/marcxml+xml", mime_application_marcxml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mathematica", mime_application_mathematica, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mathml-content+xml", mime_application_mathml_content_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mathml-presentation+xml", mime_application_mathml_presentation_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mathml+xml", mime_application_mathml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-associated-procedure-description+xml", mime_application_mbms_associated_procedure_description_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-deregister+xml", mime_application_mbms_deregister_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-envelope+xml", mime_application_mbms_envelope_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-msk-response+xml", mime_application_mbms_msk_response_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-msk+xml", mime_application_mbms_msk_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-protection-description+xml", mime_application_mbms_protection_description_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-reception-report+xml", mime_application_mbms_reception_report_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-register-response+xml", mime_application_mbms_register_response_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-register+xml", mime_application_mbms_register_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-schedule+xml", mime_application_mbms_schedule_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbms-user-service-description+xml", mime_application_mbms_user_service_description_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mbox", mime_application_mbox, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/media_control+xml", mime_application_media_control_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/media-policy-dataset+xml", mime_application_media_policy_dataset_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mediaservercontrol+xml", mime_application_mediaservercontrol_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/merge-patch+json", mime_application_merge_patch_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/metalink4+xml", mime_application_metalink4_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mets+xml", mime_application_mets_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/MF4", mime_application_MF4, ns_default, MIME_APPLICATION },
    { { HTML_APR21 }, { HTML_UNDEF }, "application/microdata+json", mime_application_microdata_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mikey", mime_application_mikey, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mipc", mime_application_mipc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mmt-aei+xml", mime_application_mmt_aei_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mmt-usd+xml", mime_application_mmt_usd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mods+xml", mime_application_mods_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/moss-keys", mime_application_moss_keys, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/moss-signature", mime_application_moss_signature, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mosskey-data", mime_application_mosskey_data, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mosskey-request", mime_application_mosskey_request, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mp21", mime_application_mp21, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mp4", mime_application_mp4, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mpeg4-generic", mime_application_mpeg4_generic, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mpeg4-iod", mime_application_mpeg4_iod, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mpeg4-iod-xmt", mime_application_mpeg4_iod_xmt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mrb-consumer+xml", mime_application_mrb_consumer_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mrb-publish+xml", mime_application_mrb_publish_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/msc-ivr+xml", mime_application_msc_ivr_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/msc-mixer+xml", mime_application_msc_mixer_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/msword", mime_application_msword, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mud+json", mime_application_mud_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/multipart-core", mime_application_multipart_core, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/mxf", mime_application_mxf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/n-quads", mime_application_n_quads, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/n-triples", mime_application_n_triples, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/nasdata", mime_application_nasdata, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/news-checkgroups", mime_application_news_checkgroups, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/news-groupinfo", mime_application_news_groupinfo, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/news-transmission", mime_application_news_transmission, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/nlsml+xml", mime_application_nlsml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/node", mime_application_node, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/nss", mime_application_nss, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ocsp-request", mime_application_ocsp_request, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ocsp-response", mime_application_ocsp_response, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/octet-stream", mime_application_octet_stream, ns_default, NOT_SCRIPT | MIME_APPLICATION | MIME_VULNERABLE },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/odm+xml", mime_application_odm_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ODX", mime_application_ODX, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/oebps-package+xml", mime_application_oebps_package_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ogg", mime_application_ogg, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/oscore", mime_application_oscore, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/oxps", mime_application_oxps, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/p2p-overlay+xml", mime_application_p2p_overlay_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/parityfec", mime_application_parityfec, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/passport", mime_application_passport, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/patch-ops-error+xml", mime_application_patch_ops_error_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pdf", mime_application_pdf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/PDX", mime_application_PDX, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pem-certificate-chain", mime_application_pem_certificate_chain, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pgp-encrypted", mime_application_pgp_encrypted, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pgp-keys", mime_application_pgp_keys, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pgp-signature", mime_application_pgp_signature, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pidf-diff+xml", mime_application_pidf_diff_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pidf+xml", mime_application_pidf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkcs10", mime_application_pkcs10, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkcs7-mime", mime_application_pkcs7_mime, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkcs7-signature", mime_application_pkcs7_signature, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkcs8", mime_application_pkcs8, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkcs8-encrypted", mime_application_pkcs8_encrypted, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkcs12", mime_application_pkcs12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkix-attr-cert", mime_application_pkix_attr_cert, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkix-cert", mime_application_pkix_cert, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkix-crl", mime_application_pkix_crl, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkix-pkipath", mime_application_pkix_pkipath, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pkixcmp", mime_application_pkixcmp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pls+xml", mime_application_pls_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/poc-settings+xml", mime_application_poc_settings_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/postscript", mime_application_postscript, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ppsp-tracker+json", mime_application_ppsp_tracker_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/problem+json", mime_application_problem_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/problem+xml", mime_application_problem_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/provenance+xml", mime_application_provenance_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/prs.alvestrand.titrax-sheet", mime_application_prs_alvestrand_titrax_sheet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/prs.cww", mime_application_prs_cww, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/prs.hpub+zip", mime_application_prs_hpub_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/prs.nprend", mime_application_prs_nprend, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/prs.plucker", mime_application_prs_plucker, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/prs.rdf-xml-crypt", mime_application_prs_rdf_xml_crypt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/prs.xsf+xml", mime_application_prs_xsf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pskc+xml", mime_application_pskc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pvd+json", mime_application_pvd_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rdf+xml", mime_application_rdf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/route-apd+xml", mime_application_route_apd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/route-s-tsid+xml", mime_application_route_s_tsid_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/route-usd+xml", mime_application_route_usd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/QSIG", mime_application_QSIG, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/raptorfec", mime_application_raptorfec, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rdap+json", mime_application_rdap_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/reginfo+xml", mime_application_reginfo_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/relax-ng-compact-syntax", mime_application_relax_ng_compact_syntax, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/remote-printing", mime_application_remote_printing, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/reputon+json", mime_application_reputon_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/resource-lists-diff+xml", mime_application_resource_lists_diff_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/resource-lists+xml", mime_application_resource_lists_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rfc+xml", mime_application_rfc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/riscos", mime_application_riscos, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rlmi+xml", mime_application_rlmi_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rls-services+xml", mime_application_rls_services_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rpki-ghostbusters", mime_application_rpki_ghostbusters, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rpki-manifest", mime_application_rpki_manifest, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rpki-publication", mime_application_rpki_publication, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rpki-roa", mime_application_rpki_roa, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rpki-updown", mime_application_rpki_updown, ns_default, MIME_APPLICATION },
    { { HTML_4_01 }, { HTML_UNDEF }, "application/rss+xml", mime_application_rss_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rtf", mime_application_rtf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rtploopback", mime_application_rtploopback, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/rtx", mime_application_rtx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/samlassertion+xml", mime_application_samlassertion_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/samlmetadata+xml", mime_application_samlmetadata_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sbe", mime_application_sbe, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sbml+xml", mime_application_sbml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/scaip+xml", mime_application_scaip_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/scim+json", mime_application_scim_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/scvp-cv-request", mime_application_scvp_cv_request, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/scvp-cv-response", mime_application_scvp_cv_response, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/scvp-vp-request", mime_application_scvp_vp_request, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/scvp-vp-response", mime_application_scvp_vp_response, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sdp", mime_application_sdp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/secevent+jwt", mime_application_secevent_jwt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/senml-etch+cbor", mime_application_senml_etch_cbor, ns_default, MIME_APPLICATION | MIME_CBOR },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/senml-etch+json", mime_application_senml_etch_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/senml-exi", mime_application_senml_exi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/senml+cbor", mime_application_senml_cbor, ns_default, MIME_APPLICATION | MIME_CBOR },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/senml+json", mime_application_senml_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/senml+xml", mime_application_senml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sensml-exi", mime_application_sensml_exi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sensml+cbor", mime_application_sensml_cbor, ns_default, MIME_APPLICATION | MIME_CBOR },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sensml+json", mime_application_sensml_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sensml+xml", mime_application_sensml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sep-exi", mime_application_sep_exi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sep+xml", mime_application_sep_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/session-info", mime_application_session_info, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/set-payment", mime_application_set_payment, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/set-payment-initiation", mime_application_set_payment_initiation, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/set-registration", mime_application_set_registration, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/set-registration-initiation", mime_application_set_registration_initiation, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sgml", mime_application_sgml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sgml-open-catalog", mime_application_sgml_open_catalog, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/shf+xml", mime_application_shf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sieve", mime_application_sieve, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/simple-filter+xml", mime_application_simple_filter_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/simple-message-summary", mime_application_simple_message_summary, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/simpleSymbolContainer", mime_application_simpleSymbolContainer, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sipc", mime_application_sipc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/slate", mime_application_slate, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/smil", mime_application_smil, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/smil+xml", mime_application_smil_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/smpte336m", mime_application_smpte336m, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/soap+fastinfoset", mime_application_soap_fastinfoset, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/soap+xml", mime_application_soap_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sparql-query", mime_application_sparql_query, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sparql-results+xml", mime_application_sparql_results_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/spirits-event+xml", mime_application_spirits_event_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sql", mime_application_sql, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/srgs", mime_application_srgs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/srgs+xml", mime_application_srgs_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/sru+xml", mime_application_sru_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ssml+xml", mime_application_ssml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/stix+json", mime_application_stix_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/swid+xml", mime_application_swid_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-apex-update", mime_application_tamp_apex_update, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-apex-update-confirm", mime_application_tamp_apex_update_confirm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-community-update", mime_application_tamp_community_update, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-community-update-confirm", mime_application_tamp_community_update_confirm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-error", mime_application_tamp_error, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-sequence-adjust", mime_application_tamp_sequence_adjust, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-sequence-adjust-confirm", mime_application_tamp_sequence_adjust_confirm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-status-query", mime_application_tamp_status_query, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-status-response", mime_application_tamp_status_response, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-update", mime_application_tamp_update, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tamp-update-confirm", mime_application_tamp_update_confirm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/taxii+json", mime_application_taxii_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tcl", mime_application_tcl, ns_default, MIME_SCRIPT | MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/td+json", mime_application_td_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tei+xml", mime_application_tei_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/TETRA_ISI", mime_application_TETRA_ISI, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/thraud+xml", mime_application_thraud_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/timestamp-query", mime_application_timestamp_query, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/timestamp-reply", mime_application_timestamp_reply, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/timestamped-data", mime_application_timestamped_data, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tlsrpt+gzip", mime_application_tlsrpt_gzip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tlsrpt+json", mime_application_tlsrpt_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tnauthlist", mime_application_tnauthlist, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/trickle-ice-sdpfrag", mime_application_trickle_ice_sdpfrag, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/trig", mime_application_trig, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ttml+xml", mime_application_ttml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tve-trigger", mime_application_tve_trigger, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tzif", mime_application_tzif, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/tzif-leap", mime_application_tzif_leap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ulpfec", mime_application_ulpfec, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/urc-grpsheet+xml", mime_application_urc_grpsheet_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/urc-ressheet+xml", mime_application_urc_ressheet_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/urc-targetdesc+xml", mime_application_urc_targetdesc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/urc-uisocketdesc+xml", mime_application_urc_uisocketdesc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vbscript", mime_application_vbscript, ns_default, MIME_SCRIPT | MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vcard+json", mime_application_vcard_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vcard+xml", mime_application_vcard_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vemmi", mime_application_vemmi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.1000minds.decision-model+xml", mime_application_vnd_1000minds_decision_model_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.access-transfer-events+xml", mime_application_vnd_3gpp_access_transfer_events_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.bsf+xml", mime_application_vnd_3gpp_bsf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.GMOP+xml", mime_application_vnd_3gpp_GMOP_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mc-signalling-ear", mime_application_vnd_3gpp_mc_signalling_ear, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcdata-affiliation-command+xml", mime_application_vnd_3gpp_mcdata_affiliation_command_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcdata-info+xml", mime_application_vnd_3gpp_mcdata_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcdata-payload", mime_application_vnd_3gpp_mcdata_payload, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcdata-service-config+xml", mime_application_vnd_3gpp_mcdata_service_config_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcdata-signalling", mime_application_vnd_3gpp_mcdata_signalling, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcdata-ue-config+xml", mime_application_vnd_3gpp_mcdata_ue_config_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcdata-user-profile+xml", mime_application_vnd_3gpp_mcdata_user_profile_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-affiliation-command+xml", mime_application_vnd_3gpp_mcptt_affiliation_command_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-floor-request+xml", mime_application_vnd_3gpp_mcptt_floor_request_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-info+xml", mime_application_vnd_3gpp_mcptt_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-location-info+xml", mime_application_vnd_3gpp_mcptt_location_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-mbms-usage-info+xml", mime_application_vnd_3gpp_mcptt_mbms_usage_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-service-config+xml", mime_application_vnd_3gpp_mcptt_service_config_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-signed+xml", mime_application_vnd_3gpp_mcptt_signed_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-ue-config+xml", mime_application_vnd_3gpp_mcptt_ue_config_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-ue-init-config+xml", mime_application_vnd_3gpp_mcptt_ue_init_config_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcptt-user-profile+xml", mime_application_vnd_3gpp_mcptt_user_profile_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-affiliation-command+xml", mime_application_vnd_3gpp_mcvideo_affiliation_command_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-affiliation-info+xml", mime_application_vnd_3gpp_mcvideo_affiliation_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-info+xml", mime_application_vnd_3gpp_mcvideo_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-location-info+xml", mime_application_vnd_3gpp_mcvideo_location_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-mbms-usage-info+xml", mime_application_vnd_3gpp_mcvideo_mbms_usage_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-service-config+xml", mime_application_vnd_3gpp_mcvideo_service_config_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-transmission-request+xml", mime_application_vnd_3gpp_mcvideo_transmission_request_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-ue-config+xml", mime_application_vnd_3gpp_mcvideo_ue_config_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mcvideo-user-profile+xml", mime_application_vnd_3gpp_mcvideo_user_profile_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.mid-call+xml", mime_application_vnd_3gpp_mid_call_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.pic-bw-large", mime_application_vnd_3gpp_pic_bw_large, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.pic-bw-small", mime_application_vnd_3gpp_pic_bw_small, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.pic-bw-var", mime_application_vnd_3gpp_pic_bw_var, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp-prose-pc3ch+xml", mime_application_vnd_3gpp_prose_pc3ch_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp-prose+xml", mime_application_vnd_3gpp_prose_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.sms", mime_application_vnd_3gpp_sms, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.sms+xml", mime_application_vnd_3gpp_sms_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.srvcc-ext+xml", mime_application_vnd_3gpp_srvcc_ext_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.SRVCC-info+xml", mime_application_vnd_3gpp_SRVCC_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.state-and-event-info+xml", mime_application_vnd_3gpp_state_and_event_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp.ussd+xml", mime_application_vnd_3gpp_ussd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp-v2x-local-service-information", mime_application_vnd_3gpp_v2x_local_service_information, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp2.bcmcsinfo+xml", mime_application_vnd_3gpp2_bcmcsinfo_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp2.sms", mime_application_vnd_3gpp2_sms, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3gpp2.tcap", mime_application_vnd_3gpp2_tcap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3lightssoftware.imagescal", mime_application_vnd_3lightssoftware_imagescal, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.3M.Post-it-Notes", mime_application_vnd_3M_Post_it_Notes, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.accpac.simply.aso", mime_application_vnd_accpac_simply_aso, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.accpac.simply.imp", mime_application_vnd_accpac_simply_imp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.acucobol", mime_application_vnd_acucobol, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.acucorp", mime_application_vnd_acucorp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_DEC20 }, "application/vnd.adobe.flash.movie", mime_application_vnd_adobe_flash_movie, ns_default, MIME_APPLICATION | MIME_VULNERABLE | MIME_WITHDRAWN },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.adobe.formscentral.fcdt", mime_application_vnd_adobe_formscentral_fcdt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.adobe.fxp", mime_application_vnd_adobe_fxp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.adobe.partial-upload", mime_application_vnd_adobe_partial_upload, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.adobe.xdp+xml", mime_application_vnd_adobe_xdp_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.adobe.xfdf", mime_application_vnd_adobe_xfdf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.aether.imp", mime_application_vnd_aether_imp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.afplinedata", mime_application_vnd_afpc_afplinedata, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.afplinedata-pagedef", mime_application_vnd_afpc_afplinedata_pagedef, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.foca-charset", mime_application_vnd_afpc_foca_charset, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.foca-codedfont", mime_application_vnd_afpc_foca_codedfont, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.foca-codepage", mime_application_vnd_afpc_foca_codepage, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.modca", mime_application_vnd_afpc_modca, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.modca-formdef", mime_application_vnd_afpc_modca_formdef, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.modca-mediummap", mime_application_vnd_afpc_modca_mediummap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.modca-objectcontainer", mime_application_vnd_afpc_modca_objectcontainer, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.modca-overlay", mime_application_vnd_afpc_modca_overlay, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.afpc.modca-pagesegment", mime_application_vnd_afpc_modca_pagesegment, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ah-barcode", mime_application_vnd_ah_barcode, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ahead.space", mime_application_vnd_ahead_space, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.airzip.filesecure.azf", mime_application_vnd_airzip_filesecure_azf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.airzip.filesecure.azs", mime_application_vnd_airzip_filesecure_azs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.amadeus+json", mime_application_vnd_amadeus_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.amazon.mobi8-ebook", mime_application_vnd_amazon_mobi8_ebook, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.americandynamics.acc", mime_application_vnd_americandynamics_acc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.amiga.ami", mime_application_vnd_amiga_ami, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.amundsen.maze+xml", mime_application_vnd_amundsen_maze_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.android.ota", mime_application_vnd_android_ota, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.anki", mime_application_vnd_anki, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.anser-web-certificate-issue-initiation", mime_application_vnd_anser_web_certificate_issue_initiation, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.antix.game-component", mime_application_vnd_antix_game_component, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apache.thrift.binary", mime_application_vnd_apache_thrift_binary, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apache.thrift.compact", mime_application_vnd_apache_thrift_compact, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apache.thrift.json", mime_application_vnd_apache_thrift_json, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.api+json", mime_application_vnd_api_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.aplextor.warrp+json", mime_application_vnd_aplextor_warrp_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apothekende.reservation+json", mime_application_vnd_apothekende_reservation_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apple.installer+xml", mime_application_vnd_apple_installer_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apple.keynote", mime_application_vnd_apple_keynote, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apple.mpegurl", mime_application_vnd_apple_mpegurl, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apple.numbers", mime_application_vnd_apple_numbers, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.apple.pages", mime_application_vnd_apple_pages, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.arastra.swi", mime_application_vnd_arastra_swi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.aristanetworks.swi", mime_application_vnd_aristanetworks_swi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.artisan+json", mime_application_vnd_artisan_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.artsquare", mime_application_vnd_artsquare, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.astraea-software.iota", mime_application_vnd_astraea_software_iota, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.audiograph", mime_application_vnd_audiograph, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.autopackage", mime_application_vnd_autopackage, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.avalon+json", mime_application_vnd_avalon_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.avistar+xml", mime_application_vnd_avistar_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.balsamiq.bmml+xml", mime_application_vnd_balsamiq_bmml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.banana-accounting", mime_application_vnd_banana_accounting, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bbf.usp.error", mime_application_vnd_bbf_usp_error, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bbf.usp.msg", mime_application_vnd_bbf_usp_msg, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bbf.usp.msg+json", mime_application_vnd_bbf_usp_msg_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.balsamiq.bmpr", mime_application_vnd_balsamiq_bmpr, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bekitzur-stech+json", mime_application_vnd_bekitzur_stech_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bint.med-content", mime_application_vnd_bint_med_content, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.biopax.rdf+xml", mime_application_vnd_biopax_rdf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.blink-idb-value-wrapper", mime_application_vnd_blink_idb_value_wrapper, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.blueice.multipass", mime_application_vnd_blueice_multipass, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bluetooth.ep.oob", mime_application_vnd_bluetooth_ep_oob, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bluetooth.le.oob", mime_application_vnd_bluetooth_le_oob, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bmi", mime_application_vnd_bmi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bpf", mime_application_vnd_bpf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.bpf3", mime_application_vnd_bpf3, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.businessobjects", mime_application_vnd_businessobjects, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.byu.uapi+json", mime_application_vnd_byu_uapi_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cab-jscript", mime_application_vnd_cab_jscript, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.canon-cpdl", mime_application_vnd_canon_cpdl, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.canon-lips", mime_application_vnd_canon_lips, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.capasystems-pg+json", mime_application_vnd_capasystems_pg_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cendio.thinlinc.clientconf", mime_application_vnd_cendio_thinlinc_clientconf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.century-systems.tcp_stream", mime_application_vnd_century_systems_tcp_stream, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.chemdraw+xml", mime_application_vnd_chemdraw_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.chess-pgn", mime_application_vnd_chess_pgn, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.chipnuts.karaoke-mmd", mime_application_vnd_chipnuts_karaoke_mmd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ciedi", mime_application_vnd_ciedi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cinderella", mime_application_vnd_cinderella, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cirpack.isdn-ext", mime_application_vnd_cirpack_isdn_ext, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.citationstyles.style+xml", mime_application_vnd_citationstyles_style_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.claymore", mime_application_vnd_claymore, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cloanto.rp9", mime_application_vnd_cloanto_rp9, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.clonk.c4group", mime_application_vnd_clonk_c4group, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cluetrust.cartomobile-config", mime_application_vnd_cluetrust_cartomobile_config, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cluetrust.cartomobile-config-pkg", mime_application_vnd_cluetrust_cartomobile_config_pkg, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.coffeescript", mime_application_vnd_coffeescript, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collabio.xodocuments.document", mime_application_vnd_collabio_xodocuments_document, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collabio.xodocuments.document-template", mime_application_vnd_collabio_xodocuments_document_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collabio.xodocuments.presentation", mime_application_vnd_collabio_xodocuments_presentation, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collabio.xodocuments.presentation-template", mime_application_vnd_collabio_xodocuments_presentation_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collabio.xodocuments.spreadsheet", mime_application_vnd_collabio_xodocuments_spreadsheet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collabio.xodocuments.spreadsheet-template", mime_application_vnd_collabio_xodocuments_spreadsheet_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collection.doc+json", mime_application_vnd_collection_doc_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collection+json", mime_application_vnd_collection_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.collection.next+json", mime_application_vnd_collection_next_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.comicbook-rar", mime_application_vnd_comicbook_rar, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.comicbook+zip", mime_application_vnd_comicbook_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.commerce-battelle", mime_application_vnd_commerce_battelle, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.commonspace", mime_application_vnd_commonspace, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.coreos.ignition+json", mime_application_vnd_coreos_ignition_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cosmocaller", mime_application_vnd_cosmocaller, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.contact.cmsg", mime_application_vnd_contact_cmsg, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.crick.clicker", mime_application_vnd_crick_clicker, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.crick.clicker.keyboard", mime_application_vnd_crick_clicker_keyboard, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.crick.clicker.palette", mime_application_vnd_crick_clicker_palette, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.crick.clicker.template", mime_application_vnd_crick_clicker_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.crick.clicker.wordbank", mime_application_vnd_crick_clicker_wordbank, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.criticaltools.wbs+xml", mime_application_vnd_criticaltools_wbs_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cryptii.pipe+json", mime_application_vnd_cryptii_pipe_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.crypto-shade-file", mime_application_vnd_crypto_shade_file, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ctc-posml", mime_application_vnd_ctc_posml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ctct.ws+xml", mime_application_vnd_ctct_ws_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cups-pdf", mime_application_vnd_cups_pdf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cups-postscript", mime_application_vnd_cups_postscript, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cups-ppd", mime_application_vnd_cups_ppd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cups-raster", mime_application_vnd_cups_raster, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cups-raw", mime_application_vnd_cups_raw, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.curl", mime_application_vnd_curl, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cyan.dean.root+xml", mime_application_vnd_cyan_dean_root_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.cybank", mime_application_vnd_cybank, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.d2l.coursepackage1p0+zip", mime_application_vnd_d2l_coursepackage1p0_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dart", mime_application_vnd_dart, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.data-vision.rdz", mime_application_vnd_data_vision_rdz, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.datapackage+json", mime_application_vnd_datapackage_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dataresource+json", mime_application_vnd_dataresource_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dbf", mime_application_vnd_dbf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.debian.binary-package", mime_application_vnd_debian_binary_package, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dece.data", mime_application_vnd_dece_data, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dece.ttml+xml", mime_application_vnd_dece_ttml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dece.unspecified", mime_application_vnd_dece_unspecified, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dece.zip", mime_application_vnd_dece_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.denovo.fcselayout-link", mime_application_vnd_denovo_fcselayout_link, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.desmume.movie", mime_application_vnd_desmume_movie, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dir-bi.plate-dl-nosuffix", mime_application_vnd_dir_bi_plate_dl_nosuffix, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dm.delegation+xml", mime_application_vnd_dm_delegation_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dna", mime_application_vnd_dna, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.document+json", mime_application_vnd_document_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dolby.mobile.1", mime_application_vnd_dolby_mobile_1, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dolby.mobile.2", mime_application_vnd_dolby_mobile_2, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.doremir.scorecloud-binary-document", mime_application_vnd_doremir_scorecloud_binary_document, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dpgraph", mime_application_vnd_dpgraph, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dreamfactory", mime_application_vnd_dreamfactory, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.drive+json", mime_application_vnd_drive_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dtg.local", mime_application_vnd_dtg_local, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dtg.local.flash", mime_application_vnd_dtg_local_flash, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dtg.local.html", mime_application_vnd_dtg_local_html, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.ait", mime_application_vnd_dvb_ait, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.dvbisl+xml", mime_application_vnd_dvb_dvbisl_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.dvbj", mime_application_vnd_dvb_dvbj, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.esgcontainer", mime_application_vnd_dvb_esgcontainer, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.ipdcdftnotifaccess", mime_application_vnd_dvb_ipdcdftnotifaccess, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.ipdcesgaccess", mime_application_vnd_dvb_ipdcesgaccess, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.ipdcesgaccess2", mime_application_vnd_dvb_ipdcesgaccess2, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.ipdcesgpdd", mime_application_vnd_dvb_ipdcesgpdd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.ipdcroaming", mime_application_vnd_dvb_ipdcroaming, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.iptv.alfec-base", mime_application_vnd_dvb_iptv_alfec_base, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.iptv.alfec-enhancement", mime_application_vnd_dvb_iptv_alfec_enhancement, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.notif-aggregate-root+xml", mime_application_vnd_dvb_notif_aggregate_root_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.notif-container+xml", mime_application_vnd_dvb_notif_container_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.notif-generic+xml", mime_application_vnd_dvb_notif_generic_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.notif-ia-msglist+xml", mime_application_vnd_dvb_notif_ia_msglist_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.notif-ia-registration-request+xml", mime_application_vnd_dvb_notif_ia_registration_request_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.notif-ia-registration-response+xml", mime_application_vnd_dvb_notif_ia_registration_response_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.notif-init+xml", mime_application_vnd_dvb_notif_init_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.pfr", mime_application_vnd_dvb_pfr, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dvb.service", mime_application_vnd_dvb_service, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dxr", mime_application_vnd_dxr, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dynageo", mime_application_vnd_dynageo, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.dzr", mime_application_vnd_dzr, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.easykaraoke.cdgdownload", mime_application_vnd_easykaraoke_cdgdownload, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ecip.rlp", mime_application_vnd_ecip_rlp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ecdis-update", mime_application_vnd_ecdis_update, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ecowin.chart", mime_application_vnd_ecowin_chart, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ecowin.filerequest", mime_application_vnd_ecowin_filerequest, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ecowin.fileupdate", mime_application_vnd_ecowin_fileupdate, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ecowin.series", mime_application_vnd_ecowin_series, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ecowin.seriesrequest", mime_application_vnd_ecowin_seriesrequest, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ecowin.seriesupdate", mime_application_vnd_ecowin_seriesupdate, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.efi.img", mime_application_vnd_efi_img, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.efi.iso", mime_application_vnd_efi_iso, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.emclient.accessrequest+xml", mime_application_vnd_emclient_accessrequest_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.enliven", mime_application_vnd_enliven, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.enphase.envoy", mime_application_vnd_enphase_envoy, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.eprints.data+xml", mime_application_vnd_eprints_data_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.epson.esf", mime_application_vnd_epson_esf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.epson.msf", mime_application_vnd_epson_msf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.epson.quickanime", mime_application_vnd_epson_quickanime, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.epson.salt", mime_application_vnd_epson_salt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.epson.ssf", mime_application_vnd_epson_ssf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ericsson.quickcall", mime_application_vnd_ericsson_quickcall, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.espass-espass+zip", mime_application_vnd_espass_espass_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.eszigno3+xml", mime_application_vnd_eszigno3_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.aoc+xml", mime_application_vnd_etsi_aoc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.asic-s+zip", mime_application_vnd_etsi_asic_s_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.asic-e+zip", mime_application_vnd_etsi_asic_e_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.cug+xml", mime_application_vnd_etsi_cug_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvcommand+xml", mime_application_vnd_etsi_iptvcommand_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvdiscovery+xml", mime_application_vnd_etsi_iptvdiscovery_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvprofile+xml", mime_application_vnd_etsi_iptvprofile_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvsad-bc+xml", mime_application_vnd_etsi_iptvsad_bc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvsad-cod+xml", mime_application_vnd_etsi_iptvsad_cod_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvsad-npvr+xml", mime_application_vnd_etsi_iptvsad_npvr_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvservice+xml", mime_application_vnd_etsi_iptvservice_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvsync+xml", mime_application_vnd_etsi_iptvsync_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.iptvueprofile+xml", mime_application_vnd_etsi_iptvueprofile_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.mcid+xml", mime_application_vnd_etsi_mcid_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.mheg5", mime_application_vnd_etsi_mheg5, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.overload-control-policy-dataset+xml", mime_application_vnd_etsi_overload_control_policy_dataset_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.pstn+xml", mime_application_vnd_etsi_pstn_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.sci+xml", mime_application_vnd_etsi_sci_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.simservs+xml", mime_application_vnd_etsi_simservs_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.timestamp-token", mime_application_vnd_etsi_timestamp_token, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.tsl+xml", mime_application_vnd_etsi_tsl_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.etsi.tsl.der", mime_application_vnd_etsi_tsl_der, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.evolv.ecig.profile", mime_application_vnd_evolv_ecig_profile, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.evolv.ecig.settings", mime_application_vnd_evolv_ecig_settings, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.evolv.ecig.theme", mime_application_vnd_evolv_ecig_theme, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.eudora.data", mime_application_vnd_eudora_data, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.exstream-empower+zip", mime_application_vnd_exstream_empower_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.exstream-package", mime_application_vnd_exstream_package, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ezpix-album", mime_application_vnd_ezpix_album, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ezpix-package", mime_application_vnd_ezpix_package, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.f-secure.mobile", mime_application_vnd_f_secure_mobile, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fastcopy-disk-image", mime_application_vnd_fastcopy_disk_image, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fdf", mime_application_vnd_fdf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fdsn.mseed", mime_application_vnd_fdsn_mseed, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fdsn.seed", mime_application_vnd_fdsn_seed, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ffsns", mime_application_vnd_ffsns, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ficlab.flb+zip", mime_application_vnd_ficlab_flb_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.filmit.zfc", mime_application_vnd_filmit_zfc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fints", mime_application_vnd_fints, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.firemonkeys.cloudcell", mime_application_vnd_firemonkeys_cloudcell, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.FloGraphIt", mime_application_vnd_FloGraphIt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fluxtime.clip", mime_application_vnd_fluxtime_clip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.font-fontforge-sfd", mime_application_vnd_font_fontforge_sfd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.framemaker", mime_application_vnd_framemaker, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.frogans.fnc", mime_application_vnd_frogans_fnc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.frogans.ltf", mime_application_vnd_frogans_ltf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fsc.weblaunch", mime_application_vnd_fsc_weblaunch, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujitsu.oasys", mime_application_vnd_fujitsu_oasys, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujitsu.oasys2", mime_application_vnd_fujitsu_oasys2, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujitsu.oasys3", mime_application_vnd_fujitsu_oasys3, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujitsu.oasysgp", mime_application_vnd_fujitsu_oasysgp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujitsu.oasysprs", mime_application_vnd_fujitsu_oasysprs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujixerox.ART4", mime_application_vnd_fujixerox_ART4, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujixerox.ART-EX", mime_application_vnd_fujixerox_ART_EX, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujixerox.ddd", mime_application_vnd_fujixerox_ddd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujixerox.docuworks", mime_application_vnd_fujixerox_docuworks, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujixerox.docuworks.binder", mime_application_vnd_fujixerox_docuworks_binder, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujixerox.docuworks.container", mime_application_vnd_fujixerox_docuworks_container, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fujixerox.HBPL", mime_application_vnd_fujixerox_HBPL, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fut-misnet", mime_application_vnd_fut_misnet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.futoin+cbor", mime_application_vnd_futoin_cbor, ns_default, MIME_APPLICATION | MIME_CBOR },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.futoin+json", mime_application_vnd_futoin_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.fuzzysheet", mime_application_vnd_fuzzysheet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.genomatix.tuxedo", mime_application_vnd_genomatix_tuxedo, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.gentics.grd+json", mime_application_vnd_gentics_grd_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.geo+json", mime_application_vnd_geo_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.geocube+xml", mime_application_vnd_geocube_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.geogebra.file", mime_application_vnd_geogebra_file, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.geogebra.tool", mime_application_vnd_geogebra_tool, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.geometry-explorer", mime_application_vnd_geometry_explorer, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.geonext", mime_application_vnd_geonext, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.geoplan", mime_application_vnd_geoplan, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.geospace", mime_application_vnd_geospace, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.gerber", mime_application_vnd_gerber, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.globalplatform.card-content-mgt", mime_application_vnd_globalplatform_card_content_mgt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.globalplatform.card-content-mgt-response", mime_application_vnd_globalplatform_card_content_mgt_response, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.gmx", mime_application_vnd_gmx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.google-earth.kml+xml", mime_application_vnd_google_earth_kml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.google-earth.kmz", mime_application_vnd_google_earth_kmz, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.gov.sk.e-form+xml", mime_application_vnd_gov_sk_e_form_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.gov.sk.e-form+zip", mime_application_vnd_gov_sk_e_form_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.gov.sk.xmldatacontainer+xml", mime_application_vnd_gov_sk_xmldatacontainer_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.grafeq", mime_application_vnd_grafeq, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.gridmp", mime_application_vnd_gridmp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.groove-account", mime_application_vnd_groove_account, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.groove-help", mime_application_vnd_groove_help, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.groove-identity-message", mime_application_vnd_groove_identity_message, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.groove-injector", mime_application_vnd_groove_injector, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.groove-tool-message", mime_application_vnd_groove_tool_message, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.groove-tool-template", mime_application_vnd_groove_tool_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.groove-vcard", mime_application_vnd_groove_vcard, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hal+json", mime_application_vnd_hal_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hal+xml", mime_application_vnd_hal_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.HandHeld-Entertainment+xml", mime_application_vnd_HandHeld_Entertainment_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hbci", mime_application_vnd_hbci, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hc+json", mime_application_vnd_hc_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hcl-bireports", mime_application_vnd_hcl_bireports, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hdt", mime_application_vnd_hdt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.heroku+json", mime_application_vnd_heroku_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hhe.lesson-player", mime_application_vnd_hhe_lesson_player, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hp-HPGL", mime_application_vnd_hp_HPGL, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hp-hpid", mime_application_vnd_hp_hpid, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hp-hps", mime_application_vnd_hp_hps, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hp-jlyt", mime_application_vnd_hp_jlyt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hp-PCL", mime_application_vnd_hp_PCL, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hp-PCLXL", mime_application_vnd_hp_PCLXL, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.httphone", mime_application_vnd_httphone, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hydrostatix.sof-data", mime_application_vnd_hydrostatix_sof_data, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hyper-item+json", mime_application_vnd_hyper_item_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hyper+json", mime_application_vnd_hyper_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hyperdrive+json", mime_application_vnd_hyperdrive_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.hzn-3d-crossword", mime_application_vnd_hzn_3d_crossword, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ibm.afplinedata", mime_application_vnd_ibm_afplinedata, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ibm.electronic-media", mime_application_vnd_ibm_electronic_media, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ibm.MiniPay", mime_application_vnd_ibm_MiniPay, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ibm.modcap", mime_application_vnd_ibm_modcap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ibm.rights-management", mime_application_vnd_ibm_rights_management, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ibm.secure-container", mime_application_vnd_ibm_secure_container, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iccprofile", mime_application_vnd_iccprofile, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ieee.1905", mime_application_vnd_ieee_1905, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.igloader", mime_application_vnd_igloader, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.imagemeter.folder+zip", mime_application_vnd_imagemeter_folder_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.imagemeter.image+zip", mime_application_vnd_imagemeter_image_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.immervision-ivp", mime_application_vnd_immervision_ivp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.immervision-ivu", mime_application_vnd_immervision_ivu, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.imsccv1p1", mime_application_vnd_ims_imsccv1p1, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.imsccv1p2", mime_application_vnd_ims_imsccv1p2, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.imsccv1p3", mime_application_vnd_ims_imsccv1p3, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.lis.v2.result+json", mime_application_vnd_ims_lis_v2_result_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.lti.v2.toolconsumerprofile+json", mime_application_vnd_ims_lti_v2_toolconsumerprofile_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.lti.v2.toolproxy.id+json", mime_application_vnd_ims_lti_v2_toolproxy_id_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.lti.v2.toolproxy+json", mime_application_vnd_ims_lti_v2_toolproxy_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.lti.v2.toolsettings+json", mime_application_vnd_ims_lti_v2_toolsettings_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ims.lti.v2.toolsettings.simple+json", mime_application_vnd_ims_lti_v2_toolsettings_simple_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.informedcontrol.rms+xml", mime_application_vnd_informedcontrol_rms_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.infotech.project", mime_application_vnd_infotech_project, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.infotech.project+xml", mime_application_vnd_infotech_project_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.informix-visionary", mime_application_vnd_informix_visionary, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.innopath.wamp.notification", mime_application_vnd_innopath_wamp_notification, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.insors.igm", mime_application_vnd_insors_igm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.intercon.formnet", mime_application_vnd_intercon_formnet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.intergeo", mime_application_vnd_intergeo, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.intertrust.digibox", mime_application_vnd_intertrust_digibox, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.intertrust.nncp", mime_application_vnd_intertrust_nncp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.intu.qbo", mime_application_vnd_intu_qbo, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.intu.qfx", mime_application_vnd_intu_qfx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iptc.g2.catalogitem+xml", mime_application_vnd_iptc_g2_catalogitem_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iptc.g2.conceptitem+xml", mime_application_vnd_iptc_g2_conceptitem_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iptc.g2.knowledgeitem+xml", mime_application_vnd_iptc_g2_knowledgeitem_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iptc.g2.newsitem+xml", mime_application_vnd_iptc_g2_newsitem_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iptc.g2.newsmessage+xml", mime_application_vnd_iptc_g2_newsmessage_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iptc.g2.packageitem+xml", mime_application_vnd_iptc_g2_packageitem_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iptc.g2.planningitem+xml", mime_application_vnd_iptc_g2_planningitem_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ipunplugged.rcprofile", mime_application_vnd_ipunplugged_rcprofile, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.irepository.package+xml", mime_application_vnd_irepository_package_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.is-xpr", mime_application_vnd_is_xpr, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.isac.fcs", mime_application_vnd_isac_fcs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.jam", mime_application_vnd_jam, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.iso11783-10+zip", mime_application_vnd_iso11783_10_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.japannet-directory-service", mime_application_vnd_japannet_directory_service, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.japannet-jpnstore-wakeup", mime_application_vnd_japannet_jpnstore_wakeup, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.japannet-payment-wakeup", mime_application_vnd_japannet_payment_wakeup, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.japannet-registration", mime_application_vnd_japannet_registration, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.japannet-registration-wakeup", mime_application_vnd_japannet_registration_wakeup, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.japannet-setstore-wakeup", mime_application_vnd_japannet_setstore_wakeup, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.japannet-verification", mime_application_vnd_japannet_verification, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.japannet-verification-wakeup", mime_application_vnd_japannet_verification_wakeup, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.jcp.javame.midlet-rms", mime_application_vnd_jcp_javame_midlet_rms, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.jisp", mime_application_vnd_jisp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.joost.joda-archive", mime_application_vnd_joost_joda_archive, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.jsk.isdn-ngn", mime_application_vnd_jsk_isdn_ngn, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kahootz", mime_application_vnd_kahootz, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kde.karbon", mime_application_vnd_kde_karbon, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kde.kchart", mime_application_vnd_kde_kchart, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kde.kformula", mime_application_vnd_kde_kformula, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kde.kivio", mime_application_vnd_kde_kivio, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kde.kontour", mime_application_vnd_kde_kontour, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kde.kpresenter", mime_application_vnd_kde_kpresenter, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kde.kspread", mime_application_vnd_kde_kspread, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kde.kword", mime_application_vnd_kde_kword, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kenameaapp", mime_application_vnd_kenameaapp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kidspiration", mime_application_vnd_kidspiration, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Kinar", mime_application_vnd_Kinar, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.koan", mime_application_vnd_koan, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.kodak-descriptor", mime_application_vnd_kodak_descriptor, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.las", mime_application_vnd_las, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.las.las+json", mime_application_vnd_las_las_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.las.las+xml", mime_application_vnd_las_las_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.laszip", mime_application_vnd_laszip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.leap+json", mime_application_vnd_leap_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.liberty-request+xml", mime_application_vnd_liberty_request_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.llamagraphics.life-balance.desktop", mime_application_vnd_llamagraphics_life_balance_desktop, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.llamagraphics.life-balance.exchange+xml", mime_application_vnd_llamagraphics_life_balance_exchange_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.logipipe.circuit+zip", mime_application_vnd_logipipe_circuit_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.loom", mime_application_vnd_loom, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.lotus-1-2-3", mime_application_vnd_lotus_1_2_3, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.lotus-approach", mime_application_vnd_lotus_approach, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.lotus-freelance", mime_application_vnd_lotus_freelance, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.lotus-notes", mime_application_vnd_lotus_notes, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.lotus-organizer", mime_application_vnd_lotus_organiser, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.lotus-screencam", mime_application_vnd_lotus_screencam, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.lotus-wordpro", mime_application_vnd_lotus_wordpro, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.macports.portpkg", mime_application_vnd_macports_portpkg, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mapbox-vector-tile", mime_application_vnd_mapbox_vector_tile, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.marlin.drm.actiontoken+xml", mime_application_vnd_marlin_drm_actiontoken_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.marlin.drm.conftoken+xml", mime_application_vnd_marlin_drm_conftoken_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.marlin.drm.license+xml", mime_application_vnd_marlin_drm_license_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.marlin.drm.mdcf", mime_application_vnd_marlin_drm_mdcf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mason+json", mime_application_vnd_mason_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.maxmind.maxmind-db", mime_application_vnd_maxmind_maxmind_db, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mcd", mime_application_vnd_mcd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.medcalcdata", mime_application_vnd_medcalcdata, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mediastation.cdkey", mime_application_vnd_mediastation_cdkey, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.meridian-slingshot", mime_application_vnd_meridian_slingshot, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.MFER", mime_application_vnd_MFER, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mfmp", mime_application_vnd_mfmp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.micro+json", mime_application_vnd_micro_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.micrografx.flo", mime_application_vnd_micrografx_flo, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.micrografx.igx", mime_application_vnd_micrografx_igx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.microsoft.portable-executable", mime_application_vnd_microsoft_portable_executable, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.microsoft.windows.thumbnail-cache", mime_application_vnd_microsoft_windows_thumbnail_cache, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.miele+json", mime_application_vnd_miele_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mif", mime_application_vnd_mif, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.minisoft-hp3000-save", mime_application_vnd_minisoft_hp3000_save, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mitsubishi.misty-guard.trustweb", mime_application_vnd_mitsubishi_misty_guard_trustweb, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Mobius.DAF", mime_application_vnd_Mobius_DAF, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Mobius.DIS", mime_application_vnd_Mobius_DIS, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Mobius.MBK", mime_application_vnd_Mobius_MBK, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Mobius.MQY", mime_application_vnd_Mobius_MQY, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Mobius.MSL", mime_application_vnd_Mobius_MSL, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Mobius.PLC", mime_application_vnd_Mobius_PLC, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Mobius.TXF", mime_application_vnd_Mobius_TXF, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mophun.application", mime_application_vnd_mophun_application, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mophun.certificate", mime_application_vnd_mophun_certificate, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.motorola.flexsuite", mime_application_vnd_motorola_flexsuite, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.motorola.flexsuite.adsi", mime_application_vnd_motorola_flexsuite_adsi, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.motorola.flexsuite.fis", mime_application_vnd_motorola_flexsuite_fis, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.motorola.flexsuite.gotap", mime_application_vnd_motorola_flexsuite_gotap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.motorola.flexsuite.kmr", mime_application_vnd_motorola_flexsuite_kmr, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.motorola.flexsuite.ttc", mime_application_vnd_motorola_flexsuite_ttc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.motorola.flexsuite.wem", mime_application_vnd_motorola_flexsuite_wem, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.motorola.iprm", mime_application_vnd_motorola_iprm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mozilla.xul+xml", mime_application_vnd_mozilla_xul_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-artgalry", mime_application_vnd_ms_artgalry, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-asf", mime_application_vnd_ms_asf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-cab-compressed", mime_application_vnd_ms_cab_compressed, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-3mfdocument", mime_application_vnd_ms_3mfdocument, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-excel", mime_application_vnd_ms_excel, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-excel.addin.macroEnabled.12", mime_application_vnd_ms_excel_addin_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-excel.sheet.binary.macroEnabled.12", mime_application_vnd_ms_excel_sheet_binary_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-excel.sheet.macroEnabled.12", mime_application_vnd_ms_excel_sheet_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-excel.template.macroEnabled.12", mime_application_vnd_ms_excel_template_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-fontobject", mime_application_vnd_ms_fontobject, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-htmlhelp", mime_application_vnd_ms_htmlhelp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-ims", mime_application_vnd_ms_ims, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-lrm", mime_application_vnd_ms_lrm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-office.activeX+xml", mime_application_vnd_ms_office_activeX_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-officetheme", mime_application_vnd_ms_officetheme, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-playready.initiator+xml", mime_application_vnd_ms_playready_initiator_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-powerpoint", mime_application_vnd_ms_powerpoint, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-powerpoint.addin.macroEnabled.12", mime_application_vnd_ms_powerpoint_addin_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-powerpoint.presentation.macroEnabled.12", mime_application_vnd_ms_powerpoint_presentation_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-powerpoint.slide.macroEnabled.12", mime_application_vnd_ms_powerpoint_slide_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-powerpoint.slideshow.macroEnabled.12", mime_application_vnd_ms_powerpoint_slideshow_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-powerpoint.template.macroEnabled.12", mime_application_vnd_ms_powerpoint_template_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-PrintDeviceCapabilities+xml", mime_application_vnd_ms_PrintDeviceCapabilities_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-PrintSchemaTicket+xml", mime_application_vnd_ms_PrintSchemaTicket_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-project", mime_application_vnd_ms_project, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-tnef", mime_application_vnd_ms_tnef, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-windows.devicepairing", mime_application_vnd_ms_windows_devicepairing, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-windows.nwprinting.oob", mime_application_vnd_ms_windows_nwprinting_oob, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-windows.printerpairing", mime_application_vnd_ms_windows_printerpairing, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-windows.wsd.oob", mime_application_vnd_ms_windows_wsd_oob, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-wmdrm.lic-chlg-req", mime_application_vnd_ms_wmdrm_lic_chlg_req, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-wmdrm.lic-resp", mime_application_vnd_ms_wmdrm_lic_resp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-wmdrm.meter-chlg-req", mime_application_vnd_ms_wmdrm_meter_chlg_req, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-wmdrm.meter-resp", mime_application_vnd_ms_wmdrm_meter_resp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-word.document.macroEnabled.12", mime_application_vnd_ms_word_document_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-word.template.macroEnabled.12", mime_application_vnd_ms_word_template_macroEnabled_12, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-works", mime_application_vnd_ms_works, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-wpl", mime_application_vnd_ms_wpl, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-xpsdocument", mime_application_vnd_ms_xpsdocument, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.msa-disk-image", mime_application_vnd_msa_disk_image, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mseq", mime_application_vnd_mseq, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.msign", mime_application_vnd_msign, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.multiad.creator", mime_application_vnd_multiad_creator, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.multiad.creator.cif", mime_application_vnd_multiad_creator_cif, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.musician", mime_application_vnd_musician, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.music-niff", mime_application_vnd_music_niff, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.muvee.style", mime_application_vnd_muvee_style, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.mynfc", mime_application_vnd_mynfc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ncd.control", mime_application_vnd_ncd_control, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ncd.reference", mime_application_vnd_ncd_reference, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nearst.inv+json", mime_application_vnd_nearst_inv_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nervana", mime_application_vnd_nervana, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.netfpx", mime_application_vnd_netfpx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.neurolanguage.nlu", mime_application_vnd_neurolanguage_nlu, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nimn", mime_application_vnd_nimn, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nintendo.snes.rom", mime_application_vnd_nintendo_snes_rom, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nintendo.nitro.rom", mime_application_vnd_nintendo_nitro_rom, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nitf", mime_application_vnd_nitf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.noblenet-directory", mime_application_vnd_noblenet_directory, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.noblenet-sealer", mime_application_vnd_noblenet_sealer, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.noblenet-web", mime_application_vnd_noblenet_web, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.catalogs", mime_application_vnd_nokia_catalogs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.conml+wbxml", mime_application_vnd_nokia_conml_wbxml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.conml+xml", mime_application_vnd_nokia_conml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.iptv.config+xml", mime_application_vnd_nokia_iptv_config_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.iSDS-radio-presets", mime_application_vnd_nokia_iSDS_radio_presets, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.landmark+wbxml", mime_application_vnd_nokia_landmark_wbxml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.landmark+xml", mime_application_vnd_nokia_landmark_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.landmarkcollection+xml", mime_application_vnd_nokia_landmarkcollection_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.ncd", mime_application_vnd_nokia_ncd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.n-gage.ac+xml", mime_application_vnd_nokia_n_gage_ac_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.n-gage.data", mime_application_vnd_nokia_n_gage_data, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.n-gage.symbian.install", mime_application_vnd_nokia_n_gage_symbian_install, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.pcd+wbxml", mime_application_vnd_nokia_pcd_wbxml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.pcd+xml", mime_application_vnd_nokia_pcd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.radio-preset", mime_application_vnd_nokia_radio_preset, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.nokia.radio-presets", mime_application_vnd_nokia_radio_presets, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.novadigm.EDM", mime_application_vnd_novadigm_EDM, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.novadigm.EDX", mime_application_vnd_novadigm_EDX, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.novadigm.EXT", mime_application_vnd_novadigm_EXT, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ntt-local.content-share", mime_application_vnd_ntt_local_content_share, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ntt-local.file-transfer", mime_application_vnd_ntt_local_file_transfer, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ntt-local.ogw_remote-access", mime_application_vnd_ntt_local_ogw_remote_access, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ntt-local.sip-ta_remote", mime_application_vnd_ntt_local_sip_ta_remote, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ntt-local.sip-ta_tcp_stream", mime_application_vnd_ntt_local_sip_ta_tcp_stream, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.chart", mime_application_vnd_oasis_opendocument_chart, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.chart-template", mime_application_vnd_oasis_opendocument_chart_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.database", mime_application_vnd_oasis_opendocument_database, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.formula", mime_application_vnd_oasis_opendocument_formula, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.formula-template", mime_application_vnd_oasis_opendocument_formula_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.graphics", mime_application_vnd_oasis_opendocument_graphics, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.graphics-template", mime_application_vnd_oasis_opendocument_graphics_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.image", mime_application_vnd_oasis_opendocument_image, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.image-template", mime_application_vnd_oasis_opendocument_image_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.presentation", mime_application_vnd_oasis_opendocument_presentation, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.presentation-template", mime_application_vnd_oasis_opendocument_presentation_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.spreadsheet", mime_application_vnd_oasis_opendocument_spreadsheet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.spreadsheet-template", mime_application_vnd_oasis_opendocument_spreadsheet_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.text", mime_application_vnd_oasis_opendocument_text, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.text-master", mime_application_vnd_oasis_opendocument_text_master, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.text-template", mime_application_vnd_oasis_opendocument_text_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oasis.opendocument.text-web", mime_application_vnd_oasis_opendocument_text_web, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.obn", mime_application_vnd_obn, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ocf+cbor", mime_application_vnd_ocf_cbor, ns_default, MIME_APPLICATION | MIME_CBOR },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oci.image.manifest.v1+json", mime_application_vnd_oci_image_manifest_v1_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oftn.l10n+json", mime_application_vnd_oftn_l10n_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.contentaccessdownload+xml", mime_application_vnd_oipf_contentaccessdownload_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.contentaccessstreaming+xml", mime_application_vnd_oipf_contentaccessstreaming_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.cspg-hexbinary", mime_application_vnd_oipf_cspg_hexbinary, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.dae.svg+xml", mime_application_vnd_oipf_dae_svg_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.dae.xhtml+xml", mime_application_vnd_oipf_dae_xhtml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.mippvcontrolmessage+xml", mime_application_vnd_oipf_mippvcontrolmessage_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.pae.gem", mime_application_vnd_oipf_pae_gem, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.spdiscovery+xml", mime_application_vnd_oipf_spdiscovery_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.spdlist+xml", mime_application_vnd_oipf_spdlist_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.ueprofile+xml", mime_application_vnd_oipf_ueprofile_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oipf.userprofile+xml", mime_application_vnd_oipf_userprofile_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.olpc-sugar", mime_application_vnd_olpc_sugar, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.associated-procedure-parameter+xml", mime_application_vnd_oma_bcast_associated_procedure_parameter_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.drm-trigger+xml", mime_application_vnd_oma_bcast_drm_trigger_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.imd+xml", mime_application_vnd_oma_bcast_imd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.ltkm", mime_application_vnd_oma_bcast_ltkm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.notification+xml", mime_application_vnd_oma_bcast_notification_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.provisioningtrigger", mime_application_vnd_oma_bcast_provisioningtrigger, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.sgboot", mime_application_vnd_oma_bcast_sgboot, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.sgdd+xml", mime_application_vnd_oma_bcast_sgdd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.sgdu", mime_application_vnd_oma_bcast_sgdu, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.simple-symbol-container", mime_application_vnd_oma_bcast_simple_symbol_container, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.smartcard-trigger+xml", mime_application_vnd_oma_bcast_smartcard_trigger_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.sprov+xml", mime_application_vnd_oma_bcast_sprov_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.bcast.stkm", mime_application_vnd_oma_bcast_stkm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.cab-address-book+xml", mime_application_vnd_oma_cab_address_book_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.cab-feature-handler+xml", mime_application_vnd_oma_cab_feature_handler_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.cab-pcc+xml", mime_application_vnd_oma_cab_pcc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.cab-subs-invite+xml", mime_application_vnd_oma_cab_subs_invite_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.cab-user-prefs+xml", mime_application_vnd_oma_cab_user_prefs_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.dcd", mime_application_vnd_oma_dcd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.dcdc", mime_application_vnd_oma_dcdc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.dd2+xml", mime_application_vnd_oma_dd2_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.drm.risd+xml", mime_application_vnd_oma_drm_risd_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.group-usage-list+xml", mime_application_vnd_oma_group_usage_list_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.lwm2m+json", mime_application_vnd_oma_lwm2m_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.lwm2m+tlv", mime_application_vnd_oma_lwm2m_tlv, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.pal+xml", mime_application_vnd_oma_pal_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.poc.detailed-progress-report+xml", mime_application_vnd_oma_poc_detailed_progress_report_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.poc.final-report+xml", mime_application_vnd_oma_poc_final_report_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.poc.groups+xml", mime_application_vnd_oma_poc_groups_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.poc.invocation-descriptor+xml", mime_application_vnd_oma_poc_invocation_descriptor_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.poc.optimized-progress-report+xml", mime_application_vnd_oma_poc_optimized_progress_report_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.push", mime_application_vnd_oma_push, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.scidm.messages+xml", mime_application_vnd_oma_scidm_messages_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma.xcap-directory+xml", mime_application_vnd_oma_xcap_directory_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.omads-email+xml", mime_application_vnd_omads_email_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.omads-file+xml", mime_application_vnd_omads_file_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.omads-folder+xml", mime_application_vnd_omads_folder_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.omaloc-supl-init", mime_application_vnd_omaloc_supl_init, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma-scws-config", mime_application_vnd_oma_scws_config, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma-scws-http-request", mime_application_vnd_oma_scws_http_request, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oma-scws-http-response", mime_application_vnd_oma_scws_http_response, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.onepager", mime_application_vnd_onepager, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.onepagertamp", mime_application_vnd_onepagertamp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.onepagertamx", mime_application_vnd_onepagertamx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.onepagertat", mime_application_vnd_onepagertat, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.onepagertatp", mime_application_vnd_onepagertatp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.onepagertatx", mime_application_vnd_onepagertatx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openblox.game-binary", mime_application_vnd_openblox_game_binary, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openblox.game+xml", mime_application_vnd_openblox_game_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openeye.oeb", mime_application_vnd_openeye_oeb, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openstreetmap.data+xml", mime_application_vnd_openstreetmap_data_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.custom-properties+xml", mime_application_vnd_openxmlformats_officedocument_custom_properties_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.customXmlProperties+xml", mime_application_vnd_openxmlformats_officedocument_customXmlProperties_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.drawing+xml", mime_application_vnd_openxmlformats_officedocument_drawing_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.drawingml.chart+xml", mime_application_vnd_openxmlformats_officedocument_drawingml_chart_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.drawingml.chartshapes+xml", mime_application_vnd_openxmlformats_officedocument_drawingml_chartshapes_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.drawingml.diagramColors+xml", mime_application_vnd_openxmlformats_officedocument_drawingml_diagramColors_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.drawingml.diagramData+xml", mime_application_vnd_openxmlformats_officedocument_drawingml_diagramData_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.drawingml.diagramLayout+xml", mime_application_vnd_openxmlformats_officedocument_drawingml_diagramLayout_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.drawingml.diagramStyle+xml", mime_application_vnd_openxmlformats_officedocument_drawingml_diagramStyle_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.extended-properties+xml", mime_application_vnd_openxmlformats_officedocument_extended_properties_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.commentAuthors+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_commentAuthors_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.comments+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_comments_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.handoutMaster+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_handoutMaster_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.notesMaster+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_notesMaster_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.notesSlide+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_notesSlide_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.presentation", mime_application_vnd_openxmlformats_officedocument_presentationml_presentation, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.presentation.main+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_presentation_main_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.presProps+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_presProps_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.slide", mime_application_vnd_openxmlformats_officedocument_presentationml_slide, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.slide+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_slide_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.slideLayout+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_slideLayout_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.slideMaster+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_slideMaster_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.slideshow", mime_application_vnd_openxmlformats_officedocument_presentationml_slideshow, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.slideshow.main+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_slideshow_main_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.slideUpdateInfo+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_slideUpdateInfo_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.tableStyles+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_tableStyles_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.tags+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_tags_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.template", mime_application_vnd_openxmlformats_officedocument_presentationml_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.template.main+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_template_main_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.presentationml.viewProps+xml", mime_application_vnd_openxmlformats_officedocument_presentationml_viewProps_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.calcChain+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_calcChain_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.chartsheet+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_chartsheet_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.comments+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_comments_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.connections+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_connections_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.dialogsheet+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_dialogsheet_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.externalLink+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_externalLink_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotCacheDefinition+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_pivotCacheDefinition_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotCacheRecords+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_pivotCacheRecords_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.pivotTable+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_pivotTable_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.queryTable+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_queryTable_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.revisionHeaders+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_revisionHeaders_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.revisionLog+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_revisionLog_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.sharedStrings+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_sharedStrings_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_sheet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_sheet_main_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.sheetMetadata+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_sheetMetadata_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_styles_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.table+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_table_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.tableSingleCells+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_tableSingleCells_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.template", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.template.main+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_template_main_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.userNames+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_userNames_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.volatileDependencies+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_volatileDependencies_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_worksheet_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.theme+xml", mime_application_vnd_openxmlformats_officedocument_theme_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.themeOverride+xml", mime_application_vnd_openxmlformats_officedocument_themeOverride_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.vmlDrawing", mime_application_vnd_openxmlformats_officedocument_vmlDrawing, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.comments+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_comments_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.document", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_document, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.document.glossary+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_document_glossary_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_document_main_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.endnotes+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_endnotes_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.fontTable+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_fontTable_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.footer+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_footer_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.footnotes+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_footnotes_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.numbering+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_numbering_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.settings+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_settings_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.styles+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_styles_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.template", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_template, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.template.main+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_template_main_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-officedocument.wordprocessingml.webSettings+xml", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_webSettings_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-package.core-properties+xml", mime_application_vnd_openxmlformats_package_core_properties_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-package.digital-signature-xmlsignature+xml", mime_application_vnd_openxmlformats_package_digital_signature_xmlsignature_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.openxmlformats-package.relationships+xml", mime_application_vnd_openxmlformats_package_relationships_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oracle.resource+json", mime_application_vnd_oracle_resource_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.orange.indata", mime_application_vnd_orange_indata, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.osa.netdeploy", mime_application_vnd_osa_netdeploy, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.osgeo.mapguide.package", mime_application_vnd_osgeo_mapguide_package, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.osgi.bundle", mime_application_vnd_osgi_bundle, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.osgi.dp", mime_application_vnd_osgi_dp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.osgi.subsystem", mime_application_vnd_osgi_subsystem, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.otps.ct-kip+xml", mime_application_vnd_otps_ct_kip_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.oxli.countgraph", mime_application_vnd_oxli_countgraph, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pagerduty+json", mime_application_vnd_pagerduty_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.palm", mime_application_vnd_palm, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.panoply", mime_application_vnd_panoply, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.paos.xml", mime_application_vnd_paos_xml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.patentdive", mime_application_vnd_patentdive, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.patientecommsdoc", mime_application_vnd_patientecommsdoc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pawaafile", mime_application_vnd_pawaafile, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pcos", mime_application_vnd_pcos, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pg.format", mime_application_vnd_pg_format, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pg.osasli", mime_application_vnd_pg_osasli, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.piaccess.application-licence", mime_application_vnd_piaccess_application_licence, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.picsel", mime_application_vnd_picsel, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pmi.widget", mime_application_vnd_pmi_widget, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.poc.group-advertisement+xml", mime_application_vnd_poc_group_advertisement_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pocketlearn", mime_application_vnd_pocketlearn, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.powerbuilder6", mime_application_vnd_powerbuilder6, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.powerbuilder6-s", mime_application_vnd_powerbuilder6_s, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.powerbuilder7", mime_application_vnd_powerbuilder7, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.powerbuilder75", mime_application_vnd_powerbuilder75, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.powerbuilder75-s", mime_application_vnd_powerbuilder75_s, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.powerbuilder7-s", mime_application_vnd_powerbuilder7_s, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.preminet", mime_application_vnd_preminet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.previewsystems.box", mime_application_vnd_previewsystems_box, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.proteus.magazine", mime_application_vnd_proteus_magazine, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.psfs", mime_application_vnd_psfs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.publishare-delta-tree", mime_application_vnd_publishare_delta_tree, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pvi.ptid1", mime_application_vnd_pvi_ptid1, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pwg-multiplexed", mime_application_vnd_pwg_multiplexed, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.pwg-xhtml-print+xml", mime_application_vnd_pwg_xhtml_print_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.qualcomm.brew-app-res", mime_application_vnd_qualcomm_brew_app_res, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.quarantainenet", mime_application_vnd_quarantainenet, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.Quark.QuarkXPress", mime_application_vnd_Quark_QuarkXPress, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.quobject-quoxdocument", mime_application_vnd_quobject_quoxdocument, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.moml+xml", mime_application_vnd_radisys_moml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-audit-conf+xml", mime_application_vnd_radisys_msml_audit_conf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-audit-conn+xml", mime_application_vnd_radisys_msml_audit_conn_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-audit-dialog+xml", mime_application_vnd_radisys_msml_audit_dialog_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-audit-stream+xml", mime_application_vnd_radisys_msml_audit_stream_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-audit+xml", mime_application_vnd_radisys_msml_audit_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-conf+xml", mime_application_vnd_radisys_msml_conf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-dialog-base+xml", mime_application_vnd_radisys_msml_dialog_base_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-dialog-fax-detect+xml", mime_application_vnd_radisys_msml_dialog_fax_detect_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-dialog-fax-sendrecv+xml", mime_application_vnd_radisys_msml_dialog_fax_sendrecv_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-dialog-group+xml", mime_application_vnd_radisys_msml_dialog_group_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-dialog-speech+xml", mime_application_vnd_radisys_msml_dialog_speech_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-dialog-transform+xml", mime_application_vnd_radisys_msml_dialog_transform_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml-dialog+xml", mime_application_vnd_radisys_msml_dialog_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.radisys.msml+xml", mime_application_vnd_radisys_msml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.rainstor.data", mime_application_vnd_rainstor_data, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.rapid", mime_application_vnd_rapid, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.rar", mime_application_vnd_rar, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.realvnc.bed", mime_application_vnd_realvnc_bed, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.recordare.musicxml", mime_application_vnd_recordare_musicxml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.recordare.musicxml+xml", mime_application_vnd_recordare_musicxml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.RenLearn.rlprint", mime_application_vnd_RenLearn_rlprint, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.restful+json", mime_application_vnd_restful_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.rig.cryptonote", mime_application_vnd_rig_cryptonote, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.route66.link66+xml", mime_application_vnd_route66_link66_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.rs-274x", mime_application_vnd_rs_274x, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ruckus.download", mime_application_vnd_ruckus_download, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.s3sms", mime_application_vnd_s3sms, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sailingtracker.track", mime_application_vnd_sailingtracker_track, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sar", mime_application_vnd_sar, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sbm.cid", mime_application_vnd_sbm_cid, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sbm.mid2", mime_application_vnd_sbm_mid2, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.scribus", mime_application_vnd_scribus, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.3df", mime_application_vnd_sealed_3df, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.csf", mime_application_vnd_sealed_csf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.doc", mime_application_vnd_sealed_doc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.eml", mime_application_vnd_sealed_eml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.mht", mime_application_vnd_sealed_mht, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.net", mime_application_vnd_sealed_net, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.ppt", mime_application_vnd_sealed_ppt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.tiff", mime_application_vnd_sealed_tiff, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealed.xls", mime_application_vnd_sealed_xls, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealedmedia.softseal.html", mime_application_vnd_sealedmedia_softseal_html, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sealedmedia.softseal.pdf", mime_application_vnd_sealedmedia_softseal_pdf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.seemail", mime_application_vnd_seemail, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sema", mime_application_vnd_sema, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.semd", mime_application_vnd_semd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.semf", mime_application_vnd_semf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shade-save-file", mime_application_vnd_shade_save_file, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shana.informed.formdata", mime_application_vnd_shana_informed_formdata, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shana.informed.formtemplate", mime_application_vnd_shana_informed_formtemplate, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shana.informed.interchange", mime_application_vnd_shana_informed_interchange, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shana.informed.package", mime_application_vnd_shana_informed_package, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shootproof+json", mime_application_vnd_shootproof_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shopkick+json", mime_application_vnd_shopkick_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shp", mime_application_vnd_shp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.shx", mime_application_vnd_shx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sigrok.session", mime_application_vnd_sigrok_session, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.SimTech-MindMapper", mime_application_vnd_SimTech_MindMapper, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.siren+json", mime_application_vnd_siren_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.smaf", mime_application_vnd_smaf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.smart.notebook", mime_application_vnd_smart_notebook, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.smart.teacher", mime_application_vnd_smart_teacher, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.snesdev-page-table", mime_application_vnd_snesdev_page_table, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.software602.filler.form+xml", mime_application_vnd_software602_filler_form_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.software602.filler.form-xml-zip", mime_application_vnd_software602_filler_form_xml_zip, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.solent.sdkm+xml", mime_application_vnd_solent_sdkm_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.spotfire.dxp", mime_application_vnd_spotfire_dxp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.spotfire.sfs", mime_application_vnd_spotfire_sfs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sqlite3", mime_application_vnd_sqlite3, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sss-cod", mime_application_vnd_sss_cod, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sss-dtf", mime_application_vnd_sss_dtf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sss-ntf", mime_application_vnd_sss_ntf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.stepmania.package", mime_application_vnd_stepmania_package, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.stepmania.stepchart", mime_application_vnd_stepmania_stepchart, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.street-stream", mime_application_vnd_street_stream, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sun.wadl+xml", mime_application_vnd_sun_wadl_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.sus-calendar", mime_application_vnd_sus_calendar, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.svd", mime_application_vnd_svd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.swiftview-ics", mime_application_vnd_swiftview_ics, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml.dm.notification", mime_application_vnd_syncml_dm_notification, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml.dmddf+xml", mime_application_vnd_syncml_dmddf_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml.dmtnds+wbxml", mime_application_vnd_syncml_dmtnds_wbxml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml.dmtnds+xml", mime_application_vnd_syncml_dmtnds_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml.dmddf+wbxml", mime_application_vnd_syncml_dmddf_wbxml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml.dm+wbxml", mime_application_vnd_syncml_dm_wbxml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml.dm+xml", mime_application_vnd_syncml_dm_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml.ds.notification", mime_application_vnd_syncml_ds_notification, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.syncml+xml", mime_application_vnd_syncml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.tableschema+json", mime_application_vnd_tableschema_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.tao.intent-module-archive", mime_application_vnd_tao_intent_module_archive, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.tcpdump.pcap", mime_application_vnd_tcpdump_pcap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.think-cell.ppttc+json", mime_application_vnd_think_cell_ppttc_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.tml", mime_application_vnd_tml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.tmd.mediaflex.api+xml", mime_application_vnd_tmd_mediaflex_api_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.tmobile-livetv", mime_application_vnd_tmobile_livetv, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.tri.onesource", mime_application_vnd_tri_onesource, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.trid.tpt", mime_application_vnd_trid_tpt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.triscape.mxs", mime_application_vnd_triscape_mxs, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.trueapp", mime_application_vnd_trueapp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.truedoc", mime_application_vnd_truedoc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ubisoft.webplayer", mime_application_vnd_ubisoft_webplayer, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ufdl", mime_application_vnd_ufdl, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uiq.theme", mime_application_vnd_uiq_theme, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.umajin", mime_application_vnd_umajin, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.unity", mime_application_vnd_unity, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uoml+xml", mime_application_vnd_uoml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.alert", mime_application_vnd_uplanet_alert, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.alert-wbxml", mime_application_vnd_uplanet_alert_wbxml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.bearer-choice", mime_application_vnd_uplanet_bearer_choice, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.bearer-choice-wbxml", mime_application_vnd_uplanet_bearer_choice_wbxml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.cacheop", mime_application_vnd_uplanet_cacheop, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.cacheop-wbxml", mime_application_vnd_uplanet_cacheop_wbxml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.channel", mime_application_vnd_uplanet_channel, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.channel-wbxml", mime_application_vnd_uplanet_channel_wbxml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.list", mime_application_vnd_uplanet_list, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.listcmd", mime_application_vnd_uplanet_listcmd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.listcmd-wbxml", mime_application_vnd_uplanet_listcmd_wbxml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.list-wbxml", mime_application_vnd_uplanet_list_wbxml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uri-map", mime_application_vnd_uri_map, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.uplanet.signal", mime_application_vnd_uplanet_signal, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.valve.source.material", mime_application_vnd_valve_source_material, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.vcx", mime_application_vnd_vcx, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.vd-study", mime_application_vnd_vd_study, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.vectorworks", mime_application_vnd_vectorworks, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.vel+json", mime_application_vnd_vel_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.verimatrix.vcas", mime_application_vnd_verimatrix_vcas, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.veryant.thin", mime_application_vnd_veryant_thin, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ves.encrypted", mime_application_vnd_ves_encrypted, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.vidsoft.vidconference", mime_application_vnd_vidsoft_vidconference, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.visio", mime_application_vnd_visio, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.visionary", mime_application_vnd_visionary, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.vividence.scriptfile", mime_application_vnd_vividence_scriptfile, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.vsf", mime_application_vnd_vsf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wap.sic", mime_application_vnd_wap_sic, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wap.slc", mime_application_vnd_wap_slc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wap.wbxml", mime_application_vnd_wap_wbxml, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wap.wmlc", mime_application_vnd_wap_wmlc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wap.wmlscriptc", mime_application_vnd_wap_wmlscriptc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.webturbo", mime_application_vnd_webturbo, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wfa.p2p", mime_application_vnd_wfa_p2p, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wfa.wsc", mime_application_vnd_wfa_wsc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.windows.devicepairing", mime_application_vnd_windows_devicepairing, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wmc", mime_application_vnd_wmc, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wmf.bootstrap", mime_application_vnd_wmf_bootstrap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wolfram.mathematica", mime_application_vnd_wolfram_mathematica, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wolfram.mathematica.package", mime_application_vnd_wolfram_mathematica_package, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wolfram.player", mime_application_vnd_wolfram_player, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wordperfect", mime_application_vnd_wordperfect, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wqd", mime_application_vnd_wqd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wrq-hp3000-labelled", mime_application_vnd_wrq_hp3000_labelled, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wt.stf", mime_application_vnd_wt_stf, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wv.csp+xml", mime_application_vnd_wv_csp_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wv.csp+wbxml", mime_application_vnd_wv_csp_wbxml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.wv.ssp+xml", mime_application_vnd_wv_ssp_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xacml+json", mime_application_vnd_xacml_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xara", mime_application_vnd_xara, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xfdl", mime_application_vnd_xfdl, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xfdl.webform", mime_application_vnd_xfdl_webform, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xmi+xml", mime_application_vnd_xmi_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xmpie.cpkg", mime_application_vnd_xmpie_cpkg, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xmpie.dpkg", mime_application_vnd_xmpie_dpkg, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xmpie.plan", mime_application_vnd_xmpie_plan, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xmpie.ppkg", mime_application_vnd_xmpie_ppkg, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.xmpie.xlim", mime_application_vnd_xmpie_xlim, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.hv-dic", mime_application_vnd_yamaha_hv_dic, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.hv-script", mime_application_vnd_yamaha_hv_script, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.hv-voice", mime_application_vnd_yamaha_hv_voice, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.openscoreformat.osfpvg+xml", mime_application_vnd_yamaha_openscoreformat_osfpvg_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.openscoreformat", mime_application_vnd_yamaha_openscoreformat, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.remote-setup", mime_application_vnd_yamaha_remote_setup, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.smaf-audio", mime_application_vnd_yamaha_smaf_audio, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.smaf-phrase", mime_application_vnd_yamaha_smaf_phrase, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.through-ngn", mime_application_vnd_yamaha_through_ngn, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yamaha.tunnel-udpencap", mime_application_vnd_yamaha_tunnel_udpencap, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yaoweme", mime_application_vnd_yaoweme, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.yellowriver-custom-menu", mime_application_vnd_yellowriver_custom_menu, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.youtube.yt", mime_application_vnd_youtube_yt, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.zul", mime_application_vnd_zul, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.zzazz.deck+xml", mime_application_vnd_zzazz_deck_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/voicexml+xml", mime_application_voicexml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/voucher-cms+json", mime_application_voucher_cms_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vq-rtcpxr", mime_application_vq_rtcpxr, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/watcherinfo+xml", mime_application_watcherinfo_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/webpush-options+json", mime_application_webpush_options_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/whoispp-query", mime_application_whoispp_query, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/whoispp-response", mime_application_whoispp_response, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/widget", mime_application_widget, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/wita", mime_application_wita, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/wordperfect5.1", mime_application_wordperfect5_1, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/wsdl+xml", mime_application_wsdl_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/wspolicy+xml", mime_application_wspolicy_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-ecmascript", mime_application_x_ecmascript, ns_default, MIME_SCRIPT | MIME_APPLICATION },
    { { XHTML_2_0 }, { HTML_UNDEF }, "application/x-java-applet", mime_application_x_java_applet, ns_default, MIME_SCRIPT | MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-javascript", mime_application_x_javascript, ns_default, MIME_SCRIPT | MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-pki-message", mime_application_x_pki_message, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-shockwave-flash", mime_application_x_shockwave_flash, ns_default, MIME_APPLICATION | MIME_VULNERABLE | MIME_WITHDRAWN },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-webfont", mime_application_x_webfont, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-www-form-urlencoded", mime_application_x_www_form_urlencoded, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-x509-ca-cert", mime_application_x_x509_ca_cert, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-x509-ca-ra-cert", mime_application_x_x509_ca_ra_cert, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-x509-next-ca-cert", mime_application_x_x509_next_ca_cert, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x400-bp", mime_application_x400_bp, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xacml+xml", mime_application_xacml_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xcap-att+xml", mime_application_xcap_att_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xcap-caps+xml", mime_application_xcap_caps_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xcap-diff+xml", mime_application_xcap_diff_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xcap-el+xml", mime_application_xcap_el_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xcap-error+xml", mime_application_xcap_error_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xcap-ns+xml", mime_application_xcap_ns_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xcon-conference-info-diff+xml", mime_application_xcon_conference_info_diff_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xcon-conference-info+xml", mime_application_xcon_conference_info_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xenc+xml", mime_application_xenc_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xhtml+xml", mime_application_xhtml_xml, ns_default, MIME_APPLICATION | MIME_XML | MIME_PAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xliff+xml", mime_application_xliff_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xml", mime_application_xml, ns_default, NOT_SCRIPT | MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xml-dtd", mime_application_xml_dtd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xml-external-parsed-entity", mime_application_xml_external_parsed_entity, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xml-patch+xml", mime_application_xml_patch_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xmpp+xml", mime_application_xmpp_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xop+xml", mime_application_xop_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xslt+xml", mime_application_xslt_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/xv+xml", mime_application_xv_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/yang", mime_application_yang, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/yang-data+json", mime_application_yang_data_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/yang-data+xml", mime_application_yang_data_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/yang-patch+json", mime_application_yang_patch_json, ns_default, MIME_APPLICATION | MIME_JSON },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/yang-patch+xml", mime_application_yang_patch_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/yin+xml", mime_application_yin_xml, ns_default, MIME_APPLICATION | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/zip", mime_application_zip, ns_default, MIME_APPLICATION | MIME_ZIP },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/zlib", mime_application_zlib, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/zstd", mime_application_zstd, ns_default, MIME_APPLICATION },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/1d-interleaved-parityfec", mime_audio_1d_interleaved_parityfec, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/32kadpcm", mime_audio_32kadpcm, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/3gpp", mime_audio_3gpp, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/3gpp2", mime_audio_3gpp2, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/aac", mime_audio_aac, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/ac3", mime_audio_ac3, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/AMR", mime_audio_AMR, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/AMR-WB", mime_audio_AMR_WB, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/amr-wb+", mime_audio_amr_wb_, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/aptx", mime_audio_aptx, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/asc", mime_audio_asc, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/ATRAC-ADVANCED-LOSSLESS", mime_audio_ATRAC_ADVANCED_LOSSLESS, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/ATRAC-X", mime_audio_ATRAC_X, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/ATRAC3", mime_audio_ATRAC3, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/basic", mime_audio_basic, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/BV16", mime_audio_BV16, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/BV32", mime_audio_BV32, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/clearmode", mime_audio_clearmode, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/CN", mime_audio_CN, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/DAT12", mime_audio_DAT12, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/dls", mime_audio_dls, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/dsr-es201108", mime_audio_dsr_es201108, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/dsr-es202050", mime_audio_dsr_es202050, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/dsr-es202211", mime_audio_dsr_es202211, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/dsr-es202212", mime_audio_dsr_es202212, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/DV", mime_audio_DV, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/DVI4", mime_audio_DVI4, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/eac3", mime_audio_eac3, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/encaprtp", mime_audio_encaprtp, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRC", mime_audio_EVRC, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRC-QCP", mime_audio_EVRC_QCP, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRC0", mime_audio_EVRC0, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRC1", mime_audio_EVRC1, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCB", mime_audio_EVRCB, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCB0", mime_audio_EVRCB0, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCB1", mime_audio_EVRCB1, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCNW", mime_audio_EVRCNW, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCNW0", mime_audio_EVRCNW0, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCNW1", mime_audio_EVRCNW1, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCWB", mime_audio_EVRCWB, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCWB0", mime_audio_EVRCWB0, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVRCWB1", mime_audio_EVRCWB1, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/EVS", mime_audio_EVS, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/example", mime_audio_example, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/flexfec", mime_audio_flexfec, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/fwdred", mime_audio_fwdred, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G711-0", mime_audio_G711_0, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G719", mime_audio_G719, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G7221", mime_audio_G7221, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G722", mime_audio_G722, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G723", mime_audio_G723, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G726-16", mime_audio_G726_16, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G726-24", mime_audio_G726_24, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G726-32", mime_audio_G726_32, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G726-40", mime_audio_G726_40, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G728", mime_audio_G728, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G729", mime_audio_G729, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G7291", mime_audio_G7291, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G729D", mime_audio_G729D, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/G729E", mime_audio_G729E, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/GSM", mime_audio_GSM, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/GSM-EFR", mime_audio_GSM_EFR, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/GSM-HR-08", mime_audio_GSM_HR_08, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/iLBC", mime_audio_iLBC, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/ip-mr_v2.5", mime_audio_ip_mr_v2_5, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/L8", mime_audio_L8, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/L16", mime_audio_L16, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/L20", mime_audio_L20, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/L24", mime_audio_L24, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/LPC", mime_audio_LPC, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/MELP", mime_audio_MELP, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/MELP600", mime_audio_MELP600, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/MELP1200", mime_audio_MELP1200, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/MELP2400", mime_audio_MELP2400, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/mhas", mime_audio_mhas, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/mobile-xmf", mime_audio_mobile_xmf, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/MPA", mime_audio_MPA, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/mp4", mime_audio_mp4, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/MP4A-LATM", mime_audio_MP4A_LATM, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/mpa-robust", mime_audio_mpa_robust, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/mpeg", mime_audio_mpeg, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/mpeg4-generic", mime_audio_mpeg4_generic, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/ogg", mime_audio_ogg, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/opus", mime_audio_opus, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/parityfec", mime_audio_parityfec, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/PCMA", mime_audio_PCMA, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/PCMA-WB", mime_audio_PCMA_WB, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/PCMU", mime_audio_PCMU, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/PCMU-WB", mime_audio_PCMU_WB, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/prs.sid", mime_audio_prs_sid, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/QCELP", mime_audio_QCELP, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/raptorfec", mime_audio_raptorfec, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/RED", mime_audio_RED, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/rtp-enc-aescm128", mime_audio_rtp_enc_aescm128, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/rtploopback", mime_audio_rtploopback, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/rtp-midi", mime_audio_rtp_midi, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/rtx", mime_audio_rtx, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/SMV", mime_audio_SMV, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/SMV0", mime_audio_SMV0, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/SMV-QCP", mime_audio_SMV_QCP, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/sp-midi", mime_audio_sp_midi, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/speex", mime_audio_speex, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/t140c", mime_audio_t140c, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/t38", mime_audio_t38, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/telephone-event", mime_audio_telephone_event, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/TETRA_ACELP", mime_audio_TETRA_ACELP, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/TETRA_ACELP_BB", mime_audio_TETRA_ACELP_BB, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/tone", mime_audio_tone, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/UEMCLIP", mime_audio_UEMCLIP, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/ulpfec", mime_audio_ulpfec, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/usac", mime_audio_usac, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/VDVI", mime_audio_VDVI, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/VMR-WB", mime_audio_VMR_WB, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.3gpp.iufp", mime_audio_vnd_3gpp_iufp, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.4SB", mime_audio_vnd_4SB, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.audiokoz", mime_audio_vnd_audiokoz, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.CELP", mime_audio_vnd_CELP, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.cisco.nse", mime_audio_vnd_cisco_nse, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.cmles.radio-events", mime_audio_vnd_cmles_radio_events, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.cns.anp1", mime_audio_vnd_cns_anp1, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.cns.inf1", mime_audio_vnd_cns_inf1, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dece.audio", mime_audio_vnd_dece_audio, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.digital-winds", mime_audio_vnd_digital_winds, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dlna.adts", mime_audio_vnd_dlna_adts, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dolby.heaac.1", mime_audio_vnd_dolby_heaac_1, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dolby.heaac.2", mime_audio_vnd_dolby_heaac_2, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dolby.mlp", mime_audio_vnd_dolby_mlp, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dolby.mps", mime_audio_vnd_dolby_mps, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dolby.pl2", mime_audio_vnd_dolby_pl2, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dolby.pl2x", mime_audio_vnd_dolby_pl2x, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dolby.pl2z", mime_audio_vnd_dolby_pl2z, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dolby.pulse.1", mime_audio_vnd_dolby_pulse_1, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dra", mime_audio_vnd_dra, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dts", mime_audio_vnd_dts, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dts.hd", mime_audio_vnd_dts_hd, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dts.uhd", mime_audio_vnd_dts_uhd, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.dvb.file", mime_audio_vnd_dvb_file, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.everad.plj", mime_audio_vnd_everad_plj, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.hns.audio", mime_audio_vnd_hns_audio, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.lucent.voice", mime_audio_vnd_lucent_voice, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.ms-playready.media.pya", mime_audio_vnd_ms_playready_media_pya, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.nokia.mobile-xmf", mime_audio_vnd_nokia_mobile_xmf, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.nortel.vbk", mime_audio_vnd_nortel_vbk, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.nuera.ecelp4800", mime_audio_vnd_nuera_ecelp4800, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.nuera.ecelp7470", mime_audio_vnd_nuera_ecelp7470, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.nuera.ecelp9600", mime_audio_vnd_nuera_ecelp9600, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.octel.sbc", mime_audio_vnd_octel_sbc, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.presonus.multitrack", mime_audio_vnd_presonus_multitrack, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.qcelp", mime_audio_vnd_qcelp, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.rhetorex.32kadpcm", mime_audio_vnd_rhetorex_32kadpcm, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.rip", mime_audio_vnd_rip, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.sealedmedia.softseal.mpeg", mime_audio_vnd_sealedmedia_softseal_mpeg, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vnd.vmx.cvsd", mime_audio_vnd_vmx_cvsd, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vorbis", mime_audio_vorbis, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/vorbis-config", mime_audio_vorbis_config, ns_default, MIME_AUDIO },
    { { HTML_4_0 }, { HTML_UNDEF }, "font/collection", mime_font_collection, ns_default, MIME_FONT },
    { { HTML_4_0 }, { HTML_UNDEF }, "font/otf", mime_font_otf, ns_default, MIME_FONT },
    { { HTML_4_0 }, { HTML_UNDEF }, "font/sfnt", mime_font_sfnt, ns_default, MIME_FONT },
    { { HTML_4_0 }, { HTML_UNDEF }, "font/ttf", mime_font_ttf, ns_default, MIME_FONT },
    { { HTML_4_0 }, { HTML_UNDEF }, "font/woff", mime_font_woff, ns_default, MIME_FONT },
    { { HTML_4_0 }, { HTML_UNDEF }, "font/woff2", mime_font_woff2, ns_default, MIME_FONT },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/aces", mime_image_aces, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/avci", mime_image_avci, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/avcs", mime_image_avcs, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/bmp", mime_image_bmp, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/cgm", mime_image_cgm, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/dicom-rle", mime_image_dicom_rle, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/emf", mime_image_emf, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/example", mime_image_example, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/fits", mime_image_fits, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/g3fax", mime_image_g3fax, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/gif", mime_image_gif, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/heic", mime_image_heic, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/heic-sequence", mime_image_heic_sequence, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/heif", mime_image_heif, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/heif-sequence", mime_image_heif_sequence, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/hej2k", mime_image_hej2k, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/hsj2", mime_image_hsj2, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/ief", mime_image_ief, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jls", mime_image_jls, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jp2", mime_image_jp2, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jpeg", mime_image_jpeg, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jph", mime_image_jph, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jphc", mime_image_jphc, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jpm", mime_image_jpm, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jpx", mime_image_jpx, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jxr", mime_image_jxr, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jxrA", mime_image_jxrA, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jxrS", mime_image_jxrS, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jxs", mime_image_jxs, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jxsc", mime_image_jxsc, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jxsi", mime_image_jxsi, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/jxss", mime_image_jxss, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/ktx", mime_image_ktx, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/naplps", mime_image_naplps, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/png", mime_image_png, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/prs.btif", mime_image_prs_btif, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/prs.pti", mime_image_prs_pti, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/pwg-raster", mime_image_pwg_raster, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/svg+xml", mime_image_svg_xml, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/t38", mime_image_t38, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/tiff", mime_image_tiff, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/tiff-fx", mime_image_tiff_fx, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.adobe.photoshop", mime_image_vnd_adobe_photoshop, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.airzip.accelerator.azv", mime_image_vnd_airzip_accelerator_azv, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.cns.inf2", mime_image_vnd_cns_inf2, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.dece.graphic", mime_image_vnd_dece_graphic, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.djvu", mime_image_vnd_djvu, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.dwg", mime_image_vnd_dwg, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.dxf", mime_image_vnd_dxf, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.dvb.subtitle", mime_image_vnd_dvb_subtitle, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.fastbidsheet", mime_image_vnd_fastbidsheet, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.fpx", mime_image_vnd_fpx, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.fst", mime_image_vnd_fst, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.fujixerox.edmics-mmr", mime_image_vnd_fujixerox_edmics_mmr, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.fujixerox.edmics-rlc", mime_image_vnd_fujixerox_edmics_rlc, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.globalgraphics.pgb", mime_image_vnd_globalgraphics_pgb, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.microsoft.icon", mime_image_vnd_microsoft_icon, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.mix", mime_image_vnd_mix, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.ms-modi", mime_image_vnd_ms_modi, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.mozilla.apng", mime_image_vnd_mozilla_apng, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.net-fpx", mime_image_vnd_net_fpx, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.radiance", mime_image_vnd_radiance, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.sealed.png", mime_image_vnd_sealed_png, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.sealedmedia.softseal.gif", mime_image_vnd_sealedmedia_softseal_gif, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.sealedmedia.softseal.jpg", mime_image_vnd_sealedmedia_softseal_jpg, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.svf", mime_image_vnd_svf, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.tencent.tap", mime_image_vnd_tencent_tap, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.valve.source.texture", mime_image_vnd_valve_source_texture, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.wap.wbmp", mime_image_vnd_wap_wbmp, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.xiff", mime_image_vnd_xiff, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/vnd.zbrush.pcx", mime_image_vnd_zbrush_pcx, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/wmf", mime_image_wmf, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-emf", mime_image_xemf, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-wmf", mime_image_xwmf, ns_default, MIME_IMAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/CPIM", mime_message_CPIM, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/delivery-status", mime_message_delivery_status, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/disposition-notification", mime_message_disposition_notification, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/example", mime_message_example, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/external-body", mime_message_external_body, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/feedback-report", mime_message_feedback_report, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/global", mime_message_global, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/global-delivery-status", mime_message_global_delivery_status, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/global-disposition-notification", mime_message_global_disposition_notification, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/global-headers", mime_message_global_headers, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/http", mime_message_http, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/imdn+xml", mime_message_imdn_xml, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/news", mime_message_news, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/partial", mime_message_partial, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/rfc822", mime_message_rfc822, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/s-http", mime_message_s_http, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/sip", mime_message_sip, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/sipfrag", mime_message_sipfrag, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/tracking-status", mime_message_tracking_status, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/vnd.si.simp", mime_message_vnd_si_simp, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "message/vnd.wfa.wsc", mime_message_vnd_wfa_wsc, ns_default, MIME_MESSAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/3mf", mime_model_3mf, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/example", mime_model_example, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/gltf-binary", mime_model_gltf_binary, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/gltf+json", mime_model_gltf_json, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/iges", mime_model_iges, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/mesh", mime_model_mesh, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/mtl", mime_model_mtl, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/obj", mime_model_obj, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/stl", mime_model_stl, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.collada+xml", mime_model_vnd_collada_xml, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.dwf", mime_model_vnd_dwf, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.flatland.3dml", mime_model_vnd_flatland_3dml, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.gdl", mime_model_vnd_gdl, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.gs-gdl", mime_model_vnd_gs_gdl, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.gtw", mime_model_vnd_gtw, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.moml+xml", mime_model_vnd_moml_xml, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.mts", mime_model_vnd_mts, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.opengex", mime_model_vnd_opengex, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.parasolid.transmit.binary", mime_model_vnd_parasolid_transmit_binary, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.parasolid.transmit.text", mime_model_vnd_parasolid_transmit_text, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.rosette.annotated-data-model", mime_model_vnd_rosette_annotated_data_model, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.usdz+zip", mime_model_vnd_usdz_zip, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.valve.source.compiled-map", mime_model_vnd_valve_source_compiled_map, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vnd.vtu", mime_model_vnd_vtu, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/vrml", mime_model_vrml, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/x3d-vrml", mime_model_x3d_vrml, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/x3d+fastinfoset", mime_model_x3d_fastinfoset, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "model/x3d+xml", mime_model_x3d_xml, ns_default, MIME_MODEL },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/alternative", mime_multipart_alternative, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/appledouble", mime_multipart_appledouble, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/byteranges", mime_multipart_byteranges, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/digest", mime_multipart_digest, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/encrypted", mime_multipart_encrypted, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/example", mime_multipart_example, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/form-data", mime_multipart_form_data, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/header-set", mime_multipart_header_set, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/mixed", mime_multipart_mixed, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/multilingual", mime_multipart_multilingual, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/parallel", mime_multipart_parallel, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/related", mime_multipart_related, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/report", mime_multipart_report, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/signed", mime_multipart_signed, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/vnd.bint.med-plus", mime_multipart_vnd_bint_med_plus, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/voice-message", mime_multipart_voice_message, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "multipart/x-mixed-replace", mime_multipart_x_mixed_replace, ns_default, MIME_MULTIPART },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/1d-interleaved-parityfec", mime_text_1d_interleaved_parityfec, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/cache-manifest", mime_text_cache_manifest, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/calendar", mime_text_calendar, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, CSS_TYPE, mime_text_css, ns_default, MIME_STYLE | MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/csv", mime_text_csv, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/csv-schema", mime_text_csv_schema, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/directory", mime_text_directory, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/dns", mime_text_dns, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/ecmascript", mime_text_ecmascript, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/encaprtp", mime_text_encaprtp, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/enriched", mime_text_enriched, ns_default, MIME_TEXT },
    { { HTML_APR21 }, { HTML_UNDEF }, "text/event-stream", mime_text_event_stream, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/example", mime_text_example, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/flexfec", mime_text_flexfec, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/fwdred", mime_text_fwdred, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/grammar-ref-list", mime_text_grammar_ref_list, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, HTML_TYPE, mime_text_html, ns_default, MIME_TEXT | MIME_PAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, HTML_TYPE "-sandboxed", mime_text_html_sandboxed, ns_default, MIME_TEXT | MIME_PAGE | MIME_UNOFFICIAL },
    { { HTML_APR21 }, { HTML_UNDEF }, "text/ping", mime_text_ping, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/javascript", mime_text_javascript, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JUL05 }, { HTML_UNDEF }, "text/javascript;e4x=1", mime_text_javascript_x, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JUL09 }, { HTML_UNDEF }, "text/javascript1.0", mime_text_javascript10, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JAN09 }, { HTML_UNDEF }, "text/javascript1.1", mime_text_javascript11, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JAN09 }, { HTML_UNDEF }, "text/javascript1.2", mime_text_javascript12, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JAN09 }, { HTML_UNDEF }, "text/javascript1.3", mime_text_javascript13, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JUL09 }, { HTML_UNDEF }, "text/javascript1.4", mime_text_javascript14, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JUL09 }, { HTML_UNDEF }, "text/javascript1.5", mime_text_javascript15, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/jcr-cnd", mime_text_jcr_cnd, ns_default, MIME_TEXT },
    { { HTML_JUL09 }, { HTML_UNDEF }, "text/jscript", mime_text_jscript, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JUL09 }, { HTML_UNDEF }, "text/livescript", mime_text_livescript, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/markdown", mime_text_markdown, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/mizar", mime_text_mizar, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/n3", mime_text_n3, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/parameters", mime_text_parameters, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/parityfec", mime_text_parityfec, ns_default, MIME_TEXT },
    { { HTML_2_0 }, { HTML_UNDEF }, "text/plain", mime_text_plain, ns_default, NOT_SCRIPT | MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/provenance-notation", mime_text_provenance_notation, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/prs.fallenstein.rst", mime_text_prs_fallenstein_rst, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/prs.lines.tag", mime_text_prs_lines_tag, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/prs.prop.logic", mime_text_prs_prop_logic, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/raptorfec", mime_text_raptorfec, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/RED", mime_text_RED, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/rfc822-headers", mime_text_rfc822_headers, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/richtext", mime_text_richtext, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/rtf", mime_text_rtf, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/rtp-enc-aescm128", mime_text_rtp_enc_aescm128, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/rtploopback", mime_text_rtploopback, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/rtx", mime_text_rtx, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/SGML", mime_text_SGML, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/strings", mime_text_strings, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/t140", mime_text_t140, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/tab-separated-values", mime_text_tab_separated_values, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/tcl", mime_text_tcl, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/troff", mime_text_troff, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/turtle", mime_text_turtle, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/ulpfec", mime_text_ulpfec, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/uri-list", mime_text_uri_list, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vbscript", mime_text_vbscript, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vcard", mime_text_vcard, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.a", mime_text_vnd_a, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.abc", mime_text_vnd_abc, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.ascii-art", mime_text_vnd_ascii_art, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.curl", mime_text_vnd_curl, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.debian.copyright", mime_text_vnd_debian_copyright, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.DMClientScript", mime_text_vnd_DMClientScript, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.dvb.subtitle", mime_text_vnd_dvb_subtitle, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.esmertec.theme-descriptor", mime_text_vnd_esmertec_theme_descriptor, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.ficlab.flt", mime_text_vnd_ficlab_flt, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.fly", mime_text_vnd_fly, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.fmi.flexstor", mime_text_vnd_fmi_flexstor, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.gml", mime_text_vnd_gml, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.graphviz", mime_text_vnd_graphviz, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.hgl", mime_text_vnd_hgl, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.in3d.3dml", mime_text_vnd_in3d_3dml, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.in3d.spot", mime_text_vnd_in3d_spot, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.IPTC.NewsML", mime_text_vnd_IPTC_NewsML, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.IPTC.NITF", mime_text_vnd_IPTC_NITF, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.latex-z", mime_text_vnd_latex_z, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.motorola.reflex", mime_text_vnd_motorola_reflex, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.ms-mediapackage", mime_text_vnd_ms_mediapackage, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.net2phone.commcenter.command", mime_text_vnd_net2phone_commcenter_command, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.radisys.msml-basic-layout", mime_text_vnd_radisys_msml_basic_layout, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.senx.warpscript", mime_text_vnd_senx_warpscript, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.si.uricatalogue", mime_text_vnd_si_uricatalogue, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.sun.j2me.app-descriptor", mime_text_vnd_sun_j2me_app_descriptor, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.sosi", mime_text_vnd_sosi, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.trolltech.linguist", mime_text_vnd_trolltech_linguist, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.wap.si", mime_text_vnd_wap_si, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.wap.sl", mime_text_vnd_wap_sl, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.wap.wml", mime_text_vnd_wap_wml, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vnd.wap.wmlscript", mime_text_vnd_wap_wmlscript, ns_default, MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/vtt", mime_text_vtt, ns_default, MIME_TEXT },
    { { HTML_JUL09 }, { HTML_UNDEF }, "text/x-ecmascript", mime_text_x_ecmascript, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_JUL09 }, { HTML_UNDEF }, "text/x-javascript", mime_text_x_javascript, ns_default, MIME_SCRIPT | MIME_TEXT },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/xml", mime_text_xml, ns_default, NOT_SCRIPT | MIME_TEXT | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/xml-external-parsed-entity", mime_text_xml_external_parsed_entity, ns_default, MIME_TEXT | MIME_XML },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/1d-interleaved-parityfec", mime_video_1d_interleaved_parityfec, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/3gpp", mime_video_3gpp, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/3gpp2", mime_video_3gpp2, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/3gpp-tt", mime_video_3gpp_tt, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/BMPEG", mime_video_BMPEG, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/BT656", mime_video_BT656, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/CelB", mime_video_CelB, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/DV", mime_video_DV, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/encaprtp", mime_video_encaprtp, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/example", mime_video_example, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/flexfec", mime_video_flexfec, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/H261", mime_video_H261, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/H263", mime_video_H263, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/H263-1998", mime_video_H263_1998, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/H263-2000", mime_video_H263_2000, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/H264", mime_video_H264, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/H264-RCDO", mime_video_H264_RCDO, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/H264-SVC", mime_video_H264_SVC, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/H265", mime_video_H265, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/iso.segment", mime_video_iso_segment, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/JPEG", mime_video_JPEG, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/jpeg2000", mime_video_jpeg2000, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/mj2", mime_video_mj2, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/MP1S", mime_video_MP1S, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/MP2P", mime_video_MP2P, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/MP2T", mime_video_MP2T, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/mp4", mime_video_mp4, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/MP4V-ES", mime_video_MP4V_ES, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/MPV", mime_video_MPV, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/mpeg", mime_video_mpeg, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/mpeg4-generic", mime_video_mpeg4_generic, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/nv", mime_video_nv, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/ogg", mime_video_ogg, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/parityfec", mime_video_parityfec, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/pointer", mime_video_pointer, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/quicktime", mime_video_quicktime, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/raptorfec", mime_video_raptorfec, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/raw", mime_video_raw, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/rtp-enc-aescm128", mime_video_rtp_enc_aescm128, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/rtploopback", mime_video_rtploopback, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/rtx", mime_video_rtx, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/smpte291", mime_video_smpte291, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/SMPTE292M", mime_video_SMPTE292M, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/ulpfec", mime_video_ulpfec, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vc1", mime_video_vc1, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vc2", mime_video_vc2, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.CCTV", mime_video_vnd_CCTV, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.dece.hd", mime_video_vnd_dece_hd, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.dece.mobile", mime_video_vnd_dece_mobile, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.dece.mp4", mime_video_vnd_dece_mp4, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.dece.pd", mime_video_vnd_dece_pd, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.dece.sd", mime_video_vnd_dece_sd, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.dece.video", mime_video_vnd_dece_video, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.directv.mpeg", mime_video_vnd_directv_mpeg, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.directv.mpeg-tts", mime_video_vnd_directv_mpeg_tts, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.dlna.mpeg-tts", mime_video_vnd_dlna_mpeg_tts, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.dvb.file", mime_video_vnd_dvb_file, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.fvt", mime_video_vnd_fvt, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.hns.video", mime_video_vnd_hns_video, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.iptvforum.1dparityfec-1010", mime_video_vnd_iptvforum_1dparityfec_1010, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.iptvforum.1dparityfec-2005", mime_video_vnd_iptvforum_1dparityfec_2005, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.iptvforum.2dparityfec-1010", mime_video_vnd_iptvforum_2dparityfec_1010, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.iptvforum.2dparityfec-2005", mime_video_vnd_iptvforum_2dparityfec_2005, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.iptvforum.ttsavc", mime_video_vnd_iptvforum_ttsavc, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.iptvforum.ttsmpeg2", mime_video_vnd_iptvforum_ttsmpeg2, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.motorola.video", mime_video_vnd_motorola_video, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.motorola.videop", mime_video_vnd_motorola_videop, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.mpegurl", mime_video_vnd_mpegurl, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.ms-playready.media.pyv", mime_video_vnd_ms_playready_media_pyv, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.nokia.interleaved-multimedia", mime_video_vnd_nokia_interleaved_multimedia, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.nokia.mp4vr", mime_video_vnd_nokia_mp4vr, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.nokia.videovoip", mime_video_vnd_nokia_videovoip, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.objectvideo", mime_video_vnd_objectvideo, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.radgamettools.bink", mime_video_vnd_radgamettools_bink, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.radgamettools.smacker", mime_video_vnd_radgamettools_smacker, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.sealed.mpeg1", mime_video_vnd_sealed_mpeg1, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.sealed.mpeg4", mime_video_vnd_sealed_mpeg4, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.sealed.swf", mime_video_vnd_sealed_swf, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.sealedmedia.softseal.mov", mime_video_vnd_sealedmedia_softseal_mov, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.uvvu.mp4", mime_video_vnd_uvvu_mp4, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.youtube.yt", mime_video_vnd_youtube_yt, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/vnd.vivo", mime_video_vnd_vivo, ns_default, MIME_VIDEO },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/VP8", mime_video_VP8, ns_default, MIME_VIDEO },
    // https://www.lifewire.com/file-extensions-and-mime-types-3469109
    { { HTML_4_0 }, { HTML_UNDEF }, "application/oda", mime_application_oda, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/olescript", mime_application_olescript, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/pics-rules", mime_application_pics_rules, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-outlook", mime_application_vnd_ms_outlook, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-pkicertstore", mime_application_vnd_ms_pkicertstore, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-pkiseccat", mime_application_vnd_ms_pkiseccat, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.ms-pkistl", mime_application_vnd_ms_pkistl, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/winhlp", mime_application_winhlp, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-bcpio", mime_application_x_bcpio, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-cdf", mime_application_x_cdf, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-compress", mime_application_x_compress, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-compressed", mime_application_x_compressed, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-cpio", mime_application_x_cpio, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-csh", mime_application_x_csh, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-director", mime_application_x_director, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-dvi", mime_application_x_dvi, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-gtar", mime_application_x_gtar, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-gzip", mime_application_x_gzip, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-hdf", mime_application_x_hdf, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-internet-signup", mime_application_x_internet_signup, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-iphone", mime_application_x_iphone, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-latex", mime_application_x_latex, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-msaccess", mime_application_x_msaccess, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-mscardfile", mime_application_x_mscardfile, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-msclip", mime_application_x_msclip, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-msdownload", mime_application_x_msdownload, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-msmediaview", mime_application_x_msmediaview, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-msmetafile", mime_application_x_msmetafile, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-msmoney", mime_application_x_msmoney, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-mspublisher", mime_application_x_mspublisher, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-msschedule", mime_application_x_msschedule, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-msterminal", mime_application_x_msterminal, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-mswrite", mime_application_x_mswrite, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-netcdf", mime_application_x_netcdf, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-perfmon", mime_application_x_perfmon, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-pkcs12", mime_application_x_pkcs12, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-pkcs7-certificates", mime_application_x_pkcs7_certificates, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-pkcs7-certreqresp", mime_application_x_pkcs7_certreqresp, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-pkcs7-mime", mime_application_x_pkcs7_mime, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-pkcs7-signature", mime_application_x_pkcs7_signature, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-sh", mime_application_x_sh, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-shar", mime_application_x_shar, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-stuffit", mime_application_x_stuffit, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-sv4cpio", mime_application_x_sv4cpio, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-sv4crc", mime_application_x_sv4crc, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-tar", mime_application_x_tar, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-tcl", mime_application_x_tcl, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-tex", mime_application_x_tex, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-texinfo", mime_application_x_texinfo, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-troff", mime_application_x_troff, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-troff-man", mime_application_x_troff_man, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-troff-me", mime_application_x_troff_me, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-troff-ms", mime_application_x_troff_ms, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-ustar", mime_application_x_ustar, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-wais-source", mime_application_x_wais_source, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/ynd.ms-pkipko", mime_application_ynd_ms_pkipko, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/mid", mime_audio_mid, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/x-aiff", mime_audio_x_aiff, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/x-mpegurl", mime_audio_x_mpegurl, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/x-pn-realaudio", mime_audio_x_pn_realaudio, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/x-wav", mime_audio_x_wav, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/cis-cod", mime_image_cis_cod, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/pipeg", mime_image_pipeg, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-cmu-raster", mime_image_x_cmu_raster, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-cmx", mime_image_x_cmx, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-icon", mime_image_x_icon, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-portable-anymap", mime_image_x_portable_anymap, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-portable-bitmap", mime_image_x_portable_bitmap, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-portable-graymap", mime_image_x_portable_graymap, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-portable-pixmap", mime_image_x_portable_pixmap, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-rgb", mime_image_x_rgb, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-xbitmap", mime_image_x_xbitmap, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-xpixmap", mime_image_x_xpixmap, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/x-xwindowdump", mime_image_x_xwindowdump, ns_default, MIME_IMAGE | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/h323", mime_text_h323, ns_default, MIME_TEXT | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/iuls", mime_text_iuls, ns_default, MIME_TEXT | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/scriptlet", mime_text_scriptlet, ns_default, MIME_TEXT | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/webviewhtml", mime_text_webviewhtml, ns_default, MIME_TEXT | MIME_UNOFFICIAL | MIME_PAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/x-component", mime_text_x_component, ns_default, MIME_TEXT | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/x-setext", mime_text_x_setext, ns_default, MIME_TEXT | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "text/x-vcard", mime_text_x_vcard, ns_default, MIME_TEXT | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/x-la-asf", mime_video_x_la_asf, ns_default, MIME_VIDEO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/x-ms-asf", mime_video_x_ms_asf, ns_default, MIME_VIDEO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/x-msvideo", mime_video_x_msvideo, ns_default, MIME_VIDEO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/x-sgi-movie", mime_video_x_sgi_movie, ns_default, MIME_VIDEO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "x-world/x-vrml", mime_x_world_x_vrml, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    // https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Common_types
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-abiword", mime_application_x_abiword, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-freearc", mime_application_x_freearc, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/vnd.amazon.ebook", mime_application_vnd_amazon_ebook, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-bzip", mime_application_x_bzip, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-bzip2", mime_application_x_bzip2, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/midi", mime_audio_midi, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/x-midi", mime_audio_x_midi, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-httpd-php", mime_application_x_httpd_php, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL | MIME_PAGE },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/wav", mime_audio_wav, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "audio/webm", mime_audio_webm, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "video/webm", mime_video_webm, ns_default, MIME_VIDEO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "image/webp", mime_image_webp, ns_default, MIME_AUDIO | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-7z-compressed", mime_application_x_7z_compressed, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    // microsoft (mostly RFCs that IANA seem to have missed)
    { { HTML_4_0 }, { HTML_UNDEF }, "application/news-message-id", mime_application_news_message_id, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL },
    { { HTML_4_0 }, { HTML_UNDEF }, "application/x-httpd-asp", mime_application_x_httpd_asp, ns_default, MIME_APPLICATION | MIME_UNOFFICIAL | MIME_PAGE },

    { { HTML_4_0 }, { HTML_UNDEF }, nullptr, mime_context } };

struct symbol_entry < html_version, e_format > format_symbol_table [] =
{   { { HTML_UNDEF }, { HTML_UNDEF }, "evy", mime_application_envoy },
    { { HTML_UNDEF }, { HTML_UNDEF }, "fif", mime_application_fractals },
    { { HTML_UNDEF }, { HTML_UNDEF }, "spl", mime_application_futuresplash },
    { { HTML_UNDEF }, { HTML_UNDEF }, "hta", mime_application_hta },
    { { HTML_UNDEF }, { HTML_UNDEF }, "acx", mime_application_internet_property_stream },
    { { HTML_UNDEF }, { HTML_UNDEF }, "hqx", mime_application_mac_binhex40 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "dot", mime_application_msword },
    { { HTML_UNDEF }, { HTML_UNDEF }, "class", mime_application_octet_stream, ns_default, MIME_VULNERABLE },
    { { HTML_UNDEF }, { HTML_UNDEF }, "dms", mime_application_octet_stream },
    { { HTML_UNDEF }, { HTML_UNDEF }, "app", mime_application_octet_stream, ns_default, MIME_MACOS | MIME_VULNERABLE },
    { { HTML_UNDEF }, { HTML_UNDEF }, "exe", mime_application_octet_stream, ns_default, MIME_WINDOWS | MIME_VULNERABLE },
    { { HTML_UNDEF }, { HTML_UNDEF }, "bat", mime_application_octet_stream, ns_default, MIME_WINDOWS | MIME_VULNERABLE },
    { { HTML_UNDEF }, { HTML_UNDEF }, "cmd", mime_application_octet_stream, ns_default, MIME_WINDOWS | MIME_VULNERABLE },
    { { HTML_UNDEF }, { HTML_UNDEF }, "lha", mime_application_octet_stream },
    { { HTML_UNDEF }, { HTML_UNDEF }, "lzh", mime_application_octet_stream },
    { { HTML_UNDEF }, { HTML_UNDEF }, "oda", mime_application_oda },
    { { HTML_UNDEF }, { HTML_UNDEF }, "axs", mime_application_olescript },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pdf", mime_application_pdf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "prf", mime_application_pics_rules },
    { { HTML_UNDEF }, { HTML_UNDEF }, "p10", mime_application_pkcs10 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "crl", mime_application_pkix_crl },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ai", mime_application_postscript },
    { { HTML_UNDEF }, { HTML_UNDEF }, "eps", mime_application_postscript },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ps", mime_application_postscript },
    { { HTML_UNDEF }, { HTML_UNDEF }, "rtf", mime_application_rtf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "setpay", mime_application_set_payment_initiation },
    { { HTML_UNDEF }, { HTML_UNDEF }, "setreg", mime_application_set_registration_initiation },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xla", mime_application_vnd_ms_excel },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xlc", mime_application_vnd_ms_excel },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xlm", mime_application_vnd_ms_excel },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xls", mime_application_vnd_ms_excel },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xlt", mime_application_vnd_ms_excel },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xlw", mime_application_vnd_ms_excel },
    { { HTML_UNDEF }, { HTML_UNDEF }, "msg", mime_application_vnd_ms_outlook },
    { { HTML_UNDEF }, { HTML_UNDEF }, "sst", mime_application_vnd_ms_pkicertstore },
    { { HTML_UNDEF }, { HTML_UNDEF }, "cat", mime_application_vnd_ms_pkiseccat },
    { { HTML_UNDEF }, { HTML_UNDEF }, "stl", mime_application_vnd_ms_pkistl },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pot", mime_application_vnd_ms_powerpoint },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pps", mime_application_vnd_ms_powerpoint },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ppt", mime_application_vnd_ms_powerpoint },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mpp", mime_application_vnd_ms_project },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wcm", mime_application_vnd_ms_works },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wdb", mime_application_vnd_ms_works },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wks", mime_application_vnd_ms_works },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wps", mime_application_vnd_ms_works },
    { { HTML_UNDEF }, { HTML_UNDEF }, "hlp", mime_application_winhlp, ns_default, MIME_WINDOWS },
    { { HTML_UNDEF }, { HTML_UNDEF }, "bcpio", mime_application_x_bcpio },
    { { HTML_UNDEF }, { HTML_UNDEF }, "cdf", mime_application_x_cdf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "z", mime_application_x_compress },
    { { HTML_UNDEF }, { HTML_UNDEF }, "tgz", mime_application_x_compressed },
    { { HTML_UNDEF }, { HTML_UNDEF }, "cpio", mime_application_x_cpio },
    { { HTML_UNDEF }, { HTML_UNDEF }, "dcr", mime_application_x_director },
    { { HTML_UNDEF }, { HTML_UNDEF }, "dir", mime_application_x_director },
    { { HTML_UNDEF }, { HTML_UNDEF }, "dxr", mime_application_x_director },
    { { HTML_UNDEF }, { HTML_UNDEF }, "dvi", mime_application_x_dvi },
    { { HTML_UNDEF }, { HTML_UNDEF }, "gtar", mime_application_x_gtar },
    { { HTML_UNDEF }, { HTML_UNDEF }, "gz", mime_application_x_gzip },
    { { HTML_UNDEF }, { HTML_UNDEF }, "hdf", mime_application_x_hdf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ins", mime_application_x_internet_signup },
    { { HTML_UNDEF }, { HTML_UNDEF }, "isp", mime_application_x_internet_signup },
    { { HTML_UNDEF }, { HTML_UNDEF }, "iii", mime_application_x_iphone, ns_default, MIME_IOS },
    { { HTML_UNDEF }, { HTML_UNDEF }, "js", mime_application_x_javascript },
    { { HTML_UNDEF }, { HTML_UNDEF }, "latex", mime_application_x_latex },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mdb", mime_application_x_msaccess },
    { { HTML_UNDEF }, { HTML_UNDEF }, "crd", mime_application_x_mscardfile },
    { { HTML_UNDEF }, { HTML_UNDEF }, "clp", mime_application_x_msclip },
    { { HTML_UNDEF }, { HTML_UNDEF }, "dll", mime_application_x_msdownload, ns_default, MIME_WINDOWS },
    { { HTML_UNDEF }, { HTML_UNDEF }, "m13", mime_application_x_msmediaview },
    { { HTML_UNDEF }, { HTML_UNDEF }, "m14", mime_application_x_msmediaview },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mvb", mime_application_x_msmediaview },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wmf", mime_application_x_msmetafile },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mny", mime_application_x_msmoney },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pub", mime_application_x_mspublisher },
    { { HTML_UNDEF }, { HTML_UNDEF }, "scd", mime_application_x_msschedule },
    { { HTML_UNDEF }, { HTML_UNDEF }, "trm", mime_application_x_msterminal },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wri", mime_application_x_mswrite },
    { { HTML_UNDEF }, { HTML_UNDEF }, "nc", mime_application_x_netcdf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pma", mime_application_x_perfmon },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pmc", mime_application_x_perfmon },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pml", mime_application_x_perfmon },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pmr", mime_application_x_perfmon },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pmw", mime_application_x_perfmon },
    { { HTML_UNDEF }, { HTML_UNDEF }, "p12", mime_application_x_pkcs12 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pfx", mime_application_x_pkcs12 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "p7b", mime_application_x_pkcs7_certificates },
    { { HTML_UNDEF }, { HTML_UNDEF }, "spc", mime_application_x_pkcs7_certificates },
    { { HTML_UNDEF }, { HTML_UNDEF }, "p7r", mime_application_x_pkcs7_certreqresp },
    { { HTML_UNDEF }, { HTML_UNDEF }, "p7c", mime_application_x_pkcs7_mime },
    { { HTML_UNDEF }, { HTML_UNDEF }, "p7m", mime_application_x_pkcs7_mime },
    { { HTML_UNDEF }, { HTML_UNDEF }, "p7s", mime_application_x_pkcs7_signature },
    { { HTML_UNDEF }, { HTML_UNDEF }, "sh", mime_application_x_sh },
    { { HTML_UNDEF }, { HTML_UNDEF }, "shar", mime_application_x_shar },
    { { HTML_UNDEF }, { HTML_DEC20 }, "swf", mime_application_x_shockwave_flash, ns_default, MIME_VULNERABLE | MIME_WITHDRAWN },
    { { HTML_UNDEF }, { HTML_UNDEF }, "sit", mime_application_x_stuffit },
    { { HTML_UNDEF }, { HTML_UNDEF }, "sv4cpio", mime_application_x_sv4cpio },
    { { HTML_UNDEF }, { HTML_UNDEF }, "sv4crc", mime_application_x_sv4crc },
    { { HTML_UNDEF }, { HTML_UNDEF }, "tar", mime_application_x_tar },
    { { HTML_UNDEF }, { HTML_UNDEF }, "tcl", mime_application_x_tcl },
    { { HTML_UNDEF }, { HTML_UNDEF }, "tex", mime_application_x_tex },
    { { HTML_UNDEF }, { HTML_UNDEF }, "texi", mime_application_x_texinfo },
    { { HTML_UNDEF }, { HTML_UNDEF }, "texinfo", mime_application_x_texinfo },
    { { HTML_UNDEF }, { HTML_UNDEF }, "roff", mime_application_x_troff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "t", mime_application_x_troff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "tr", mime_application_x_troff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "man", mime_application_x_troff_man },
    { { HTML_UNDEF }, { HTML_UNDEF }, "me", mime_application_x_troff_me },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ms", mime_application_x_troff_ms },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ustar", mime_application_x_ustar },
    { { HTML_UNDEF }, { HTML_UNDEF }, "src", mime_application_x_wais_source },
    { { HTML_UNDEF }, { HTML_UNDEF }, "cer", mime_application_x_x509_ca_cert },
    { { HTML_UNDEF }, { HTML_UNDEF }, "crt", mime_application_x_x509_ca_cert },
    { { HTML_UNDEF }, { HTML_UNDEF }, "der", mime_application_x_x509_ca_cert },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pko", mime_application_ynd_ms_pkipko },
    { { HTML_UNDEF }, { HTML_UNDEF }, "zip", mime_application_zip, ns_default, MIME_ZIP },
    { { HTML_UNDEF }, { HTML_UNDEF }, "au", mime_audio_basic },
    { { HTML_UNDEF }, { HTML_UNDEF }, "snd", mime_audio_basic },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mid", mime_audio_mid },
    { { HTML_UNDEF }, { HTML_UNDEF }, "rmi", mime_audio_mid },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mp3", mime_audio_mpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "aif", mime_audio_x_aiff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "aifc", mime_audio_x_aiff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "aiff", mime_audio_x_aiff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "m3u", mime_audio_x_mpegurl },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ra", mime_audio_x_pn_realaudio },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ram", mime_audio_x_pn_realaudio },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wav", mime_audio_x_wav },
    { { HTML_UNDEF }, { HTML_UNDEF }, "bmp", mime_image_bmp },
    { { HTML_UNDEF }, { HTML_UNDEF }, "cod", mime_image_cis_cod },
    { { HTML_UNDEF }, { HTML_UNDEF }, "gif", mime_image_gif },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ief", mime_image_ief },
    { { HTML_UNDEF }, { HTML_UNDEF }, "jpe", mime_image_jpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "jpeg", mime_image_jpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "jpg", mime_image_jpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "jfif", mime_image_pipeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "svg", mime_image_svg_xml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "tif", mime_image_tiff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "tiff", mime_image_tiff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ras", mime_image_x_cmu_raster },
    { { HTML_UNDEF }, { HTML_UNDEF }, "cmx", mime_image_x_cmx },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pnm", mime_image_x_portable_anymap },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pbm", mime_image_x_portable_bitmap },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pgm", mime_image_x_portable_graymap },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ppm", mime_image_x_portable_pixmap },
    { { HTML_UNDEF }, { HTML_UNDEF }, "rgb", mime_image_x_rgb },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xbm", mime_image_x_xbitmap },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xpm", mime_image_x_xpixmap },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xwd", mime_image_x_xwindowdump },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mht", mime_message_rfc822 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mhtml", mime_message_rfc822 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "nws", mime_message_rfc822 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "css", mime_text_css, ns_default, MIME_STYLE },
    { { HTML_UNDEF }, { HTML_UNDEF }, "323", mime_text_h323 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "htm", mime_text_html },
    { { HTML_UNDEF }, { HTML_UNDEF }, "html", mime_text_html },
    { { HTML_UNDEF }, { HTML_UNDEF }, "shtml", mime_text_html },
    { { HTML_UNDEF }, { HTML_UNDEF }, "stm", mime_text_html },
    { { HTML_UNDEF }, { HTML_UNDEF }, "uls", mime_text_iuls },
    { { HTML_UNDEF }, { HTML_UNDEF }, "bas", mime_text_plain },
    { { HTML_UNDEF }, { HTML_UNDEF }, "c", mime_text_plain },
    { { HTML_UNDEF }, { HTML_UNDEF }, "h", mime_text_plain },
    { { HTML_UNDEF }, { HTML_UNDEF }, "txt", mime_text_plain },
    { { HTML_UNDEF }, { HTML_UNDEF }, "rtx", mime_text_richtext },
    { { HTML_UNDEF }, { HTML_UNDEF }, "sct", mime_text_scriptlet },
    { { HTML_UNDEF }, { HTML_UNDEF }, "tsv", mime_text_tab_separated_values },
    { { HTML_UNDEF }, { HTML_UNDEF }, "htt", mime_text_webviewhtml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "htc", mime_text_x_component },
    { { HTML_UNDEF }, { HTML_UNDEF }, "etx", mime_text_x_setext },
    { { HTML_UNDEF }, { HTML_UNDEF }, "vcf", mime_text_x_vcard },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mp2", mime_video_mpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mpa", mime_video_mpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mpe", mime_video_mpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mpeg", mime_video_mpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mpg", mime_video_mpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mpv2", mime_video_mpeg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mp4", mime_video_mp4 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mov", mime_video_quicktime },
    { { HTML_UNDEF }, { HTML_UNDEF }, "qt", mime_video_quicktime },
    { { HTML_UNDEF }, { HTML_UNDEF }, "lsf", mime_video_x_la_asf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "lsx", mime_video_x_la_asf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "asf", mime_video_x_ms_asf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "asr", mime_video_x_ms_asf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "asx", mime_video_x_ms_asf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "avi", mime_video_x_msvideo },
    { { HTML_UNDEF }, { HTML_UNDEF }, "movie", mime_video_x_sgi_movie },
    { { HTML_UNDEF }, { HTML_UNDEF }, "flr", mime_x_world_x_vrml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "vrml", mime_x_world_x_vrml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wrl", mime_x_world_x_vrml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "wrz", mime_x_world_x_vrml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xaf", mime_x_world_x_vrml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xof", mime_x_world_x_vrml },

// https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Common_types
    { { HTML_UNDEF }, { HTML_UNDEF }, "aac", mime_audio_aac },
    { { HTML_UNDEF }, { HTML_UNDEF }, "abw", mime_application_x_abiword },
    { { HTML_UNDEF }, { HTML_UNDEF }, "arc", mime_application_x_freearc },
    { { HTML_UNDEF }, { HTML_UNDEF }, "azw", mime_application_vnd_amazon_ebook },
    { { HTML_UNDEF }, { HTML_UNDEF }, "bin", mime_application_octet_stream, ns_default, MIME_VULNERABLE },
    { { HTML_UNDEF }, { HTML_UNDEF }, "bz", mime_application_x_bzip },
    { { HTML_UNDEF }, { HTML_UNDEF }, "bz2", mime_application_x_bzip2 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "csh", mime_application_x_csh },
    { { HTML_UNDEF }, { HTML_UNDEF }, "csv", mime_text_csv },
    { { HTML_UNDEF }, { HTML_UNDEF }, "doc", mime_application_msword },
    { { HTML_UNDEF }, { HTML_UNDEF }, "docx", mime_application_vnd_openxmlformats_officedocument_wordprocessingml_document },
    { { HTML_UNDEF }, { HTML_UNDEF }, "eot", mime_application_vnd_ms_fontobject },
    { { HTML_UNDEF }, { HTML_UNDEF }, "epub", mime_application_epub_zip },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ico", mime_image_vnd_microsoft_icon },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ics", mime_text_calendar },
    { { HTML_UNDEF }, { HTML_UNDEF }, "jar", mime_application_java_archive },
    { { HTML_UNDEF }, { HTML_UNDEF }, "json", mime_application_json, ns_default, MIME_JSON },
    { { HTML_UNDEF }, { HTML_UNDEF }, "jsonld", mime_application_ld_json, ns_default, MIME_JSON },
    { { HTML_UNDEF }, { HTML_UNDEF }, "midi", mime_audio_midi },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mjs", mime_text_javascript },
    { { HTML_UNDEF }, { HTML_UNDEF }, "mpkg", mime_application_vnd_apple_installer_xml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "odp", mime_application_vnd_oasis_opendocument_presentation },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ods", mime_application_vnd_oasis_opendocument_spreadsheet },
    { { HTML_UNDEF }, { HTML_UNDEF }, "odt", mime_application_vnd_oasis_opendocument_text },
    { { HTML_UNDEF }, { HTML_UNDEF }, "oga", mime_audio_ogg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ogv", mime_video_ogg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ogx", mime_application_ogg },
    { { HTML_UNDEF }, { HTML_UNDEF }, "opus", mime_audio_opus },
    { { HTML_UNDEF }, { HTML_UNDEF }, "otf", mime_font_otf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "png", mime_image_png },
    { { HTML_UNDEF }, { HTML_UNDEF }, "php", mime_application_x_httpd_php },
    { { HTML_UNDEF }, { HTML_UNDEF }, "pptx", mime_application_vnd_openxmlformats_officedocument_presentationml_presentation },
    { { HTML_UNDEF }, { HTML_UNDEF }, "rar", mime_application_vnd_rar },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ts", mime_video_mp2t },
    { { HTML_UNDEF }, { HTML_UNDEF }, "ttf", mime_font_ttf },
    { { HTML_UNDEF }, { HTML_UNDEF }, "vsd", mime_application_vnd_visio },
    { { HTML_UNDEF }, { HTML_UNDEF }, "weba", mime_audio_webm },
    { { HTML_UNDEF }, { HTML_UNDEF }, "webm", mime_video_webm },
    { { HTML_UNDEF }, { HTML_UNDEF }, "webp", mime_image_webp },
    { { HTML_UNDEF }, { HTML_UNDEF }, "woff", mime_font_woff },
    { { HTML_UNDEF }, { HTML_UNDEF }, "woff2", mime_font_woff2 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xhtml", mime_application_xhtml_xml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xlsx", mime_application_vnd_openxmlformats_officedocument_spreadsheetml_sheet },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xml", mime_application_xml, ns_default, MIME_XML },
    { { HTML_UNDEF }, { HTML_UNDEF }, "xul", mime_application_vnd_mozilla_xul_xml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "3gp", mime_video_3gpp },
    { { HTML_UNDEF }, { HTML_UNDEF }, "3g2", mime_video_3gpp2 },
    { { HTML_UNDEF }, { HTML_UNDEF }, "7z", mime_application_x_7z_compressed },

    { { HTML_UNDEF }, { HTML_UNDEF }, "asp", mime_application_x_httpd_asp },
    { { HTML_UNDEF }, { HTML_UNDEF }, "m4v", mime_video_mp4 },
    { { HTML_4_01 }, { HTML_UNDEF }, "rss", mime_application_rss_xml },
    { { HTML_UNDEF }, { HTML_UNDEF }, "vtt", mime_text_vtt },

    { { HTML_UNDEF }, { HTML_UNDEF }, nullptr, mime_context } };

void mime_init (nitpick& nits)
{   type_master < t_mime > :: init (nits, mimetype_symbol_table, sizeof (mimetype_symbol_table) / sizeof (symbol_entry < html_version, e_mimetype >));
    type_master < t_format > :: init (nits, format_symbol_table, sizeof (format_symbol_table) / sizeof (symbol_entry < html_version, e_format >)); }

e_format extension_format (nitpick& , const html_version& v, const ::std::string& ext, flags_t& flags)
{   return type_master < t_format > :: find (v, ext, ns_default, nullptr, nullptr, &flags); }

bool is_compatible_extension (const html_version& v, const e_mimetype em, const ::std::string& ext)
{   if (v.mjr () < 4) return true;
    nitpick nits;
    flags_t flags = 0;
    e_format mimex = extension_format (nits, v, ext, flags);
    if (mimex == mime_bork) return true;
    return (em == static_cast < e_mimetype> (mimex)); }

bool has_external_vulnerability (nitpick& nits, const html_version& , const e_mimetype em)
{   flags_t f (type_master < t_mime > :: flags (em));
    if ((f & MIME_SCRIPT) != 0)
        nits.pick (nit_reputation, es_error, ec_mime, "cross site scripting leaves the integrity, security and reputation of your site dependent on the good practice and intent of the third-party site");
    else if ((f & MIME_STYLE) != 0)
        nits.pick (nit_reputation, es_warning, ec_mime, "the security, integrity, presentation and reputation of your site is dependent on the good practice and intent of the external site");
    else return false;
    return true; }

bool has_embed_vulnerability (nitpick& nits, const html_version& v, const e_mimetype em)
{   if (v.mjr () < 4) return false;
    flags_t f (type_master < t_mime > :: flags (em));
    if ((f & MIME_APPLICATION) != 0)
        nits.pick (nit_reputation, es_warning, ec_mime, "referring to an external site leaves the reputation of your site dependent on their good practice and intent");
    else if ((f & (MIME_AUDIO | MIME_FONT | MIME_IMAGE | MIME_VIDEO)) != 0)
        nits.pick (nit_reputation, es_comment, ec_mime, "referring to an external site leaves means the reputation of your site dependent on their good practice and intent");
    else if ((f &  MIME_MULTIPART) != 0)
        nits.pick (nit_reputation, es_info, ec_mime, "referring to an external site here leaves the reputation of your site dependent on their good practice and intent");
    else return false;
    return true; }

bool has_extension_incompatibility (nitpick& nits, const html_version& v, const e_mimetype em, const ::std::string& ext)
{   if (ext.empty () || (em == mime_bork) || (em == mime_context)) return false;
    flags_t flags = 0;
    e_mimetype mt (static_cast < e_mimetype > (extension_format (nits, v, ext, flags)));
    if ((mt == mime_context) || (mt == mime_bork)) return false;
    if (mt == em) return false;
    if ((flags & MIME_COMMON_MASK) != 0)
        if ((flags & type_master < t_mime> :: flags (em) & MIME_COMMON_MASK) != 0) return false;
    nits.pick (nit_incompatible_mime, es_info, ec_mime, "the file extension ", quote (ext), " is not normally associated with ", quote (type_master < t_mime > :: name (em)));
    return true; }

void check_extension_compatibility (nitpick& nits, const html_version& v, const flags_t family, const ::std::string& ext)
{   if ((! ext.empty ()) && (family != 0))
    {   e_mimetype em = static_cast < e_mimetype> (type_master < t_format > :: find (v, ext, ns_default));
        if ((em != mime_context) && (em != mime_bork))
        {   flags_t flags = type_master < t_mime > :: flags (em);
            if ((family & flags) == 0)
                nits.pick (nit_incompatible_mime, es_info, ec_mime, "a file with extension '.", ext, "' is unsuitable here"); } } }

void check_extension_compatibility (nitpick& nits, const html_version& v, const e_mimetype mt, const ::std::string& ext)
{   if (! ext.empty ())
    {   e_mimetype em = static_cast < e_mimetype> (type_master < t_format > :: find (v, ext, ns_default));
        if ((em != mime_context) && (em != mime_bork))
            if (em != mt)
                nits.pick (nit_incompatible_mime, es_info, ec_mime, "a file of media type ", type_master < t_mime > :: name (mt), " is expected"); } }

void check_extension_compatibility (nitpick& nits, const html_version& v, const e_mimetype em, const vurl_t& u, const bool src)
{   for (auto uu : u)
    {   if (uu.has_extension ()) has_extension_incompatibility (nits, v, em, uu.extension ());
        if (src && ! uu.is_local ()) has_embed_vulnerability (nits, v, em); } }

void check_extension_compatibility (nitpick& nits, const html_version& v, const ::std::string& s, const vurl_t& u, const bool src)
{   if (! s.empty ())
    {   nitpick nuts;
        e_mimetype mt = examine_value < t_mime > (nuts, v, s);
        if ((mt != mime_bork) && (mt != mime_context))
            check_extension_compatibility (nits, v, mt, u, src); } }

void check_extension_compatibility (nitpick& nits, const html_version& v, const vurl_t& u, const flags_t family)
{   PRESUME (family != 0, __FILE__, __LINE__);
    for (auto uu : u)
        if (uu.has_extension ()) check_extension_compatibility (nits, v, family, uu.extension ()); }

void check_extension_compatibility (nitpick& nits, const html_version& v, const vurl_t& u, const e_mimetype mt)
{   for (auto uu : u)
        if (uu.has_extension ()) check_extension_compatibility (nits, v, mt, uu.extension ()); }

bool report_flag_issues (nitpick& nits, const html_version& , const e_mimetype em, const bool specified, const ::std::string& ref)
{   bool res = false;
    flags_t f (type_master < t_mime > :: flags (em));
    if (specified && ((f & MIME_UNOFFICIAL) == MIME_UNOFFICIAL))
    {   nits.pick (nit_mime, ed_mimetype, "https://www.iana.org/assignments/media-types/media-types.xhtml", es_info, ec_mime, quote (type_master < t_mime > :: name (em)), " is a non-standard media type");
        res = true; }
    if ((f & MIME_WITHDRAWN) == MIME_WITHDRAWN)
    {   if ((f & MIME_VULNERABLE) == MIME_VULNERABLE)
            nits.pick (nit_reputation, es_warning, ec_mime, "insecure, vulnerable media/file type ", quote (ref), " withdrawn");
        else nits.pick (nit_reputation, es_info, ec_mime, "media/file type ", quote (ref), " is no longer valid");
        res = true; }
    else if ((f & MIME_VULNERABLE) == MIME_VULNERABLE)
    {   nits.pick (nit_reputation, es_warning, ec_mime, "media/file type ", quote (ref), " is insecure and vulnerable");
        res = true; }
    if ((f & MIME_WINDOWS) == MIME_WINDOWS)
        nits.pick (nit_os_dependent, es_comment, ec_mime, "media/file type ", quote (ref), " requires Windows");
    else if ((f & MIME_MACOS) == MIME_MACOS)
        nits.pick (nit_os_dependent, es_comment, ec_mime, "media/file type ", quote (ref), " requires MacOS / OS X");
    else if ((f & MIME_IOS) == MIME_IOS)
        nits.pick (nit_os_dependent, es_comment, ec_mime, "media/file type ", quote (ref), " requires iOS");
    else if ((f & MIME_ANDROID) == MIME_ANDROID)
        nits.pick (nit_os_dependent, es_comment, ec_mime, "media/file type ", quote (ref), " requires Android");
    else return res;
    return true; }

void check_mimetype_vulnerability (nitpick& nits, const html_version& v, const e_mimetype em, const bool local, const bool specified, const ::std::string& ref)
{   if (! local) has_external_vulnerability (nits, v, em);
    report_flag_issues (nits, v, em, specified, ref); }

void check_mimetype_vulnerability (nitpick& nits, const html_version& v, const ::std::string& s, const bool local, const bool specified)
{   if (! s.empty ())
    {   nitpick nuts;
        e_mimetype mt = examine_value < t_mime > (nuts, v, s);
        if ((mt != mime_bork) && (mt != mime_context))
            check_mimetype_vulnerability (nits, v, mt, local, specified, s); } }

void check_extension_vulnerability (nitpick& nits, const html_version& v, const ::std::string& ext, const bool local)
{   if (! ext.empty ())
    {   flags_t flags = 0;
        e_mimetype em (static_cast < e_mimetype > (extension_format (nits, v, ext, flags)));
        if ((em != mime_context) && (em != mime_bork))
            check_mimetype_vulnerability (nits, v, em, local, false, ext); } }

void check_extension_vulnerability (nitpick& nits, const html_version& v, const vurl_t& vu)
{   for (auto u : vu)
        if (u.has_extension ())
            check_extension_vulnerability (nits, v, u.extension (), u.is_local ()); }

void check_vulnerability (nitpick& nits, const html_version& v, const e_mimetype em, const ::std::string& ext, const bool local)
{   bool ee = ext.empty ();
    if ((em != mime_bork) && (em != mime_context))
    {   if (! ee) has_extension_incompatibility (nits, v, em, ext);
        check_mimetype_vulnerability (nits, v, em, local, true, type_master < t_mime > :: name (em)); }
    if (! ee) check_extension_vulnerability (nits, v, ext, local); }

void check_vulnerability (nitpick& nits, const html_version& v, const e_mimetype em, const vurl_t& u, const bool src)
{   for (auto uu : u)
    {   if (uu.has_extension ())
            check_vulnerability (nits, v, em, uu.extension (), uu.is_local ());
        if (src && ! uu.is_local ()) has_embed_vulnerability (nits, v, em); } }

void check_vulnerability (nitpick& nits, const html_version& v, const ::std::string& s, const vurl_t& u, const bool src)
{   if (! s.empty ())
    {   nitpick nuts;
        e_mimetype mt = examine_value < t_mime > (nuts, v, s);
        check_vulnerability (nits, v, mt, u, src); } }

void check_mimetype_family (nitpick& nits, const html_version& v, const e_mimetype em, const flags_t family, const ::std::string& ref)
{   report_flag_issues (nits, v, em, true, ref);
    flags_t flags = type_master < t_mime > :: flags (em);
    if ((family & flags) == 0)
        nits.pick (nit_incompatible_mime, es_info, ec_mime, type_master < t_mime > :: name (em), " is unsuitable here"); }

void check_mimetype_family (nitpick& nits, const html_version& v, const ::std::string& s, const flags_t family)
{   vstr_t ms (split_by_space (s));
    for (auto ss : ms)
    {   nitpick nuts;
        e_mimetype mt = examine_value < t_mime > (nits, v, s);
        if ((mt != mime_bork) && (mt != mime_context))
            check_mimetype_family (nits, v, mt, family, ss); } }
